/***************************************************************************
 *                                                                         *
 * Projekt:  norGIS ALKIS Import                                           *
 * Purpose:  ALKIS-Schema ggf. migrieren                                   *
 * Author:   Jürgen E. Fischer <jef@norbit.de>                             *
 *                                                                         *
 ***************************************************************************
 * Copyright (c) 2012-2020, Jürgen E. Fischer <jef@norbit.de>              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

SET client_encoding = 'UTF8';
SET search_path = :"postgis_schema", public;

\i alkis-compat.sql

-- Stored Procedures laden
\i alkis-functions.sql

--
-- Datenbankmigration
--

CREATE FUNCTION pg_temp.alkis_rename_table(t TEXT) RETURNS varchar AS $$
BEGIN
	PERFORM alkis_dropobject(t || '_');

	EXECUTE 'ALTER TABLE ' || t || ' RENAME TO ' || t || '_';

	PERFORM alkis_dropobject(t || '_geom_idx');                -- < GDAL 1.11
	PERFORM alkis_dropobject(t || '_wkb_geometry_geom_idx');   -- >= GDAL 1.11

	RETURN t || ' umbenannt - INHALT MANUELL MIGRIEREN.';
EXCEPTION WHEN OTHERS THEN
	RETURN '';
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION pg_temp.alkis_update_schema() RETURNS varchar AS $$
DECLARE
	c RECORD;
	s INTEGER;
	v_n INTEGER;
	i INTEGER;
	ver INTEGER;
	r TEXT;
BEGIN
	r := NULL;

	--
	-- ALKIS-Schema
	--
	SELECT count(*) INTO v_n FROM information_schema.columns
		WHERE table_schema=current_schema()
		  AND table_name='ax_flurstueck'
		  AND column_name='sonstigesmodell';
	IF v_n=0 THEN
		RAISE EXCEPTION 'Modell zu alt für Migration.';
	END IF;

	BEGIN
		SELECT version INTO ver FROM alkis_version;

	EXCEPTION WHEN OTHERS THEN
		ver := 0;
		CREATE TABLE alkis_version(version INTEGER);
		INSERT INTO alkis_version(version) VALUES (ver);

		BEGIN ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD name varchar; EXCEPTION WHEN OTHERS THEN END;
	END;

	RAISE NOTICE 'ALKIS-Schema-Version: %', ver;

	IF ver<1 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 1';

		PERFORM alkis_dropobject('ax_tatsaechlichenutzung');
		PERFORM alkis_dropobject('ax_klassifizierung');
		PERFORM alkis_dropobject('ax_ausfuehrendestellen');
		PERFORM alkis_dropobject('v_eigentuemer');
		PERFORM alkis_dropobject('v_haeuser');
		PERFORM alkis_dropobject('v_schutzgebietnachwasserrecht');
		PERFORM alkis_dropobject('v_schutzgebietnachnaturumweltoderbodenschutzrecht');

		ALTER TABLE ax_flurstueck ALTER angabenzumabschnittnummeraktenzeichen TYPE varchar[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER ortsteil TYPE varchar;
		ALTER TABLE ax_historischesflurstueck ALTER zaehler TYPE varchar;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER zaehler TYPE varchar;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER rechtsbehelfsverfahren TYPE varchar;
		ALTER TABLE ax_gebaeude ALTER geschossflaeche TYPE double precision;
		ALTER TABLE ax_gebaeude ALTER grundflaeche TYPE double precision;
		ALTER TABLE ax_gebaeude ALTER umbauterraum TYPE double precision;
		ALTER TABLE ax_bodenschaetzung ALTER bodenzahlodergruenlandgrundzahl TYPE varchar;
		ALTER TABLE ax_bodenschaetzung ALTER ackerzahlodergruenlandzahl TYPE varchar;
		ALTER TABLE ax_grablochderbodenschaetzung ALTER bodenzahlodergruenlandgrundzahl TYPE varchar;
		ALTER TABLE ax_gemarkungsteilflur ADD gehoertzu character(16)[];
		CREATE INDEX ax_gemarkungsteilflur_ghz ON ax_gemarkungsteilflur USING gin (gehoertzu);
		ALTER TABLE ax_dienststelle ADD kennung varchar;
		ALTER TABLE ax_wohnplatz ADD zweitname varchar;
		ALTER TABLE ax_baublock ADD art integer;

		-- gml_id: varchar => character(16)
		s := 0;
		i := 0;
		FOR c IN
			SELECT table_name
			FROM information_schema.columns a
			WHERE a.table_schema=current_schema()
			  AND (a.table_name LIKE 'ax_%' OR a.table_name LIKE 'ap_%')
			  AND a.column_name='gml_id'
			  AND a.data_type='character varying'
		LOOP
			-- RAISE NOTICE '%', 'UPDATE ' || c.table_name || ' SET gml_id=substring(gml_id,1,16) WHERE length(gml_id)>16';
			EXECUTE 'UPDATE ' || c.table_name || ' SET gml_id=substring(gml_id,1,16) WHERE length(gml_id)>16';
			GET DIAGNOSTICS v_n = ROW_COUNT;
			s := s + v_n;

			-- RAISE NOTICE '%', 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN gml_id TYPE character(16)';
			EXECUTE 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN gml_id TYPE character(16)';
			i := i + 1;
		END LOOP;

		IF i > 0 OR s > 0 THEN
			r := alkis_string_append(r, i || ' Tabellen mit ' || s || ' lange AAA-Identifikatoren geändert.');
		END IF;

		-- land, gemarkungsnummer, gemeinde, regierungsbezirk, bezirk, kreis, schluesselgesamt: integer => varchar
		i := 0;
		FOR c IN
			SELECT table_name, column_name
			FROM information_schema.columns a
			WHERE a.table_schema=current_schema()
			  AND a.table_name LIKE 'ax_%'
			  AND a.column_name IN ('land','gemarkungsnummer','gemeinde','regierungsbezirk','bezirk','kreis','schluesselgesamt')
			  AND a.data_type='integer'
		LOOP
			-- RAISE NOTICE '%', 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN ' || c.column_name || ' TYPE character varying';
			EXECUTE 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN ' || c.column_name || ' TYPE character varying';
			i := i + 1;
		END LOOP;

		IF i > 0 THEN
			r := alkis_string_append(r, i || ' Spalten angepaßt (integer->character varying).');
		END IF;

		-- Relationen: varchar => character(16) bzw. varchar[] => character(16)[]
		i := 0;
		FOR c IN
			WITH RECURSIVE
				element(name,base) AS (
					SELECT name,unnest(name||abgeleitet_aus) AS base
					FROM alkis_elemente
				UNION
					SELECT a.name,unnest(b.abgeleitet_aus) AS base
					FROM element a
					JOIN alkis_elemente b ON a.base=b.name
				),
				relation(element,bezeichnung,kennung) AS (
					SELECT element,bezeichnung,kennung FROM alkis_relationsart
					UNION
					SELECT b.element,a.bezeichnung,a.kennung FROM alkis_relationsart a JOIN relation b ON a.element=lower(b.bezeichnung)
				)
			SELECT col.table_name,col.column_name,col.udt_name
			FROM element t
			JOIN relation a ON t.base=a.element
			JOIN information_schema.columns col ON lower(t.name)=col.table_name AND lower(a.bezeichnung)=col.column_name
			WHERE col.udt_name IN ('_varchar','varchar')
		LOOP
			IF c.udt_name='_varchar' THEN
				-- RAISE NOTICE '%', 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN ' || c.column_name || ' TYPE character(16)[]';
				EXECUTE 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN ' || c.column_name || ' TYPE character(16)[]';
				i := i + 1;
			ELSE
				-- RAISE NOTICE '%', 'UPDATE ' || c.table_name || ' SET ' || c.column_name || '=' || 'substring('||c.column_name||',1,16) WHERE length('||c.column_name||')>16';
				EXECUTE 'UPDATE ' || c.table_name || ' SET ' || c.column_name || '=' || 'substring('||c.column_name||',1,16) WHERE length('||c.column_name||')>16';

				-- RAISE NOTICE '%', 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN ' || c.column_name || ' TYPE character(16)';
				EXECUTE 'ALTER TABLE ' || c.table_name || ' ALTER COLUMN ' || c.column_name || ' TYPE character(16)';
				i := i + 1;
			END IF;
		END LOOP;

		IF i > 0 THEN
			r := alkis_string_append(r, i || ' Spalten angepaßt (varchar->character(16)).');
		END IF;

		UPDATE alkis_version SET version=1;
	END IF;

	IF ver<2 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 2';

		-- Indizes ergänzen
		CREATE UNIQUE INDEX ax_sicherungspunkt_gmlid ON ax_sicherungspunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_sicherungspunkt_bsa ON ax_sicherungspunkt USING btree (beziehtsichauf);
		CREATE INDEX ax_sicherungspunkt_ghz ON ax_sicherungspunkt USING btree (gehoertzu);

		-- drop identifier
		i := 0;
		FOR c IN
			SELECT table_name
			FROM information_schema.columns a
			WHERE a.table_schema=current_schema()
			  AND (a.table_name LIKE 'ax_%' OR a.table_name LIKE 'ap_%')
			  AND a.column_name='identifier'
		LOOP
			-- RAISE NOTICE '%', 'ALTER TABLE ' || c.table_name || ' DROP COLUMN identifier';
			EXECUTE 'ALTER TABLE ' || c.table_name || ' DROP COLUMN identifier';
			i := i + 1;
		END LOOP;

		IF i > 0 THEN
			r := alkis_string_append(r, i || ' identifier-Spalten gelöscht.');
		END IF;

		UPDATE alkis_version SET version=2;
	END IF;

	IF ver<3 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 3';

		ALTER TABLE ax_fortfuehrungsfall ALTER zeigtaufaltesflurstueck TYPE character(20)[];
		ALTER TABLE ax_fortfuehrungsfall ALTER zeigtaufneuesflurstueck TYPE character(20)[];

		UPDATE alkis_version SET version=3;
	END IF;

	IF ver<4 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 4';

		BEGIN
			ALTER TABLE ax_lagebezeichnungmithausnummer ADD unverschluesselt varchar;
			ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD unverschluesselt varchar;
		EXCEPTION WHEN OTHERS THEN
			--
		END;

		UPDATE alkis_version SET version=4;
	END IF;

	IF ver<5 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 5';

		DROP INDEX delete_fid;
		CREATE INDEX delete_fid ON "delete"(featureid);

		UPDATE alkis_version SET version=5;
	END IF;

	IF ver<6 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 6';

		CREATE INDEX ap_ppo_art ON ap_ppo USING btree (art);
		CREATE INDEX ap_lpo_art ON ap_lpo USING btree (art);

		UPDATE alkis_version SET version=6;
	END IF;

	IF ver<7 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 7';

		ALTER TABLE ax_gebaeude ADD gebaeudekennzeichen varchar;
		ALTER TABLE ax_gebaeude RENAME baujahr TO baujahr_;
		ALTER TABLE ax_gebaeude ADD baujahr integer[];
		UPDATE ax_gebaeude SET baujahr=ARRAY[baujahr_];
		ALTER TABLE ax_gebaeude DROP baujahr_;

		UPDATE alkis_version SET version=7;
	END IF;

	IF ver<8 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 8';

		BEGIN
			ALTER TABLE ax_tagesabschnitt DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_tagesabschnitt RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_tagesabschnitt','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_tagesabschnitt SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_tagesabschnitt DROP wkb_geometry_ CASCADE;

			CREATE INDEX ax_tagesabschnitt_geom_idx ON ax_tagesabschnitt USING gist(wkb_geometry);
		END;

		UPDATE alkis_version SET version=8;
	END IF;

	IF ver<9 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 9';

		BEGIN
			ALTER TABLE ax_topographischelinie DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_topographischelinie RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_topographischelinie','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_topographischelinie SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_topographischelinie DROP wkb_geometry_ CASCADE;

			CREATE INDEX ax_topographischelinie_geom_idx ON ax_topographischelinie USING gist(wkb_geometry);
		END;

		UPDATE alkis_version SET version=9;
	END IF;

	IF ver<10 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 10';

		i := 0;
		FOR c IN
			SELECT table_name
			FROM information_schema.columns a
			WHERE a.table_schema=current_schema()
			  AND (a.table_name LIKE 'ax_%' OR a.table_name LIKE 'ap_%' OR a.table_name LIKE 'ks_%')
			  AND a.column_name='anlass'
			  AND a.data_type='character varying'
		LOOP
			EXECUTE 'ALTER TABLE ' || c.table_name || ' RENAME anlass TO anlass_';
			EXECUTE 'ALTER TABLE ' || c.table_name || ' ADD anlass varchar[]';
			EXECUTE 'UPDATE ' || c.table_name || ' SET anlass=ARRAY[anlass_]';
			EXECUTE 'ALTER TABLE ' || c.table_name || ' DROP anlass_';
			i := i + 1;
		END LOOP;

		IF i > 0 THEN
			r := alkis_string_append(r, i || ' anlass-Spalten angepaßt (character varying->character varying[])');
		END IF;

		UPDATE alkis_version SET version=10;
	END IF;

	IF ver<11 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 11';

		EXECUTE 'ALTER TABLE "delete" RENAME anlass TO anlass_';
		EXECUTE 'ALTER TABLE "delete" ADD anlass varchar[]';
		EXECUTE 'UPDATE "delete" SET anlass=ARRAY[anlass_]';
		EXECUTE 'ALTER TABLE "delete" DROP anlass_';

		IF i > 0 THEN
			r := alkis_string_append(r, 'Spalte delete.anlass angepaßt (character varying->character varying[])');
		END IF;

		UPDATE alkis_version SET version=11;
	END IF;

	IF ver<12 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 12';

		BEGIN
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD oberflaechenmaterial integer;
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD material integer[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD bezeichnung varchar;
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD zustand integer;

		EXCEPTION WHEN OTHERS THEN
			CREATE TABLE ks_einrichtunginoeffentlichenbereichen (
				ogc_fid                 serial NOT NULL,
				gml_id                  character(16) NOT NULL,
				beginnt                 character(20),
				endet                   character(20),
				advstandardmodell       varchar[],
				sonstigesmodell         varchar[],
				anlass                  varchar[],
				art                     varchar,
				oberflaechenmaterial    integer,
				material                integer[],
				bezeichnung             varchar,
				zustand                 integer,
				PRIMARY KEY (ogc_fid)
			);

			PERFORM AddGeometryColumn('ks_einrichtunginoeffentlichenbereichen','wkb_geometry',find_srid('','ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
		END;

		CREATE INDEX ks_einrichtunginoeffentlichenbereichen_geom_idx ON ks_einrichtunginoeffentlichenbereichen USING gist (wkb_geometry);

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_bauwerkanlagenfuerverundentsorgung'));

		CREATE TABLE ks_bauwerkanlagenfuerverundentsorgung (
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			art                     integer,
			bezeichnung             varchar,
			zustand                 integer,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_bauwerkanlagenfuerverundentsorgung','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'POINT',2);

		CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_geom_idx ON ks_bauwerkanlagenfuerverundentsorgung USING gist (wkb_geometry);

		ALTER TABLE ks_sonstigesbauwerk ADD advstandardmodell varchar[];
		ALTER TABLE ks_sonstigesbauwerk ADD bezeichnung varchar;

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_einrichtungimstrassenverkehr'));

		CREATE TABLE ks_einrichtungimstrassenverkehr(
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			art                     integer,
			oberflaechenmaterial    integer,
			bezeichnung             varchar,
			zustand                 integer,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_einrichtungimstrassenverkehr','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);

		CREATE INDEX ks_einrichtungimstrassenverkehr_geom_idx ON ks_einrichtungimstrassenverkehr USING gist (wkb_geometry);

		BEGIN
			ALTER TABLE ks_verkehrszeichen ADD gefahrzeichen integer[];
			ALTER TABLE ks_verkehrszeichen ADD vorschriftzeichen integer[];
			ALTER TABLE ks_verkehrszeichen ADD richtzeichen integer[];

			ALTER TABLE ks_verkehrszeichen RENAME verkehrseinrichtung TO verkehrseinrichtung_;
			ALTER TABLE ks_verkehrszeichen ADD verkehrseinrichtung integer[];
			UPDATE ks_verkehrszeichen SET verkehrseinrichtung=ARRAY[verkehrseinrichtung_];
			ALTER TABLE ks_verkehrszeichen DROP verkehrseinrichtung_;

			ALTER TABLE ks_verkehrszeichen ADD zusatzzeichen integer[];
			ALTER TABLE ks_verkehrszeichen ADD bezeichnung varchar;
		EXCEPTION WHEN OTHERS THEN
			CREATE TABLE ks_verkehrszeichen (
				ogc_fid                 serial NOT NULL,
				gml_id                  character(16) NOT NULL,
				beginnt                 character(20),
				endet                   character(20),
				advstandardmodell       varchar[],
				sonstigesmodell         varchar[],
				anlass                  varchar[],
				gefahrzeichen           integer[],
				vorschriftzeichen       integer[],
				richtzeichen            integer[],
				verkehrseinrichtung     integer[],
				zusatzzeichen           integer[],
				bezeichnung             varchar,
				PRIMARY KEY (ogc_fid)
			);

			PERFORM AddGeometryColumn('ks_verkehrszeichen','wkb_geometry',find_srid('','ax_flurstueck','wkb_geometry'),'POINT',2);

			CREATE INDEX ks_verkehrszeichen_geom_idx ON ks_verkehrszeichen USING gist (wkb_geometry);
		END;

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_einrichtungimbahnverkehr'));

		CREATE TABLE ks_einrichtungimbahnverkehr(
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			art                     integer,
			bezeichnung             varchar,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_einrichtungimbahnverkehr','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);

		CREATE INDEX ks_einrichtungimbahnverkehr_geom_idx ON ks_einrichtungimbahnverkehr USING gist (wkb_geometry);

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_bauwerkimgewaesserbereich'));

		CREATE TABLE ks_bauwerkimgewaesserbereich (
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			bauwerksfunktion        integer,
			bezeichnung             varchar,
			zustand                 integer,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_bauwerkimgewaesserbereich','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'LINESTRING',2);

		CREATE INDEX ks_bauwerkimgewaesserbereich_geom_idx ON ks_bauwerkimgewaesserbereich USING gist (wkb_geometry);

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_vegetationsmerkmal'));

		CREATE TABLE ks_vegetationsmerkmal (
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			bewuchs                 integer,
			zustand                 integer,
			breitedesobjekts        double precision,
			name                    varchar,
			bezeichnung             varchar,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_vegetationsmerkmal','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);

		CREATE INDEX ks_vegetationsmerkmal_geom_idx ON ks_vegetationsmerkmal USING gist (wkb_geometry);

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_bauraumoderbodenordnungsrecht'));

		CREATE TABLE ks_bauraumoderbodenordnungsrecht (
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			artderfestlegung        integer,
			bezeichnung             varchar,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_bauraumoderbodenordnungsrecht','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);

		CREATE INDEX ks_bauraumoderbodenordnungsrecht_geom_idx ON ks_vegetationsmerkmal USING gist (wkb_geometry);

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ks_kommunalerbesitz'));

		CREATE TABLE ks_kommunalerbesitz (
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			zustaendigkeit          varchar,
			nutzung                 varchar,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ks_kommunalerbesitz','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);

		CREATE INDEX ks_kommunalerbesitz_geom_idx ON ks_vegetationsmerkmal USING gist (wkb_geometry);

		UPDATE alkis_version SET version=12;
	END IF;

	IF ver<13 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 13';

		r := alkis_string_append(r, pg_temp.alkis_rename_table('ax_landschaft'));

		CREATE TABLE ax_landschaft(
			ogc_fid                 serial NOT NULL,
			gml_id                  character(16) NOT NULL,
			beginnt                 character(20),
			endet                   character(20),
			advstandardmodell       varchar[],
			sonstigesmodell         varchar[],
			anlass                  varchar[],
			landschaftstyp          integer,
			name                    varchar,
			PRIMARY KEY (ogc_fid)
		);

		PERFORM AddGeometryColumn('ax_landschaft','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2); -- POINT/LINESTRING

		CREATE INDEX ax_landschaft_geom_idx   ON ax_landschaft USING gist (wkb_geometry);
		CREATE UNIQUE INDEX ax_landschaft_gml ON ax_landschaft USING btree (gml_id,beginnt);

		UPDATE alkis_version SET version=13;
	END IF;

	IF ver<14 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 14';

		PERFORM alkis_dropobject('ks_bauraumoderbodenordnungsrecht_geom_idx');
		CREATE INDEX ks_bauraumoderbodenordnungsrecht_geom_idx ON ks_bauraumoderbodenordnungsrecht USING gist (wkb_geometry);

		PERFORM alkis_dropobject('ks_kommunalerbesitz_geom_idx');
		CREATE INDEX ks_kommunalerbesitz_geom_idx ON ks_kommunalerbesitz USING gist (wkb_geometry);

		UPDATE alkis_version SET version=14;
	END IF;

	IF ver<15 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 15';

		-- aa_aktivitaet.art => art: character(16) => character varying
		ALTER TABLE aa_aktivitaet ALTER art TYPE character varying;
		ALTER TABLE aa_aktivitaet ALTER art SET NOT NULL;
		ALTER TABLE aa_aktivitaet ALTER beginnt SET NOT NULL;
		ALTER TABLE aa_aktivitaet ALTER status SET NOT NULL;
		ALTER TABLE aa_aktivitaet ADD anlass character varying[];
		ALTER TABLE aa_aktivitaet ADD erlaeuterung character varying;
		ALTER TABLE aa_aktivitaet ADD istteilvon character(16)[];
		ALTER TABLE aa_aktivitaet ADD zeigtaufexternes_art character varying[];
		ALTER TABLE aa_aktivitaet ADD zeigtaufexternes_name character varying[];
		ALTER TABLE aa_aktivitaet ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2d578cc8_196f_46b3_b8e0_66e5a0338b7b ON aa_aktivitaet USING btree (endet);
		CREATE INDEX alkis_59bcc1e2_30d5_46bf_b306_3873fcc849ba ON aa_aktivitaet USING btree (gml_id, beginnt);
		CREATE INDEX alkis_659bbfd8_37f7_4c4f_8557_75ed73427057 ON aa_aktivitaet USING btree (status);
		CREATE INDEX alkis_9aae1167_d2ce_4a30_a9e2_8627524d2984 ON aa_aktivitaet USING gin (istteilvon);

		ALTER TABLE aa_antrag ALTER antragunterbrochen SET NOT NULL;
		-- aa_antrag.art => art: character(16) => character varying
		ALTER TABLE aa_antrag ALTER art TYPE character varying;
		ALTER TABLE aa_antrag ALTER art SET NOT NULL;
		ALTER TABLE aa_antrag ALTER beginnt SET NOT NULL;
		ALTER TABLE aa_antrag ALTER kennzeichen SET NOT NULL;
		ALTER TABLE aa_antrag ALTER verweistauf SET NOT NULL;
		ALTER TABLE aa_antrag ADD anlass character varying[];
		ALTER TABLE aa_antrag ADD erlaeuterungzumstatus character varying;
		ALTER TABLE aa_antrag ADD istteilvon character(16)[];
		ALTER TABLE aa_antrag ADD zeigtaufexternes_art character varying[];
		ALTER TABLE aa_antrag ADD zeigtaufexternes_name character varying[];
		ALTER TABLE aa_antrag ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_b193c3f2_4bfc_4203_ae8f_09f9f97fe0e9 ON aa_antrag USING btree (bearbeitungsstatus);
		CREATE INDEX alkis_7ccd6052_c941_47f6_9b02_8507c6354a94 ON aa_antrag USING btree (endet);
		CREATE INDEX alkis_fc76ab2e_0294_4666_84f1_c6232056c9bf ON aa_antrag USING btree (gebiet);
		CREATE INDEX alkis_4ab44846_c317_4231_8b43_eb40e95e4f0a ON aa_antrag USING btree (gml_id, beginnt);
		CREATE INDEX alkis_c36ccbf5_a1e9_45bc_a6c1_90d2618a04f7 ON aa_antrag USING gin (istteilvon);
		CREATE INDEX alkis_3386c374_f521_4e84_9f86_618a6c85dc67 ON aa_antrag USING gin (verweistauf);

		ALTER TABLE aa_antragsgebiet ALTER beginnt SET NOT NULL;
		-- aa_antragsgebiet.wkb_geometry => wkb_geometry: geometry(Polygon,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE aa_antragsgebiet DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE aa_antragsgebiet RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('aa_antragsgebiet','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE aa_antragsgebiet SET wkb_geometry=wkb_geometry_;
			ALTER TABLE aa_antragsgebiet DROP wkb_geometry_ CASCADE;
			CREATE INDEX aa_antragsgebiet_wkb_geometry_idx ON aa_antragsgebiet USING gist(wkb_geometry);
		END;
		ALTER TABLE aa_antragsgebiet ADD anlass character varying[];
		ALTER TABLE aa_antragsgebiet ADD hatdirektunten character(16)[];
		ALTER TABLE aa_antragsgebiet ADD istabgeleitetaus character(16)[];
		ALTER TABLE aa_antragsgebiet ADD istteilvon character(16)[];
		ALTER TABLE aa_antragsgebiet ADD traegtbeizu character(16)[];
		ALTER TABLE aa_antragsgebiet ADD zeigtaufexternes_art character varying[];
		ALTER TABLE aa_antragsgebiet ADD zeigtaufexternes_name character varying[];
		ALTER TABLE aa_antragsgebiet ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4ff31191_d6e7_4f5a_aa51_39ebb7fd4830 ON aa_antragsgebiet USING btree (endet);
		CREATE INDEX alkis_0d2da273_581b_45bf_8cc4_d7d3f928837d ON aa_antragsgebiet USING btree (gml_id, beginnt);
		CREATE INDEX alkis_6d486f97_4c37_4a43_a473_4f4128d854a1 ON aa_antragsgebiet USING gin (hatdirektunten);
		CREATE INDEX alkis_dbe486cf_4661_4e0c_b89a_43405c71e854 ON aa_antragsgebiet USING gin (istabgeleitetaus);
		CREATE INDEX alkis_9819200b_8169_4143_bec4_181890f8edd3 ON aa_antragsgebiet USING gin (istteilvon);
		CREATE INDEX alkis_766469cc_e0df_4b38_a864_0fffc20c3ea7 ON aa_antragsgebiet USING gin (traegtbeizu);

		ALTER TABLE aa_meilenstein ALTER beginnt SET NOT NULL;
		-- aa_meilenstein.vonantrag => vonantrag: character(16) => character(16)[]
		ALTER TABLE aa_meilenstein ALTER vonantrag TYPE character(16)[] USING CASE WHEN vonantrag IS NULL THEN NULL ELSE ARRAY[vonantrag] END;
		-- aa_meilenstein.vonvorgang => vonvorgang: character(16) => character(16)[]
		ALTER TABLE aa_meilenstein ALTER vonvorgang TYPE character(16)[] USING CASE WHEN vonvorgang IS NULL THEN NULL ELSE ARRAY[vonvorgang] END;
		ALTER TABLE aa_meilenstein ADD anlass character varying[];
		ALTER TABLE aa_meilenstein ADD istteilvon character(16)[];
		ALTER TABLE aa_meilenstein ADD kategorie character varying;
		ALTER TABLE aa_meilenstein ADD vonaktivitaet character(16)[];
		ALTER TABLE aa_meilenstein ADD wer character(16);
		ALTER TABLE aa_meilenstein ADD zeigtaufexternes_art character varying[];
		ALTER TABLE aa_meilenstein ADD zeigtaufexternes_name character varying[];
		ALTER TABLE aa_meilenstein ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_6fd3f59b_77d0_4ec2_81ac_3c9eb2915093 ON aa_meilenstein USING btree (endet);
		CREATE INDEX alkis_7f41ad24_0da4_4ab3_b328_e7d8a45dae8d ON aa_meilenstein USING btree (gml_id, beginnt);
		CREATE INDEX alkis_1b8a0d0b_761e_494d_981d_c04cec8bd849 ON aa_meilenstein USING btree (wer);
		CREATE INDEX alkis_f5010937_d163_4090_90e2_f2a066075fe2 ON aa_meilenstein USING gin (istteilvon);
		CREATE INDEX alkis_a408f318_9e14_4f93_9614_98a58de63a9b ON aa_meilenstein USING gin (vonaktivitaet);
		CREATE INDEX alkis_9bb84517_f345_45c2_8dcc_73e54306f54b ON aa_meilenstein USING gin (vonantrag);
		CREATE INDEX alkis_0c12fdc1_461c_4984_ac8c_6510440e7235 ON aa_meilenstein USING gin (vonvorgang);

		-- aa_projektsteuerung.anlassdesprozesses => anlassdesprozesses: character(6) => character varying[]
		ALTER TABLE aa_projektsteuerung ALTER anlassdesprozesses TYPE character varying[] USING CASE WHEN anlassdesprozesses IS NULL THEN NULL ELSE ARRAY[anlassdesprozesses] END;
		ALTER TABLE aa_projektsteuerung ALTER anlassdesprozesses SET NOT NULL;
		-- aa_projektsteuerung.art => art: character(16) => character varying
		ALTER TABLE aa_projektsteuerung ALTER art TYPE character varying;
		ALTER TABLE aa_projektsteuerung ALTER art SET NOT NULL;
		ALTER TABLE aa_projektsteuerung ALTER beginnt SET NOT NULL;
		ALTER TABLE aa_projektsteuerung ALTER enthaelt SET NOT NULL;
		ALTER TABLE aa_projektsteuerung ADD anlass character varying[];
		ALTER TABLE aa_projektsteuerung ADD istteilvon character(16)[];
		ALTER TABLE aa_projektsteuerung ADD parameterwert character varying;
		ALTER TABLE aa_projektsteuerung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE aa_projektsteuerung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE aa_projektsteuerung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_ca5e8d86_d7ad_4582_b2dd_46b771d0bab1 ON aa_projektsteuerung USING btree (endet);
		CREATE INDEX alkis_af16f507_98af_498e_b199_ba833ab8c6f1 ON aa_projektsteuerung USING btree (gml_id, beginnt);
		CREATE INDEX alkis_39a525e1_a473_48bd_aa1a_bce73e05cf77 ON aa_projektsteuerung USING gin (enthaelt);
		CREATE INDEX alkis_e9c97980_1bfc_4966_b97f_83ffcbdb357c ON aa_projektsteuerung USING gin (istteilvon);

		-- aa_vorgang.art => art: character(16) => character varying
		ALTER TABLE aa_vorgang ALTER art TYPE character varying;
		ALTER TABLE aa_vorgang ALTER art SET NOT NULL;
		ALTER TABLE aa_vorgang ALTER bearbeitbardurch SET NOT NULL;
		ALTER TABLE aa_vorgang ALTER beginnt SET NOT NULL;
		ALTER TABLE aa_vorgang ALTER status SET NOT NULL;
		ALTER TABLE aa_vorgang ADD anlass character varying[];
		ALTER TABLE aa_vorgang ADD erlaeuterung character varying;
		ALTER TABLE aa_vorgang ADD istteilvon character(16)[];
		ALTER TABLE aa_vorgang ADD synchronisiertmit character(16);
		ALTER TABLE aa_vorgang ADD zeigtaufexternes_art character varying[];
		ALTER TABLE aa_vorgang ADD zeigtaufexternes_name character varying[];
		ALTER TABLE aa_vorgang ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_506dd4d2_1a45_43a3_9b51_56d970718496 ON aa_vorgang USING btree (bearbeitbardurch);
		CREATE INDEX alkis_cac97355_f732_4f50_854e_b62c3243a9a6 ON aa_vorgang USING btree (endet);
		CREATE INDEX alkis_4f7a1db3_1399_4edc_ab6c_6c029a70eb74 ON aa_vorgang USING btree (gml_id, beginnt);
		CREATE INDEX alkis_7f2120ab_0a56_46b6_af44_1db9bffd41c9 ON aa_vorgang USING btree (status);
		CREATE INDEX alkis_0b3f7ddf_31c3_4db5_8384_86afb585ddaf ON aa_vorgang USING btree (synchronisiertmit);
		CREATE INDEX alkis_90fda40c_070f_4030_bd2b_c6e16510374d ON aa_vorgang USING gin (enthaelt);
		CREATE INDEX alkis_326ad559_9bfb_42d3_adc2_176841b83ddd ON aa_vorgang USING gin (istteilvon);

		ALTER TABLE ap_darstellung ALTER beginnt SET NOT NULL;
		-- ap_darstellung.positionierungsregel => positionierungsregel: integer => character varying
		ALTER TABLE ap_darstellung ALTER positionierungsregel TYPE character varying USING positionierungsregel::varchar;
		ALTER TABLE ap_darstellung ADD istteilvon character(16)[];
		ALTER TABLE ap_darstellung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ap_darstellung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ap_darstellung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_bd33d1d7_ed33_4110_8e9a_8253721fa8ee ON ap_darstellung USING gin (istteilvon);

		ALTER TABLE ap_lpo ALTER beginnt SET NOT NULL;
		ALTER TABLE ap_lpo ADD hatdirektunten character(16)[];
		ALTER TABLE ap_lpo ADD istabgeleitetaus character(16)[];
		ALTER TABLE ap_lpo ADD istteilvon character(16)[];
		ALTER TABLE ap_lpo ADD traegtbeizu character(16)[];
		ALTER TABLE ap_lpo ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ap_lpo ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ap_lpo ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_dcad2a31_02c9_4c5d_bc70_4e039f5a7bc4 ON ap_lpo USING gin (hatdirektunten);
		CREATE INDEX alkis_4ad5172a_7092_4268_9a56_5218bf3a5c6a ON ap_lpo USING gin (istabgeleitetaus);
		CREATE INDEX alkis_2dd26091_115c_4206_8a2d_98f4b43dfc87 ON ap_lpo USING gin (istteilvon);
		CREATE INDEX alkis_58075be7_f312_44ed_8974_e1a83d8f58d2 ON ap_lpo USING gin (traegtbeizu);

		ALTER TABLE ap_lto ALTER beginnt SET NOT NULL;
		ALTER TABLE ap_lto ALTER fontsperrung SET NOT NULL;
		ALTER TABLE ap_lto ALTER horizontaleausrichtung SET NOT NULL;
		ALTER TABLE ap_lto ALTER skalierung SET NOT NULL;
		ALTER TABLE ap_lto ALTER vertikaleausrichtung SET NOT NULL;
		-- ap_lto.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ap_lto DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ap_lto RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ap_lto','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ap_lto SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ap_lto DROP wkb_geometry_ CASCADE;
			CREATE INDEX ap_lto_wkb_geometry_idx ON ap_lto USING gist(wkb_geometry);
		END;
		ALTER TABLE ap_lto ADD hatdirektunten character(16)[];
		ALTER TABLE ap_lto ADD istabgeleitetaus character(16)[];
		ALTER TABLE ap_lto ADD istteilvon character(16)[];
		ALTER TABLE ap_lto ADD traegtbeizu character(16)[];
		ALTER TABLE ap_lto ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ap_lto ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ap_lto ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4a8057aa_55ab_4714_9b55_a9e0f50738dc ON ap_lto USING gin (hatdirektunten);
		CREATE INDEX alkis_fba62a13_2e92_4074_8a59_eb89f9d0bcbb ON ap_lto USING gin (istabgeleitetaus);
		CREATE INDEX alkis_489e017f_7df8_4e1e_b679_f9f68c640fdd ON ap_lto USING gin (istteilvon);
		CREATE INDEX alkis_3917c24d_0821_498f_b9b0_7e5131e2609e ON ap_lto USING gin (traegtbeizu);

		ALTER TABLE ap_ppo ALTER beginnt SET NOT NULL;
		ALTER TABLE ap_ppo ADD hatdirektunten character(16)[];
		ALTER TABLE ap_ppo ADD istabgeleitetaus character(16)[];
		ALTER TABLE ap_ppo ADD istteilvon character(16)[];
		ALTER TABLE ap_ppo ADD traegtbeizu character(16)[];
		ALTER TABLE ap_ppo ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ap_ppo ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ap_ppo ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_3c2d61c2_ba0b_4224_8d07_2c26b8eaecb7 ON ap_ppo USING gin (hatdirektunten);
		CREATE INDEX alkis_3e18a97c_11c8_4f38_a916_8958563b7112 ON ap_ppo USING gin (istabgeleitetaus);
		CREATE INDEX alkis_7317cf3d_9834_45e7_a78d_06665a615de2 ON ap_ppo USING gin (istteilvon);
		CREATE INDEX alkis_0602817f_edd4_46e4_9b75_2629069bcbda ON ap_ppo USING gin (traegtbeizu);

		ALTER TABLE ap_pto ALTER beginnt SET NOT NULL;
		ALTER TABLE ap_pto ALTER fontsperrung SET NOT NULL;
		ALTER TABLE ap_pto ALTER horizontaleausrichtung SET NOT NULL;
		ALTER TABLE ap_pto ALTER skalierung SET NOT NULL;
		ALTER TABLE ap_pto ALTER vertikaleausrichtung SET NOT NULL;
		-- ap_pto.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ap_pto DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ap_pto RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ap_pto','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ap_pto SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ap_pto DROP wkb_geometry_ CASCADE;
			CREATE INDEX ap_pto_wkb_geometry_idx ON ap_pto USING gist(wkb_geometry);
		END;
		ALTER TABLE ap_pto ADD hatdirektunten character(16)[];
		ALTER TABLE ap_pto ADD istabgeleitetaus character(16)[];
		ALTER TABLE ap_pto ADD istteilvon character(16)[];
		ALTER TABLE ap_pto ADD traegtbeizu character(16)[];
		ALTER TABLE ap_pto ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ap_pto ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ap_pto ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_db273ead_24b0_4aa7_a7e8_57c9f52b151e ON ap_pto USING gin (hatdirektunten);
		CREATE INDEX alkis_2d1af67d_18fa_462f_a42f_d11c6dbaa82b ON ap_pto USING gin (istabgeleitetaus);
		CREATE INDEX alkis_4811f6b4_058e_478e_b1fa_bf8344c56de7 ON ap_pto USING gin (istteilvon);
		CREATE INDEX alkis_e42aa703_06d8_4ec2_adc1_2e30682cbe61 ON ap_pto USING gin (traegtbeizu);

		ALTER TABLE ax_anderefestlegungnachwasserrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_anderefestlegungnachwasserrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD nummer character varying;
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_address character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_role character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD statement character varying;
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_3e13c5de_73bd_4485_8de4_c7cdf4b0b57f ON ax_anderefestlegungnachwasserrecht USING btree (endet);
		CREATE INDEX alkis_25da7d4d_f1e2_46f6_8881_ea2aed035f1e ON ax_anderefestlegungnachwasserrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_115541ac_5b9c_4cb5_b5d8_8923f85cde9d ON ax_anderefestlegungnachwasserrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_56f48b65_1491_48ea_8c92_d409b88d26e2 ON ax_anderefestlegungnachwasserrecht USING gin (istteilvon);
		CREATE INDEX alkis_1be8fb52_e0fc_4e68_9bad_f5f940ec882d ON ax_anderefestlegungnachwasserrecht USING gin (traegtbeizu);

		ALTER TABLE ax_anschrift ALTER beginnt SET NOT NULL;
		-- ax_anschrift.fax => fax: character varying => character varying[]
		ALTER TABLE ax_anschrift ALTER fax TYPE character varying[] USING CASE WHEN fax IS NULL THEN NULL ELSE ARRAY[fax] END;
		ALTER TABLE ax_anschrift RENAME organisationname TO processstep_organisationname;
		-- ax_anschrift.organisationname => processstep_organisationname: character varying => character varying[]
		ALTER TABLE ax_anschrift ALTER processstep_organisationname TYPE character varying[] USING CASE WHEN processstep_organisationname IS NULL THEN NULL ELSE ARRAY[processstep_organisationname] END;
		ALTER TABLE ax_anschrift ALTER ort_post SET NOT NULL;
		-- ax_anschrift.telefon => telefon: character varying => character varying[]
		ALTER TABLE ax_anschrift ALTER telefon TYPE character varying[] USING CASE WHEN telefon IS NULL THEN NULL ELSE ARRAY[telefon] END;
		ALTER TABLE ax_anschrift ADD ax_li_processstep_ohnedatenerhebung_description character varying[];
		ALTER TABLE ax_anschrift ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_anschrift ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_anschrift ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_anschrift ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_anschrift ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_anschrift ADD istteilvon character(16)[];
		ALTER TABLE ax_anschrift ADD ort_amtlichesortsnamensverzeichnis character varying;
		ALTER TABLE ax_anschrift ADD processstep_address character varying[];
		ALTER TABLE ax_anschrift ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_anschrift ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_anschrift ADD processstep_datetime character(20)[];
		ALTER TABLE ax_anschrift ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_anschrift ADD processstep_individualname character varying[];
		ALTER TABLE ax_anschrift ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_anschrift ADD processstep_phone character varying[];
		ALTER TABLE ax_anschrift ADD processstep_positionname character varying[];
		ALTER TABLE ax_anschrift ADD processstep_rationale character varying[];
		ALTER TABLE ax_anschrift ADD processstep_role character varying[];
		ALTER TABLE ax_anschrift ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_anschrift ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_anschrift ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_anschrift ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_anschrift ADD statement character varying;
		ALTER TABLE ax_anschrift ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_anschrift ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_anschrift ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_7b2b63da_0a74_49a7_9ba5_8bca43f0bcbc ON ax_anschrift USING btree (endet);
		CREATE INDEX alkis_5f545065_d5fb_4a3c_8b1a_ec9db7018664 ON ax_anschrift USING gin (istteilvon);

		ALTER TABLE ax_aufnahmepunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_aufnahmepunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_aufnahmepunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_aufnahmepunkt ALTER vermarkung_marke SET NOT NULL;
		ALTER TABLE ax_aufnahmepunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_aufnahmepunkt ADD beziehtsichauf character(16)[];
		ALTER TABLE ax_aufnahmepunkt ADD gehoertzu character(16)[];
		ALTER TABLE ax_aufnahmepunkt ADD haengtan character(16)[];
		ALTER TABLE ax_aufnahmepunkt ADD hatidentitaet character(16)[];
		ALTER TABLE ax_aufnahmepunkt ADD horizontfreiheit integer;
		ALTER TABLE ax_aufnahmepunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_aufnahmepunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_aufnahmepunkt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_aufnahmepunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_45827218_8025_4d64_862a_2cd3e320ee01 ON ax_aufnahmepunkt USING btree (endet);
		CREATE INDEX alkis_c469e649_e99a_460f_afa8_2288d5017b0c ON ax_aufnahmepunkt USING gin (bestehtaus);
		CREATE INDEX alkis_11127394_be07_44b5_816f_767a3e100ee3 ON ax_aufnahmepunkt USING gin (beziehtsichauf);
		CREATE INDEX alkis_78ee36ff_d872_42c9_a41d_305966f3112c ON ax_aufnahmepunkt USING gin (gehoertzu);
		CREATE INDEX alkis_8074699e_56c3_4ad1_85b0_e72a61b6da9a ON ax_aufnahmepunkt USING gin (haengtan);
		CREATE INDEX alkis_acabc7da_f6bf_4b93_8466_f4c35a398cce ON ax_aufnahmepunkt USING gin (hatidentitaet);
		CREATE INDEX alkis_50c03631_a9e3_4ac3_90ef_4f1c4eb7fa37 ON ax_aufnahmepunkt USING gin (istteilvon);

		-- ax_bahnverkehr.bahnkategorie => bahnkategorie: integer => integer[]
		ALTER TABLE ax_bahnverkehr ALTER bahnkategorie TYPE integer[] USING CASE WHEN bahnkategorie IS NULL THEN NULL ELSE ARRAY[bahnkategorie] END;
		ALTER TABLE ax_bahnverkehr ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bahnverkehr DROP bezeichnung;
		ALTER TABLE ax_bahnverkehr ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_bahnverkehr ADD gemeinde character varying;
		ALTER TABLE ax_bahnverkehr ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bahnverkehr ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bahnverkehr ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bahnverkehr ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bahnverkehr ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bahnverkehr ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bahnverkehr ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bahnverkehr ADD istteilvon character(16)[];
		ALTER TABLE ax_bahnverkehr ADD kreis character varying;
		ALTER TABLE ax_bahnverkehr ADD lage character varying;
		ALTER TABLE ax_bahnverkehr ADD land character varying;
		ALTER TABLE ax_bahnverkehr ADD processstep_address character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bahnverkehr ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_individualname character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_phone character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_positionname character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_rationale character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_role character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bahnverkehr ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bahnverkehr ADD regierungsbezirk character varying;
		ALTER TABLE ax_bahnverkehr ADD statement character varying;
		ALTER TABLE ax_bahnverkehr ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bahnverkehr ADD unverschluesselt character varying;
		ALTER TABLE ax_bahnverkehr ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bahnverkehr ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bahnverkehr ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_185545e9_1d5d_41ae_978d_7905e2df5e04 ON ax_bahnverkehr USING btree (endet);
		CREATE INDEX alkis_0165e719_59cf_4997_be39_42deff6ebe7c ON ax_bahnverkehr USING gin (hatdirektunten);
		CREATE INDEX alkis_56f98b09_eff3_4018_a29e_1fcded48cd05 ON ax_bahnverkehr USING gin (istabgeleitetaus);
		CREATE INDEX alkis_12e90b67_954b_4b32_a2b1_3ecd3a6843cd ON ax_bahnverkehr USING gin (istteilvon);
		CREATE INDEX alkis_aa4a5e33_7b7a_45e3_a78d_37d76e3d5b98 ON ax_bahnverkehr USING gin (traegtbeizu);

		ALTER TABLE ax_bahnverkehrsanlage ALTER bahnhofskategorie SET NOT NULL;
		-- ax_bahnverkehrsanlage.bahnkategorie => bahnkategorie: integer => integer[]
		ALTER TABLE ax_bahnverkehrsanlage ALTER bahnkategorie TYPE integer[] USING CASE WHEN bahnkategorie IS NULL THEN NULL ELSE ARRAY[bahnkategorie] END;
		ALTER TABLE ax_bahnverkehrsanlage ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bahnverkehrsanlage ADD bezeichnung character varying;
		ALTER TABLE ax_bahnverkehrsanlage ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bahnverkehrsanlage ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bahnverkehrsanlage ADD istteilvon character(16)[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_address character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_individualname character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_phone character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_positionname character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_rationale character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_role character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD statement character varying;
		ALTER TABLE ax_bahnverkehrsanlage ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bahnverkehrsanlage ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_bahnverkehrsanlage ADD zustand integer;
		CREATE INDEX alkis_9c23cb0d_7ad6_4f73_a1ed_87b77cd3e6b6 ON ax_bahnverkehrsanlage USING btree (endet);
		CREATE INDEX alkis_66ea059d_7fab_4f3b_8459_639cf3ce35a0 ON ax_bahnverkehrsanlage USING gin (hatdirektunten);
		CREATE INDEX alkis_51cc82d4_7608_4056_bea2_ad83369eb777 ON ax_bahnverkehrsanlage USING gin (istabgeleitetaus);
		CREATE INDEX alkis_1a0b1518_1a53_4232_acf6_c18aa3641fe0 ON ax_bahnverkehrsanlage USING gin (istteilvon);
		CREATE INDEX alkis_b014825d_36f2_474e_b053_a45bfed037ff ON ax_bahnverkehrsanlage USING gin (traegtbeizu);

		ALTER TABLE ax_baublock ALTER baublockbezeichnung SET NOT NULL;
		ALTER TABLE ax_baublock ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_baublock ADD hatdirektunten character(16)[];
		ALTER TABLE ax_baublock ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_baublock ADD istteilvon character(16)[];
		ALTER TABLE ax_baublock ADD traegtbeizu character(16)[];
		ALTER TABLE ax_baublock ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_baublock ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_baublock ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_a3abf190_f565_40ab_838c_ddb9a03ddd53 ON ax_baublock USING btree (endet);
		CREATE INDEX alkis_6190f146_21fe_4596_a2ac_89c97b45f539 ON ax_baublock USING gin (hatdirektunten);
		CREATE INDEX alkis_30f049d4_2b5a_4863_8b1e_1a6e4aa156ef ON ax_baublock USING gin (istabgeleitetaus);
		CREATE INDEX alkis_8cef5106_e093_4370_a1c6_9903b8e8c94e ON ax_baublock USING gin (istteilvon);
		CREATE INDEX alkis_747be46a_e029_484e_9e9f_4f2e94c39917 ON ax_baublock USING gin (traegtbeizu);

		ALTER TABLE ax_bauraumoderbodenordnungsrecht RENAME art TO zeigtaufexternes_art;
		-- ax_bauraumoderbodenordnungsrecht.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ALTER beginnt SET NOT NULL;
		-- ax_bauraumoderbodenordnungsrecht.datumanordnung => datumanordnung: character varying => date
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ALTER datumanordnung TYPE date USING to_date(datumanordnung, 'YYYY-mm-dd');
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD datumabgabe date;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD datumbesitzeinweisung date;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD datumrechtskraeftig date;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_address character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_role character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD statement character varying;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD veraenderungohneruecksprache character varying;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_3be8dc35_2cc8_4574_a90b_3de1cdc65088 ON ax_bauraumoderbodenordnungsrecht USING btree (endet);
		CREATE INDEX alkis_e764099b_f9c2_4512_ae96_e07191e23d38 ON ax_bauraumoderbodenordnungsrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_e1916c1a_51bb_4069_ba19_38adf0129654 ON ax_bauraumoderbodenordnungsrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_1b09786c_4a4f_4140_a865_b36cbe459c4f ON ax_bauraumoderbodenordnungsrecht USING gin (istteilvon);
		CREATE INDEX alkis_aed62756_da4c_48b1_8c7a_831392fc6121 ON ax_bauraumoderbodenordnungsrecht USING gin (traegtbeizu);

		ALTER TABLE ax_bauteil DROP anzahlderunterirdischengeschosse;
		ALTER TABLE ax_bauteil ALTER bauart SET NOT NULL;
		ALTER TABLE ax_bauteil ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bauteil ADD baujahr integer[];
		ALTER TABLE ax_bauteil ADD durchfahrtshoehe double precision;
		ALTER TABLE ax_bauteil ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bauteil ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bauteil ADD istteilvon character(16)[];
		ALTER TABLE ax_bauteil ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bauteil ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bauteil ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bauteil ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_8527c5ec_6ae1_480c_a1bd_c653a87995df ON ax_bauteil USING btree (endet);
		CREATE INDEX alkis_bd68e2ae_f7e0_474a_8118_af6303abc205 ON ax_bauteil USING gin (hatdirektunten);
		CREATE INDEX alkis_5406fcb3_e999_49bb_b6b7_9efec19f25b5 ON ax_bauteil USING gin (istabgeleitetaus);
		CREATE INDEX alkis_6535e3a5_05c0_487e_a204_ca575278a43a ON ax_bauteil USING gin (istteilvon);
		CREATE INDEX alkis_f88ae71b_1f86_4d15_9075_84085a5a5f03 ON ax_bauteil USING gin (traegtbeizu);

		ALTER TABLE ax_bauwerkimgewaesserbereich ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_bauwerkimgewaesserbereich ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD bezeichnung character varying;
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD istteilvon character(16)[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_address character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_individualname character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_phone character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_positionname character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_rationale character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_role character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD statement character varying;
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_fbf9b933_085b_41fb_9589_965bff86caee ON ax_bauwerkimgewaesserbereich USING btree (endet);
		CREATE INDEX alkis_7787a6de_f3dc_4952_b3fd_21c126144804 ON ax_bauwerkimgewaesserbereich USING gin (hatdirektunten);
		CREATE INDEX alkis_f84d31dd_1471_427a_8c22_6fc8ad3fbb54 ON ax_bauwerkimgewaesserbereich USING gin (istabgeleitetaus);
		CREATE INDEX alkis_4663cb0a_9791_4734_bb9d_185795098da5 ON ax_bauwerkimgewaesserbereich USING gin (istteilvon);
		CREATE INDEX alkis_8a1acbf1_16a2_4817_823c_273c65dd95f5 ON ax_bauwerkimgewaesserbereich USING gin (traegtbeizu);

		ALTER TABLE ax_bauwerkimverkehrsbereich ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_bauwerkimverkehrsbereich ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD bezeichnung character varying;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD breitedesobjekts double precision;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD durchfahrtshoehe double precision;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD istteilvon character(16)[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_address character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_individualname character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_phone character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_positionname character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_rationale character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_role character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD statement character varying;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_44d1f505_ca56_4519_86b3_82fb254664db ON ax_bauwerkimverkehrsbereich USING btree (endet);
		CREATE INDEX alkis_eea0e06c_36eb_4ed4_a18c_9a693618269e ON ax_bauwerkimverkehrsbereich USING gin (hatdirektunten);
		CREATE INDEX alkis_e3383eef_c0ce_4154_9c27_e3f37b9e1ac8 ON ax_bauwerkimverkehrsbereich USING gin (istabgeleitetaus);
		CREATE INDEX alkis_ad1155bb_27fb_430b_8f19_726dfa2bcf57 ON ax_bauwerkimverkehrsbereich USING gin (istteilvon);
		CREATE INDEX alkis_9c873c43_19aa_4e0a_9d90_fd5a673e5492 ON ax_bauwerkimverkehrsbereich USING gin (traegtbeizu);

		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD bezeichnung character varying;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD istteilvon character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_address character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_individualname character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_phone character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_positionname character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_rationale character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_role character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD statement character varying;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_6c998569_f93a_4f8d_9ea3_610906a73319 ON ax_bauwerkoderanlagefuerindustrieundgewerbe USING btree (endet);
		CREATE INDEX alkis_2b351a9a_d4d7_4a8f_b100_e6ec88c43f87 ON ax_bauwerkoderanlagefuerindustrieundgewerbe USING gin (hatdirektunten);
		CREATE INDEX alkis_715b534a_b938_4af6_baa4_6277b2c72f82 ON ax_bauwerkoderanlagefuerindustrieundgewerbe USING gin (istabgeleitetaus);
		CREATE INDEX alkis_a548da01_17cc_49c3_8580_6824af9fb18f ON ax_bauwerkoderanlagefuerindustrieundgewerbe USING gin (istteilvon);
		CREATE INDEX alkis_fa81bd04_4d46_4e20_9344_0b7073dbfcf6 ON ax_bauwerkoderanlagefuerindustrieundgewerbe USING gin (traegtbeizu);

		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD breitedesobjekts double precision;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD istteilvon character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_address character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_individualname character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_phone character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_positionname character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_rationale character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_role character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD statement character varying;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2baa2cdc_b720_4c52_9e9c_c0f94a6d2750 ON ax_bauwerkoderanlagefuersportfreizeitunderholung USING btree (endet);
		CREATE INDEX alkis_4c658a91_6526_4a52_a9e1_61d247b6c5ba ON ax_bauwerkoderanlagefuersportfreizeitunderholung USING gin (hatdirektunten);
		CREATE INDEX alkis_6963db31_c66c_4e9d_a324_9ebd9481dcb2 ON ax_bauwerkoderanlagefuersportfreizeitunderholung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_1751ef17_71de_4c87_8962_68fd310f5557 ON ax_bauwerkoderanlagefuersportfreizeitunderholung USING gin (istteilvon);
		CREATE INDEX alkis_7b9c2b2a_3e8e_4c3e_90d4_f140fffc8642 ON ax_bauwerkoderanlagefuersportfreizeitunderholung USING gin (traegtbeizu);

		ALTER TABLE ax_bergbaubetrieb ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bergbaubetrieb ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_bergbaubetrieb ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bergbaubetrieb ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bergbaubetrieb ADD istteilvon character(16)[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_address character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_individualname character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_phone character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_positionname character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_rationale character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_role character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD statement character varying;
		ALTER TABLE ax_bergbaubetrieb ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bergbaubetrieb ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bergbaubetrieb ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_8ab53362_3a88_4ad1_aa63_9a6308eab663 ON ax_bergbaubetrieb USING btree (endet);
		CREATE INDEX alkis_a05a1aa9_7c1f_4edc_8633_1916bd72c7c4 ON ax_bergbaubetrieb USING gin (hatdirektunten);
		CREATE INDEX alkis_0224cc73_89a9_4c83_b4dc_f586a5b4cffe ON ax_bergbaubetrieb USING gin (istabgeleitetaus);
		CREATE INDEX alkis_4fea7ef6_4f7b_43ab_ab77_60f4ba1feb97 ON ax_bergbaubetrieb USING gin (istteilvon);
		CREATE INDEX alkis_addc85cf_daec_4607_bbb5_17f38bd1288e ON ax_bergbaubetrieb USING gin (traegtbeizu);

		ALTER TABLE ax_besondereflurstuecksgrenze ALTER artderflurstuecksgrenze SET NOT NULL;
		ALTER TABLE ax_besondereflurstuecksgrenze ALTER beginnt SET NOT NULL;
		-- ax_besondereflurstuecksgrenze.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_besondereflurstuecksgrenze DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_besondereflurstuecksgrenze RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_besondereflurstuecksgrenze','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_besondereflurstuecksgrenze SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_besondereflurstuecksgrenze DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_besondereflurstuecksgrenze_wkb_geometry_idx ON ax_besondereflurstuecksgrenze USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_besondereflurstuecksgrenze ADD hatdirektunten character(16)[];
		ALTER TABLE ax_besondereflurstuecksgrenze ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_besondereflurstuecksgrenze ADD istteilvon character(16)[];
		ALTER TABLE ax_besondereflurstuecksgrenze ADD traegtbeizu character(16)[];
		ALTER TABLE ax_besondereflurstuecksgrenze ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_besondereflurstuecksgrenze ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_besondereflurstuecksgrenze ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_9dc43c8f_2c0e_4d30_a830_3650a4c5cf75 ON ax_besondereflurstuecksgrenze USING btree (endet);
		CREATE INDEX alkis_fd2d6ddf_b109_4ad5_9b6d_5ccdeb676d92 ON ax_besondereflurstuecksgrenze USING gin (hatdirektunten);
		CREATE INDEX alkis_beff5c16_3a95_4ae8_b34f_6907e00b9fab ON ax_besondereflurstuecksgrenze USING gin (istabgeleitetaus);
		CREATE INDEX alkis_a73f83bd_2ed2_4985_944c_a1b3f59009eb ON ax_besondereflurstuecksgrenze USING gin (istteilvon);
		CREATE INDEX alkis_5109b1e2_f0a8_4c0b_9620_18906c586cf8 ON ax_besondereflurstuecksgrenze USING gin (traegtbeizu);

		ALTER TABLE ax_besonderegebaeudelinie ALTER beginnt SET NOT NULL;
		UPDATE ax_besonderegebaeudelinie SET beschaffenheit=ARRAY[]::integer[] WHERE beschaffenheit IS NULL;
		ALTER TABLE ax_besonderegebaeudelinie ALTER beschaffenheit SET NOT NULL;
		ALTER TABLE ax_besonderegebaeudelinie ADD hatdirektunten character(16)[];
		ALTER TABLE ax_besonderegebaeudelinie ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_besonderegebaeudelinie ADD istteilvon character(16)[];
		ALTER TABLE ax_besonderegebaeudelinie ADD traegtbeizu character(16)[];
		ALTER TABLE ax_besonderegebaeudelinie ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_besonderegebaeudelinie ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_besonderegebaeudelinie ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e58c842d_76b6_4baa_8d62_6f19ba077d2f ON ax_besonderegebaeudelinie USING btree (endet);
		CREATE INDEX alkis_1e91b566_7f96_47be_a445_489fe0d41455 ON ax_besonderegebaeudelinie USING gin (hatdirektunten);
		CREATE INDEX alkis_a041d288_b0fd_4f28_be8d_b4261a6c56d9 ON ax_besonderegebaeudelinie USING gin (istabgeleitetaus);
		CREATE INDEX alkis_a830c043_30b8_4d53_8168_e2df881368bc ON ax_besonderegebaeudelinie USING gin (istteilvon);
		CREATE INDEX alkis_b71ea13c_fa6c_4dfc_9287_2332d3009525 ON ax_besonderegebaeudelinie USING gin (traegtbeizu);

		ALTER TABLE ax_besondererbauwerkspunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_besondererbauwerkspunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_besondererbauwerkspunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_besondererbauwerkspunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_besondererbauwerkspunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_besondererbauwerkspunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_besondererbauwerkspunkt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_besondererbauwerkspunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_9acb2b7b_a00a_42a0_8ae2_5ceda2f35327 ON ax_besondererbauwerkspunkt USING btree (endet);
		CREATE INDEX alkis_9eea4ad7_2b08_4e4f_a6f4_0c6996dcd2a4 ON ax_besondererbauwerkspunkt USING gin (bestehtaus);
		CREATE INDEX alkis_6c138329_2333_4e97_9563_4ab8f51ca5a5 ON ax_besondererbauwerkspunkt USING gin (istteilvon);

		-- ax_besonderergebaeudepunkt.art => art: character varying => integer
		ALTER TABLE ax_besonderergebaeudepunkt ALTER art TYPE integer USING art::int;
		ALTER TABLE ax_besonderergebaeudepunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_besonderergebaeudepunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_besonderergebaeudepunkt RENAME name TO zeigtaufexternes_name;
		ALTER TABLE ax_besonderergebaeudepunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_besonderergebaeudepunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_besonderergebaeudepunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_besonderergebaeudepunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_besonderergebaeudepunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_83c0a5cf_2ec2_4516_9912_4bc81642db42 ON ax_besonderergebaeudepunkt USING btree (endet);
		CREATE INDEX alkis_471b89e0_9121_4139_aa5c_43ba723abc29 ON ax_besonderergebaeudepunkt USING gin (bestehtaus);
		CREATE INDEX alkis_6e49cc8a_1fb1_4a9e_8365_edab82e2a4c1 ON ax_besonderergebaeudepunkt USING gin (istteilvon);

		ALTER TABLE ax_besondererhoehenpunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_besondererhoehenpunkt ALTER besonderebedeutung SET NOT NULL;
		-- ax_besondererhoehenpunkt.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_besondererhoehenpunkt DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_besondererhoehenpunkt RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_besondererhoehenpunkt','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_besondererhoehenpunkt SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_besondererhoehenpunkt DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_besondererhoehenpunkt_wkb_geometry_idx ON ax_besondererhoehenpunkt USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_besondererhoehenpunkt ADD ax_dqerfassungsmethodebesondererhoehenpunkt integer;
		ALTER TABLE ax_besondererhoehenpunkt ADD erfassungbesondererhoehenpunkt_datetime character(20);
		ALTER TABLE ax_besondererhoehenpunkt ADD hatdirektunten character(16)[];
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_datetime character(20)[];
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_evaluationmethoddescription character varying;
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_evaluationmethodtype character varying;
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_evaluationprocedure character varying;
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_measuredescription character varying;
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_measureidentification character varying;
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_nameofmeasure character varying[];
		ALTER TABLE ax_besondererhoehenpunkt ADD hoehengenauigkeit_result character varying[];
		ALTER TABLE ax_besondererhoehenpunkt ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_besondererhoehenpunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_besondererhoehenpunkt ADD traegtbeizu character(16)[];
		ALTER TABLE ax_besondererhoehenpunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_besondererhoehenpunkt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_besondererhoehenpunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_10ea255e_ec36_49c3_b306_a8bf89c3fc3d ON ax_besondererhoehenpunkt USING btree (endet);
		CREATE INDEX alkis_c549c779_3e80_415c_a828_c1b80679ef72 ON ax_besondererhoehenpunkt USING gin (hatdirektunten);
		CREATE INDEX alkis_b5c305d1_c4b7_4ced_96f5_47138a2aa46e ON ax_besondererhoehenpunkt USING gin (istabgeleitetaus);
		CREATE INDEX alkis_55109b6d_a350_4ce0_baa0_57b3aac06d88 ON ax_besondererhoehenpunkt USING gin (istteilvon);
		CREATE INDEX alkis_93d66305_1791_482a_9c9d_25c7955f30c6 ON ax_besondererhoehenpunkt USING gin (traegtbeizu);

		ALTER TABLE ax_besonderertopographischerpunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_besonderertopographischerpunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_besonderertopographischerpunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_besonderertopographischerpunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_besonderertopographischerpunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_besonderertopographischerpunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_besonderertopographischerpunkt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_besonderertopographischerpunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_67cb24ef_f675_4abf_ac33_7ae4dc75ad57 ON ax_besonderertopographischerpunkt USING btree (endet);
		CREATE INDEX alkis_0b285432_09d1_4df2_8acf_4739e1139a0a ON ax_besonderertopographischerpunkt USING gin (bestehtaus);
		CREATE INDEX alkis_361f41bc_c31c_42c9_82d8_eef4c1711994 ON ax_besonderertopographischerpunkt USING gin (istteilvon);

		ALTER TABLE ax_bewertung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bewertung ALTER klassifizierung SET NOT NULL;
		ALTER TABLE ax_bewertung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bewertung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bewertung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bewertung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bewertung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bewertung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bewertung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bewertung ADD istteilvon character(16)[];
		ALTER TABLE ax_bewertung ADD processstep_address character varying[];
		ALTER TABLE ax_bewertung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bewertung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bewertung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bewertung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bewertung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bewertung ADD processstep_individualname character varying[];
		ALTER TABLE ax_bewertung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bewertung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bewertung ADD processstep_phone character varying[];
		ALTER TABLE ax_bewertung ADD processstep_positionname character varying[];
		ALTER TABLE ax_bewertung ADD processstep_rationale character varying[];
		ALTER TABLE ax_bewertung ADD processstep_role character varying[];
		ALTER TABLE ax_bewertung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bewertung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bewertung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bewertung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bewertung ADD statement character varying;
		ALTER TABLE ax_bewertung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bewertung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bewertung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bewertung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_87fb9190_30fc_4ac2_890e_f1066d85b873 ON ax_bewertung USING btree (endet);
		CREATE INDEX alkis_c16a72f3_17ed_419d_8e6e_dbf9c29d0d6c ON ax_bewertung USING gin (hatdirektunten);
		CREATE INDEX alkis_e5d2522d_3c80_4a50_9887_a6cb7da65faf ON ax_bewertung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_daddb948_bfd0_4108_be7b_cb82c3dc77ec ON ax_bewertung USING gin (istteilvon);
		CREATE INDEX alkis_1450698a_3081_4669_a1c5_e662fc9ed29b ON ax_bewertung USING gin (traegtbeizu);

		ALTER TABLE ax_bodenschaetzung RENAME art TO zeigtaufexternes_art;
		-- ax_bodenschaetzung.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_bodenschaetzung ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_bodenschaetzung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bodenschaetzung ALTER bodenart SET NOT NULL;
		ALTER TABLE ax_bodenschaetzung ALTER kulturart SET NOT NULL;
		ALTER TABLE ax_bodenschaetzung RENAME name TO zeigtaufexternes_name;
		-- ax_bodenschaetzung.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_bodenschaetzung ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_bodenschaetzung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_bodenschaetzung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bodenschaetzung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bodenschaetzung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bodenschaetzung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bodenschaetzung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bodenschaetzung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_bodenschaetzung ADD istteilvon character(16)[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_address character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_individualname character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_phone character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_positionname character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_rationale character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_role character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bodenschaetzung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bodenschaetzung ADD statement character varying;
		ALTER TABLE ax_bodenschaetzung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_bodenschaetzung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_154bc81a_fbda_496f_bb4e_e2e145608f67 ON ax_bodenschaetzung USING btree (endet);
		CREATE INDEX alkis_b058e450_f586_4c25_a653_3712fac8a3f9 ON ax_bodenschaetzung USING gin (hatdirektunten);
		CREATE INDEX alkis_0984a710_c22c_4476_8322_a402c404bb3c ON ax_bodenschaetzung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_54caaeed_6c8b_4bf3_be05_be55410ab745 ON ax_bodenschaetzung USING gin (istteilvon);
		CREATE INDEX alkis_9c161b79_15b1_460c_a7e5_e627a605711b ON ax_bodenschaetzung USING gin (traegtbeizu);

		ALTER TABLE ax_boeschungkliff ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_boeschungkliff ADD bestehtaus character(16)[];
		ALTER TABLE ax_boeschungkliff ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_boeschungkliff ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_boeschungkliff ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_boeschungkliff ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_boeschungkliff ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_boeschungkliff ADD istteilvon character(16)[];
		ALTER TABLE ax_boeschungkliff ADD name character varying;
		ALTER TABLE ax_boeschungkliff ADD processstep_address character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_datetime character(20)[];
		ALTER TABLE ax_boeschungkliff ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_individualname character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_organisationname character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_phone character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_positionname character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_rationale character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_role character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_boeschungkliff ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_boeschungkliff ADD statement character varying;
		ALTER TABLE ax_boeschungkliff ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_boeschungkliff ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_boeschungkliff ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_boeschungkliff ADD zustand integer;
		CREATE INDEX alkis_9797aa3f_af91_4219_93ce_bae08ede27f2 ON ax_boeschungkliff USING btree (endet);
		CREATE INDEX alkis_8f59fb77_7230_4ec7_a5f9_096e6f67acfb ON ax_boeschungkliff USING gin (bestehtaus);
		CREATE INDEX alkis_a13db4e5_77df_47d7_a3df_eb7d12079720 ON ax_boeschungkliff USING gin (istteilvon);

		ALTER TABLE ax_boeschungsflaeche ALTER beginnt SET NOT NULL;
		-- ax_boeschungsflaeche.istteilvon => istteilvon: character(16) => character(16)[]
		ALTER TABLE ax_boeschungsflaeche ALTER istteilvon TYPE character(16)[] USING CASE WHEN istteilvon IS NULL THEN NULL ELSE ARRAY[istteilvon] END;
		ALTER TABLE ax_boeschungsflaeche ADD hatdirektunten character(16)[];
		ALTER TABLE ax_boeschungsflaeche ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_boeschungsflaeche ADD traegtbeizu character(16)[];
		ALTER TABLE ax_boeschungsflaeche ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_boeschungsflaeche ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_boeschungsflaeche ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_boeschungsflaeche' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_boeschungsflaeche USING btree (istteilvon)';
		CREATE INDEX alkis_bacfa673_743d_439e_a495_b451abf9b13b ON ax_boeschungsflaeche USING btree (endet);
		CREATE INDEX alkis_303c3669_1366_4619_8c07_f299c82611e5 ON ax_boeschungsflaeche USING gin (hatdirektunten);
		CREATE INDEX alkis_5a612553_f658_4f02_bbd3_91ce7dfd18e5 ON ax_boeschungsflaeche USING gin (istabgeleitetaus);
		CREATE INDEX alkis_b90bf03f_8462_428a_9f34_8a45da1a77d7 ON ax_boeschungsflaeche USING gin (istteilvon);
		CREATE INDEX alkis_4416a2b4_2f5d_4252_b58a_0092ae23ea94 ON ax_boeschungsflaeche USING gin (traegtbeizu);

		ALTER TABLE ax_buchungsblatt RENAME art TO zeigtaufexternes_art;
		-- ax_buchungsblatt.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_buchungsblatt ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_buchungsblatt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_buchungsblatt ALTER bezirk SET NOT NULL;
		-- ax_buchungsblatt.blattart => blattart: character varying => integer
		ALTER TABLE ax_buchungsblatt ALTER blattart TYPE integer USING blattart::int;
		ALTER TABLE ax_buchungsblatt ALTER blattart SET NOT NULL;
		ALTER TABLE ax_buchungsblatt ALTER buchungsblattkennzeichen SET NOT NULL;
		ALTER TABLE ax_buchungsblatt ALTER buchungsblattnummermitbuchstabenerweiterung SET NOT NULL;
		ALTER TABLE ax_buchungsblatt ALTER land SET NOT NULL;
		ALTER TABLE ax_buchungsblatt ADD istteilvon character(16)[];
		ALTER TABLE ax_buchungsblatt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_buchungsblatt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_fb82bd5d_aa48_448f_8ea0_5131bfde22fd ON ax_buchungsblatt USING btree (endet);
		CREATE INDEX alkis_e52deb37_704a_487d_be0e_3cbc5637bfe0 ON ax_buchungsblatt USING gin (istteilvon);

		ALTER TABLE ax_buchungsblattbezirk ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_buchungsblattbezirk ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_buchungsblattbezirk ALTER bezirk SET NOT NULL;
		ALTER TABLE ax_buchungsblattbezirk DROP gehoertzu;
		ALTER TABLE ax_buchungsblattbezirk ALTER land SET NOT NULL;
		ALTER TABLE ax_buchungsblattbezirk ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_buchungsblattbezirk RENAME stelle TO gehoertzu_stelle;
		ALTER TABLE ax_buchungsblattbezirk ADD administrativefunktion integer[];
		ALTER TABLE ax_buchungsblattbezirk ADD gehoertzu_land character varying;
		ALTER TABLE ax_buchungsblattbezirk ADD istteilvon character(16)[];
		ALTER TABLE ax_buchungsblattbezirk ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_buchungsblattbezirk ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_buchungsblattbezirk ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2cf634ae_780c_4b4f_af12_87f1c219b70b ON ax_buchungsblattbezirk USING btree (endet);
		CREATE INDEX alkis_cf6bb3e4_045b_44b7_9361_aaa14ec3d258 ON ax_buchungsblattbezirk USING gin (istteilvon);

		ALTER TABLE ax_buchungsstelle ALTER beginnt SET NOT NULL;
		-- ax_buchungsstelle.beschreibungdesumfangsderbuchung => beschreibungdesumfangsderbuchung: character(1) => character varying
		ALTER TABLE ax_buchungsstelle ALTER beschreibungdesumfangsderbuchung TYPE character varying;
		ALTER TABLE ax_buchungsstelle ALTER buchungsart SET NOT NULL;
		ALTER TABLE ax_buchungsstelle ALTER istbestandteilvon SET NOT NULL;
		ALTER TABLE ax_buchungsstelle ALTER laufendenummer SET NOT NULL;
		ALTER TABLE ax_buchungsstelle ADD istteilvon character(16)[];
		ALTER TABLE ax_buchungsstelle ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_buchungsstelle ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_buchungsstelle ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_buchungsstelle ADD zeitpunktdereintragung date;
		CREATE INDEX alkis_33b89c13_234f_4094_9dd7_8167c4a6ac41 ON ax_buchungsstelle USING btree (endet);
		CREATE INDEX alkis_ae09a09f_12ee_431d_ab58_5a08e3ba2716 ON ax_buchungsstelle USING gin (istteilvon);

		ALTER TABLE ax_bundesland ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_bundesland ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_bundesland ALTER land SET NOT NULL;
		ALTER TABLE ax_bundesland ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_bundesland RENAME stelle TO istamtsbezirkvon_stelle;
		-- ax_bundesland.stelle => istamtsbezirkvon_stelle: character varying => character varying[]
		ALTER TABLE ax_bundesland ALTER istamtsbezirkvon_stelle TYPE character varying[] USING CASE WHEN istamtsbezirkvon_stelle IS NULL THEN NULL ELSE ARRAY[istamtsbezirkvon_stelle] END;
		ALTER TABLE ax_bundesland ADD administrativefunktion integer[];
		ALTER TABLE ax_bundesland ADD istamtsbezirkvon_land character varying[];
		ALTER TABLE ax_bundesland ADD istteilvon character(16)[];
		ALTER TABLE ax_bundesland ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_bundesland ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_bundesland ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_20de57d7_48a1_4b74_8457_a39eb839d9b5 ON ax_bundesland USING btree (endet);
		CREATE INDEX alkis_177b9d11_962d_430e_9ef2_e886b6263d44 ON ax_bundesland USING gin (istteilvon);

		ALTER TABLE ax_dammwalldeich ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_dammwalldeich ADD bezeichnung character varying;
		ALTER TABLE ax_dammwalldeich ADD hatdirektunten character(16)[];
		ALTER TABLE ax_dammwalldeich ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_dammwalldeich ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_dammwalldeich ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_dammwalldeich ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_dammwalldeich ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_dammwalldeich ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_dammwalldeich ADD istteilvon character(16)[];
		ALTER TABLE ax_dammwalldeich ADD objekthoehe double precision;
		ALTER TABLE ax_dammwalldeich ADD processstep_address character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_datetime character(20)[];
		ALTER TABLE ax_dammwalldeich ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_individualname character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_organisationname character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_phone character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_positionname character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_rationale character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_role character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_dammwalldeich ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_dammwalldeich ADD statement character varying;
		ALTER TABLE ax_dammwalldeich ADD traegtbeizu character(16)[];
		ALTER TABLE ax_dammwalldeich ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_dammwalldeich ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_dammwalldeich ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_c046d253_4ea4_4fa3_a70c_c04e36955815 ON ax_dammwalldeich USING btree (endet);
		CREATE INDEX alkis_ed19fd19_d53d_4336_9608_a764bd2e6e0b ON ax_dammwalldeich USING gin (hatdirektunten);
		CREATE INDEX alkis_641f2425_b248_4d57_b6cb_b8411bff3354 ON ax_dammwalldeich USING gin (istabgeleitetaus);
		CREATE INDEX alkis_86a39d4f_bf32_49ba_9f9b_fa6d9413b46a ON ax_dammwalldeich USING gin (istteilvon);
		CREATE INDEX alkis_e1137839_7ab5_4b77_893e_dd5bf6328446 ON ax_dammwalldeich USING gin (traegtbeizu);

		ALTER TABLE ax_denkmalschutzrecht RENAME art TO zeigtaufexternes_art;
		-- ax_denkmalschutzrecht.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_denkmalschutzrecht ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_denkmalschutzrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_denkmalschutzrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_denkmalschutzrecht ADD bezeichnung character varying;
		ALTER TABLE ax_denkmalschutzrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_denkmalschutzrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_denkmalschutzrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_address character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_role character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD statement character varying;
		ALTER TABLE ax_denkmalschutzrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_denkmalschutzrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_denkmalschutzrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4d1bf09c_115b_41cb_83ae_bc608848ca56 ON ax_denkmalschutzrecht USING btree (endet);
		CREATE INDEX alkis_3d0cbc45_7ba5_4867_9298_8a052312e3de ON ax_denkmalschutzrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_e822c652_d8a3_455b_9821_87777be09d87 ON ax_denkmalschutzrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_f89a4c4d_70cb_440f_9fee_3e961d35a58b ON ax_denkmalschutzrecht USING gin (istteilvon);
		CREATE INDEX alkis_90dd0d36_5b10_40ff_a8f3_d43453a773b1 ON ax_denkmalschutzrecht USING gin (traegtbeizu);

		ALTER TABLE ax_dienststelle ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_dienststelle ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_dienststelle ALTER land SET NOT NULL;
		ALTER TABLE ax_dienststelle ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_dienststelle ALTER stelle SET NOT NULL;
		ALTER TABLE ax_dienststelle ADD administrativefunktion integer[];
		ALTER TABLE ax_dienststelle ADD istteilvon character(16)[];
		ALTER TABLE ax_dienststelle ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_dienststelle ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_dienststelle ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_7d0bd967_aa79_47c3_9cc2_0a3114aa5fa5 ON ax_dienststelle USING btree (endet);
		CREATE INDEX alkis_eeae2144_b738_478b_88ba_e87d61a8baab ON ax_dienststelle USING btree (hat);
		CREATE INDEX alkis_3bc4d2c7_cd43_416a_b6a0_4130e5525d07 ON ax_dienststelle USING gin (istteilvon);

		ALTER TABLE ax_duene ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_duene ADD hatdirektunten character(16)[];
		ALTER TABLE ax_duene ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_duene ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_duene ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_duene ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_duene ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_duene ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_duene ADD istteilvon character(16)[];
		ALTER TABLE ax_duene ADD processstep_address character varying[];
		ALTER TABLE ax_duene ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_duene ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_duene ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_duene ADD processstep_datetime character(20)[];
		ALTER TABLE ax_duene ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_duene ADD processstep_individualname character varying[];
		ALTER TABLE ax_duene ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_duene ADD processstep_organisationname character varying[];
		ALTER TABLE ax_duene ADD processstep_phone character varying[];
		ALTER TABLE ax_duene ADD processstep_positionname character varying[];
		ALTER TABLE ax_duene ADD processstep_rationale character varying[];
		ALTER TABLE ax_duene ADD processstep_role character varying[];
		ALTER TABLE ax_duene ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_duene ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_duene ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_duene ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_duene ADD statement character varying;
		ALTER TABLE ax_duene ADD traegtbeizu character(16)[];
		ALTER TABLE ax_duene ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_duene ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_duene ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_a30b3ca7_ffef_4471_ac89_8f48a3bb31bb ON ax_duene USING btree (endet);
		CREATE INDEX alkis_36c30b5b_f958_44cb_ba62_309f6f970132 ON ax_duene USING gin (hatdirektunten);
		CREATE INDEX alkis_5edf69d7_2bf5_4b7e_bfe9_55664ff16e0f ON ax_duene USING gin (istabgeleitetaus);
		CREATE INDEX alkis_819e01f3_be87_4127_a103_9e705b1d4fa4 ON ax_duene USING gin (istteilvon);
		CREATE INDEX alkis_ba54a5c0_dec4_4fcd_8642_1e2793e7109f ON ax_duene USING gin (traegtbeizu);

		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ALTER art SET NOT NULL;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ALTER beginnt SET NOT NULL;
		-- ax_einrichtungenfuerdenschiffsverkehr.kilometerangabe => kilometerangabe: character varying => double precision
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ALTER kilometerangabe TYPE double precision USING kilometerangabe::double precision;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD bezeichnung character varying;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD hatdirektunten character(16)[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD istteilvon character(16)[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_address character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_datetime character(20)[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_individualname character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_organisationname character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_phone character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_positionname character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_rationale character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_role character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD statement character varying;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD traegtbeizu character(16)[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_bf834453_e06d_41a0_bee3_00ceaf4e83d5 ON ax_einrichtungenfuerdenschiffsverkehr USING btree (endet);
		CREATE INDEX alkis_9bc5ab35_7e5a_4129_a0bd_37fd1adbbb0f ON ax_einrichtungenfuerdenschiffsverkehr USING gin (hatdirektunten);
		CREATE INDEX alkis_1989f906_6c91_4f8c_bf9d_5e58d356f514 ON ax_einrichtungenfuerdenschiffsverkehr USING gin (istabgeleitetaus);
		CREATE INDEX alkis_d485d94e_2790_4266_8822_ab26c213e62e ON ax_einrichtungenfuerdenschiffsverkehr USING gin (istteilvon);
		CREATE INDEX alkis_3c8e3463_8847_41d8_b9b5_9d7d4620f8ff ON ax_einrichtungenfuerdenschiffsverkehr USING gin (traegtbeizu);

		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ALTER art SET NOT NULL;
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ALTER beginnt SET NOT NULL;
		-- ax_einrichtunginoeffentlichenbereichen.kilometerangabe => kilometerangabe: character varying => double precision
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ALTER kilometerangabe TYPE double precision USING kilometerangabe::double precision;
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD hatdirektunten character(16)[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD istteilvon character(16)[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_address character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_datetime character(20)[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_individualname character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_organisationname character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_phone character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_positionname character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_rationale character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_role character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD statement character varying;
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD traegtbeizu character(16)[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_226537cd_6adb_4302_a125_42b3302abd77 ON ax_einrichtunginoeffentlichenbereichen USING btree (endet);
		CREATE INDEX alkis_22bb6df7_b98d_4a02_9f26_96677d9662aa ON ax_einrichtunginoeffentlichenbereichen USING gin (hatdirektunten);
		CREATE INDEX alkis_d704c80f_e841_486b_994b_6c6f5f9b5427 ON ax_einrichtunginoeffentlichenbereichen USING gin (istabgeleitetaus);
		CREATE INDEX alkis_941168c8_8d32_42a9_ba5b_24460a676dd6 ON ax_einrichtunginoeffentlichenbereichen USING gin (istteilvon);
		CREATE INDEX alkis_c323cc57_005e_4fff_beee_607e0fe5a6d0 ON ax_einrichtunginoeffentlichenbereichen USING gin (traegtbeizu);

		ALTER TABLE ax_felsenfelsblockfelsnadel ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD bezeichnung character varying;
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD hatdirektunten character(16)[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD istteilvon character(16)[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD objekthoehe double precision;
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_address character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_datetime character(20)[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_individualname character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_organisationname character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_phone character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_positionname character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_rationale character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_role character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD statement character varying;
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD traegtbeizu character(16)[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e6d6932a_8fca_4c45_bc9f_dfd853945cbc ON ax_felsenfelsblockfelsnadel USING btree (endet);
		CREATE INDEX alkis_251b30b0_7926_42d6_b154_9cb67fef3dfc ON ax_felsenfelsblockfelsnadel USING gin (hatdirektunten);
		CREATE INDEX alkis_8e8e4602_4168_4bb3_882a_d9f33430af9b ON ax_felsenfelsblockfelsnadel USING gin (istabgeleitetaus);
		CREATE INDEX alkis_86d6c488_657a_4893_9209_819b92673229 ON ax_felsenfelsblockfelsnadel USING gin (istteilvon);
		CREATE INDEX alkis_d269714c_448b_4c16_9702_a4b3541d7150 ON ax_felsenfelsblockfelsnadel USING gin (traegtbeizu);

		ALTER TABLE ax_firstlinie RENAME art TO zeigtaufexternes_art;
		-- ax_firstlinie.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_firstlinie ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_firstlinie ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_firstlinie RENAME uri TO zeigtaufexternes_uri;
		-- ax_firstlinie.uri => zeigtaufexternes_uri: character varying => character varying[]
		ALTER TABLE ax_firstlinie ALTER zeigtaufexternes_uri TYPE character varying[] USING CASE WHEN zeigtaufexternes_uri IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_uri] END;
		-- ax_firstlinie.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_firstlinie DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_firstlinie RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_firstlinie','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_firstlinie SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_firstlinie DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_firstlinie_wkb_geometry_idx ON ax_firstlinie USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_firstlinie ADD hatdirektunten character(16)[];
		ALTER TABLE ax_firstlinie ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_firstlinie ADD istteilvon character(16)[];
		ALTER TABLE ax_firstlinie ADD traegtbeizu character(16)[];
		ALTER TABLE ax_firstlinie ADD zeigtaufexternes_name character varying[];
		CREATE INDEX alkis_a81a3d7e_ffc8_473a_9782_2c4aad862225 ON ax_firstlinie USING btree (endet);
		CREATE INDEX alkis_68ecdb08_6e43_4193_ad1f_e9c2b9d0a56b ON ax_firstlinie USING gin (hatdirektunten);
		CREATE INDEX alkis_22c7fc14_570b_4555_b321_8ffbd5765b8f ON ax_firstlinie USING gin (istabgeleitetaus);
		CREATE INDEX alkis_1c90850d_6c1a_4387_bafe_9dff7f00a6dc ON ax_firstlinie USING gin (istteilvon);
		CREATE INDEX alkis_cc53cd4a_b12c_469b_b749_4828140ec9a8 ON ax_firstlinie USING gin (traegtbeizu);

		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD istteilvon character(16)[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_address character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_individualname character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_phone character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_positionname character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_rationale character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_role character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD statement character varying;
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_ab792357_45a5_41a1_a434_377f600ba902 ON ax_flaechebesondererfunktionalerpraegung USING btree (endet);
		CREATE INDEX alkis_c757afa3_2915_409f_a4cf_09036cf42af7 ON ax_flaechebesondererfunktionalerpraegung USING gin (hatdirektunten);
		CREATE INDEX alkis_5532c029_24fc_4d92_8bc4_832f407dcb1e ON ax_flaechebesondererfunktionalerpraegung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_862beefa_6132_4fd3_b1a9_5d9079b029e2 ON ax_flaechebesondererfunktionalerpraegung USING gin (istteilvon);
		CREATE INDEX alkis_d85d7526_d456_45db_84bb_d5034c7da23f ON ax_flaechebesondererfunktionalerpraegung USING gin (traegtbeizu);

		ALTER TABLE ax_flaechegemischternutzung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_flaechegemischternutzung ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_flaechegemischternutzung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_flaechegemischternutzung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_flaechegemischternutzung ADD istteilvon character(16)[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_address character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_individualname character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_phone character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_positionname character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_rationale character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_role character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD statement character varying;
		ALTER TABLE ax_flaechegemischternutzung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_flaechegemischternutzung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_flaechegemischternutzung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_676e630d_d2fa_4842_903d_18204789903e ON ax_flaechegemischternutzung USING btree (endet);
		CREATE INDEX alkis_cd643cb6_5c46_40c2_92a8_76aeb7b8de55 ON ax_flaechegemischternutzung USING gin (hatdirektunten);
		CREATE INDEX alkis_27ab6964_0eba_4dec_b6a9_aa869dd9c3cb ON ax_flaechegemischternutzung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_4764023d_223e_47fd_a00b_a9f32ee11223 ON ax_flaechegemischternutzung USING gin (istteilvon);
		CREATE INDEX alkis_df5d6f81_9fcf_4f69_ad26_bea5e2c10866 ON ax_flaechegemischternutzung USING gin (traegtbeizu);

		ALTER TABLE ax_fliessgewaesser ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_fliessgewaesser RENAME name TO zeigtaufexternes_name;
		-- ax_fliessgewaesser.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_fliessgewaesser ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_fliessgewaesser ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_fliessgewaesser ADD gemeinde character varying;
		ALTER TABLE ax_fliessgewaesser ADD hatdirektunten character(16)[];
		ALTER TABLE ax_fliessgewaesser ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_fliessgewaesser ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_fliessgewaesser ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_fliessgewaesser ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_fliessgewaesser ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_fliessgewaesser ADD hydrologischesmerkmal integer;
		ALTER TABLE ax_fliessgewaesser ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_fliessgewaesser ADD istteilvon character(16)[];
		ALTER TABLE ax_fliessgewaesser ADD kreis character varying;
		ALTER TABLE ax_fliessgewaesser ADD lage character varying;
		ALTER TABLE ax_fliessgewaesser ADD land character varying;
		ALTER TABLE ax_fliessgewaesser ADD processstep_address character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_datetime character(20)[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_individualname character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_organisationname character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_phone character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_positionname character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_rationale character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_role character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_fliessgewaesser ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_fliessgewaesser ADD regierungsbezirk character varying;
		ALTER TABLE ax_fliessgewaesser ADD statement character varying;
		ALTER TABLE ax_fliessgewaesser ADD traegtbeizu character(16)[];
		ALTER TABLE ax_fliessgewaesser ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_fliessgewaesser ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_bd2f3148_e944_45e3_8b41_dc94fd3e3b39 ON ax_fliessgewaesser USING btree (endet);
		CREATE INDEX alkis_41aacf9f_f09e_4f28_bc4b_fb5fd3e05fa9 ON ax_fliessgewaesser USING gin (hatdirektunten);
		CREATE INDEX alkis_7340a489_10e6_4e54_bc69_ec0663c3f0e6 ON ax_fliessgewaesser USING gin (istabgeleitetaus);
		CREATE INDEX alkis_325f3576_e2c7_41f5_8dad_4ddd2f547ad9 ON ax_fliessgewaesser USING gin (istteilvon);
		CREATE INDEX alkis_6ee4a06a_f55f_4ba2_9708_c3cebeae808e ON ax_fliessgewaesser USING gin (traegtbeizu);

		ALTER TABLE ax_flugverkehr ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_flugverkehr RENAME name TO zeigtaufexternes_name;
		-- ax_flugverkehr.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_flugverkehr ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_flugverkehr ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_flugverkehr ADD gemeinde character varying;
		ALTER TABLE ax_flugverkehr ADD hatdirektunten character(16)[];
		ALTER TABLE ax_flugverkehr ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_flugverkehr ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_flugverkehr ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_flugverkehr ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_flugverkehr ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_flugverkehr ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_flugverkehr ADD istteilvon character(16)[];
		ALTER TABLE ax_flugverkehr ADD kreis character varying;
		ALTER TABLE ax_flugverkehr ADD lage character varying;
		ALTER TABLE ax_flugverkehr ADD land character varying;
		ALTER TABLE ax_flugverkehr ADD processstep_address character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_datetime character(20)[];
		ALTER TABLE ax_flugverkehr ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_individualname character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_organisationname character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_phone character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_positionname character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_rationale character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_role character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_flugverkehr ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_flugverkehr ADD regierungsbezirk character varying;
		ALTER TABLE ax_flugverkehr ADD statement character varying;
		ALTER TABLE ax_flugverkehr ADD traegtbeizu character(16)[];
		ALTER TABLE ax_flugverkehr ADD unverschluesselt character varying;
		ALTER TABLE ax_flugverkehr ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_flugverkehr ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_525ef6bf_aa47_4463_a688_22688a1c4cad ON ax_flugverkehr USING btree (endet);
		CREATE INDEX alkis_33398a2a_863e_4a7c_ab08_e0dbb0da76d1 ON ax_flugverkehr USING gin (hatdirektunten);
		CREATE INDEX alkis_d78a37c4_b5d4_4363_aa0d_697c334d77b2 ON ax_flugverkehr USING gin (istabgeleitetaus);
		CREATE INDEX alkis_65a6e0f1_03d2_42b4_bde4_0920125c428a ON ax_flugverkehr USING gin (istteilvon);
		CREATE INDEX alkis_34c58017_d2d9_475d_901b_79a567a2159f ON ax_flugverkehr USING gin (traegtbeizu);

		ALTER TABLE ax_flugverkehrsanlage ALTER art SET NOT NULL;
		ALTER TABLE ax_flugverkehrsanlage ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_flugverkehrsanlage ADD bezeichnung character varying;
		ALTER TABLE ax_flugverkehrsanlage ADD breitedesobjekts double precision;
		ALTER TABLE ax_flugverkehrsanlage ADD hatdirektunten character(16)[];
		ALTER TABLE ax_flugverkehrsanlage ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_flugverkehrsanlage ADD istteilvon character(16)[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_address character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_datetime character(20)[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_individualname character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_organisationname character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_phone character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_positionname character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_rationale character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_role character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD statement character varying;
		ALTER TABLE ax_flugverkehrsanlage ADD traegtbeizu character(16)[];
		ALTER TABLE ax_flugverkehrsanlage ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e42a4d9e_2067_43e8_b06d_6e27bd5d1015 ON ax_flugverkehrsanlage USING btree (endet);
		CREATE INDEX alkis_17fb735c_1f0a_4070_8d59_97e3ae529c67 ON ax_flugverkehrsanlage USING gin (hatdirektunten);
		CREATE INDEX alkis_04b4748f_57ca_4fe4_9971_20c714b444bb ON ax_flugverkehrsanlage USING gin (istabgeleitetaus);
		CREATE INDEX alkis_0b881eae_9d3f_4a38_884b_c85652d95d60 ON ax_flugverkehrsanlage USING gin (istteilvon);
		CREATE INDEX alkis_81881d87_9a91_4e81_8746_9325dbf1e361 ON ax_flugverkehrsanlage USING gin (traegtbeizu);

		PERFORM alkis_dropobject('v_eigentuemer');
		PERFORM alkis_dropobject('v_haeuser');
		PERFORM alkis_dropobject('ax_flurstueck_flsnr');
		PERFORM alkis_dropobject('alkis_flsnrk');
		PERFORM alkis_dropobject('alkis_flsnr');

		ALTER TABLE ax_flurstueck ALTER amtlicheflaeche SET NOT NULL;
		ALTER TABLE ax_flurstueck ALTER beginnt SET NOT NULL;
		-- ax_flurstueck.flurstueckskennzeichen => flurstueckskennzeichen: character(20) => character varying
		ALTER TABLE ax_flurstueck ALTER flurstueckskennzeichen TYPE character varying;
		ALTER TABLE ax_flurstueck ALTER flurstueckskennzeichen SET NOT NULL;
		ALTER TABLE ax_flurstueck ALTER gemarkungsnummer SET NOT NULL;
		ALTER TABLE ax_flurstueck RENAME gemeinde TO gemeindezugehoerigkeit_gemeinde;
		ALTER TABLE ax_flurstueck ALTER istgebucht SET NOT NULL;
		ALTER TABLE ax_flurstueck RENAME kreis TO gemeindezugehoerigkeit_kreis;
		ALTER TABLE ax_flurstueck ALTER land SET NOT NULL;
		ALTER TABLE ax_flurstueck RENAME name TO zeigtaufexternes_name;
		ALTER TABLE ax_flurstueck RENAME regierungsbezirk TO gemeindezugehoerigkeit_regierungsbezirk;
		ALTER TABLE ax_flurstueck RENAME stelle TO zustaendigestelle_stelle;
		-- ax_flurstueck.stelle => zustaendigestelle_stelle: character varying => character varying[]
		ALTER TABLE ax_flurstueck ALTER zustaendigestelle_stelle TYPE character varying[] USING CASE WHEN zustaendigestelle_stelle IS NULL THEN NULL ELSE ARRAY[zustaendigestelle_stelle] END;
		-- ax_flurstueck.zaehler => zaehler: integer => character varying
		ALTER TABLE ax_flurstueck ALTER zaehler TYPE character varying USING zaehler::varchar;
		ALTER TABLE ax_flurstueck ALTER zaehler SET NOT NULL;
		-- ax_flurstueck.zeitpunktderentstehung => zeitpunktderentstehung: character varying => date
		ALTER TABLE ax_flurstueck ALTER zeitpunktderentstehung TYPE date USING to_date(zeitpunktderentstehung, 'YYYY-mm-dd');
		ALTER TABLE ax_flurstueck ADD angabenzumabschnittstelle character varying[];
		ALTER TABLE ax_flurstueck ADD gemeindezugehoerigkeit_gemeindeteil character varying;
		ALTER TABLE ax_flurstueck ADD gemeindezugehoerigkeit_land character varying;
		ALTER TABLE ax_flurstueck ADD hatdirektunten character(16)[];
		ALTER TABLE ax_flurstueck ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_flurstueck ADD istteilvon character(16)[];
		PERFORM AddGeometryColumn('ax_flurstueck','objektkoordinaten',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'POINT',2);
		ALTER TABLE ax_flurstueck ADD traegtbeizu character(16)[];
		ALTER TABLE ax_flurstueck ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_flurstueck ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_flurstueck ADD zustaendigestelle_land character varying[];
		CREATE INDEX alkis_27e07827_6d01_43f4_ad5f_8dea320a2740 ON ax_flurstueck USING btree (endet);
		CREATE INDEX alkis_cb85f565_7819_42bb_8803_5bbafa698aee ON ax_flurstueck USING gin (hatdirektunten);
		CREATE INDEX alkis_1f28a686_b0cc_4e60_a4ce_bbc792087c27 ON ax_flurstueck USING gin (istabgeleitetaus);
		CREATE INDEX alkis_91dd21ec_509f_4b3d_92ae_ba53318da7b7 ON ax_flurstueck USING gin (istteilvon);
		CREATE INDEX alkis_69f6e6f3_3ff8_4001_b2df_b3e0e9b146be ON ax_flurstueck USING gin (traegtbeizu);
		CREATE INDEX alkis_b4a717b0_cbce_4dfe_8665_c995ceaca879 ON ax_flurstueck USING gist (objektkoordinaten);

		ALTER TABLE ax_forstrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_forstrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_forstrecht ADD bezeichnung character varying;
		ALTER TABLE ax_forstrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_forstrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_forstrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_forstrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_forstrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_forstrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_forstrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_forstrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_forstrecht ADD processstep_address character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_forstrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_role character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_forstrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_forstrecht ADD statement character varying;
		ALTER TABLE ax_forstrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_forstrecht ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_forstrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_forstrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_ad777bd3_c408_4486_a5c1_20f8a1860a73 ON ax_forstrecht USING btree (endet);
		CREATE INDEX alkis_9d75f975_be8e_4153_8a60_127223f35dc8 ON ax_forstrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_34647045_7b35_4045_b7ec_bb398e15a775 ON ax_forstrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_d29c4644_2af7_4753_96df_f684e7611417 ON ax_forstrecht USING gin (istteilvon);
		CREATE INDEX alkis_61b1563b_d105_456f_9543_7045bc073e70 ON ax_forstrecht USING gin (traegtbeizu);

		ALTER TABLE ax_fortfuehrungsfall ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_fortfuehrungsfall ALTER fortfuehrungsfallnummer SET NOT NULL;
		-- ax_fortfuehrungsfall.laufendenummer => laufendenummer: integer => character varying
		ALTER TABLE ax_fortfuehrungsfall ALTER laufendenummer TYPE character varying USING laufendenummer::varchar;
		-- ax_fortfuehrungsfall.ueberschriftimfortfuehrungsnachweis => ueberschriftimfortfuehrungsnachweis: integer[] => character varying[]
		ALTER TABLE ax_fortfuehrungsfall RENAME ueberschriftimfortfuehrungsnachweis TO ueberschriftimfortfuehrungsnachweis_;
		ALTER TABLE ax_fortfuehrungsfall ADD ueberschriftimfortfuehrungsnachweis character varying[];
		UPDATE ax_fortfuehrungsfall SET ueberschriftimfortfuehrungsnachweis=ARRAY(SELECT unnest(ueberschriftimfortfuehrungsnachweis_)::text);
		ALTER TABLE ax_fortfuehrungsfall DROP ueberschriftimfortfuehrungsnachweis_;
		ALTER TABLE ax_fortfuehrungsfall ALTER ueberschriftimfortfuehrungsnachweis SET NOT NULL;
		ALTER TABLE ax_fortfuehrungsfall RENAME uri TO zeigtaufexternes_uri;
		-- ax_fortfuehrungsfall.uri => zeigtaufexternes_uri: character varying => character varying[]
		ALTER TABLE ax_fortfuehrungsfall ALTER zeigtaufexternes_uri TYPE character varying[] USING CASE WHEN zeigtaufexternes_uri IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_uri] END;
		-- ax_fortfuehrungsfall.zeigtaufaltesflurstueck => zeigtaufaltesflurstueck: character(20)[] => character varying[]
		ALTER TABLE ax_fortfuehrungsfall ALTER zeigtaufaltesflurstueck TYPE character varying[];
		-- ax_fortfuehrungsfall.zeigtaufneuesflurstueck => zeigtaufneuesflurstueck: character(20)[] => character varying[]
		ALTER TABLE ax_fortfuehrungsfall ALTER zeigtaufneuesflurstueck TYPE character varying[];
		ALTER TABLE ax_fortfuehrungsfall ADD anmerkungfuerdennotar character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD dienststellenlogo_uri character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD enthaeltewp_uri character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD fortfuehrungsmitteilunganeigentuemerantragsteller character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD istteilvon character(16)[];
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_artderausgabe character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_datumderausgabe character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_dienststelle character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_plzort character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_strassehausnummer character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_telefon character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_uri character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_fortfuehrungsfall ADD zeigtaufexternes_name character varying[];
		CREATE INDEX alkis_cbbdd51c_a38c_4d94_af5c_6cbff266a691 ON ax_fortfuehrungsfall USING btree (endet);
		CREATE INDEX alkis_d6e173d1_f1e0_46a4_9673_d5e695c4d2c2 ON ax_fortfuehrungsfall USING btree (gml_id, beginnt);
		CREATE INDEX alkis_ae04c997_ccd8_4671_ba12_846a59be4cfb ON ax_fortfuehrungsfall USING gin (istteilvon);

		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER beginnt SET NOT NULL;
		-- ax_fortfuehrungsnachweisdeckblatt.beziehtsichauf => beziehtsichauf: character(16) => character(16)[]
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER beziehtsichauf TYPE character(16)[] USING CASE WHEN beziehtsichauf IS NULL THEN NULL ELSE ARRAY[beziehtsichauf] END;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER beziehtsichauf SET NOT NULL;
		-- ax_fortfuehrungsnachweisdeckblatt.erstelltam => erstelltam: character varying => date
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER erstelltam TYPE date USING to_date(erstelltam, 'YYYY-mm-dd');
		-- ax_fortfuehrungsnachweisdeckblatt.fortfuehrungsentscheidungam => fortfuehrungsentscheidungam: character varying => date
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER fortfuehrungsentscheidungam TYPE date USING to_date(fortfuehrungsentscheidungam, 'YYYY-mm-dd');
		-- ax_fortfuehrungsnachweisdeckblatt.laufendenummer => laufendenummer: integer => character varying
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER laufendenummer TYPE character varying USING laufendenummer::varchar;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER laufendenummer SET NOT NULL;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER titel SET NOT NULL;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt RENAME uri TO zeigtaufexternes_uri;
		-- ax_fortfuehrungsnachweisdeckblatt.uri => zeigtaufexternes_uri: character varying => character varying[]
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ALTER zeigtaufexternes_uri TYPE character varying[] USING CASE WHEN zeigtaufexternes_uri IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_uri] END;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD artderausgabe character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD auszugfuer_adressat character varying[];
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD auszugfuer_art integer[];
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD auszugfuer_datum date[];
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD bekanntgabeanbeteiligteam date;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD datumderausgabe character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD dienststelle character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD dienststellenlogo_uri character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD eignungspruefungam date;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD eignungspruefungvon character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD enthaeltewp_uri character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD erstelltvon character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD fnnummer_gemarkungsnummer character varying NOT NULL;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD fnnummer_land character varying NOT NULL;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD fortfuehrungsmitteilungenerzeugt date;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD grundbuchmitteilungfuerfinanzamt character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD ingemarkung_gemarkungsnummer character varying NOT NULL;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD ingemarkung_land character varying NOT NULL;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD istteilvon character(16)[];
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD plzort character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD strassehausnummer character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD telefon character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD verwaltungsaktjn character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD zeigtaufexternes_name character varying[];
		CREATE INDEX alkis_89c5800e_434d_4dd0_b6ec_e04dbca6ffc4 ON ax_fortfuehrungsnachweisdeckblatt USING btree (endet);
		CREATE INDEX alkis_28654c37_5796_479c_97cc_cecce4fcd9cd ON ax_fortfuehrungsnachweisdeckblatt USING btree (gml_id, beginnt);
		CREATE INDEX alkis_4d2d1453_d6fe_4660_8756_808594eee875 ON ax_fortfuehrungsnachweisdeckblatt USING gin (beziehtsichauf);
		CREATE INDEX alkis_d73d151c_1e36_4692_8eb2_25426dc6b62b ON ax_fortfuehrungsnachweisdeckblatt USING gin (istteilvon);

		ALTER TABLE ax_friedhof ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_friedhof ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_friedhof ADD hatdirektunten character(16)[];
		ALTER TABLE ax_friedhof ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_friedhof ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_friedhof ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_friedhof ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_friedhof ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_friedhof ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_friedhof ADD istteilvon character(16)[];
		ALTER TABLE ax_friedhof ADD processstep_address character varying[];
		ALTER TABLE ax_friedhof ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_friedhof ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_friedhof ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_friedhof ADD processstep_datetime character(20)[];
		ALTER TABLE ax_friedhof ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_friedhof ADD processstep_individualname character varying[];
		ALTER TABLE ax_friedhof ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_friedhof ADD processstep_organisationname character varying[];
		ALTER TABLE ax_friedhof ADD processstep_phone character varying[];
		ALTER TABLE ax_friedhof ADD processstep_positionname character varying[];
		ALTER TABLE ax_friedhof ADD processstep_rationale character varying[];
		ALTER TABLE ax_friedhof ADD processstep_role character varying[];
		ALTER TABLE ax_friedhof ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_friedhof ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_friedhof ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_friedhof ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_friedhof ADD statement character varying;
		ALTER TABLE ax_friedhof ADD traegtbeizu character(16)[];
		ALTER TABLE ax_friedhof ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_friedhof ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_friedhof ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4adcc6b0_3cd5_48d3_81d5_3eb0fd719420 ON ax_friedhof USING btree (endet);
		CREATE INDEX alkis_598f426c_1cd4_45b8_86bf_28cd24b9e0b9 ON ax_friedhof USING gin (hatdirektunten);
		CREATE INDEX alkis_e54a16d9_8067_4b08_bb2f_1499dc6ed30f ON ax_friedhof USING gin (istabgeleitetaus);
		CREATE INDEX alkis_f9ec9f90_3e8d_4188_aeb9_a23bc5df801d ON ax_friedhof USING gin (istteilvon);
		CREATE INDEX alkis_c775f8d9_73c1_4796_834a_0e9ed18a38f1 ON ax_friedhof USING gin (traegtbeizu);

		ALTER TABLE ax_gebaeude RENAME art TO zeigtaufexternes_art;
		-- ax_gebaeude.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_gebaeude ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_gebaeude ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gebaeude RENAME description TO processstep_ax_li_processstep_mitdatenerhebung_description;
		-- ax_gebaeude.description => processstep_ax_li_processstep_mitdatenerhebung_description: integer => character varying[]
		ALTER TABLE ax_gebaeude ALTER processstep_ax_li_processstep_mitdatenerhebung_description TYPE character varying[] USING CASE WHEN processstep_ax_li_processstep_mitdatenerhebung_description IS NULL THEN NULL ELSE ARRAY[processstep_ax_li_processstep_mitdatenerhebung_description::int] END;
		ALTER TABLE ax_gebaeude ALTER gebaeudefunktion SET NOT NULL;
		ALTER TABLE ax_gebaeude RENAME individualname TO processstep_individualname;
		-- ax_gebaeude.individualname => processstep_individualname: character varying => character varying[]
		ALTER TABLE ax_gebaeude ALTER processstep_individualname TYPE character varying[] USING CASE WHEN processstep_individualname IS NULL THEN NULL ELSE ARRAY[processstep_individualname] END;
		ALTER TABLE ax_gebaeude DROP qualitaetsangaben;
		ALTER TABLE ax_gebaeude ADD anteil integer[];
		ALTER TABLE ax_gebaeude ADD hatdirektunten character(16)[];
		ALTER TABLE ax_gebaeude ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_gebaeude ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_gebaeude ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_gebaeude ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_gebaeude ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_gebaeude ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_gebaeude ADD istteilvon character(16)[];
		ALTER TABLE ax_gebaeude ADD nutzung integer[];
		ALTER TABLE ax_gebaeude ADD processstep_address character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_datetime character(20)[];
		ALTER TABLE ax_gebaeude ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_organisationname character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_phone character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_positionname character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_rationale character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_role character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_gebaeude ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_gebaeude ADD statement character varying;
		ALTER TABLE ax_gebaeude ADD traegtbeizu character(16)[];
		ALTER TABLE ax_gebaeude ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gebaeude ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_5dd50074_eca8_47b8_ab8c_4d490829111b ON ax_gebaeude USING btree (endet);
		CREATE INDEX alkis_dd0811b0_0440_46d2_a336_7e241e3874b0 ON ax_gebaeude USING gin (hatdirektunten);
		CREATE INDEX alkis_089146da_1f80_4a11_bb93_544fda3369f2 ON ax_gebaeude USING gin (istabgeleitetaus);
		CREATE INDEX alkis_d44b9d64_4abd_4ba0_98bd_8742c88c1927 ON ax_gebaeude USING gin (istteilvon);
		CREATE INDEX alkis_c6877f2d_9c71_42c7_8892_04bc76f18c50 ON ax_gebaeude USING gin (traegtbeizu);

		ALTER TABLE ax_gebaeudeausgestaltung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gebaeudeausgestaltung ALTER darstellung SET NOT NULL;
		ALTER TABLE ax_gebaeudeausgestaltung ALTER zeigtauf SET NOT NULL;
		ALTER TABLE ax_gebaeudeausgestaltung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_gebaeudeausgestaltung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_gebaeudeausgestaltung ADD istteilvon character(16)[];
		ALTER TABLE ax_gebaeudeausgestaltung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_gebaeudeausgestaltung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gebaeudeausgestaltung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gebaeudeausgestaltung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_3c37ba21_f94a_4826_b785_4b52445cd81d ON ax_gebaeudeausgestaltung USING btree (endet);
		CREATE INDEX alkis_71b39464_2f8b_45c4_b80e_20106c1f4b95 ON ax_gebaeudeausgestaltung USING btree (zeigtauf);
		CREATE INDEX alkis_c52fd0f5_bdf4_45ba_b5a3_b86deb479890 ON ax_gebaeudeausgestaltung USING gin (hatdirektunten);
		CREATE INDEX alkis_19cb724f_ef08_4e39_b4bc_d027d31596c5 ON ax_gebaeudeausgestaltung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_5dcd38bd_7ce0_4a3d_bae6_84e5f4e1dcd7 ON ax_gebaeudeausgestaltung USING gin (istteilvon);
		CREATE INDEX alkis_cab5b3c9_6617_4771_85a6_379230be110d ON ax_gebaeudeausgestaltung USING gin (traegtbeizu);

		ALTER TABLE ax_gehoelz ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gehoelz ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_gehoelz ADD hatdirektunten character(16)[];
		ALTER TABLE ax_gehoelz ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_gehoelz ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_gehoelz ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_gehoelz ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_gehoelz ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_gehoelz ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_gehoelz ADD istteilvon character(16)[];
		ALTER TABLE ax_gehoelz ADD processstep_address character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_datetime character(20)[];
		ALTER TABLE ax_gehoelz ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_individualname character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_organisationname character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_phone character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_positionname character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_rationale character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_role character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_gehoelz ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_gehoelz ADD statement character varying;
		ALTER TABLE ax_gehoelz ADD traegtbeizu character(16)[];
		ALTER TABLE ax_gehoelz ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gehoelz ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gehoelz ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_105a4e12_0883_4d66_abad_9c23523ab26f ON ax_gehoelz USING btree (endet);
		CREATE INDEX alkis_438572db_a448_45d5_a9f1_a2c06a67de47 ON ax_gehoelz USING gin (hatdirektunten);
		CREATE INDEX alkis_2c59d705_2eea_4d69_9917_3d29748034b1 ON ax_gehoelz USING gin (istabgeleitetaus);
		CREATE INDEX alkis_12a8f628_dcdc_483a_b7ff_b5cb675e72dc ON ax_gehoelz USING gin (istteilvon);
		CREATE INDEX alkis_f60b50c7_f357_4725_9bc4_2106baed130e ON ax_gehoelz USING gin (traegtbeizu);

		ALTER TABLE ax_gelaendekante RENAME art TO zeigtaufexternes_art;
		-- ax_gelaendekante.art => zeigtaufexternes_art: integer => character varying[]
		ALTER TABLE ax_gelaendekante ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art::int] END;
		ALTER TABLE ax_gelaendekante ALTER artdergelaendekante SET NOT NULL;
		ALTER TABLE ax_gelaendekante RENAME ax_dqerfassungsmethode TO erfassung_ax_dqerfassungsmethode;
		ALTER TABLE ax_gelaendekante ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gelaendekante RENAME identifikation TO erfassung_identifikation;
		-- ax_gelaendekante.istteilvon => istteilvon: character(16) => character(16)[]
		ALTER TABLE ax_gelaendekante ALTER istteilvon TYPE character(16)[] USING CASE WHEN istteilvon IS NULL THEN NULL ELSE ARRAY[istteilvon] END;
		-- ax_gelaendekante.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_gelaendekante DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_gelaendekante RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_gelaendekante','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_gelaendekante SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_gelaendekante DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_gelaendekante_wkb_geometry_idx ON ax_gelaendekante USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_gelaendekante ADD erfassung_datetime character(20);
		ALTER TABLE ax_gelaendekante ADD hatdirektunten character(16)[];
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_datetime character(20)[];
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_evaluationmethoddescription character varying;
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_evaluationmethodtype character varying;
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_evaluationprocedure character varying;
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_measuredescription character varying;
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_measureidentification character varying;
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_nameofmeasure character varying[];
		ALTER TABLE ax_gelaendekante ADD hoehengenauigkeit_result character varying[];
		ALTER TABLE ax_gelaendekante ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_gelaendekante ADD traegtbeizu character(16)[];
		ALTER TABLE ax_gelaendekante ADD ursprung integer;
		ALTER TABLE ax_gelaendekante ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gelaendekante ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_gelaendekante' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_gelaendekante USING btree (istteilvon)';
		CREATE INDEX alkis_0db30901_776c_44b6_aedd_124f25701111 ON ax_gelaendekante USING btree (endet);
		CREATE INDEX alkis_6c7c6055_990c_4a97_82e3_16d84ef87380 ON ax_gelaendekante USING gin (hatdirektunten);
		CREATE INDEX alkis_b366adc0_4ddc_4674_bec8_8cc395e62070 ON ax_gelaendekante USING gin (istabgeleitetaus);
		CREATE INDEX alkis_0b32692d_cee9_4dbb_9964_6ece25bc33e0 ON ax_gelaendekante USING gin (istteilvon);
		CREATE INDEX alkis_8c4a4019_f040_4f7a_aef1_18a88593a626 ON ax_gelaendekante USING gin (traegtbeizu);

		ALTER TABLE ax_gemarkung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gemarkung ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_gemarkung ALTER gemarkungsnummer SET NOT NULL;
		ALTER TABLE ax_gemarkung ALTER land SET NOT NULL;
		ALTER TABLE ax_gemarkung ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_gemarkung RENAME stelle TO istamtsbezirkvon_stelle;
		-- ax_gemarkung.stelle => istamtsbezirkvon_stelle: character varying => character varying[]
		ALTER TABLE ax_gemarkung ALTER istamtsbezirkvon_stelle TYPE character varying[] USING CASE WHEN istamtsbezirkvon_stelle IS NULL THEN NULL ELSE ARRAY[istamtsbezirkvon_stelle] END;
		ALTER TABLE ax_gemarkung ADD administrativefunktion integer[];
		ALTER TABLE ax_gemarkung ADD istamtsbezirkvon_land character varying[];
		ALTER TABLE ax_gemarkung ADD istteilvon character(16)[];
		ALTER TABLE ax_gemarkung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gemarkung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gemarkung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_84241d11_8817_4ff0_8e98_e1501bf6b52e ON ax_gemarkung USING btree (endet);
		CREATE INDEX alkis_4d5d6399_579d_443b_a52d_d2432e9742f0 ON ax_gemarkung USING gin (istteilvon);

		ALTER TABLE ax_gemarkungsteilflur ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gemarkungsteilflur ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_gemarkungsteilflur DROP gehoertzu;
		-- ax_gemarkungsteilflur.gemarkung => gemarkung: integer => character varying
		ALTER TABLE ax_gemarkungsteilflur ALTER gemarkung TYPE character varying USING gemarkung::varchar;
		ALTER TABLE ax_gemarkungsteilflur ALTER gemarkung SET NOT NULL;
		-- ax_gemarkungsteilflur.gemarkungsteilflur => gemarkungsteilflur: integer => character varying
		ALTER TABLE ax_gemarkungsteilflur ALTER gemarkungsteilflur TYPE character varying USING gemarkungsteilflur::varchar;
		ALTER TABLE ax_gemarkungsteilflur ALTER gemarkungsteilflur SET NOT NULL;
		ALTER TABLE ax_gemarkungsteilflur ALTER land SET NOT NULL;
		ALTER TABLE ax_gemarkungsteilflur ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_gemarkungsteilflur ADD administrativefunktion integer[];
		ALTER TABLE ax_gemarkungsteilflur ADD gehoertzu_land character varying[];
		ALTER TABLE ax_gemarkungsteilflur ADD gehoertzu_stelle character varying[];
		ALTER TABLE ax_gemarkungsteilflur ADD istteilvon character(16)[];
		ALTER TABLE ax_gemarkungsteilflur ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gemarkungsteilflur ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gemarkungsteilflur ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_f1b119b8_e7fc_40c5_8d7d_0c1cf2187a20 ON ax_gemarkungsteilflur USING btree (endet);
		CREATE INDEX alkis_4c10aa55_816e_451f_a803_b2a2b2789ddf ON ax_gemarkungsteilflur USING gin (istteilvon);

		ALTER TABLE ax_gemeinde ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gemeinde ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_gemeinde ALTER gemeinde SET NOT NULL;
		ALTER TABLE ax_gemeinde DROP istamtsbezirkvon;
		ALTER TABLE ax_gemeinde ALTER kreis SET NOT NULL;
		ALTER TABLE ax_gemeinde ALTER land SET NOT NULL;
		ALTER TABLE ax_gemeinde ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_gemeinde RENAME stelle TO istamtsbezirkvon_stelle;
		-- ax_gemeinde.stelle => istamtsbezirkvon_stelle: character varying => character varying[]
		ALTER TABLE ax_gemeinde ALTER istamtsbezirkvon_stelle TYPE character varying[] USING CASE WHEN istamtsbezirkvon_stelle IS NULL THEN NULL ELSE ARRAY[istamtsbezirkvon_stelle] END;
		ALTER TABLE ax_gemeinde ADD administrativefunktion integer[];
		ALTER TABLE ax_gemeinde ADD gemeindeteil character varying;
		ALTER TABLE ax_gemeinde ADD istamtsbezirkvon_land character varying[];
		ALTER TABLE ax_gemeinde ADD istteilvon character(16)[];
		ALTER TABLE ax_gemeinde ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gemeinde ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gemeinde ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_f3dfa217_6d68_4070_8ee0_3da328cda109 ON ax_gemeinde USING btree (endet);
		CREATE INDEX alkis_b01ea41d_e68d_4918_8270_686bc9f72f7c ON ax_gemeinde USING gin (istteilvon);

		-- ax_gemeindeteil.administrativefunktion => administrativefunktion: integer => integer[]
		ALTER TABLE ax_gemeindeteil ALTER administrativefunktion TYPE integer[] USING CASE WHEN administrativefunktion IS NULL THEN NULL ELSE ARRAY[administrativefunktion] END;
		ALTER TABLE ax_gemeindeteil ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gemeindeteil ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_gemeindeteil ALTER gemeinde SET NOT NULL;
		-- ax_gemeindeteil.gemeindeteil => gemeindeteil: integer => character varying
		ALTER TABLE ax_gemeindeteil ALTER gemeindeteil TYPE character varying USING gemeindeteil::varchar;
		ALTER TABLE ax_gemeindeteil ALTER kreis SET NOT NULL;
		ALTER TABLE ax_gemeindeteil ALTER land SET NOT NULL;
		ALTER TABLE ax_gemeindeteil ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_gemeindeteil ADD istteilvon character(16)[];
		ALTER TABLE ax_gemeindeteil ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gemeindeteil ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gemeindeteil ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2806019d_869e_4b2c_a4d5_b7240d6922a3 ON ax_gemeindeteil USING btree (endet);
		CREATE INDEX alkis_746bdc1a_bafc_4b0e_85cf_75121a9513e3 ON ax_gemeindeteil USING gin (istteilvon);

		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER gemeinde SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER hatauch SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER hausnummer SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER kreis SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER land SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER ortsteil SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER qualitaetsangaben SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER regierungsbezirk SET NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER strassenschluessel SET NOT NULL;
		-- ax_georeferenziertegebaeudeadresse.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_georeferenziertegebaeudeadresse DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_georeferenziertegebaeudeadresse RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_georeferenziertegebaeudeadresse','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_georeferenziertegebaeudeadresse SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_georeferenziertegebaeudeadresse DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_georeferenziertegebaeudeadresse_wkb_geometry_idx ON ax_georeferenziertegebaeudeadresse USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD datensatznummer character varying;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD hatdirektunten character(16)[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD istteilvon character(16)[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD traegtbeizu character(16)[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_6a7da82f_53be_4bcf_9040_d37b21f682ca ON ax_georeferenziertegebaeudeadresse USING btree (endet);
		CREATE INDEX alkis_4f405a2b_46f7_472f_920f_5dc3e48fa01a ON ax_georeferenziertegebaeudeadresse USING btree (hatauch);
		CREATE INDEX alkis_4d4fb4d2_c8eb_42fd_bd33_f2f2a5e88c3b ON ax_georeferenziertegebaeudeadresse USING gin (hatdirektunten);
		CREATE INDEX alkis_e9b60326_e972_49fd_828a_e9f0e2dee591 ON ax_georeferenziertegebaeudeadresse USING gin (istabgeleitetaus);
		CREATE INDEX alkis_f193fa1d_d0be_47c7_a046_3caa5b60b34f ON ax_georeferenziertegebaeudeadresse USING gin (istteilvon);
		CREATE INDEX alkis_4e38af04_b6cb_45f2_8d64_e5953f776ee8 ON ax_georeferenziertegebaeudeadresse USING gin (traegtbeizu);

		ALTER TABLE ax_gewaessermerkmal ALTER art SET NOT NULL;
		ALTER TABLE ax_gewaessermerkmal ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gewaessermerkmal ADD bezeichnung character varying;
		ALTER TABLE ax_gewaessermerkmal ADD hatdirektunten character(16)[];
		ALTER TABLE ax_gewaessermerkmal ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD hydrologischesmerkmal integer;
		ALTER TABLE ax_gewaessermerkmal ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_gewaessermerkmal ADD istteilvon character(16)[];
		ALTER TABLE ax_gewaessermerkmal ADD objekthoehe double precision;
		ALTER TABLE ax_gewaessermerkmal ADD processstep_address character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_datetime character(20)[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_individualname character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_organisationname character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_phone character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_positionname character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_rationale character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_role character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD statement character varying;
		ALTER TABLE ax_gewaessermerkmal ADD traegtbeizu character(16)[];
		ALTER TABLE ax_gewaessermerkmal ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_0f8b3b81_6117_4684_95c9_a8659129edf5 ON ax_gewaessermerkmal USING btree (endet);
		CREATE INDEX alkis_2bcbc336_3e89_4196_9301_e1545e4805eb ON ax_gewaessermerkmal USING gin (hatdirektunten);
		CREATE INDEX alkis_503f4fd4_adcd_4b98_a09e_0100c99bcc6c ON ax_gewaessermerkmal USING gin (istabgeleitetaus);
		CREATE INDEX alkis_054f22db_8fe1_4714_9129_29f86aba6cd5 ON ax_gewaessermerkmal USING gin (istteilvon);
		CREATE INDEX alkis_67557914_4355_4bbe_a578_b5e2ba5ec40b ON ax_gewaessermerkmal USING gin (traegtbeizu);

		-- ax_gleis.bahnkategorie => bahnkategorie: integer => integer[]
		ALTER TABLE ax_gleis ALTER bahnkategorie TYPE integer[] USING CASE WHEN bahnkategorie IS NULL THEN NULL ELSE ARRAY[bahnkategorie] END;
		ALTER TABLE ax_gleis ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_gleis ADD hatdirektunten character(16)[];
		ALTER TABLE ax_gleis ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_gleis ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_gleis ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_gleis ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_gleis ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_gleis ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_gleis ADD istteilvon character(16)[];
		ALTER TABLE ax_gleis ADD processstep_address character varying[];
		ALTER TABLE ax_gleis ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_gleis ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_gleis ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_gleis ADD processstep_datetime character(20)[];
		ALTER TABLE ax_gleis ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_gleis ADD processstep_individualname character varying[];
		ALTER TABLE ax_gleis ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_gleis ADD processstep_organisationname character varying[];
		ALTER TABLE ax_gleis ADD processstep_phone character varying[];
		ALTER TABLE ax_gleis ADD processstep_positionname character varying[];
		ALTER TABLE ax_gleis ADD processstep_rationale character varying[];
		ALTER TABLE ax_gleis ADD processstep_role character varying[];
		ALTER TABLE ax_gleis ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_gleis ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_gleis ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_gleis ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_gleis ADD statement character varying;
		ALTER TABLE ax_gleis ADD traegtbeizu character(16)[];
		ALTER TABLE ax_gleis ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_gleis ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_gleis ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_df69597d_b2a8_417b_ac8d_8c71461dca45 ON ax_gleis USING btree (endet);
		CREATE INDEX alkis_a0ea9a4f_a0e0_49ec_8b04_002ed5edb8a1 ON ax_gleis USING gin (hatdirektunten);
		CREATE INDEX alkis_44120a9d_9fbe_4fbd_ba8a_c0988a84c9e4 ON ax_gleis USING gin (istabgeleitetaus);
		CREATE INDEX alkis_69b4a829_34f0_4fb7_a0fe_c3dcb14c5559 ON ax_gleis USING gin (istteilvon);
		CREATE INDEX alkis_9a270b76_b72c_41bf_bd98_440f92d9eab8 ON ax_gleis USING gin (traegtbeizu);

		ALTER TABLE ax_grablochderbodenschaetzung RENAME art TO zeigtaufexternes_art;
		-- ax_grablochderbodenschaetzung.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_grablochderbodenschaetzung ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		UPDATE ax_grablochderbodenschaetzung SET bedeutung=ARRAY[]::integer[] WHERE bedeutung IS NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ALTER bedeutung SET NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung RENAME name TO zeigtaufexternes_name;
		-- ax_grablochderbodenschaetzung.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_grablochderbodenschaetzung ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		UPDATE ax_grablochderbodenschaetzung SET nummerdesgrablochs='' WHERE nummerdesgrablochs='';
		ALTER TABLE ax_grablochderbodenschaetzung ALTER nummerdesgrablochs SET NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung RENAME nummerierungsbezirk TO kennziffer_nummerierungsbezirk;
		-- ax_grablochderbodenschaetzung.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_grablochderbodenschaetzung DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_grablochderbodenschaetzung RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_grablochderbodenschaetzung','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_grablochderbodenschaetzung SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_grablochderbodenschaetzung DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_grablochderbodenschaetzung_wkb_geometry_idx ON ax_grablochderbodenschaetzung USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_grablochderbodenschaetzung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD ingemarkung_gemarkungsnummer character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD ingemarkung_land character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD istteilvon character(16)[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD kennziffer_gemarkungsnummer character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD kennziffer_land character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_address character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_individualname character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_phone character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_positionname character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_rationale character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_role character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD statement character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_5b2b6142_7abb_48ff_8d58_106393cd4241 ON ax_grablochderbodenschaetzung USING btree (endet);
		CREATE INDEX alkis_652a92aa_edb7_4f76_9c64_9dd2b45afb06 ON ax_grablochderbodenschaetzung USING btree (gehoertzu);
		CREATE INDEX alkis_7359ddc6_6160_479b_8bb0_b40ccf6d2b57 ON ax_grablochderbodenschaetzung USING gin (hatdirektunten);
		CREATE INDEX alkis_e9f0ba2b_4842_4ea3_817b_f01b61400c0d ON ax_grablochderbodenschaetzung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_c076f5f0_4cbb_4419_b14b_e58c568b20f2 ON ax_grablochderbodenschaetzung USING gin (istteilvon);
		CREATE INDEX alkis_170ea0ce_94ba_49a1_bc50_4b861c4e2648 ON ax_grablochderbodenschaetzung USING gin (traegtbeizu);

		ALTER TABLE ax_grenzpunkt ALTER abmarkung_marke SET NOT NULL;
		ALTER TABLE ax_grenzpunkt RENAME art TO zeigtaufexternes_art;
		-- ax_grenzpunkt.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_grenzpunkt ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_grenzpunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_grenzpunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_grenzpunkt RENAME name TO zeigtaufexternes_name;
		ALTER TABLE ax_grenzpunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_grenzpunkt ADD ausgesetzteabmarkung_land character varying;
		ALTER TABLE ax_grenzpunkt ADD ausgesetzteabmarkung_stelle character varying;
		ALTER TABLE ax_grenzpunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_grenzpunkt ADD beziehtsichaufsfp character(16)[];
		ALTER TABLE ax_grenzpunkt ADD gehoertzulfp character(16)[];
		ALTER TABLE ax_grenzpunkt ADD gruendederausgesetztenabmarkung integer;
		ALTER TABLE ax_grenzpunkt ADD horizontfreiheit integer;
		ALTER TABLE ax_grenzpunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_grenzpunkt ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_grenzpunkt ADD zwischenmarke character varying;
		CREATE INDEX alkis_a789f1d1_b7f0_4316_bbf7_124ee0b167ba ON ax_grenzpunkt USING btree (endet);
		CREATE INDEX alkis_8d8c9e94_83ef_4b69_b64e_3fdf276e891a ON ax_grenzpunkt USING gin (bestehtaus);
		CREATE INDEX alkis_76ca051f_269c_48a0_96d9_5cea5efaa5ad ON ax_grenzpunkt USING gin (beziehtsichaufsfp);
		CREATE INDEX alkis_f2d59f31_e2ea_4366_b531_d63097656111 ON ax_grenzpunkt USING gin (gehoertzulfp);
		CREATE INDEX alkis_4d2c815c_eec3_42ba_8029_10da23d51e73 ON ax_grenzpunkt USING gin (istteilvon);

		ALTER TABLE ax_hafenbecken ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_hafenbecken RENAME name TO zeigtaufexternes_name;
		-- ax_hafenbecken.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_hafenbecken ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_hafenbecken ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_hafenbecken ADD gemeinde character varying;
		ALTER TABLE ax_hafenbecken ADD hatdirektunten character(16)[];
		ALTER TABLE ax_hafenbecken ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_hafenbecken ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_hafenbecken ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_hafenbecken ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_hafenbecken ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_hafenbecken ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_hafenbecken ADD istteilvon character(16)[];
		ALTER TABLE ax_hafenbecken ADD kreis character varying;
		ALTER TABLE ax_hafenbecken ADD lage character varying;
		ALTER TABLE ax_hafenbecken ADD land character varying;
		ALTER TABLE ax_hafenbecken ADD processstep_address character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_datetime character(20)[];
		ALTER TABLE ax_hafenbecken ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_individualname character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_organisationname character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_phone character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_positionname character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_rationale character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_role character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_hafenbecken ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_hafenbecken ADD regierungsbezirk character varying;
		ALTER TABLE ax_hafenbecken ADD statement character varying;
		ALTER TABLE ax_hafenbecken ADD traegtbeizu character(16)[];
		ALTER TABLE ax_hafenbecken ADD unverschluesselt character varying;
		ALTER TABLE ax_hafenbecken ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_hafenbecken ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_6a1cdcfb_3ce9_4f09_9990_20154ac143d1 ON ax_hafenbecken USING btree (endet);
		CREATE INDEX alkis_ef5f5fb9_81a7_4676_83f3_efe99b1418fe ON ax_hafenbecken USING gin (hatdirektunten);
		CREATE INDEX alkis_dde1982b_9cd9_46fd_a914_36da84a0f083 ON ax_hafenbecken USING gin (istabgeleitetaus);
		CREATE INDEX alkis_4188d97a_1f7e_43eb_8d1b_b0233bf40a69 ON ax_hafenbecken USING gin (istteilvon);
		CREATE INDEX alkis_40fd7535_72d0_4643_8cc4_7da0fd24ba4b ON ax_hafenbecken USING gin (traegtbeizu);

		ALTER TABLE ax_halde ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_halde ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_halde ADD hatdirektunten character(16)[];
		ALTER TABLE ax_halde ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_halde ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_halde ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_halde ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_halde ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_halde ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_halde ADD istteilvon character(16)[];
		ALTER TABLE ax_halde ADD processstep_address character varying[];
		ALTER TABLE ax_halde ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_halde ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_halde ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_halde ADD processstep_datetime character(20)[];
		ALTER TABLE ax_halde ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_halde ADD processstep_individualname character varying[];
		ALTER TABLE ax_halde ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_halde ADD processstep_organisationname character varying[];
		ALTER TABLE ax_halde ADD processstep_phone character varying[];
		ALTER TABLE ax_halde ADD processstep_positionname character varying[];
		ALTER TABLE ax_halde ADD processstep_rationale character varying[];
		ALTER TABLE ax_halde ADD processstep_role character varying[];
		ALTER TABLE ax_halde ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_halde ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_halde ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_halde ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_halde ADD statement character varying;
		ALTER TABLE ax_halde ADD traegtbeizu character(16)[];
		ALTER TABLE ax_halde ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_halde ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_halde ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_17fe5a12_ed35_4473_b66c_f83a8cf86991 ON ax_halde USING btree (endet);
		CREATE INDEX alkis_69cf0daa_db19_4c14_ab44_9ff8e68300fd ON ax_halde USING gin (hatdirektunten);
		CREATE INDEX alkis_7388a385_fc73_41a4_b2dc_39849efeef0a ON ax_halde USING gin (istabgeleitetaus);
		CREATE INDEX alkis_6a9cfa1e_75cf_40b7_96ac_29fb60cf23b0 ON ax_halde USING gin (istteilvon);
		CREATE INDEX alkis_e7458aec_e719_4367_bbda_e284d3033877 ON ax_halde USING gin (traegtbeizu);

		ALTER TABLE ax_heide ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_heide ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_heide ADD hatdirektunten character(16)[];
		ALTER TABLE ax_heide ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_heide ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_heide ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_heide ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_heide ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_heide ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_heide ADD istteilvon character(16)[];
		ALTER TABLE ax_heide ADD processstep_address character varying[];
		ALTER TABLE ax_heide ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_heide ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_heide ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_heide ADD processstep_datetime character(20)[];
		ALTER TABLE ax_heide ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_heide ADD processstep_individualname character varying[];
		ALTER TABLE ax_heide ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_heide ADD processstep_organisationname character varying[];
		ALTER TABLE ax_heide ADD processstep_phone character varying[];
		ALTER TABLE ax_heide ADD processstep_positionname character varying[];
		ALTER TABLE ax_heide ADD processstep_rationale character varying[];
		ALTER TABLE ax_heide ADD processstep_role character varying[];
		ALTER TABLE ax_heide ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_heide ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_heide ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_heide ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_heide ADD statement character varying;
		ALTER TABLE ax_heide ADD traegtbeizu character(16)[];
		ALTER TABLE ax_heide ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_heide ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_heide ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e2be50f0_fc8e_452d_9648_1f2dbaeab41f ON ax_heide USING btree (endet);
		CREATE INDEX alkis_c2028b06_c80e_44f2_86d3_079f8f33b7a3 ON ax_heide USING gin (hatdirektunten);
		CREATE INDEX alkis_89bf0187_99ae_4ead_a0ef_16d307f4a028 ON ax_heide USING gin (istabgeleitetaus);
		CREATE INDEX alkis_22296889_7275_4fa1_b628_8daf53775c42 ON ax_heide USING gin (istteilvon);
		CREATE INDEX alkis_5ed93688_e3b8_46ca_9333_f741f26534f7 ON ax_heide USING gin (traegtbeizu);

		UPDATE ax_heilquellegasquelle SET art=-1 WHERE art IS NULL;
		ALTER TABLE ax_heilquellegasquelle ALTER art SET NOT NULL;
		ALTER TABLE ax_heilquellegasquelle ALTER beginnt SET NOT NULL;
		-- ax_heilquellegasquelle.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_heilquellegasquelle DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_heilquellegasquelle RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_heilquellegasquelle','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_heilquellegasquelle SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_heilquellegasquelle DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_heilquellegasquelle_wkb_geometry_idx ON ax_heilquellegasquelle USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_heilquellegasquelle ADD hatdirektunten character(16)[];
		ALTER TABLE ax_heilquellegasquelle ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD hydrologischesmerkmal integer;
		ALTER TABLE ax_heilquellegasquelle ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_heilquellegasquelle ADD istteilvon character(16)[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_address character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_datetime character(20)[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_individualname character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_organisationname character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_phone character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_positionname character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_rationale character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_role character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD statement character varying;
		ALTER TABLE ax_heilquellegasquelle ADD traegtbeizu character(16)[];
		ALTER TABLE ax_heilquellegasquelle ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_heilquellegasquelle ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_574253b4_e2e4_47e7_821f_ff9b721efff6 ON ax_heilquellegasquelle USING btree (endet);
		CREATE INDEX alkis_bc5620c9_be32_498b_b1d2_1ac0555337ad ON ax_heilquellegasquelle USING gin (hatdirektunten);
		CREATE INDEX alkis_bb4dc703_8b0e_4ab1_af96_9ea07a8d8159 ON ax_heilquellegasquelle USING gin (istabgeleitetaus);
		CREATE INDEX alkis_3e949eab_0036_48c4_9cec_e3511a7064b6 ON ax_heilquellegasquelle USING gin (istteilvon);
		CREATE INDEX alkis_92ed52f9_0e40_4fa4_b3ac_7a40f8e4a80a ON ax_heilquellegasquelle USING gin (traegtbeizu);

		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ALTER archaeologischertyp SET NOT NULL;
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD istteilvon character(16)[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_address character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_individualname character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_phone character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_positionname character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_rationale character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_role character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD statement character varying;
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_c713ca44_47e5_4807_a556_f0619c55b775 ON ax_historischesbauwerkoderhistorischeeinrichtung USING btree (endet);
		CREATE INDEX alkis_7685acf3_5bf5_4687_a5c4_456ad669a364 ON ax_historischesbauwerkoderhistorischeeinrichtung USING gin (hatdirektunten);
		CREATE INDEX alkis_cd63491f_edff_498d_83cc_a5dd81b69cf1 ON ax_historischesbauwerkoderhistorischeeinrichtung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_8e73bf26_62f4_47b7_8aa8_d944b9772c9b ON ax_historischesbauwerkoderhistorischeeinrichtung USING gin (istteilvon);
		CREATE INDEX alkis_61daf965_a86a_46b6_be7b_9189ba11a892 ON ax_historischesbauwerkoderhistorischeeinrichtung USING gin (traegtbeizu);

		ALTER TABLE ax_historischesflurstueck ALTER amtlicheflaeche SET NOT NULL;
		ALTER TABLE ax_historischesflurstueck RENAME art TO zeigtaufexternes_art;
		ALTER TABLE ax_historischesflurstueck ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_historischesflurstueck RENAME bezirk TO buchungsblattbezirk_bezirk;
		-- ax_historischesflurstueck.bezirk => buchungsblattbezirk_bezirk: character varying => character varying[]
		ALTER TABLE ax_historischesflurstueck ALTER buchungsblattbezirk_bezirk TYPE character varying[] USING CASE WHEN buchungsblattbezirk_bezirk IS NULL THEN NULL ELSE ARRAY[buchungsblattbezirk_bezirk] END;
		-- ax_historischesflurstueck.blattart => blattart: integer => integer[]
		ALTER TABLE ax_historischesflurstueck ALTER blattart TYPE integer[] USING CASE WHEN blattart IS NULL THEN NULL ELSE ARRAY[blattart] END;
		-- ax_historischesflurstueck.buchungsart => buchungsart: character varying => character varying[]
		ALTER TABLE ax_historischesflurstueck ALTER buchungsart TYPE character varying[] USING CASE WHEN buchungsart IS NULL THEN NULL ELSE ARRAY[buchungsart] END;
		-- ax_historischesflurstueck.flurstueckskennzeichen => flurstueckskennzeichen: character(20) => character varying
		ALTER TABLE ax_historischesflurstueck ALTER flurstueckskennzeichen TYPE character varying;
		ALTER TABLE ax_historischesflurstueck ALTER flurstueckskennzeichen SET NOT NULL;
		ALTER TABLE ax_historischesflurstueck ALTER gemarkungsnummer SET NOT NULL;
		ALTER TABLE ax_historischesflurstueck RENAME gemeinde TO gemeindezugehoerigkeit_gemeinde;
		ALTER TABLE ax_historischesflurstueck RENAME kreis TO gemeindezugehoerigkeit_kreis;
		ALTER TABLE ax_historischesflurstueck ALTER land SET NOT NULL;
		-- ax_historischesflurstueck.laufendenummerderbuchungsstelle => laufendenummerderbuchungsstelle: character varying => character varying[]
		ALTER TABLE ax_historischesflurstueck ALTER laufendenummerderbuchungsstelle TYPE character varying[] USING CASE WHEN laufendenummerderbuchungsstelle IS NULL THEN NULL ELSE ARRAY[laufendenummerderbuchungsstelle] END;
		ALTER TABLE ax_historischesflurstueck RENAME name TO zeigtaufexternes_name;
		ALTER TABLE ax_historischesflurstueck RENAME regierungsbezirk TO gemeindezugehoerigkeit_regierungsbezirk;
		ALTER TABLE ax_historischesflurstueck DROP vorgaengerflurstueckskennzeichen;
		ALTER TABLE ax_historischesflurstueck ALTER zaehler SET NOT NULL;
		-- ax_historischesflurstueck.zeitpunktderentstehung => zeitpunktderentstehung: character(10) => date
		ALTER TABLE ax_historischesflurstueck ALTER zeitpunktderentstehung TYPE date USING to_date(zeitpunktderentstehung, 'YYYY-mm-dd');
		-- ax_historischesflurstueck.zeitpunktderhistorisierung => zeitpunktderhistorisierung: character(10) => date
		ALTER TABLE ax_historischesflurstueck ALTER zeitpunktderhistorisierung TYPE date USING to_date(zeitpunktderhistorisierung, 'YYYY-mm-dd');
		ALTER TABLE ax_historischesflurstueck ADD angabenzumabschnittbemerkung character varying[];
		ALTER TABLE ax_historischesflurstueck ADD angabenzumabschnittflurstueck character varying[];
		ALTER TABLE ax_historischesflurstueck ADD angabenzumabschnittnummeraktenzeichen character varying[];
		ALTER TABLE ax_historischesflurstueck ADD angabenzumabschnittstelle character varying[];
		ALTER TABLE ax_historischesflurstueck ADD buchungsblattbezirk_land character varying[];
		ALTER TABLE ax_historischesflurstueck ADD flaechedesabschnitts double precision[];
		ALTER TABLE ax_historischesflurstueck ADD flurstuecksfolge character varying;
		ALTER TABLE ax_historischesflurstueck ADD gemeindezugehoerigkeit_gemeindeteil character varying;
		ALTER TABLE ax_historischesflurstueck ADD gemeindezugehoerigkeit_land character varying;
		ALTER TABLE ax_historischesflurstueck ADD hatdirektunten character(16)[];
		ALTER TABLE ax_historischesflurstueck ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_historischesflurstueck ADD istteilvon character(16)[];
		ALTER TABLE ax_historischesflurstueck ADD kennungschluessel character varying[];
		PERFORM AddGeometryColumn('ax_historischesflurstueck','objektkoordinaten',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'POINT',2);
		ALTER TABLE ax_historischesflurstueck ADD traegtbeizu character(16)[];
		ALTER TABLE ax_historischesflurstueck ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2e76a0c0_6f40_4a62_8f6d_be5ef7fb08a4 ON ax_historischesflurstueck USING btree (endet);
		CREATE INDEX alkis_ee8a169d_9bda_4331_9542_1b147a2ae208 ON ax_historischesflurstueck USING gin (hatdirektunten);
		CREATE INDEX alkis_5fe471a0_5572_427e_82c5_04a3e916657f ON ax_historischesflurstueck USING gin (istabgeleitetaus);
		CREATE INDEX alkis_64957e28_b6af_4d7c_8b4a_3532973b613e ON ax_historischesflurstueck USING gin (istteilvon);
		CREATE INDEX alkis_4525c6f7_c122_4977_9aef_533777d6d25e ON ax_historischesflurstueck USING gin (traegtbeizu);
		CREATE INDEX alkis_d448bc6e_a481_4a59_a79c_b4d8ab2991d2 ON ax_historischesflurstueck USING gist (objektkoordinaten);

		ALTER TABLE ax_historischesflurstueckalb DROP abweichenderrechtszustand;
		ALTER TABLE ax_historischesflurstueckalb ALTER amtlicheflaeche SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckalb ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckalb RENAME bezirk TO buchungsblattbezirk_bezirk;
		-- ax_historischesflurstueckalb.bezirk => buchungsblattbezirk_bezirk: character varying => character varying[]
		ALTER TABLE ax_historischesflurstueckalb ALTER buchungsblattbezirk_bezirk TYPE character varying[] USING CASE WHEN buchungsblattbezirk_bezirk IS NULL THEN NULL ELSE ARRAY[buchungsblattbezirk_bezirk] END;
		-- ax_historischesflurstueckalb.blattart => blattart: integer => integer[]
		ALTER TABLE ax_historischesflurstueckalb ALTER blattart TYPE integer[] USING CASE WHEN blattart IS NULL THEN NULL ELSE ARRAY[blattart] END;
		-- ax_historischesflurstueckalb.flurstueckskennzeichen => flurstueckskennzeichen: character(20) => character varying
		ALTER TABLE ax_historischesflurstueckalb ALTER flurstueckskennzeichen TYPE character varying;
		ALTER TABLE ax_historischesflurstueckalb ALTER flurstueckskennzeichen SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckalb ALTER gemarkungsnummer SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckalb DROP gemeinde;
		ALTER TABLE ax_historischesflurstueckalb ALTER land SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckalb RENAME name TO zeigtaufexternes_name;
		ALTER TABLE ax_historischesflurstueckalb DROP rechtsbehelfsverfahren;
		-- ax_historischesflurstueckalb.zaehler => zaehler: integer => character varying
		ALTER TABLE ax_historischesflurstueckalb ALTER zaehler TYPE character varying USING zaehler::varchar;
		ALTER TABLE ax_historischesflurstueckalb ALTER zaehler SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckalb DROP zeitpunktderentstehung;
		-- ax_historischesflurstueckalb.zeitpunktderentstehungdesbezugsflurstuecks => zeitpunktderentstehungdesbezugsflurstuecks: character varying => date
		ALTER TABLE ax_historischesflurstueckalb ALTER zeitpunktderentstehungdesbezugsflurstuecks TYPE date USING to_date(zeitpunktderentstehungdesbezugsflurstuecks, 'YYYY-mm-dd');
		ALTER TABLE ax_historischesflurstueckalb DROP zweifelhafterflurstuecksnachweis;
		ALTER TABLE ax_historischesflurstueckalb ADD buchungsblattbezirk_land character varying[];
		ALTER TABLE ax_historischesflurstueckalb ADD istteilvon character(16)[];
		PERFORM AddGeometryColumn('ax_historischesflurstueckalb','objektkoordinaten',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'POINT',2);
		ALTER TABLE ax_historischesflurstueckalb ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_historischesflurstueckalb ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_historischesflurstueckalb' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_historischesflurstueckalb USING btree (nachfolgerflurstueckskennzeichen)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_historischesflurstueckalb' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_historischesflurstueckalb USING btree (vorgaengerflurstueckskennzeichen)';
		CREATE INDEX alkis_21db3780_12d8_48f1_8e13_f7b893e1dacc ON ax_historischesflurstueckalb USING btree (endet);
		CREATE INDEX alkis_b80f6956_7814_44c9_980e_45b8fa85bb23 ON ax_historischesflurstueckalb USING btree (flurstueckskennzeichen);
		CREATE INDEX alkis_4ae16a49_f4cb_46ad_be1a_62db75c6981d ON ax_historischesflurstueckalb USING gin (istteilvon);
		CREATE INDEX alkis_b49146d2_be2c_4c28_a45e_f1ac1b1983f6 ON ax_historischesflurstueckalb USING gin (nachfolgerflurstueckskennzeichen);
		CREATE INDEX alkis_10099ea3_e629_4a56_9b2c_3df8916327d8 ON ax_historischesflurstueckalb USING gin (vorgaengerflurstueckskennzeichen);
		CREATE INDEX alkis_626ef53e_3f57_48b3_b87f_a70eedc796a8 ON ax_historischesflurstueckalb USING gist (objektkoordinaten);

		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER amtlicheflaeche SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER beginnt SET NOT NULL;
		-- ax_historischesflurstueckohneraumbezug.flurstueckskennzeichen => flurstueckskennzeichen: character(20) => character varying
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER flurstueckskennzeichen TYPE character varying;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER flurstueckskennzeichen SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER gemarkungsnummer SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckohneraumbezug RENAME gemeinde TO gemeindezugehoerigkeit_gemeinde;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER land SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckohneraumbezug RENAME name TO zeigtaufexternes_name;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER zaehler SET NOT NULL;
		-- ax_historischesflurstueckohneraumbezug.zeitpunktderentstehung => zeitpunktderentstehung: character varying => date
		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER zeitpunktderentstehung TYPE date USING to_date(zeitpunktderentstehung, 'YYYY-mm-dd');
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD angabenzumabschnittbemerkung character varying[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD angabenzumabschnittflurstueck character varying[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD angabenzumabschnittnummeraktenzeichen character varying[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD angabenzumabschnittstelle character varying[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD flaechedesabschnitts double precision[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD flurstuecksfolge character varying;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD gemeindezugehoerigkeit_gemeindeteil character varying;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD gemeindezugehoerigkeit_kreis character varying;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD gemeindezugehoerigkeit_land character varying;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD gemeindezugehoerigkeit_regierungsbezirk character varying;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD istteilvon character(16)[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD kennungschluessel character varying[];
		PERFORM AddGeometryColumn('ax_historischesflurstueckohneraumbezug','objektkoordinaten',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'POINT',2);
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_historischesflurstueckohneraumbezug' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_historischesflurstueckohneraumbezug USING btree (nachfolgerflurstueckskennzeichen)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_historischesflurstueckohneraumbezug' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_historischesflurstueckohneraumbezug USING btree (vorgaengerflurstueckskennzeichen)';
		CREATE INDEX alkis_52405507_de46_42fb_86da_44c0a630f3b9 ON ax_historischesflurstueckohneraumbezug USING btree (endet);
		CREATE INDEX alkis_a13c748f_cb0a_4327_a59e_e5b12a707285 ON ax_historischesflurstueckohneraumbezug USING btree (gml_id, beginnt);
		CREATE INDEX alkis_d3ae2a2b_b690_468e_ac81_25ec6bf9c808 ON ax_historischesflurstueckohneraumbezug USING gin (istteilvon);
		CREATE INDEX alkis_68bd32fd_f199_4f7b_8c9e_ab1690c3c8cd ON ax_historischesflurstueckohneraumbezug USING gin (nachfolgerflurstueckskennzeichen);
		CREATE INDEX alkis_ead6e84b_eb1e_481a_a60b_cf86beba8404 ON ax_historischesflurstueckohneraumbezug USING gin (vorgaengerflurstueckskennzeichen);
		CREATE INDEX alkis_895edadb_aa82_41cd_b6f4_e568925beb4e ON ax_historischesflurstueckohneraumbezug USING gist (objektkoordinaten);

		ALTER TABLE ax_hoehenlinie ALTER beginnt SET NOT NULL;
		UPDATE ax_hoehenlinie SET hoehevonhoehenlinie=0.0 WHERE hoehevonhoehenlinie IS NULL;
		ALTER TABLE ax_hoehenlinie ALTER hoehevonhoehenlinie SET NOT NULL;
		-- ax_hoehenlinie.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_hoehenlinie DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_hoehenlinie RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_hoehenlinie','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_hoehenlinie SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_hoehenlinie DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_hoehenlinie_wkb_geometry_idx ON ax_hoehenlinie USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_hoehenlinie ADD hatdirektunten character(16)[];
		ALTER TABLE ax_hoehenlinie ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_hoehenlinie ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_hoehenlinie ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_hoehenlinie ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_hoehenlinie ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_hoehenlinie ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_hoehenlinie ADD istteilvon character(16)[];
		ALTER TABLE ax_hoehenlinie ADD processstep_address character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_datetime character(20)[];
		ALTER TABLE ax_hoehenlinie ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_individualname character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_organisationname character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_phone character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_positionname character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_rationale character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_role character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_hoehenlinie ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_hoehenlinie ADD statement character varying;
		ALTER TABLE ax_hoehenlinie ADD traegtbeizu character(16)[];
		ALTER TABLE ax_hoehenlinie ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_hoehenlinie ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_hoehenlinie ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_f3492c5c_8c1e_43a2_ad96_a0ddd4fd2b92 ON ax_hoehenlinie USING btree (endet);
		CREATE INDEX alkis_4f4ca521_321a_405a_a0a4_2602c7a9b527 ON ax_hoehenlinie USING gin (hatdirektunten);
		CREATE INDEX alkis_5b278176_3b87_417c_ae5d_8c8df0c622ef ON ax_hoehenlinie USING gin (istabgeleitetaus);
		CREATE INDEX alkis_395cd9ae_a8af_49ec_b98d_bbf2dd4ab556 ON ax_hoehenlinie USING gin (istteilvon);
		CREATE INDEX alkis_6fcd3afe_b777_42b6_83f4_e352b7d0153b ON ax_hoehenlinie USING gin (traegtbeizu);

		ALTER TABLE ax_hoehleneingang ALTER beginnt SET NOT NULL;
		-- ax_hoehleneingang.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_hoehleneingang DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_hoehleneingang RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_hoehleneingang','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_hoehleneingang SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_hoehleneingang DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_hoehleneingang_wkb_geometry_idx ON ax_hoehleneingang USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_hoehleneingang ADD hatdirektunten character(16)[];
		ALTER TABLE ax_hoehleneingang ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_hoehleneingang ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_hoehleneingang ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_hoehleneingang ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_hoehleneingang ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_hoehleneingang ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_hoehleneingang ADD istteilvon character(16)[];
		ALTER TABLE ax_hoehleneingang ADD processstep_address character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_datetime character(20)[];
		ALTER TABLE ax_hoehleneingang ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_individualname character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_organisationname character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_phone character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_positionname character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_rationale character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_role character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_hoehleneingang ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_hoehleneingang ADD statement character varying;
		ALTER TABLE ax_hoehleneingang ADD traegtbeizu character(16)[];
		ALTER TABLE ax_hoehleneingang ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_hoehleneingang ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_hoehleneingang ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_hoehleneingang ADD zustand integer;
		CREATE INDEX alkis_fd75254d_1a1f_4c06_8ee7_2b7a4e0cca80 ON ax_hoehleneingang USING btree (endet);
		CREATE INDEX alkis_e343c236_fc7f_49cf_8768_0715dd4311f3 ON ax_hoehleneingang USING gin (hatdirektunten);
		CREATE INDEX alkis_dfc6aaba_7f66_4432_ad51_61c1c16d5e4b ON ax_hoehleneingang USING gin (istabgeleitetaus);
		CREATE INDEX alkis_0e012b3b_a2f1_4d54_a554_2b25b3d86787 ON ax_hoehleneingang USING gin (istteilvon);
		CREATE INDEX alkis_aac50656_1b06_451d_bef1_a91030a92847 ON ax_hoehleneingang USING gin (traegtbeizu);

		ALTER TABLE ax_industrieundgewerbeflaeche ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_industrieundgewerbeflaeche ADD bezeichnung character varying;
		ALTER TABLE ax_industrieundgewerbeflaeche ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_industrieundgewerbeflaeche ADD hatdirektunten character(16)[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD istteilvon character(16)[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_address character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_datetime character(20)[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_individualname character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_organisationname character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_phone character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_positionname character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_rationale character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_role character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD statement character varying;
		ALTER TABLE ax_industrieundgewerbeflaeche ADD traegtbeizu character(16)[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_30ddf2c0_b7d0_408f_b29f_8b5713721cff ON ax_industrieundgewerbeflaeche USING btree (endet);
		CREATE INDEX alkis_2561ffa4_4672_4647_b3f3_305ae7e45f36 ON ax_industrieundgewerbeflaeche USING gin (hatdirektunten);
		CREATE INDEX alkis_c915450c_f6a1_4e87_a777_9d3beb81d325 ON ax_industrieundgewerbeflaeche USING gin (istabgeleitetaus);
		CREATE INDEX alkis_6ea74ee3_5936_4298_ba61_a0a8e63a724a ON ax_industrieundgewerbeflaeche USING gin (istteilvon);
		CREATE INDEX alkis_4dfc8869_285c_463b_b8ce_c2340b380023 ON ax_industrieundgewerbeflaeche USING gin (traegtbeizu);

		ALTER TABLE ax_klassifizierungnachstrassenrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_klassifizierungnachstrassenrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_address character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_role character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD statement character varying;
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_3cebb3a0_eb04_4707_b379_999224ee807e ON ax_klassifizierungnachstrassenrecht USING btree (endet);
		CREATE INDEX alkis_03800c22_e4d6_4abe_b7ec_5c5938bc02cc ON ax_klassifizierungnachstrassenrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_dcdbf8e8_d1a6_4b77_afed_225b671f4a87 ON ax_klassifizierungnachstrassenrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_c683a542_a7c0_443f_b42b_b1db81a262f4 ON ax_klassifizierungnachstrassenrecht USING gin (istteilvon);
		CREATE INDEX alkis_f00113db_f002_40c4_a835_93a99ef8e47e ON ax_klassifizierungnachstrassenrecht USING gin (traegtbeizu);

		ALTER TABLE ax_klassifizierungnachwasserrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_klassifizierungnachwasserrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD bezeichnung character varying;
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_address character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_role character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD statement character varying;
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_9aeb5a89_93d0_45a9_8eaa_fc9357182830 ON ax_klassifizierungnachwasserrecht USING btree (endet);
		CREATE INDEX alkis_2d8bbf9d_d3df_47d4_a76a_7f0f967d46ba ON ax_klassifizierungnachwasserrecht USING btree (gml_id, beginnt);
		CREATE INDEX alkis_0e8751e9_6d74_4e1e_8a68_eca131a07fc6 ON ax_klassifizierungnachwasserrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_5cbb09c3_507f_4978_953f_933c2e5905ff ON ax_klassifizierungnachwasserrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_255d83d1_aad0_45ea_b30c_63f274328712 ON ax_klassifizierungnachwasserrecht USING gin (istteilvon);
		CREATE INDEX alkis_f599f774_0855_48f8_a47f_20f56c1bc592 ON ax_klassifizierungnachwasserrecht USING gin (traegtbeizu);

		ALTER TABLE ax_kleinraeumigerlandschaftsteil ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ALTER landschaftstyp SET NOT NULL;
		UPDATE ax_kleinraeumigerlandschaftsteil SET name='' WHERE name IS NULL;
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ALTER name SET NOT NULL;
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD hatdirektunten character(16)[];
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD istteilvon character(16)[];
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD traegtbeizu character(16)[];
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_aaa44559_4549_4a5f_ac62_7dc9d79c6e2d ON ax_kleinraeumigerlandschaftsteil USING btree (endet);
		CREATE INDEX alkis_60e5db53_8409_41a8_9709_469c74a2fa61 ON ax_kleinraeumigerlandschaftsteil USING gin (hatdirektunten);
		CREATE INDEX alkis_5d2837e6_6e03_442a_86f6_288c89be29a2 ON ax_kleinraeumigerlandschaftsteil USING gin (istabgeleitetaus);
		CREATE INDEX alkis_f082c6b7_bb50_49d2_8ad3_48b2b5aa8cdd ON ax_kleinraeumigerlandschaftsteil USING gin (istteilvon);
		CREATE INDEX alkis_81ebf052_364a_451f_a930_c8d4d7593aac ON ax_kleinraeumigerlandschaftsteil USING gin (traegtbeizu);

		ALTER TABLE ax_kommunalesgebiet ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_kommunalesgebiet ALTER gemeinde SET NOT NULL;
		ALTER TABLE ax_kommunalesgebiet ALTER kreis SET NOT NULL;
		ALTER TABLE ax_kommunalesgebiet ALTER land SET NOT NULL;
		ALTER TABLE ax_kommunalesgebiet ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_kommunalesgebiet ADD gemeindeteil character varying;
		ALTER TABLE ax_kommunalesgebiet ADD hatdirektunten character(16)[];
		ALTER TABLE ax_kommunalesgebiet ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_kommunalesgebiet ADD istteilvon character(16)[];
		ALTER TABLE ax_kommunalesgebiet ADD traegtbeizu character(16)[];
		ALTER TABLE ax_kommunalesgebiet ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_kommunalesgebiet ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_kommunalesgebiet ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_1cfddb27_ab66_4adf_bf2d_a18817ba05c9 ON ax_kommunalesgebiet USING btree (endet);
		CREATE INDEX alkis_f72ba4ef_31e5_48bc_b9ed_555eb354926c ON ax_kommunalesgebiet USING gin (hatdirektunten);
		CREATE INDEX alkis_1fba25e6_844f_4f82_879f_8fe8c7674d26 ON ax_kommunalesgebiet USING gin (istabgeleitetaus);
		CREATE INDEX alkis_e476e65b_3c84_4986_bb35_473a5cf4f855 ON ax_kommunalesgebiet USING gin (istteilvon);
		CREATE INDEX alkis_6976efd3_8be9_47ac_8abc_87aeb5b9eb52 ON ax_kommunalesgebiet USING gin (traegtbeizu);

		ALTER TABLE ax_kreisregion ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_kreisregion ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_kreisregion ALTER kreis SET NOT NULL;
		ALTER TABLE ax_kreisregion ALTER land SET NOT NULL;
		ALTER TABLE ax_kreisregion ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_kreisregion ADD administrativefunktion integer[];
		ALTER TABLE ax_kreisregion ADD istamtsbezirkvon_land character varying[];
		ALTER TABLE ax_kreisregion ADD istamtsbezirkvon_stelle character varying[];
		ALTER TABLE ax_kreisregion ADD istteilvon character(16)[];
		ALTER TABLE ax_kreisregion ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_kreisregion ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_kreisregion ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_b05dab96_50d6_4f12_ab63_79a14847acd0 ON ax_kreisregion USING btree (endet);
		CREATE INDEX alkis_b9e0fded_55c1_469c_9df7_ded942784245 ON ax_kreisregion USING gin (istteilvon);

		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER gemeinde SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER kreis SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER lage SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER land SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD administrativefunktion integer[];
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD istteilvon character(16)[];
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD kennung character varying;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_a32d8702_8f6f_4f75_aa0e_0bbc8e17527d ON ax_lagebezeichnungkatalogeintrag USING btree (endet);
		CREATE INDEX alkis_955990c3_7604_4265_9dc7_c9dceecc0889 ON ax_lagebezeichnungkatalogeintrag USING gin (istteilvon);

		ALTER TABLE ax_lagebezeichnungmithausnummer ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungmithausnummer ALTER hausnummer SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungmithausnummer ADD istteilvon character(16)[];
		ALTER TABLE ax_lagebezeichnungmithausnummer ADD ortsteil character varying;
		ALTER TABLE ax_lagebezeichnungmithausnummer ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_lagebezeichnungmithausnummer ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_lagebezeichnungmithausnummer ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_fab89e96_865d_4b1d_aeda_892b9be50b01 ON ax_lagebezeichnungmithausnummer USING btree (endet);
		CREATE INDEX alkis_46949710_71d5_423a_b3eb_0ab971bf32b0 ON ax_lagebezeichnungmithausnummer USING gin (istteilvon);

		ALTER TABLE ax_lagebezeichnungmitpseudonummer ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ALTER pseudonummer SET NOT NULL;
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD istteilvon character(16)[];
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD ortsteil character varying;
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_bcb24e0a_b08d_49b3_816d_5a53d654799f ON ax_lagebezeichnungmitpseudonummer USING btree (endet);
		CREATE INDEX alkis_fb50f465_d0e1_4569_886f_15ece7313d6c ON ax_lagebezeichnungmitpseudonummer USING gin (istteilvon);

		ALTER TABLE ax_lagebezeichnungohnehausnummer ALTER beginnt SET NOT NULL;
		-- ax_lagebezeichnungohnehausnummer.gehoertzu => gehoertzu: character varying[] => character(16)[]
		ALTER TABLE ax_lagebezeichnungohnehausnummer ALTER gehoertzu TYPE character(16)[];
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD istteilvon character(16)[];
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD ortsteil character varying;
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_9c0d232d_ff0e_4f0f_bbee_b5bcb6e18d95 ON ax_lagebezeichnungohnehausnummer USING btree (endet);
		CREATE INDEX alkis_7edcc632_43ed_4d1f_884d_f0517772f66e ON ax_lagebezeichnungohnehausnummer USING gin (istteilvon);

		ALTER TABLE ax_landschaft ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_landschaft ALTER landschaftstyp SET NOT NULL;
		ALTER TABLE ax_landschaft ALTER name SET NOT NULL;
		ALTER TABLE ax_landschaft ADD hatdirektunten character(16)[];
		ALTER TABLE ax_landschaft ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_landschaft ADD istteilvon character(16)[];
		ALTER TABLE ax_landschaft ADD traegtbeizu character(16)[];
		ALTER TABLE ax_landschaft ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_landschaft ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_landschaft ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_3cbdf208_321c_4f34_8cfb_4071f3aec31e ON ax_landschaft USING btree (endet);
		CREATE INDEX alkis_b24755e6_a148_4704_9849_57b6ed734953 ON ax_landschaft USING gin (hatdirektunten);
		CREATE INDEX alkis_f6d2e868_a46e_4030_a9dc_8f2f5cbbbf89 ON ax_landschaft USING gin (istabgeleitetaus);
		CREATE INDEX alkis_789242f5_865b_481e_bbe0_5bfc4c20ee4e ON ax_landschaft USING gin (istteilvon);
		CREATE INDEX alkis_88ed0571_435e_4764_9a71_3aa6fa56b0bd ON ax_landschaft USING gin (traegtbeizu);

		ALTER TABLE ax_landwirtschaft ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_landwirtschaft ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_landwirtschaft ADD hatdirektunten character(16)[];
		ALTER TABLE ax_landwirtschaft ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_landwirtschaft ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_landwirtschaft ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_landwirtschaft ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_landwirtschaft ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_landwirtschaft ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_landwirtschaft ADD istteilvon character(16)[];
		ALTER TABLE ax_landwirtschaft ADD processstep_address character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_datetime character(20)[];
		ALTER TABLE ax_landwirtschaft ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_individualname character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_organisationname character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_phone character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_positionname character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_rationale character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_role character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_landwirtschaft ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_landwirtschaft ADD statement character varying;
		ALTER TABLE ax_landwirtschaft ADD traegtbeizu character(16)[];
		ALTER TABLE ax_landwirtschaft ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_landwirtschaft ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_landwirtschaft ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_c1ab5c1e_edd9_4a7a_b74e_b37f37dbf28a ON ax_landwirtschaft USING btree (endet);
		CREATE INDEX alkis_f269a606_a42b_44ba_bf33_aa77822302f1 ON ax_landwirtschaft USING gin (hatdirektunten);
		CREATE INDEX alkis_7d57e7a8_60f9_47eb_9251_471534724675 ON ax_landwirtschaft USING gin (istabgeleitetaus);
		CREATE INDEX alkis_a533bc3e_9301_4014_92a5_971b456cad08 ON ax_landwirtschaft USING gin (istteilvon);
		CREATE INDEX alkis_86f68f6d_17ba_4911_8bba_40dcfc679ff6 ON ax_landwirtschaft USING gin (traegtbeizu);

		ALTER TABLE ax_leitung ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_leitung ALTER beginnt SET NOT NULL;
		-- ax_leitung.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_leitung DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_leitung RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_leitung','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_leitung SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_leitung DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_leitung_wkb_geometry_idx ON ax_leitung USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_leitung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_leitung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_leitung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_leitung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_leitung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_leitung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_leitung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_leitung ADD istteilvon character(16)[];
		ALTER TABLE ax_leitung ADD name character varying;
		ALTER TABLE ax_leitung ADD processstep_address character varying[];
		ALTER TABLE ax_leitung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_leitung ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_leitung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_leitung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_leitung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_leitung ADD processstep_individualname character varying[];
		ALTER TABLE ax_leitung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_leitung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_leitung ADD processstep_phone character varying[];
		ALTER TABLE ax_leitung ADD processstep_positionname character varying[];
		ALTER TABLE ax_leitung ADD processstep_rationale character varying[];
		ALTER TABLE ax_leitung ADD processstep_role character varying[];
		ALTER TABLE ax_leitung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_leitung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_leitung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_leitung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_leitung ADD statement character varying;
		ALTER TABLE ax_leitung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_leitung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_leitung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_leitung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2a4c1617_2135_41ee_b20d_48b9f995da7a ON ax_leitung USING btree (endet);
		CREATE INDEX alkis_4c9de9ae_ec2a_4462_a425_3d77faeeada0 ON ax_leitung USING gin (hatdirektunten);
		CREATE INDEX alkis_cc932a19_f766_441d_a864_46de46348136 ON ax_leitung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_94c765cd_ffe0_4c71_b871_7e66f170a1fb ON ax_leitung USING gin (istteilvon);
		CREATE INDEX alkis_a56ad157_0b34_4e64_95fc_e9190ec9b989 ON ax_leitung USING gin (traegtbeizu);

		ALTER TABLE ax_meer ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_meer RENAME name TO zeigtaufexternes_name;
		-- ax_meer.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_meer ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_meer ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_meer ADD gemeinde character varying;
		ALTER TABLE ax_meer ADD hatdirektunten character(16)[];
		ALTER TABLE ax_meer ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_meer ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_meer ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_meer ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_meer ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_meer ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_meer ADD istteilvon character(16)[];
		ALTER TABLE ax_meer ADD kreis character varying;
		ALTER TABLE ax_meer ADD lage character varying;
		ALTER TABLE ax_meer ADD land character varying;
		ALTER TABLE ax_meer ADD processstep_address character varying[];
		ALTER TABLE ax_meer ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_meer ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_meer ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_meer ADD processstep_datetime character(20)[];
		ALTER TABLE ax_meer ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_meer ADD processstep_individualname character varying[];
		ALTER TABLE ax_meer ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_meer ADD processstep_organisationname character varying[];
		ALTER TABLE ax_meer ADD processstep_phone character varying[];
		ALTER TABLE ax_meer ADD processstep_positionname character varying[];
		ALTER TABLE ax_meer ADD processstep_rationale character varying[];
		ALTER TABLE ax_meer ADD processstep_role character varying[];
		ALTER TABLE ax_meer ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_meer ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_meer ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_meer ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_meer ADD regierungsbezirk character varying;
		ALTER TABLE ax_meer ADD statement character varying;
		ALTER TABLE ax_meer ADD traegtbeizu character(16)[];
		ALTER TABLE ax_meer ADD unverschluesselt character varying;
		ALTER TABLE ax_meer ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_meer ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_meer ADD zweitname character varying[];
		CREATE INDEX alkis_4543998c_970d_42f0_88a0_7be8859921e9 ON ax_meer USING btree (endet);
		CREATE INDEX alkis_17243af4_b1fc_4fa3_aa0a_23864bab0d12 ON ax_meer USING gin (hatdirektunten);
		CREATE INDEX alkis_df56a5aa_af33_43a6_8eee_d1751f2c3921 ON ax_meer USING gin (istabgeleitetaus);
		CREATE INDEX alkis_ee41b43a_62cf_426c_adc3_e0cd5a61f815 ON ax_meer USING gin (istteilvon);
		CREATE INDEX alkis_15e1a2dd_e814_476a_bd3b_e07c80d5ba75 ON ax_meer USING gin (traegtbeizu);

		ALTER TABLE ax_moor ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_moor ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_moor ADD hatdirektunten character(16)[];
		ALTER TABLE ax_moor ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_moor ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_moor ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_moor ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_moor ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_moor ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_moor ADD istteilvon character(16)[];
		ALTER TABLE ax_moor ADD processstep_address character varying[];
		ALTER TABLE ax_moor ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_moor ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_moor ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_moor ADD processstep_datetime character(20)[];
		ALTER TABLE ax_moor ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_moor ADD processstep_individualname character varying[];
		ALTER TABLE ax_moor ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_moor ADD processstep_organisationname character varying[];
		ALTER TABLE ax_moor ADD processstep_phone character varying[];
		ALTER TABLE ax_moor ADD processstep_positionname character varying[];
		ALTER TABLE ax_moor ADD processstep_rationale character varying[];
		ALTER TABLE ax_moor ADD processstep_role character varying[];
		ALTER TABLE ax_moor ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_moor ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_moor ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_moor ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_moor ADD statement character varying;
		ALTER TABLE ax_moor ADD traegtbeizu character(16)[];
		ALTER TABLE ax_moor ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_moor ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_moor ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e3d6066c_9898_47ab_b5e0_2f99adecafab ON ax_moor USING btree (endet);
		CREATE INDEX alkis_e6fade99_823a_42f0_ad32_3224b2cfdf1e ON ax_moor USING gin (hatdirektunten);
		CREATE INDEX alkis_3bc327e4_ad4c_4c0a_a61d_4cc3d4e50cd8 ON ax_moor USING gin (istabgeleitetaus);
		CREATE INDEX alkis_c0189944_b6be_4713_9a90_a04bb3d84455 ON ax_moor USING gin (istteilvon);
		CREATE INDEX alkis_1f975089_6687_465f_b2d1_391a4590c3ae ON ax_moor USING gin (traegtbeizu);

		ALTER TABLE ax_musterlandesmusterundvergleichsstueck RENAME art TO zeigtaufexternes_art;
		-- ax_musterlandesmusterundvergleichsstueck.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ALTER beginnt SET NOT NULL;
		-- ax_musterlandesmusterundvergleichsstueck.entstehungsartoderklimastufewasserverhaeltnisse => entstehungsartoderklimastufewasserverhaeltnisse: integer => integer[]
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ALTER entstehungsartoderklimastufewasserverhaeltnisse TYPE integer[] USING CASE WHEN entstehungsartoderklimastufewasserverhaeltnisse IS NULL THEN NULL ELSE ARRAY[entstehungsartoderklimastufewasserverhaeltnisse] END;
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ALTER merkmal SET NOT NULL;
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck RENAME name TO zeigtaufexternes_name;
		-- ax_musterlandesmusterundvergleichsstueck.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		-- ax_musterlandesmusterundvergleichsstueck.sonstigeangaben => sonstigeangaben: integer => integer[]
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ALTER sonstigeangaben TYPE integer[] USING CASE WHEN sonstigeangaben IS NULL THEN NULL ELSE ARRAY[sonstigeangaben] END;
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD hatdirektunten character(16)[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD istteilvon character(16)[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_address character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_datetime character(20)[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_individualname character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_organisationname character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_phone character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_positionname character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_rationale character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_role character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD statement character varying;
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD traegtbeizu character(16)[];
		ALTER TABLE ax_musterlandesmusterundvergleichsstueck ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_103f4faa_e89a_433b_98e8_bb05fb0b191d ON ax_musterlandesmusterundvergleichsstueck USING btree (endet);
		CREATE INDEX alkis_cc96c3cf_cd2c_4794_8738_58a6d7d43b8b ON ax_musterlandesmusterundvergleichsstueck USING gin (hatdirektunten);
		CREATE INDEX alkis_40cb070a_1444_44e9_a67d_ec4df1beb208 ON ax_musterlandesmusterundvergleichsstueck USING gin (istabgeleitetaus);
		CREATE INDEX alkis_00b5d3cc_156e_4959_b163_3da418f07300 ON ax_musterlandesmusterundvergleichsstueck USING gin (istteilvon);
		CREATE INDEX alkis_abc9c642_10c9_4454_be3b_1e7d988da253 ON ax_musterlandesmusterundvergleichsstueck USING gin (traegtbeizu);

		ALTER TABLE ax_namensnummer ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_namensnummer ALTER istbestandteilvon SET NOT NULL;
		-- ax_namensnummer.laufendenummernachdin1421 => laufendenummernachdin1421: character(16) => character varying
		ALTER TABLE ax_namensnummer ALTER laufendenummernachdin1421 TYPE character varying;
		ALTER TABLE ax_namensnummer ADD istteilvon character(16)[];
		ALTER TABLE ax_namensnummer ADD strichblattnummer integer;
		ALTER TABLE ax_namensnummer ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_namensnummer ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_namensnummer ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e25bcb78_4520_4e13_bba2_c3f11b5a3a61 ON ax_namensnummer USING btree (endet);
		CREATE INDEX alkis_22eb0d2c_a5ba_4d53_beca_b406b28c04de ON ax_namensnummer USING gin (istteilvon);

		ALTER TABLE ax_naturumweltoderbodenschutzrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD bezeichnung character varying;
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_address character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_role character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD statement character varying;
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD zustand integer;
		CREATE INDEX alkis_4ae7e4cd_bda8_4c7b_a108_750e249b41cd ON ax_naturumweltoderbodenschutzrecht USING btree (endet);
		CREATE INDEX alkis_1cabbd81_1099_4b10_88a2_a966f5d608f4 ON ax_naturumweltoderbodenschutzrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_68f0036f_b644_423f_8c4d_aa341659d00b ON ax_naturumweltoderbodenschutzrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_6920bb42_2447_4402_96da_7c5f6db1935a ON ax_naturumweltoderbodenschutzrecht USING gin (istteilvon);
		CREATE INDEX alkis_f946250d_a834_4b6a_9630_85b1b06b1810 ON ax_naturumweltoderbodenschutzrecht USING gin (traegtbeizu);

		ALTER TABLE ax_person ALTER beginnt SET NOT NULL;
		-- ax_person.geburtsdatum => geburtsdatum: character varying => date
		ALTER TABLE ax_person ALTER geburtsdatum TYPE date USING to_date(geburtsdatum, 'YYYY-mm-dd');
		ALTER TABLE ax_person ALTER nachnameoderfirma SET NOT NULL;
		ALTER TABLE ax_person ADD ax_li_processstep_ohnedatenerhebung_description character varying[];
		ALTER TABLE ax_person ADD beruf character varying;
		ALTER TABLE ax_person ADD haushaltsstellelandesgrundbesitz character varying;
		ALTER TABLE ax_person ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_person ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_person ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_person ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_person ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_person ADD istteilvon character(16)[];
		ALTER TABLE ax_person ADD processstep_address character varying[];
		ALTER TABLE ax_person ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_person ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_person ADD processstep_datetime character(20)[];
		ALTER TABLE ax_person ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_person ADD processstep_individualname character varying[];
		ALTER TABLE ax_person ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_person ADD processstep_organisationname character varying[];
		ALTER TABLE ax_person ADD processstep_phone character varying[];
		ALTER TABLE ax_person ADD processstep_positionname character varying[];
		ALTER TABLE ax_person ADD processstep_rationale character varying[];
		ALTER TABLE ax_person ADD processstep_role character varying[];
		ALTER TABLE ax_person ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_person ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_person ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_person ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_person ADD sonstigeeigenschaften character varying;
		ALTER TABLE ax_person ADD statement character varying;
		ALTER TABLE ax_person ADD wohnortodersitz character varying;
		ALTER TABLE ax_person ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_person ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_person ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_f967b26e_6fe3_4852_a8db_62b31666ff4b ON ax_person USING btree (endet);
		CREATE INDEX alkis_a4c94835_2c94_438a_8128_f39ba667c7b5 ON ax_person USING gin (istteilvon);

		ALTER TABLE ax_platz ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_platz RENAME name TO zeigtaufexternes_name;
		-- ax_platz.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_platz ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_platz ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_platz ADD hatdirektunten character(16)[];
		ALTER TABLE ax_platz ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_platz ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_platz ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_platz ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_platz ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_platz ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_platz ADD istteilvon character(16)[];
		ALTER TABLE ax_platz ADD processstep_address character varying[];
		ALTER TABLE ax_platz ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_platz ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_platz ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_platz ADD processstep_datetime character(20)[];
		ALTER TABLE ax_platz ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_platz ADD processstep_individualname character varying[];
		ALTER TABLE ax_platz ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_platz ADD processstep_organisationname character varying[];
		ALTER TABLE ax_platz ADD processstep_phone character varying[];
		ALTER TABLE ax_platz ADD processstep_positionname character varying[];
		ALTER TABLE ax_platz ADD processstep_rationale character varying[];
		ALTER TABLE ax_platz ADD processstep_role character varying[];
		ALTER TABLE ax_platz ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_platz ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_platz ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_platz ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_platz ADD statement character varying;
		ALTER TABLE ax_platz ADD strassenschluessel character varying;
		ALTER TABLE ax_platz ADD traegtbeizu character(16)[];
		ALTER TABLE ax_platz ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_platz ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4331d124_88f6_4e23_ae75_205086c3cc86 ON ax_platz USING btree (endet);
		CREATE INDEX alkis_765c7df4_27b8_4100_965f_37f5e6594666 ON ax_platz USING gin (hatdirektunten);
		CREATE INDEX alkis_06ee8c51_169f_4257_b47b_af14d1f39ca8 ON ax_platz USING gin (istabgeleitetaus);
		CREATE INDEX alkis_51a349ea_0dfb_4dad_a7de_012e9aec9434 ON ax_platz USING gin (istteilvon);
		CREATE INDEX alkis_04d95c70_7cc5_4e07_abbd_440eaf94af93 ON ax_platz USING gin (traegtbeizu);

		ALTER TABLE ax_punktkennunguntergegangen ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_punktkennunguntergegangen ALTER punktkennung SET NOT NULL;
		ALTER TABLE ax_punktkennunguntergegangen ADD istteilvon character(16)[];
		ALTER TABLE ax_punktkennunguntergegangen ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_punktkennunguntergegangen ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_punktkennunguntergegangen ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_a9c12b65_4c8a_4568_a8e2_2d830b2a986c ON ax_punktkennunguntergegangen USING btree (endet);
		CREATE INDEX alkis_5abb7525_2be4_429d_a136_17ccaf456ec2 ON ax_punktkennunguntergegangen USING btree (gml_id, beginnt);
		CREATE INDEX alkis_3278d65b_7ece_4af8_8a57_564218abded1 ON ax_punktkennunguntergegangen USING gin (istteilvon);

		ALTER TABLE ax_punktortag RENAME art TO zeigtaufexternes_art;
		ALTER TABLE ax_punktortag DROP ax_datenerhebung_punktort;
		ALTER TABLE ax_punktortag ALTER beginnt SET NOT NULL;
		-- ax_punktortag.istteilvon => istteilvon: character(16) => character(16)[]
		ALTER TABLE ax_punktortag ALTER istteilvon TYPE character(16)[] USING CASE WHEN istteilvon IS NULL THEN NULL ELSE ARRAY[istteilvon] END;
		ALTER TABLE ax_punktortag RENAME name TO zeigtaufexternes_name;
		-- ax_punktortag.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_punktortag DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_punktortag RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_punktortag','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_punktortag SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_punktortag DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_punktortag_wkb_geometry_idx ON ax_punktortag USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_punktortag ADD genauigkeitswert_datetime character(20)[];
		ALTER TABLE ax_punktortag ADD genauigkeitswert_evaluationmethoddescription character varying;
		ALTER TABLE ax_punktortag ADD genauigkeitswert_evaluationmethodtype character varying;
		ALTER TABLE ax_punktortag ADD genauigkeitswert_evaluationprocedure character varying;
		ALTER TABLE ax_punktortag ADD genauigkeitswert_measuredescription character varying;
		ALTER TABLE ax_punktortag ADD genauigkeitswert_measureidentification character varying;
		ALTER TABLE ax_punktortag ADD genauigkeitswert_nameofmeasure character varying[];
		ALTER TABLE ax_punktortag ADD genauigkeitswert_result character varying[];
		ALTER TABLE ax_punktortag ADD hatdirektunten character(16)[];
		ALTER TABLE ax_punktortag ADD herkunft_source_source_description character varying[];
		ALTER TABLE ax_punktortag ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_punktortag ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_punktortag ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_punktortag ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_punktortag ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_punktortag ADD lagezuverlaessigkeit character varying;
		ALTER TABLE ax_punktortag ADD processstep_address character varying[];
		ALTER TABLE ax_punktortag ADD processstep_ax_li_processstep_punktort_description character varying[];
		ALTER TABLE ax_punktortag ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_punktortag ADD processstep_datetime character(20)[];
		ALTER TABLE ax_punktortag ADD processstep_description character varying[];
		ALTER TABLE ax_punktortag ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_punktortag ADD processstep_individualname character varying[];
		ALTER TABLE ax_punktortag ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_punktortag ADD processstep_organisationname character varying[];
		ALTER TABLE ax_punktortag ADD processstep_phone character varying[];
		ALTER TABLE ax_punktortag ADD processstep_positionname character varying[];
		ALTER TABLE ax_punktortag ADD processstep_rationale character varying[];
		ALTER TABLE ax_punktortag ADD processstep_role character varying[];
		ALTER TABLE ax_punktortag ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_punktortag ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_punktortag ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_punktortag ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_punktortag ADD statement character varying;
		ALTER TABLE ax_punktortag ADD traegtbeizu character(16)[];
		ALTER TABLE ax_punktortag ADD ueberpruefungsdatum date;
		ALTER TABLE ax_punktortag ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_punktortag' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_punktortag USING btree (istteilvon)';
		CREATE INDEX alkis_7611c1a4_2ef3_494c_a214_1affcb79103a ON ax_punktortag USING btree (endet);
		CREATE INDEX alkis_517810ac_6763_45ee_97aa_256346f1fe43 ON ax_punktortag USING gin (hatdirektunten);
		CREATE INDEX alkis_a28e5561_e73a_49f1_a785_a9813c40513b ON ax_punktortag USING gin (istabgeleitetaus);
		CREATE INDEX alkis_bf58512b_27b5_4641_840c_78fdfa838ba8 ON ax_punktortag USING gin (istteilvon);
		CREATE INDEX alkis_0b0b1e8a_876a_4c33_bf0a_75577699e308 ON ax_punktortag USING gin (traegtbeizu);

		ALTER TABLE ax_punktortau DROP ax_datenerhebung_punktort;
		ALTER TABLE ax_punktortau ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_punktortau RENAME individualname TO processstep_individualname;
		-- ax_punktortau.individualname => processstep_individualname: character varying => character varying[]
		ALTER TABLE ax_punktortau ALTER processstep_individualname TYPE character varying[] USING CASE WHEN processstep_individualname IS NULL THEN NULL ELSE ARRAY[processstep_individualname] END;
		-- ax_punktortau.istteilvon => istteilvon: character(16) => character(16)[]
		ALTER TABLE ax_punktortau ALTER istteilvon TYPE character(16)[] USING CASE WHEN istteilvon IS NULL THEN NULL ELSE ARRAY[istteilvon] END;
		ALTER TABLE ax_punktortau RENAME name TO zeigtaufexternes_name;
		-- ax_punktortau.wkb_geometry => wkb_geometry: geometry(PointZ,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_punktortau DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_punktortau RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_punktortau','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE ax_punktortau SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_punktortau DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_punktortau_wkb_geometry_idx ON ax_punktortau USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_punktortau ADD genauigkeitswert_datetime character(20)[];
		ALTER TABLE ax_punktortau ADD genauigkeitswert_evaluationmethoddescription character varying;
		ALTER TABLE ax_punktortau ADD genauigkeitswert_evaluationmethodtype character varying;
		ALTER TABLE ax_punktortau ADD genauigkeitswert_evaluationprocedure character varying;
		ALTER TABLE ax_punktortau ADD genauigkeitswert_measuredescription character varying;
		ALTER TABLE ax_punktortau ADD genauigkeitswert_measureidentification character varying;
		ALTER TABLE ax_punktortau ADD genauigkeitswert_nameofmeasure character varying[];
		ALTER TABLE ax_punktortau ADD genauigkeitswert_result character varying[];
		ALTER TABLE ax_punktortau ADD hatdirektunten character(16)[];
		ALTER TABLE ax_punktortau ADD herkunft_source_source_description character varying[];
		ALTER TABLE ax_punktortau ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_punktortau ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_punktortau ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_punktortau ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_punktortau ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_punktortau ADD lagezuverlaessigkeit character varying;
		ALTER TABLE ax_punktortau ADD processstep_address character varying[];
		ALTER TABLE ax_punktortau ADD processstep_ax_li_processstep_punktort_description character varying[];
		ALTER TABLE ax_punktortau ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_punktortau ADD processstep_datetime character(20)[];
		ALTER TABLE ax_punktortau ADD processstep_description character varying[];
		ALTER TABLE ax_punktortau ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_punktortau ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_punktortau ADD processstep_organisationname character varying[];
		ALTER TABLE ax_punktortau ADD processstep_phone character varying[];
		ALTER TABLE ax_punktortau ADD processstep_positionname character varying[];
		ALTER TABLE ax_punktortau ADD processstep_rationale character varying[];
		ALTER TABLE ax_punktortau ADD processstep_role character varying[];
		ALTER TABLE ax_punktortau ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_punktortau ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_punktortau ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_punktortau ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_punktortau ADD statement character varying;
		ALTER TABLE ax_punktortau ADD traegtbeizu character(16)[];
		ALTER TABLE ax_punktortau ADD ueberpruefungsdatum date;
		ALTER TABLE ax_punktortau ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_punktortau ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_punktortau' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_punktortau USING btree (istteilvon)';
		CREATE INDEX alkis_f512fd00_cdb6_4b78_9804_b37c2170bbfe ON ax_punktortau USING btree (endet);
		CREATE INDEX alkis_f636c79e_8a6b_4db5_8e70_c6fe8773c857 ON ax_punktortau USING gin (hatdirektunten);
		CREATE INDEX alkis_69d8ec8b_748b_4c60_b9d8_213e752f0965 ON ax_punktortau USING gin (istabgeleitetaus);
		CREATE INDEX alkis_b5176aa7_69d7_404b_b2a7_93df5960ec5a ON ax_punktortau USING gin (istteilvon);
		CREATE INDEX alkis_ddd73802_16ff_41a5_8275_c44afe3b826f ON ax_punktortau USING gin (traegtbeizu);

		ALTER TABLE ax_punktortta RENAME art TO zeigtaufexternes_art;
		ALTER TABLE ax_punktortta DROP ax_datenerhebung_punktort;
		ALTER TABLE ax_punktortta ALTER beginnt SET NOT NULL;
		-- ax_punktortta.istteilvon => istteilvon: character(16) => character(16)[]
		ALTER TABLE ax_punktortta ALTER istteilvon TYPE character(16)[] USING CASE WHEN istteilvon IS NULL THEN NULL ELSE ARRAY[istteilvon] END;
		ALTER TABLE ax_punktortta RENAME name TO zeigtaufexternes_name;
		-- ax_punktortta.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_punktortta DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_punktortta RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_punktortta','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_punktortta SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_punktortta DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_punktortta_wkb_geometry_idx ON ax_punktortta USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_punktortta ADD genauigkeitswert_datetime character(20)[];
		ALTER TABLE ax_punktortta ADD genauigkeitswert_evaluationmethoddescription character varying;
		ALTER TABLE ax_punktortta ADD genauigkeitswert_evaluationmethodtype character varying;
		ALTER TABLE ax_punktortta ADD genauigkeitswert_evaluationprocedure character varying;
		ALTER TABLE ax_punktortta ADD genauigkeitswert_measuredescription character varying;
		ALTER TABLE ax_punktortta ADD genauigkeitswert_measureidentification character varying;
		ALTER TABLE ax_punktortta ADD genauigkeitswert_nameofmeasure character varying[];
		ALTER TABLE ax_punktortta ADD genauigkeitswert_result character varying[];
		ALTER TABLE ax_punktortta ADD hatdirektunten character(16)[];
		ALTER TABLE ax_punktortta ADD herkunft_source_source_description character varying[];
		ALTER TABLE ax_punktortta ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_punktortta ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_punktortta ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_punktortta ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_punktortta ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_punktortta ADD lagezuverlaessigkeit character varying;
		ALTER TABLE ax_punktortta ADD processstep_address character varying[];
		ALTER TABLE ax_punktortta ADD processstep_ax_li_processstep_punktort_description character varying[];
		ALTER TABLE ax_punktortta ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_punktortta ADD processstep_datetime character(20)[];
		ALTER TABLE ax_punktortta ADD processstep_description character varying[];
		ALTER TABLE ax_punktortta ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_punktortta ADD processstep_individualname character varying[];
		ALTER TABLE ax_punktortta ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_punktortta ADD processstep_organisationname character varying[];
		ALTER TABLE ax_punktortta ADD processstep_phone character varying[];
		ALTER TABLE ax_punktortta ADD processstep_positionname character varying[];
		ALTER TABLE ax_punktortta ADD processstep_rationale character varying[];
		ALTER TABLE ax_punktortta ADD processstep_role character varying[];
		ALTER TABLE ax_punktortta ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_punktortta ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_punktortta ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_punktortta ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_punktortta ADD statement character varying;
		ALTER TABLE ax_punktortta ADD traegtbeizu character(16)[];
		ALTER TABLE ax_punktortta ADD ueberpruefungsdatum date;
		ALTER TABLE ax_punktortta ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_punktortta' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_punktortta USING btree (istteilvon)';
		CREATE INDEX alkis_7b3c63dc_e6bf_44a8_b9ac_209ca8a3d8e8 ON ax_punktortta USING gin (hatdirektunten);
		CREATE INDEX alkis_d0154547_40df_4b9d_a9b0_07f71d0ebcdb ON ax_punktortta USING gin (istabgeleitetaus);
		CREATE INDEX alkis_60968e58_e1b1_4a6f_8a0a_86cf1bb2261a ON ax_punktortta USING gin (istteilvon);
		CREATE INDEX alkis_e026cd5c_783d_4551_b5c9_5511040b8608 ON ax_punktortta USING gin (traegtbeizu);

		ALTER TABLE ax_regierungsbezirk ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_regierungsbezirk ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_regierungsbezirk ALTER land SET NOT NULL;
		ALTER TABLE ax_regierungsbezirk ALTER regierungsbezirk SET NOT NULL;
		ALTER TABLE ax_regierungsbezirk ALTER schluesselgesamt SET NOT NULL;
		ALTER TABLE ax_regierungsbezirk ADD administrativefunktion integer[];
		ALTER TABLE ax_regierungsbezirk ADD istteilvon character(16)[];
		ALTER TABLE ax_regierungsbezirk ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_regierungsbezirk ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_regierungsbezirk ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4fb4cd36_d1b6_48cb_81c8_1950e100487f ON ax_regierungsbezirk USING btree (endet);
		CREATE INDEX alkis_1574bc43_c060_413a_a7e6_f64ff1b5dabb ON ax_regierungsbezirk USING gin (istteilvon);

		-- ax_reservierung.ablaufderreservierung => ablaufderreservierung: character varying => date
		ALTER TABLE ax_reservierung ALTER ablaufderreservierung TYPE date USING to_date(ablaufderreservierung, 'YYYY-mm-dd');
		ALTER TABLE ax_reservierung ALTER art SET NOT NULL;
		ALTER TABLE ax_reservierung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_reservierung ALTER land SET NOT NULL;
		ALTER TABLE ax_reservierung ALTER nummer SET NOT NULL;
		ALTER TABLE ax_reservierung ALTER stelle SET NOT NULL;
		ALTER TABLE ax_reservierung ADD buchungsblattbezirk_bezirk character varying;
		ALTER TABLE ax_reservierung ADD buchungsblattbezirk_land character varying;
		ALTER TABLE ax_reservierung ADD flur_gemarkung character varying;
		ALTER TABLE ax_reservierung ADD flur_gemarkungsteilflur character varying;
		ALTER TABLE ax_reservierung ADD flur_land character varying;
		ALTER TABLE ax_reservierung ADD gemarkung_gemarkungsnummer character varying;
		ALTER TABLE ax_reservierung ADD gemarkung_land character varying;
		ALTER TABLE ax_reservierung ADD istteilvon character(16)[];
		ALTER TABLE ax_reservierung ADD nummerierungsbezirk character varying;
		ALTER TABLE ax_reservierung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_reservierung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_reservierung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_15e95ff5_73fb_435a_9ee0_d37870971803 ON ax_reservierung USING btree (endet);
		CREATE INDEX alkis_d47d4d1b_e253_4f42_8efc_4f035d1dc137 ON ax_reservierung USING btree (gml_id, beginnt);
		CREATE INDEX alkis_c4805830_11f4_4c1a_9bf5_6b69956cab56 ON ax_reservierung USING gin (istteilvon);

		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ALTER beginnt SET NOT NULL;
		-- ax_schifffahrtsliniefaehrverkehr.wkb_geometry => wkb_geometry: geometry(LineString,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_schifffahrtsliniefaehrverkehr DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_schifffahrtsliniefaehrverkehr RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_schifffahrtsliniefaehrverkehr','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_schifffahrtsliniefaehrverkehr SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_schifffahrtsliniefaehrverkehr DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_schifffahrtsliniefaehrverkehr_wkb_geometry_idx ON ax_schifffahrtsliniefaehrverkehr USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD hatdirektunten character(16)[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD istteilvon character(16)[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_address character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_datetime character(20)[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_individualname character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_organisationname character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_phone character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_positionname character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_rationale character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_role character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD statement character varying;
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD traegtbeizu character(16)[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_c41d3455_9fdb_4da6_93cd_e8867a6f5173 ON ax_schifffahrtsliniefaehrverkehr USING btree (endet);
		CREATE INDEX alkis_060ec5e4_d37e_42cc_ba8f_31189f2a9694 ON ax_schifffahrtsliniefaehrverkehr USING gin (hatdirektunten);
		CREATE INDEX alkis_00166e68_d67b_44ec_a8f9_740a184756e7 ON ax_schifffahrtsliniefaehrverkehr USING gin (istabgeleitetaus);
		CREATE INDEX alkis_8656686a_cf4b_431e_95f1_96c86cc9b709 ON ax_schifffahrtsliniefaehrverkehr USING gin (istteilvon);
		CREATE INDEX alkis_d8830234_e1f3_4c2f_87e8_5211659332e0 ON ax_schifffahrtsliniefaehrverkehr USING gin (traegtbeizu);

		ALTER TABLE ax_schiffsverkehr ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_schiffsverkehr RENAME name TO zeigtaufexternes_name;
		-- ax_schiffsverkehr.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_schiffsverkehr ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_schiffsverkehr ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_schiffsverkehr ADD gemeinde character varying;
		ALTER TABLE ax_schiffsverkehr ADD hatdirektunten character(16)[];
		ALTER TABLE ax_schiffsverkehr ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_schiffsverkehr ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_schiffsverkehr ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_schiffsverkehr ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_schiffsverkehr ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_schiffsverkehr ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_schiffsverkehr ADD istteilvon character(16)[];
		ALTER TABLE ax_schiffsverkehr ADD kreis character varying;
		ALTER TABLE ax_schiffsverkehr ADD lage character varying;
		ALTER TABLE ax_schiffsverkehr ADD land character varying;
		ALTER TABLE ax_schiffsverkehr ADD processstep_address character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_datetime character(20)[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_individualname character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_organisationname character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_phone character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_positionname character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_rationale character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_role character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_schiffsverkehr ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_schiffsverkehr ADD regierungsbezirk character varying;
		ALTER TABLE ax_schiffsverkehr ADD statement character varying;
		ALTER TABLE ax_schiffsverkehr ADD traegtbeizu character(16)[];
		ALTER TABLE ax_schiffsverkehr ADD unverschluesselt character varying;
		ALTER TABLE ax_schiffsverkehr ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_schiffsverkehr ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_4dffe632_8503_4ce8_bb02_4121d18a8f09 ON ax_schiffsverkehr USING btree (endet);
		CREATE INDEX alkis_2df433ae_bcea_4416_b253_df663dba0e51 ON ax_schiffsverkehr USING gin (hatdirektunten);
		CREATE INDEX alkis_31f49200_66f2_4543_8c6d_f48d99db67d1 ON ax_schiffsverkehr USING gin (istabgeleitetaus);
		CREATE INDEX alkis_1d59b629_560a_4753_a3a3_f7ec97213327 ON ax_schiffsverkehr USING gin (istteilvon);
		CREATE INDEX alkis_e0a23b09_a876_459b_8064_64b9cceadd9d ON ax_schiffsverkehr USING gin (traegtbeizu);

		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD bestehtaus character(16)[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD nummerdesschutzgebietes character varying;
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_address character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_role character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD statement character varying;
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_f5bab60b_9905_4412_b350_ab63cfe117a5 ON ax_schutzgebietnachnaturumweltoderbodenschutzrecht USING btree (endet);
		CREATE INDEX alkis_463dc50b_11c2_457e_814e_e15733ff1069 ON ax_schutzgebietnachnaturumweltoderbodenschutzrecht USING gin (bestehtaus);
		CREATE INDEX alkis_a75245ac_310e_430f_b4ef_e1dc958d8d32 ON ax_schutzgebietnachnaturumweltoderbodenschutzrecht USING gin (istteilvon);

		ALTER TABLE ax_schutzgebietnachwasserrecht RENAME art TO zeigtaufexternes_art;
		ALTER TABLE ax_schutzgebietnachwasserrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_schutzgebietnachwasserrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD bestehtaus character(16)[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD funktion integer;
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_address character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_role character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD statement character varying;
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_afe65b3f_ff2e_4621_91d8_f3382bb9795d ON ax_schutzgebietnachwasserrecht USING btree (endet);
		CREATE INDEX alkis_e8ce640c_bcc2_4a9a_aa75_fca123659174 ON ax_schutzgebietnachwasserrecht USING gin (bestehtaus);
		CREATE INDEX alkis_959b21fe_fe3c_474e_b80c_791aeba90cff ON ax_schutzgebietnachwasserrecht USING gin (istteilvon);

		ALTER TABLE ax_schutzzone RENAME art TO zeigtaufexternes_art;
		ALTER TABLE ax_schutzzone ALTER beginnt SET NOT NULL;
		-- ax_schutzzone.istteilvon => istteilvon: character(16) => character(16)[]
		ALTER TABLE ax_schutzzone ALTER istteilvon TYPE character(16)[] USING CASE WHEN istteilvon IS NULL THEN NULL ELSE ARRAY[istteilvon] END;
		ALTER TABLE ax_schutzzone ALTER zone SET NOT NULL;
		ALTER TABLE ax_schutzzone ADD hatdirektunten character(16)[];
		ALTER TABLE ax_schutzzone ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_schutzzone ADD nummerderschutzzone character varying;
		ALTER TABLE ax_schutzzone ADD rechtszustand integer;
		ALTER TABLE ax_schutzzone ADD traegtbeizu character(16)[];
		ALTER TABLE ax_schutzzone ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_schutzzone ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_schutzzone' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_schutzzone USING btree (istteilvon)';
		CREATE INDEX alkis_c5ffeeb0_c531_41a3_902f_7d078e9cae30 ON ax_schutzzone USING btree (endet);
		CREATE INDEX alkis_3d5c780d_90a7_4cdc_b3dd_8633402df859 ON ax_schutzzone USING gin (hatdirektunten);
		CREATE INDEX alkis_a707ffa1_1d01_4d7d_b463_51e1087d7f74 ON ax_schutzzone USING gin (istabgeleitetaus);
		CREATE INDEX alkis_b954697f_05fb_484e_bf91_312009dc34bf ON ax_schutzzone USING gin (istteilvon);
		CREATE INDEX alkis_64fff255_dc50_4417_8085_7a9c9353f105 ON ax_schutzzone USING gin (traegtbeizu);

		ALTER TABLE ax_seilbahnschwebebahn ALTER bahnkategorie SET NOT NULL;
		ALTER TABLE ax_seilbahnschwebebahn ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_seilbahnschwebebahn ADD hatdirektunten character(16)[];
		ALTER TABLE ax_seilbahnschwebebahn ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_seilbahnschwebebahn ADD istteilvon character(16)[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_address character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_datetime character(20)[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_individualname character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_organisationname character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_phone character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_positionname character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_rationale character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_role character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD statement character varying;
		ALTER TABLE ax_seilbahnschwebebahn ADD traegtbeizu character(16)[];
		ALTER TABLE ax_seilbahnschwebebahn ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_seilbahnschwebebahn ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_088f8a74_d5b2_4231_a370_26cbbf956cbe ON ax_seilbahnschwebebahn USING btree (endet);
		CREATE INDEX alkis_7decde0d_5b31_4733_a6a3_9df348829b36 ON ax_seilbahnschwebebahn USING gin (hatdirektunten);
		CREATE INDEX alkis_900fb3c6_70bb_4871_9974_c8f0ba7f7eb5 ON ax_seilbahnschwebebahn USING gin (istabgeleitetaus);
		CREATE INDEX alkis_de97f000_0e80_437a_87f1_667d42b9d6dd ON ax_seilbahnschwebebahn USING gin (istteilvon);
		CREATE INDEX alkis_8b3c1784_b74d_4309_93eb_4f4a44aec97c ON ax_seilbahnschwebebahn USING gin (traegtbeizu);

		ALTER TABLE ax_sicherungspunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_sicherungspunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_sicherungspunkt RENAME name TO zeigtaufexternes_name;
		-- ax_sicherungspunkt.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_sicherungspunkt ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_sicherungspunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_sicherungspunkt ALTER vermarkung_marke SET NOT NULL;
		ALTER TABLE ax_sicherungspunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_sicherungspunkt ADD hat character(16)[];
		ALTER TABLE ax_sicherungspunkt ADD horizontfreiheit integer;
		ALTER TABLE ax_sicherungspunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_sicherungspunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_sicherungspunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_b2595bb3_98d8_4249_99da_930fe2c01250 ON ax_sicherungspunkt USING btree (endet);
		CREATE INDEX alkis_37c09f70_6231_44fa_91e8_a940b95d5d08 ON ax_sicherungspunkt USING gin (bestehtaus);
		CREATE INDEX alkis_6cd88406_9ab6_44e5_943c_6afd28b6b06e ON ax_sicherungspunkt USING gin (hat);
		CREATE INDEX alkis_7f7a29e2_a0c3_40c0_9d74_6329887001c0 ON ax_sicherungspunkt USING gin (istteilvon);

		ALTER TABLE ax_soll ALTER beginnt SET NOT NULL;
		-- ax_soll.wkb_geometry => wkb_geometry: geometry(Polygon,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_soll DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_soll RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_soll','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_soll SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_soll DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_soll_wkb_geometry_idx ON ax_soll USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_soll ADD hatdirektunten character(16)[];
		ALTER TABLE ax_soll ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_soll ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_soll ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_soll ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_soll ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_soll ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_soll ADD istteilvon character(16)[];
		ALTER TABLE ax_soll ADD processstep_address character varying[];
		ALTER TABLE ax_soll ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_soll ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_soll ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_soll ADD processstep_datetime character(20)[];
		ALTER TABLE ax_soll ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_soll ADD processstep_individualname character varying[];
		ALTER TABLE ax_soll ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_soll ADD processstep_organisationname character varying[];
		ALTER TABLE ax_soll ADD processstep_phone character varying[];
		ALTER TABLE ax_soll ADD processstep_positionname character varying[];
		ALTER TABLE ax_soll ADD processstep_rationale character varying[];
		ALTER TABLE ax_soll ADD processstep_role character varying[];
		ALTER TABLE ax_soll ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_soll ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_soll ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_soll ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_soll ADD statement character varying;
		ALTER TABLE ax_soll ADD traegtbeizu character(16)[];
		ALTER TABLE ax_soll ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_soll ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_soll ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_96f17510_595d_4693_9ccf_922f5fda6ba0 ON ax_soll USING btree (endet);
		CREATE INDEX alkis_ac8cebf5_dfdb_45b9_ae2d_c32781f04851 ON ax_soll USING gin (hatdirektunten);
		CREATE INDEX alkis_6b59edb9_5a53_4523_922a_2cc26811015a ON ax_soll USING gin (istabgeleitetaus);
		CREATE INDEX alkis_fcbef8ec_05e3_41d7_807a_42c288911f64 ON ax_soll USING gin (istteilvon);
		CREATE INDEX alkis_0adb38f5_f174_4806_9737_749efd8b2461 ON ax_soll USING gin (traegtbeizu);

		ALTER TABLE ax_sonstigervermessungspunkt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_sonstigervermessungspunkt RENAME land TO zustaendigestelle_land;
		ALTER TABLE ax_sonstigervermessungspunkt RENAME stelle TO zustaendigestelle_stelle;
		ALTER TABLE ax_sonstigervermessungspunkt ALTER vermarkung_marke SET NOT NULL;
		ALTER TABLE ax_sonstigervermessungspunkt ADD bestehtaus character(16)[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD beziehtsichauf character(16)[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD gehoertzu character(16)[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD horizontfreiheit integer;
		ALTER TABLE ax_sonstigervermessungspunkt ADD istteilvon character(16)[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD verbundenmit character(16)[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_24e3cbe0_a123_4b5e_8f7e_37d4f9d7f9d1 ON ax_sonstigervermessungspunkt USING btree (endet);
		CREATE INDEX alkis_b3c85d35_9ca5_418e_941e_ff85e2ef9de8 ON ax_sonstigervermessungspunkt USING gin (bestehtaus);
		CREATE INDEX alkis_5c3ba3db_6103_423d_adf0_54b22421b2f6 ON ax_sonstigervermessungspunkt USING gin (beziehtsichauf);
		CREATE INDEX alkis_1bec07e9_0d6a_4133_b859_dcf0c6d15d84 ON ax_sonstigervermessungspunkt USING gin (gehoertzu);
		CREATE INDEX alkis_ad99f1f6_1f4d_4cf8_a14f_8c4008b5dcc6 ON ax_sonstigervermessungspunkt USING gin (istteilvon);
		CREATE INDEX alkis_66eebbe8_25b9_4115_aaf2_929f0cbb9007 ON ax_sonstigervermessungspunkt USING gin (verbundenmit);

		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung RENAME description TO processstep_ax_li_processstep_mitdatenerhebung_description;
		-- ax_sonstigesbauwerkodersonstigeeinrichtung.description => processstep_ax_li_processstep_mitdatenerhebung_description: integer => character varying[]
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ALTER processstep_ax_li_processstep_mitdatenerhebung_description TYPE character varying[] USING CASE WHEN processstep_ax_li_processstep_mitdatenerhebung_description IS NULL THEN NULL ELSE ARRAY[processstep_ax_li_processstep_mitdatenerhebung_description::int] END;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung DROP gehoertzubauwerk;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD bezeichnung character varying;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_abschnitt character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_ast character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_bahnverkehrsanlage character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_bauwerkimgewaesserbereich character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_bauwerkimverkehrsbereich character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_bauwerkoderanlagefuerindustrieundgewer character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_bauwerkoderanlagefuersportfreizeitunde character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_einrichtungenfuerdenschiffsverkehr character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_einrichtunginoeffentlichenbereichen character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_flugverkehrsanlage character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_gewaessermerkmal character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_gewaesserstationierungsachse character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_gleis character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_grenzuebergang character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_hafen character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_heilquellegasquelle character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_historischesbauwerkoderhistorischeeinr character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_leitung character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_netzknoten character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_nullpunkt character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_ortslage character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_polder character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_schifffahrtsliniefaehrverkehr character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_schleuse character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_seilbahnschwebebahn character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_sickerstrecke character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_sonstigesbauwerkodersonstigeeinrichtun character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_strassenverkehrsanlage character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_testgelaende character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_transportanlage character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_turm character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_untergeordnetesgewaesser character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_vegetationsmerkmal character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_vorratsbehaelterspeicherbauwerk character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_wasserspiegelhoehe character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD gehoertzubauwerk_ax_wegpfadsteig character(16);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD hatdirektunten character(16)[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD hydrologischesmerkmal integer;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD istteilvon character(16)[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD objekthoehe double precision;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_address character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_individualname character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_phone character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_positionname character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_rationale character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_role character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD statement character varying;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD traegtbeizu character(16)[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_sonstigesbauwerkodersonstigeeinrichtung' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk)';
		CREATE INDEX alkis_883c12ad_45ba_4b06_9a9c_98b0aff853f3 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (endet);
		CREATE INDEX alkis_cc40e634_bd89_4bb4_9c24_32648a5f94fb ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_abschnitt);
		CREATE INDEX alkis_e0df5d9f_e7ee_4a31_b572_0cb7f74a1eae ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_ast);
		CREATE INDEX alkis_eb61156c_4cb3_4007_ac4d_c29a0ffb670a ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_bahnverkehrsanlage);
		CREATE INDEX alkis_01126df7_aba1_4c72_ab27_a2666a9cd602 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_bauwerkimgewaesserbereich);
		CREATE INDEX alkis_301c30db_c3fd_48e3_a0c7_afde999f03d5 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_bauwerkimverkehrsbereich);
		CREATE INDEX alkis_e43cf3ea_416e_4421_92b6_8acaa82e7442 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_bauwerkoderanlagefuerindustrieundgewer);
		CREATE INDEX alkis_353588fe_303d_49c6_95ad_c18d54633bd3 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_bauwerkoderanlagefuersportfreizeitunde);
		CREATE INDEX alkis_eb7ab46e_0ead_4c15_bb75_e89cf520c807 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_einrichtungenfuerdenschiffsverkehr);
		CREATE INDEX alkis_b37b8956_7fd1_4cb8_a01f_8472add24123 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_einrichtunginoeffentlichenbereichen);
		CREATE INDEX alkis_bb5ffe1b_1ee6_4cfd_a1b1_134532f66c45 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_flugverkehrsanlage);
		CREATE INDEX alkis_4e04bc35_7622_4b38_9993_ef4fd7507f3c ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_gewaessermerkmal);
		CREATE INDEX alkis_96416332_352c_4331_9bca_b236224be490 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_gewaesserstationierungsachse);
		CREATE INDEX alkis_fbe2b696_d3c9_44ec_a0f7_6f5094508183 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_gleis);
		CREATE INDEX alkis_b3934314_1da7_41e2_a627_b9010db385c3 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_grenzuebergang);
		CREATE INDEX alkis_db244b10_933b_48dd_aa05_928618f43513 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_hafen);
		CREATE INDEX alkis_850ef963_6031_4f1c_ae66_cbb52bac7ef4 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_heilquellegasquelle);
		CREATE INDEX alkis_04529a66_7309_4b95_b8ee_27bdb52673e5 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_historischesbauwerkoderhistorischeeinr);
		CREATE INDEX alkis_9f05bdca_95e3_4103_baa0_7694576dac5c ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_leitung);
		CREATE INDEX alkis_730e962a_1798_4cf3_8254_9b7141bd97ef ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_netzknoten);
		CREATE INDEX alkis_e91fed58_96b3_4533_92f2_5fab821c7642 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_nullpunkt);
		CREATE INDEX alkis_8609fcbc_1f5a_4f30_b896_7df1b269de47 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_ortslage);
		CREATE INDEX alkis_e7918d29_4225_4e34_9a07_56fbbd035734 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_polder);
		CREATE INDEX alkis_689a51e1_58c8_4003_a3f2_dc4ed556a997 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_schifffahrtsliniefaehrverkehr);
		CREATE INDEX alkis_4b12de8c_2a09_4d37_85b8_0ae60a82f064 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_schleuse);
		CREATE INDEX alkis_a053989e_549a_4414_8cbe_903af58ddbae ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_seilbahnschwebebahn);
		CREATE INDEX alkis_4c480257_894c_4cde_888a_25390d0204ff ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_sickerstrecke);
		CREATE INDEX alkis_ab06253f_a213_4bd9_81fd_622e059b443c ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_sonstigesbauwerkodersonstigeeinrichtun);
		CREATE INDEX alkis_714b88ee_b924_4615_b42a_ab76c4a2d93e ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_strassenverkehrsanlage);
		CREATE INDEX alkis_a71b74f9_f986_426b_ba09_131d7ab2df18 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_testgelaende);
		CREATE INDEX alkis_8a80344a_e6bf_4b34_9d5b_62f877b74efa ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_transportanlage);
		CREATE INDEX alkis_6dcc77cc_4167_4129_ba6a_49d4157ca39e ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_turm);
		CREATE INDEX alkis_e904c709_ceb3_48ce_beae_ae924378e8de ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_untergeordnetesgewaesser);
		CREATE INDEX alkis_993ad727_bbfc_4396_875a_543fe84a5446 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_vegetationsmerkmal);
		CREATE INDEX alkis_262d9d21_c56a_46d0_a1ea_b85401da694a ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_vorratsbehaelterspeicherbauwerk);
		CREATE INDEX alkis_12763e6c_6666_4302_a556_b2aeff74b421 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_wasserspiegelhoehe);
		CREATE INDEX alkis_d77010ed_e406_4fbc_afb1_30daf7e9380c ON ax_sonstigesbauwerkodersonstigeeinrichtung USING btree (gehoertzubauwerk_ax_wegpfadsteig);
		CREATE INDEX alkis_1052e3f5_0211_4a48_8367_9ee4c8d23583 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING gin (hatdirektunten);
		CREATE INDEX alkis_14835e4c_416a_4055_a29d_f91941366c5e ON ax_sonstigesbauwerkodersonstigeeinrichtung USING gin (istabgeleitetaus);
		CREATE INDEX alkis_60af1f78_0dea_4af5_aa8a_d743f7c0f113 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING gin (istteilvon);
		CREATE INDEX alkis_61d462e4_12cb_499b_98cb_db9cf40914d2 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING gin (traegtbeizu);

		ALTER TABLE ax_sonstigesrecht RENAME art TO zeigtaufexternes_art;
		-- ax_sonstigesrecht.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_sonstigesrecht ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_sonstigesrecht ALTER artderfestlegung SET NOT NULL;
		ALTER TABLE ax_sonstigesrecht ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_sonstigesrecht DROP characterstring;
		ALTER TABLE ax_sonstigesrecht DROP funktion;
		ALTER TABLE ax_sonstigesrecht ADD hatdirektunten character(16)[];
		ALTER TABLE ax_sonstigesrecht ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_sonstigesrecht ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_sonstigesrecht ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_sonstigesrecht ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_sonstigesrecht ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_sonstigesrecht ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_sonstigesrecht ADD istteilvon character(16)[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_address character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_datetime character(20)[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_individualname character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_organisationname character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_phone character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_positionname character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_rationale character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_role character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_sonstigesrecht ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_sonstigesrecht ADD statement character varying;
		ALTER TABLE ax_sonstigesrecht ADD traegtbeizu character(16)[];
		ALTER TABLE ax_sonstigesrecht ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_sonstigesrecht ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_84893f48_bc81_4120_b017_f44c923220a9 ON ax_sonstigesrecht USING btree (endet);
		CREATE INDEX alkis_f337a134_f9fe_4f7a_8671_26e9692278e7 ON ax_sonstigesrecht USING gin (hatdirektunten);
		CREATE INDEX alkis_8cdffee8_a012_4097_9b8b_6c460d28c893 ON ax_sonstigesrecht USING gin (istabgeleitetaus);
		CREATE INDEX alkis_093b8ba3_c327_4309_a7e0_217b2890e561 ON ax_sonstigesrecht USING gin (istteilvon);
		CREATE INDEX alkis_46ff8bff_0b5e_402e_8927_a87413008743 ON ax_sonstigesrecht USING gin (traegtbeizu);

		ALTER TABLE ax_sportfreizeitunderholungsflaeche ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD bezeichnung character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD hatdirektunten character(16)[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD istteilvon character(16)[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_address character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_datetime character(20)[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_individualname character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_organisationname character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_phone character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_positionname character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_rationale character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_role character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD statement character varying;
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD traegtbeizu character(16)[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_84013e64_abc0_44ca_a057_0e060c19d697 ON ax_sportfreizeitunderholungsflaeche USING btree (endet);
		CREATE INDEX alkis_bea3119c_aff6_4f45_8cb3_cde242751fc6 ON ax_sportfreizeitunderholungsflaeche USING gin (hatdirektunten);
		CREATE INDEX alkis_c7068084_90bb_453c_9b2e_d78cc82e09d0 ON ax_sportfreizeitunderholungsflaeche USING gin (istabgeleitetaus);
		CREATE INDEX alkis_3cc2532c_af74_4cfe_a5d6_2de406ce4c44 ON ax_sportfreizeitunderholungsflaeche USING gin (istteilvon);
		CREATE INDEX alkis_47da9a40_3481_4142_92c4_2e201b5560fc ON ax_sportfreizeitunderholungsflaeche USING gin (traegtbeizu);

		ALTER TABLE ax_stehendesgewaesser ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_stehendesgewaesser RENAME name TO zeigtaufexternes_name;
		-- ax_stehendesgewaesser.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_stehendesgewaesser ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_stehendesgewaesser ADD bezeichnung character varying;
		ALTER TABLE ax_stehendesgewaesser ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_stehendesgewaesser ADD gemeinde character varying;
		ALTER TABLE ax_stehendesgewaesser ADD hatdirektunten character(16)[];
		ALTER TABLE ax_stehendesgewaesser ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_stehendesgewaesser ADD istteilvon character(16)[];
		ALTER TABLE ax_stehendesgewaesser ADD kreis character varying;
		ALTER TABLE ax_stehendesgewaesser ADD lage character varying;
		ALTER TABLE ax_stehendesgewaesser ADD land character varying;
		ALTER TABLE ax_stehendesgewaesser ADD processstep_address character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_datetime character(20)[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_individualname character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_organisationname character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_phone character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_positionname character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_rationale character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_role character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD regierungsbezirk character varying;
		ALTER TABLE ax_stehendesgewaesser ADD schifffahrtskategorie integer;
		ALTER TABLE ax_stehendesgewaesser ADD statement character varying;
		ALTER TABLE ax_stehendesgewaesser ADD traegtbeizu character(16)[];
		ALTER TABLE ax_stehendesgewaesser ADD widmung integer;
		ALTER TABLE ax_stehendesgewaesser ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_114f4d4e_785e_4f97_9805_94b1675a5388 ON ax_stehendesgewaesser USING btree (endet);
		CREATE INDEX alkis_194915c0_b58c_45ad_a03b_cedaa569a854 ON ax_stehendesgewaesser USING gin (hatdirektunten);
		CREATE INDEX alkis_365c8a1e_613d_4a28_8d63_1df37a32525e ON ax_stehendesgewaesser USING gin (istabgeleitetaus);
		CREATE INDEX alkis_287507be_09ad_4ec6_894a_96d40475c742 ON ax_stehendesgewaesser USING gin (istteilvon);
		CREATE INDEX alkis_d4c1dbc5_f13c_4217_80c1_be01be1af93d ON ax_stehendesgewaesser USING gin (traegtbeizu);

		ALTER TABLE ax_strassenverkehr ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_strassenverkehr RENAME name TO zeigtaufexternes_name;
		-- ax_strassenverkehr.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_strassenverkehr ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_strassenverkehr ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_strassenverkehr ADD hatdirektunten character(16)[];
		ALTER TABLE ax_strassenverkehr ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_strassenverkehr ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_strassenverkehr ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_strassenverkehr ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_strassenverkehr ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_strassenverkehr ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_strassenverkehr ADD istteilvon character(16)[];
		ALTER TABLE ax_strassenverkehr ADD processstep_address character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_datetime character(20)[];
		ALTER TABLE ax_strassenverkehr ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_individualname character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_organisationname character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_phone character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_positionname character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_rationale character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_role character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_strassenverkehr ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_strassenverkehr ADD statement character varying;
		ALTER TABLE ax_strassenverkehr ADD traegtbeizu character(16)[];
		ALTER TABLE ax_strassenverkehr ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_strassenverkehr ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_035fef35_dc12_4eff_afae_20b5cd44971c ON ax_strassenverkehr USING btree (endet);
		CREATE INDEX alkis_5fd84952_8486_4da7_968d_2ccb41ece4a6 ON ax_strassenverkehr USING gin (hatdirektunten);
		CREATE INDEX alkis_7b234dc8_b08a_4723_a034_dd673ac1fd60 ON ax_strassenverkehr USING gin (istabgeleitetaus);
		CREATE INDEX alkis_7b29b31a_9b7e_4ec0_aa72_5ddc9dd0046c ON ax_strassenverkehr USING gin (istteilvon);
		CREATE INDEX alkis_5f7fb978_caa9_459a_a3d0_d7382fc76b59 ON ax_strassenverkehr USING gin (traegtbeizu);

		ALTER TABLE ax_strassenverkehrsanlage ALTER art SET NOT NULL;
		ALTER TABLE ax_strassenverkehrsanlage ALTER beginnt SET NOT NULL;
		-- ax_strassenverkehrsanlage.bezeichnung => bezeichnung: character varying => character varying[]
		ALTER TABLE ax_strassenverkehrsanlage ALTER bezeichnung TYPE character varying[] USING CASE WHEN bezeichnung IS NULL THEN NULL ELSE ARRAY[bezeichnung] END;
		ALTER TABLE ax_strassenverkehrsanlage ADD hatdirektunten character(16)[];
		ALTER TABLE ax_strassenverkehrsanlage ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_strassenverkehrsanlage ADD istteilvon character(16)[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_address character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_datetime character(20)[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_individualname character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_organisationname character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_phone character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_positionname character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_rationale character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_role character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD statement character varying;
		ALTER TABLE ax_strassenverkehrsanlage ADD strassenschluessel character varying;
		ALTER TABLE ax_strassenverkehrsanlage ADD traegtbeizu character(16)[];
		ALTER TABLE ax_strassenverkehrsanlage ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_strassenverkehrsanlage ADD zweitname character varying;
		CREATE INDEX alkis_c8e20472_6df6_4af4_87dc_986a9993d323 ON ax_strassenverkehrsanlage USING btree (endet);
		CREATE INDEX alkis_36dc8e9e_673d_4e57_b887_f844ebbe2e83 ON ax_strassenverkehrsanlage USING gin (hatdirektunten);
		CREATE INDEX alkis_21d036cb_89ff_4260_9e7a_c5945ab772a1 ON ax_strassenverkehrsanlage USING gin (istabgeleitetaus);
		CREATE INDEX alkis_c38b8084_3809_4f32_8ec3_9f746fa0f97d ON ax_strassenverkehrsanlage USING gin (istteilvon);
		CREATE INDEX alkis_f568fb3f_d5d4_4165_8b89_af906cca8434 ON ax_strassenverkehrsanlage USING gin (traegtbeizu);

		ALTER TABLE ax_sumpf ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_sumpf ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_sumpf ADD hatdirektunten character(16)[];
		ALTER TABLE ax_sumpf ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_sumpf ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_sumpf ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_sumpf ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_sumpf ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_sumpf ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_sumpf ADD istteilvon character(16)[];
		ALTER TABLE ax_sumpf ADD processstep_address character varying[];
		ALTER TABLE ax_sumpf ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_sumpf ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_sumpf ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_sumpf ADD processstep_datetime character(20)[];
		ALTER TABLE ax_sumpf ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_sumpf ADD processstep_individualname character varying[];
		ALTER TABLE ax_sumpf ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_sumpf ADD processstep_organisationname character varying[];
		ALTER TABLE ax_sumpf ADD processstep_phone character varying[];
		ALTER TABLE ax_sumpf ADD processstep_positionname character varying[];
		ALTER TABLE ax_sumpf ADD processstep_rationale character varying[];
		ALTER TABLE ax_sumpf ADD processstep_role character varying[];
		ALTER TABLE ax_sumpf ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_sumpf ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_sumpf ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_sumpf ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_sumpf ADD statement character varying;
		ALTER TABLE ax_sumpf ADD traegtbeizu character(16)[];
		ALTER TABLE ax_sumpf ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_sumpf ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_sumpf ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e13e5165_e423_4dd6_a4a0_003a4aa63fe3 ON ax_sumpf USING btree (endet);
		CREATE INDEX alkis_3565e92e_31bf_4bec_9f56_ec8d205e7deb ON ax_sumpf USING gin (hatdirektunten);
		CREATE INDEX alkis_19421cea_36fe_448b_a928_a3d082f40c2c ON ax_sumpf USING gin (istabgeleitetaus);
		CREATE INDEX alkis_04549102_fe12_49f5_b243_8830d78f350f ON ax_sumpf USING gin (istteilvon);
		CREATE INDEX alkis_6a2708de_6ae7_42f3_b4ab_db95c0a321a5 ON ax_sumpf USING gin (traegtbeizu);

		ALTER TABLE ax_tagebaugrubesteinbruch ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD bezeichnung character varying;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_tagebaugrubesteinbruch ADD hatdirektunten character(16)[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD istteilvon character(16)[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_address character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_datetime character(20)[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_individualname character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_organisationname character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_phone character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_positionname character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_rationale character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_role character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD statement character varying;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD traegtbeizu character(16)[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_tagebaugrubesteinbruch ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_2315e942_97e5_4fb0_9e62_f4350c30bf7e ON ax_tagebaugrubesteinbruch USING btree (endet);
		CREATE INDEX alkis_c9a61a4d_9304_4718_a136_ab188e243401 ON ax_tagebaugrubesteinbruch USING gin (hatdirektunten);
		CREATE INDEX alkis_f18c2976_07c7_46d1_bec4_b5a14b3df883 ON ax_tagebaugrubesteinbruch USING gin (istabgeleitetaus);
		CREATE INDEX alkis_40947f73_e89d_4ec2_83a3_8481e105129d ON ax_tagebaugrubesteinbruch USING gin (istteilvon);
		CREATE INDEX alkis_b7b0dc34_98aa_4abc_bddc_3d7dab48c8f5 ON ax_tagebaugrubesteinbruch USING gin (traegtbeizu);

		ALTER TABLE ax_tagesabschnitt ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_tagesabschnitt ALTER tagesabschnittsnummer SET NOT NULL;
		ALTER TABLE ax_tagesabschnitt ADD hatdirektunten character(16)[];
		ALTER TABLE ax_tagesabschnitt ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_tagesabschnitt ADD istteilvon character(16)[];
		ALTER TABLE ax_tagesabschnitt ADD traegtbeizu character(16)[];
		ALTER TABLE ax_tagesabschnitt ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_tagesabschnitt ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_tagesabschnitt ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_36378475_d0a7_4cb4_ab48_5261618285a5 ON ax_tagesabschnitt USING btree (endet);
		CREATE INDEX alkis_5dbd83fa_41d1_429f_9ce9_12e27c101ed7 ON ax_tagesabschnitt USING gin (hatdirektunten);
		CREATE INDEX alkis_2d93029a_7dc9_487f_bc4f_6b2f6c6222a8 ON ax_tagesabschnitt USING gin (istabgeleitetaus);
		CREATE INDEX alkis_2b9e3857_8d14_4dd8_9ddb_d0bbe42dc347 ON ax_tagesabschnitt USING gin (istteilvon);
		CREATE INDEX alkis_0d20d5b7_c5ff_4bde_bcd5_569a939034de ON ax_tagesabschnitt USING gin (traegtbeizu);

		ALTER TABLE ax_topographischelinie ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_topographischelinie ALTER liniendarstellung SET NOT NULL;
		ALTER TABLE ax_topographischelinie ADD hatdirektunten character(16)[];
		ALTER TABLE ax_topographischelinie ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_topographischelinie ADD istteilvon character(16)[];
		ALTER TABLE ax_topographischelinie ADD traegtbeizu character(16)[];
		ALTER TABLE ax_topographischelinie ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_topographischelinie ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_topographischelinie ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_c2e1f847_c243_418b_98aa_efed9e52493d ON ax_topographischelinie USING btree (endet);
		CREATE INDEX alkis_1fb5ff91_0f28_4d33_85bd_150704d0d034 ON ax_topographischelinie USING gin (hatdirektunten);
		CREATE INDEX alkis_fec26ad5_5a4b_4fc3_80e4_24de613549e9 ON ax_topographischelinie USING gin (istabgeleitetaus);
		CREATE INDEX alkis_bf4e8d3d_e0b3_4db3_91f3_88264834ea46 ON ax_topographischelinie USING gin (istteilvon);
		CREATE INDEX alkis_9b10d6ff_7129_4674_9f22_7245e8ee840b ON ax_topographischelinie USING gin (traegtbeizu);

		ALTER TABLE ax_transportanlage RENAME art TO zeigtaufexternes_art;
		-- ax_transportanlage.art => zeigtaufexternes_art: character varying => character varying[]
		ALTER TABLE ax_transportanlage ALTER zeigtaufexternes_art TYPE character varying[] USING CASE WHEN zeigtaufexternes_art IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_art] END;
		ALTER TABLE ax_transportanlage ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_transportanlage ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_transportanlage RENAME name TO zeigtaufexternes_name;
		-- ax_transportanlage.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_transportanlage ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_transportanlage ADD hatdirektunten character(16)[];
		ALTER TABLE ax_transportanlage ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_transportanlage ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_transportanlage ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_transportanlage ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_transportanlage ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_transportanlage ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_transportanlage ADD istteilvon character(16)[];
		ALTER TABLE ax_transportanlage ADD processstep_address character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_datetime character(20)[];
		ALTER TABLE ax_transportanlage ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_individualname character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_organisationname character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_phone character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_positionname character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_rationale character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_role character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_transportanlage ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_transportanlage ADD statement character varying;
		ALTER TABLE ax_transportanlage ADD traegtbeizu character(16)[];
		ALTER TABLE ax_transportanlage ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_efbb80ce_d49c_44ac_8a9f_5d9c6d7930ba ON ax_transportanlage USING btree (endet);
		CREATE INDEX alkis_4b662244_3302_4fcd_86ff_563499a71be7 ON ax_transportanlage USING gin (hatdirektunten);
		CREATE INDEX alkis_aff025f8_5167_4803_89e5_d9b5cdd4e9e5 ON ax_transportanlage USING gin (istabgeleitetaus);
		CREATE INDEX alkis_922e24ee_a8b4_4bb5_8d12_e3d3b8aac44d ON ax_transportanlage USING gin (istteilvon);
		CREATE INDEX alkis_564ac042_f731_499f_9beb_56ed026ccc49 ON ax_transportanlage USING gin (traegtbeizu);

		-- ax_turm.bauwerksfunktion => bauwerksfunktion: integer => integer[]
		ALTER TABLE ax_turm ALTER bauwerksfunktion TYPE integer[] USING CASE WHEN bauwerksfunktion IS NULL THEN NULL ELSE ARRAY[bauwerksfunktion] END;
		ALTER TABLE ax_turm ALTER bauwerksfunktion SET NOT NULL;
		ALTER TABLE ax_turm ALTER beginnt SET NOT NULL;
		-- ax_turm.zeigtauf => zeigtauf: character(16) => character(16)[]
		ALTER TABLE ax_turm ALTER zeigtauf TYPE character(16)[] USING CASE WHEN zeigtauf IS NULL THEN NULL ELSE ARRAY[zeigtauf] END;
		ALTER TABLE ax_turm ADD hatdirektunten character(16)[];
		ALTER TABLE ax_turm ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_turm ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_turm ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_turm ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_turm ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_turm ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_turm ADD istteilvon character(16)[];
		ALTER TABLE ax_turm ADD objekthoehe double precision;
		ALTER TABLE ax_turm ADD processstep_address character varying[];
		ALTER TABLE ax_turm ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_turm ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_turm ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_turm ADD processstep_datetime character(20)[];
		ALTER TABLE ax_turm ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_turm ADD processstep_individualname character varying[];
		ALTER TABLE ax_turm ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_turm ADD processstep_organisationname character varying[];
		ALTER TABLE ax_turm ADD processstep_phone character varying[];
		ALTER TABLE ax_turm ADD processstep_positionname character varying[];
		ALTER TABLE ax_turm ADD processstep_rationale character varying[];
		ALTER TABLE ax_turm ADD processstep_role character varying[];
		ALTER TABLE ax_turm ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_turm ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_turm ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_turm ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_turm ADD statement character varying;
		ALTER TABLE ax_turm ADD traegtbeizu character(16)[];
		ALTER TABLE ax_turm ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_turm ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_turm ADD zeigtaufexternes_uri character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_turm' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_turm USING btree (zeigtauf)';
		CREATE INDEX alkis_97d04fc1_bdf6_4978_b376_5678d5e7455c ON ax_turm USING btree (endet);
		CREATE INDEX alkis_4a6977a6_28a6_43d0_a542_1706c03dfc99 ON ax_turm USING gin (hatdirektunten);
		CREATE INDEX alkis_8ef79b33_5de7_4202_8d06_c6860adff24b ON ax_turm USING gin (istabgeleitetaus);
		CREATE INDEX alkis_4c793ced_3e9e_40fc_8c47_d23b3c7ea556 ON ax_turm USING gin (istteilvon);
		CREATE INDEX alkis_bfbcbc0f_2950_45f2_b125_b81a64260f2a ON ax_turm USING gin (traegtbeizu);
		CREATE INDEX alkis_dcf731b3_9941_47cc_a3cc_225a88d4b71c ON ax_turm USING gin (zeigtauf);

		ALTER TABLE ax_unlandvegetationsloseflaeche ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD hatdirektunten character(16)[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD istteilvon character(16)[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_address character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_datetime character(20)[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_individualname character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_organisationname character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_phone character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_positionname character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_rationale character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_role character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD statement character varying;
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD traegtbeizu character(16)[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_a39b050a_9fee_4fcb_bb00_aa33fe2d6b61 ON ax_unlandvegetationsloseflaeche USING btree (endet);
		CREATE INDEX alkis_cddc9c34_6b34_4e83_80f7_aca4efd73b47 ON ax_unlandvegetationsloseflaeche USING gin (hatdirektunten);
		CREATE INDEX alkis_5d97999c_2d89_473c_a993_8ebb73eee425 ON ax_unlandvegetationsloseflaeche USING gin (istabgeleitetaus);
		CREATE INDEX alkis_1b344fe5_034a_4fce_af66_2a9ccc35022f ON ax_unlandvegetationsloseflaeche USING gin (istteilvon);
		CREATE INDEX alkis_832f882b_41b5_42ec_8c56_79d5f4fcf6c6 ON ax_unlandvegetationsloseflaeche USING gin (traegtbeizu);

		ALTER TABLE ax_untergeordnetesgewaesser ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_untergeordnetesgewaesser ADD hatdirektunten character(16)[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD istteilvon character(16)[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_address character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_datetime character(20)[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_individualname character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_organisationname character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_phone character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_positionname character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_rationale character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_role character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD statement character varying;
		ALTER TABLE ax_untergeordnetesgewaesser ADD traegtbeizu character(16)[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_747c62de_7ab8_4886_a034_b0201eec47eb ON ax_untergeordnetesgewaesser USING btree (endet);
		CREATE INDEX alkis_0825db75_73fb_45d1_a2eb_77a3d312039c ON ax_untergeordnetesgewaesser USING gin (hatdirektunten);
		CREATE INDEX alkis_fe184775_a077_4a06_8ded_e963669edd39 ON ax_untergeordnetesgewaesser USING gin (istabgeleitetaus);
		CREATE INDEX alkis_01b41756_e4fd_4042_b6dc_01f10db36055 ON ax_untergeordnetesgewaesser USING gin (istteilvon);
		CREATE INDEX alkis_7c92750a_9a48_4b52_8f49_9f5c4394233e ON ax_untergeordnetesgewaesser USING gin (traegtbeizu);

		ALTER TABLE ax_vegetationsmerkmal ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_vegetationsmerkmal ADD bezeichnung character varying;
		ALTER TABLE ax_vegetationsmerkmal ADD breitedesobjekts double precision;
		ALTER TABLE ax_vegetationsmerkmal ADD funktion integer;
		ALTER TABLE ax_vegetationsmerkmal ADD hatdirektunten character(16)[];
		ALTER TABLE ax_vegetationsmerkmal ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_vegetationsmerkmal ADD istteilvon character(16)[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_address character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_datetime character(20)[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_individualname character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_organisationname character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_phone character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_positionname character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_rationale character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_role character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD statement character varying;
		ALTER TABLE ax_vegetationsmerkmal ADD traegtbeizu character(16)[];
		ALTER TABLE ax_vegetationsmerkmal ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_vegetationsmerkmal ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_012bf8c0_0caa_4dc9_87de_a8dec4e65fb5 ON ax_vegetationsmerkmal USING btree (endet);
		CREATE INDEX alkis_21fef265_8ad0_4938_9082_c5110dab0793 ON ax_vegetationsmerkmal USING gin (hatdirektunten);
		CREATE INDEX alkis_bdd4f932_09d6_438a_974b_d2330dd00daf ON ax_vegetationsmerkmal USING gin (istabgeleitetaus);
		CREATE INDEX alkis_e9ec1be4_44a1_4c6a_a765_e614cb89030e ON ax_vegetationsmerkmal USING gin (istteilvon);
		CREATE INDEX alkis_9c9886b5_ca51_419c_ba61_57b7c40c097d ON ax_vegetationsmerkmal USING gin (traegtbeizu);

		ALTER TABLE ax_vertretung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_vertretung ALTER haengtan SET NOT NULL;
		ALTER TABLE ax_vertretung ADD angabenzurvertretung character varying;
		ALTER TABLE ax_vertretung ADD artdervertretung character varying[];
		ALTER TABLE ax_vertretung ADD beginndervertretung date;
		ALTER TABLE ax_vertretung ADD endedervertretung date;
		ALTER TABLE ax_vertretung ADD istteilvon character(16)[];
		ALTER TABLE ax_vertretung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_vertretung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_vertretung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_8a8c8269_6895_47f6_9969_3d795eaa5f36 ON ax_vertretung USING btree (endet);
		CREATE INDEX alkis_32c51271_cafa_4acc_b7e0_b76532b3956f ON ax_vertretung USING btree (gml_id, beginnt);
		CREATE INDEX alkis_f35ba914_2f60_4073_a705_51fa489c3e02 ON ax_vertretung USING btree (haengtan);
		CREATE INDEX alkis_ed1318ee_b553_4740_848a_95d8441965f8 ON ax_vertretung USING gin (beziehtsichauf);
		CREATE INDEX alkis_36443c57_839b_45aa_a0d5_6570ce8339ee ON ax_vertretung USING gin (istteilvon);
		CREATE INDEX alkis_6cd5876b_988e_4e67_af1f_389510d66a45 ON ax_vertretung USING gin (vertritt);

		ALTER TABLE ax_verwaltung ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_verwaltung ALTER haengtan SET NOT NULL;
		ALTER TABLE ax_verwaltung ADD ax_li_processstep_ohnedatenerhebung_description character varying[];
		ALTER TABLE ax_verwaltung ADD beginnderbestellung date;
		ALTER TABLE ax_verwaltung ADD bestellungsbeschluss character varying;
		ALTER TABLE ax_verwaltung ADD endederbestellung date;
		ALTER TABLE ax_verwaltung ADD grundakt character varying;
		ALTER TABLE ax_verwaltung ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_verwaltung ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_verwaltung ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_verwaltung ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_verwaltung ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_verwaltung ADD istteilvon character(16)[];
		ALTER TABLE ax_verwaltung ADD notariat character varying;
		ALTER TABLE ax_verwaltung ADD processstep_address character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_datetime character(20)[];
		ALTER TABLE ax_verwaltung ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_individualname character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_organisationname character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_phone character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_positionname character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_rationale character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_role character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_verwaltung ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_verwaltung ADD statement character varying;
		ALTER TABLE ax_verwaltung ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_verwaltung ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_verwaltung ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_c58d6105_d099_40bc_85e7_2e20d50a5fef ON ax_verwaltung USING btree (endet);
		CREATE INDEX alkis_963197f8_987c_40fe_acbd_41f79968c7e3 ON ax_verwaltung USING btree (gml_id, beginnt);
		CREATE INDEX alkis_80432bab_4461_4c74_983f_ea1636669116 ON ax_verwaltung USING btree (haengtan);
		CREATE INDEX alkis_f50a3b63_14bc_4e12_9919_0a9dd0feb815 ON ax_verwaltung USING gin (beziehtsichauf);
		CREATE INDEX alkis_9d5c5caf_acf8_4e86_b187_7c63cc45fea1 ON ax_verwaltung USING gin (istteilvon);

		ALTER TABLE ax_verwaltungsgemeinschaft ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_verwaltungsgemeinschaft ALTER bezeichnung SET NOT NULL;
		ALTER TABLE ax_verwaltungsgemeinschaft ALTER kreis SET NOT NULL;
		ALTER TABLE ax_verwaltungsgemeinschaft ALTER land SET NOT NULL;
		ALTER TABLE ax_verwaltungsgemeinschaft ALTER schluesselgesamt SET NOT NULL;
		-- ax_verwaltungsgemeinschaft.verwaltungsgemeinschaft => verwaltungsgemeinschaft: integer => character varying
		ALTER TABLE ax_verwaltungsgemeinschaft ALTER verwaltungsgemeinschaft TYPE character varying USING verwaltungsgemeinschaft::varchar;
		ALTER TABLE ax_verwaltungsgemeinschaft ALTER verwaltungsgemeinschaft SET NOT NULL;
		ALTER TABLE ax_verwaltungsgemeinschaft ADD administrativefunktion integer[];
		ALTER TABLE ax_verwaltungsgemeinschaft ADD bestehtaus character(16)[];
		ALTER TABLE ax_verwaltungsgemeinschaft ADD istteilvon character(16)[];
		ALTER TABLE ax_verwaltungsgemeinschaft ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_verwaltungsgemeinschaft ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_verwaltungsgemeinschaft ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_f39424b1_f43f_426b_ab8b_b2f7ef9b6469 ON ax_verwaltungsgemeinschaft USING btree (endet);
		CREATE INDEX alkis_e1604d84_e100_4500_bad4_82ecc1d29542 ON ax_verwaltungsgemeinschaft USING btree (gml_id, beginnt);
		CREATE INDEX alkis_1aec869b_8c49_48a6_be74_aa3fe63245ba ON ax_verwaltungsgemeinschaft USING gin (bestehtaus);
		CREATE INDEX alkis_036218c4_f443_4572_bb0e_518bb5d952ae ON ax_verwaltungsgemeinschaft USING gin (istteilvon);

		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD hatdirektunten character(16)[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD istteilvon character(16)[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD objekthoehe double precision;
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_address character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_datetime character(20)[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_individualname character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_organisationname character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_phone character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_positionname character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_rationale character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_role character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD statement character varying;
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD traegtbeizu character(16)[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_de92ad47_6165_48b6_9509_7986ebd38111 ON ax_vorratsbehaelterspeicherbauwerk USING btree (endet);
		CREATE INDEX alkis_cfba6705_a90c_4800_a38a_fbdf3dbde172 ON ax_vorratsbehaelterspeicherbauwerk USING gin (hatdirektunten);
		CREATE INDEX alkis_09b0b001_36fc_43a6_b1fd_be43b5b7c8da ON ax_vorratsbehaelterspeicherbauwerk USING gin (istabgeleitetaus);
		CREATE INDEX alkis_c749ee2f_2a37_43fc_9c7a_7e927c2c7036 ON ax_vorratsbehaelterspeicherbauwerk USING gin (istteilvon);
		CREATE INDEX alkis_cc265066_cd12_4bd9_9626_b50cc7c75b46 ON ax_vorratsbehaelterspeicherbauwerk USING gin (traegtbeizu);

		ALTER TABLE ax_wald ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_wald ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_wald ADD hatdirektunten character(16)[];
		ALTER TABLE ax_wald ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_wald ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_wald ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_wald ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_wald ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_wald ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_wald ADD istteilvon character(16)[];
		ALTER TABLE ax_wald ADD processstep_address character varying[];
		ALTER TABLE ax_wald ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_wald ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_wald ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_wald ADD processstep_datetime character(20)[];
		ALTER TABLE ax_wald ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_wald ADD processstep_individualname character varying[];
		ALTER TABLE ax_wald ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_wald ADD processstep_organisationname character varying[];
		ALTER TABLE ax_wald ADD processstep_phone character varying[];
		ALTER TABLE ax_wald ADD processstep_positionname character varying[];
		ALTER TABLE ax_wald ADD processstep_rationale character varying[];
		ALTER TABLE ax_wald ADD processstep_role character varying[];
		ALTER TABLE ax_wald ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_wald ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_wald ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_wald ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_wald ADD statement character varying;
		ALTER TABLE ax_wald ADD traegtbeizu character(16)[];
		ALTER TABLE ax_wald ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_wald ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_wald ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_a4e1f3ad_cb2d_4ddb_8e98_92182bfaf008 ON ax_wald USING btree (endet);
		CREATE INDEX alkis_b78a8b34_278d_4ccb_8e5b_7ac874a1631e ON ax_wald USING gin (hatdirektunten);
		CREATE INDEX alkis_457773d3_5bc0_44d9_9908_cde9ccef4e3d ON ax_wald USING gin (istabgeleitetaus);
		CREATE INDEX alkis_b10a76fe_77df_4b90_9f49_9d8f34cfbd5a ON ax_wald USING gin (istteilvon);
		CREATE INDEX alkis_3f475463_06c1_444c_97ae_eba26591ddcf ON ax_wald USING gin (traegtbeizu);

		ALTER TABLE ax_wasserspiegelhoehe ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_wasserspiegelhoehe ALTER hoehedeswasserspiegels SET NOT NULL;
		-- ax_wasserspiegelhoehe.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_wasserspiegelhoehe DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_wasserspiegelhoehe RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_wasserspiegelhoehe','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_wasserspiegelhoehe SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_wasserspiegelhoehe DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_wasserspiegelhoehe_wkb_geometry_idx ON ax_wasserspiegelhoehe USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_wasserspiegelhoehe ADD hatdirektunten character(16)[];
		ALTER TABLE ax_wasserspiegelhoehe ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_wasserspiegelhoehe ADD istteilvon character(16)[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_address character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_datetime character(20)[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_individualname character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_organisationname character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_phone character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_positionname character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_rationale character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_role character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD statement character varying;
		ALTER TABLE ax_wasserspiegelhoehe ADD traegtbeizu character(16)[];
		ALTER TABLE ax_wasserspiegelhoehe ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_e14036cb_e8fc_4e6e_81cd_3174b230bddc ON ax_wasserspiegelhoehe USING btree (endet);
		CREATE INDEX alkis_11696f21_6b91_49bc_abfc_78edbf64463a ON ax_wasserspiegelhoehe USING gin (hatdirektunten);
		CREATE INDEX alkis_a7857584_3df2_4d25_a061_7ea50f2f466b ON ax_wasserspiegelhoehe USING gin (istabgeleitetaus);
		CREATE INDEX alkis_8819c8fb_2344_4177_b6c8_77c4df9e27eb ON ax_wasserspiegelhoehe USING gin (istteilvon);
		CREATE INDEX alkis_630279b3_c271_4db7_971c_ee5d13914651 ON ax_wasserspiegelhoehe USING gin (traegtbeizu);

		ALTER TABLE ax_weg ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_weg RENAME name TO zeigtaufexternes_name;
		-- ax_weg.name => zeigtaufexternes_name: character varying => character varying[]
		ALTER TABLE ax_weg ALTER zeigtaufexternes_name TYPE character varying[] USING CASE WHEN zeigtaufexternes_name IS NULL THEN NULL ELSE ARRAY[zeigtaufexternes_name] END;
		ALTER TABLE ax_weg ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_weg ADD hatdirektunten character(16)[];
		ALTER TABLE ax_weg ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_weg ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_weg ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_weg ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_weg ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_weg ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_weg ADD istteilvon character(16)[];
		ALTER TABLE ax_weg ADD processstep_address character varying[];
		ALTER TABLE ax_weg ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_weg ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_weg ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_weg ADD processstep_datetime character(20)[];
		ALTER TABLE ax_weg ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_weg ADD processstep_individualname character varying[];
		ALTER TABLE ax_weg ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_weg ADD processstep_organisationname character varying[];
		ALTER TABLE ax_weg ADD processstep_phone character varying[];
		ALTER TABLE ax_weg ADD processstep_positionname character varying[];
		ALTER TABLE ax_weg ADD processstep_rationale character varying[];
		ALTER TABLE ax_weg ADD processstep_role character varying[];
		ALTER TABLE ax_weg ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_weg ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_weg ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_weg ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_weg ADD statement character varying;
		ALTER TABLE ax_weg ADD traegtbeizu character(16)[];
		ALTER TABLE ax_weg ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_weg ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_5167164d_afc5_4662_8930_e2baaf5c88c8 ON ax_weg USING btree (endet);
		CREATE INDEX alkis_8f4ef0f8_b3b9_4c9e_a225_02c03ddf1960 ON ax_weg USING gin (hatdirektunten);
		CREATE INDEX alkis_64be3114_2960_4b4f_beb7_b2b56d7f14f6 ON ax_weg USING gin (istabgeleitetaus);
		CREATE INDEX alkis_5d311977_50b6_46e4_9d65_77eafbac6fad ON ax_weg USING gin (istteilvon);
		CREATE INDEX alkis_084ac247_05fc_42d1_81a3_09bd008eef16 ON ax_weg USING gin (traegtbeizu);

		ALTER TABLE ax_wegpfadsteig ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_wegpfadsteig ADD befestigung integer;
		ALTER TABLE ax_wegpfadsteig ADD bezeichnung character varying;
		ALTER TABLE ax_wegpfadsteig ADD breitedesverkehrsweges integer;
		ALTER TABLE ax_wegpfadsteig ADD hatdirektunten character(16)[];
		ALTER TABLE ax_wegpfadsteig ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_wegpfadsteig ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_wegpfadsteig ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_wegpfadsteig ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_wegpfadsteig ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_wegpfadsteig ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_wegpfadsteig ADD istteilvon character(16)[];
		ALTER TABLE ax_wegpfadsteig ADD markierung integer;
		ALTER TABLE ax_wegpfadsteig ADD processstep_address character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_datetime character(20)[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_individualname character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_organisationname character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_phone character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_positionname character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_rationale character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_role character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_wegpfadsteig ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_wegpfadsteig ADD statement character varying;
		ALTER TABLE ax_wegpfadsteig ADD strassenschluessel character varying;
		ALTER TABLE ax_wegpfadsteig ADD traegtbeizu character(16)[];
		ALTER TABLE ax_wegpfadsteig ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_wegpfadsteig ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_wegpfadsteig ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_wegpfadsteig ADD zweitname character varying;
		CREATE INDEX alkis_206d1c7c_de8a_4d01_8e87_526d5bf4b45e ON ax_wegpfadsteig USING btree (endet);
		CREATE INDEX alkis_7f545e57_def4_4e50_8017_53cb027fd393 ON ax_wegpfadsteig USING gin (hatdirektunten);
		CREATE INDEX alkis_97f3fa52_64e9_412f_a69d_b55bd3f81ac8 ON ax_wegpfadsteig USING gin (istabgeleitetaus);
		CREATE INDEX alkis_9825a239_8d09_4d3e_9c69_b8a752555053 ON ax_wegpfadsteig USING gin (istteilvon);
		CREATE INDEX alkis_dd494fad_512c_43ac_9d4a_81bd07bafb03 ON ax_wegpfadsteig USING gin (traegtbeizu);

		ALTER TABLE ax_wirtschaftlicheeinheit ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_wirtschaftlicheeinheit ADD bestehtaus character(16)[];
		ALTER TABLE ax_wirtschaftlicheeinheit ADD istteilvon character(16)[];
		ALTER TABLE ax_wirtschaftlicheeinheit ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_wirtschaftlicheeinheit ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_wirtschaftlicheeinheit ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_27ba03e1_1a12_42e7_8bcb_c63daf7c46da ON ax_wirtschaftlicheeinheit USING btree (endet);
		CREATE INDEX alkis_1c5856cf_6b52_4b71_997d_2f3b3de31cd7 ON ax_wirtschaftlicheeinheit USING btree (gml_id, beginnt);
		CREATE INDEX alkis_a83f5929_6259_47b1_8450_4611ca0dd4e0 ON ax_wirtschaftlicheeinheit USING gin (bestehtaus);
		CREATE INDEX alkis_0b8dcdd0_67bc_4276_90f0_755ad2c220de ON ax_wirtschaftlicheeinheit USING gin (istteilvon);

		ALTER TABLE ax_wohnbauflaeche ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_wohnbauflaeche ADD datumderletztenueberpruefung character(20);
		ALTER TABLE ax_wohnbauflaeche ADD hatdirektunten character(16)[];
		ALTER TABLE ax_wohnbauflaeche ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_wohnbauflaeche ADD istteilvon character(16)[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_address character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_datetime character(20)[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_individualname character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_organisationname character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_phone character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_positionname character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_rationale character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_role character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD statement character varying;
		ALTER TABLE ax_wohnbauflaeche ADD traegtbeizu character(16)[];
		ALTER TABLE ax_wohnbauflaeche ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD zeigtaufexternes_uri character varying[];
		ALTER TABLE ax_wohnbauflaeche ADD zweitname character varying;
		CREATE INDEX alkis_21ca05fa_f292_40c0_8a83_6b7232096251 ON ax_wohnbauflaeche USING btree (endet);
		CREATE INDEX alkis_28b4994b_27bb_4917_b991_0108060ed58f ON ax_wohnbauflaeche USING gin (hatdirektunten);
		CREATE INDEX alkis_86a47a7d_de6b_4dd8_8f5a_9ed021054dcc ON ax_wohnbauflaeche USING gin (istabgeleitetaus);
		CREATE INDEX alkis_06e406a8_f7cb_4776_a47d_3ac28701f94c ON ax_wohnbauflaeche USING gin (istteilvon);
		CREATE INDEX alkis_36f5abb5_9328_467a_b2eb_8265eabc3e72 ON ax_wohnbauflaeche USING gin (traegtbeizu);

		ALTER TABLE ax_wohnplatz ALTER beginnt SET NOT NULL;
		ALTER TABLE ax_wohnplatz ALTER name SET NOT NULL;
		-- ax_wohnplatz.wkb_geometry => wkb_geometry: geometry(Point,25832) => geometry(Geometry,25832)
		BEGIN
			ALTER TABLE ax_wohnplatz DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ax_wohnplatz RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ax_wohnplatz','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
			UPDATE ax_wohnplatz SET wkb_geometry=wkb_geometry_;
			ALTER TABLE ax_wohnplatz DROP wkb_geometry_ CASCADE;
			CREATE INDEX ax_wohnplatz_wkb_geometry_idx ON ax_wohnplatz USING gist(wkb_geometry);
		END;
		ALTER TABLE ax_wohnplatz ADD bezeichnung character varying[];
		ALTER TABLE ax_wohnplatz ADD einwohnerzahl character varying;
		ALTER TABLE ax_wohnplatz ADD hatdirektunten character(16)[];
		ALTER TABLE ax_wohnplatz ADD istabgeleitetaus character(16)[];
		ALTER TABLE ax_wohnplatz ADD istteilvon character(16)[];
		ALTER TABLE ax_wohnplatz ADD traegtbeizu character(16)[];
		ALTER TABLE ax_wohnplatz ADD zeigtaufexternes_art character varying[];
		ALTER TABLE ax_wohnplatz ADD zeigtaufexternes_name character varying[];
		ALTER TABLE ax_wohnplatz ADD zeigtaufexternes_uri character varying[];
		CREATE INDEX alkis_dda8a583_40fb_492e_942e_5fced40b27c0 ON ax_wohnplatz USING btree (endet);
		CREATE INDEX alkis_d6c698c1_1646_4a56_b19e_139b3abe5cf1 ON ax_wohnplatz USING gin (hatdirektunten);
		CREATE INDEX alkis_675567e1_fbfc_4c21_b097_89ff9dd37f95 ON ax_wohnplatz USING gin (istabgeleitetaus);
		CREATE INDEX alkis_bbe1f5ef_025e_4336_8881_eb1037e663d7 ON ax_wohnplatz USING gin (istteilvon);
		CREATE INDEX alkis_c29cef1e_2cb8_4681_a702_18331d2c97d6 ON ax_wohnplatz USING gin (traegtbeizu);


		CREATE TABLE aa_advstandardmodell (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE aa_advstandardmodell IS 'Alias: "AA_AdVStandardModell", UML-Typ: Enumeration';
		INSERT INTO aa_advstandardmodell (wert,beschreibung,dokumentation) VALUES
		('Basis-DLM', 'BasisLandschaftsModell', ''),
		('DFGM', 'Festpunktmodell', ''),
		('DGM2', 'DigitalesGelaendemodell2', ''),
		('DGM25', 'DigitalesGelaendemodell25', ''),
		('DGM5', 'DigitalesGelaendemodell5', ''),
		('DGM50', 'Digitales Gelaendemodell50', ''),
		('DKKM1000', 'KatasterkartenModell1000', ''),
		('DKKM2000', 'KatasterkartenModell2000', ''),
		('DKKM500', 'KatasterkartenModell500', ''),
		('DKKM5000', 'KatasterkartenModell5000', ''),
		('DLKM', 'LiegenschaftskatasterModell', ''),
		('DLM1000', 'LandschaftsModell1000', ''),
		('DLM250', 'LandschaftsModell250', ''),
		('DLM50', 'LandschaftsModell50', ''),
		('DTK10', 'TopographischeKarte10', ''),
		('DTK100', 'TopographischeKarte100', ''),
		('DTK1000', 'TopographischeKarte1000', ''),
		('DTK25', 'TopographischeKarte25', ''),
		('DTK250', 'TopographischeKarte250', ''),
		('DTK50', 'TopographischeKarte50', '');
		CREATE TABLE aa_nas_ausgabeform (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE aa_nas_ausgabeform IS 'Alias: "AA_NAS_Ausgabeform", UML-Typ: Enumeration';
		INSERT INTO aa_nas_ausgabeform (wert,beschreibung,dokumentation) VALUES
		('application/xml', NULL, ''),
		('application/gzip', NULL, ''),
		('application/zip', NULL, '');
		CREATE TABLE nas_filter_capabilities (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE nas_filter_capabilities IS 'Alias: "NAS_Filter_Capabilities", UML-Typ: Enumeration';
		INSERT INTO nas_filter_capabilities (wert,beschreibung,dokumentation) VALUES
		('PropertyIsOfType', NULL, ''),
		('multiplePropertyValues', NULL, ''),
		('XlinkPropertyPath_leafOnly', NULL, ''),
		('transparentXlinks', NULL, ''),
		('XlinkPropertyPath', NULL, ''),
		('XlinkPropertyName', NULL, '');
		CREATE TABLE aa_themendimension (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE aa_themendimension IS 'Alias: "AA_Themendimension", UML-Typ: Enumeration';
		INSERT INTO aa_themendimension (wert,beschreibung,dokumentation) VALUES
		('1000', 'Punkt-Linien-Thema (Dimension 1)', ''),
		('2000', 'Topologiethema (Dimension 2)', '');
		CREATE TABLE aa_art_themendefinition (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE aa_art_themendefinition IS 'Alias: "AA_Art_Themendefinition", UML-Typ: Enumeration';
		INSERT INTO aa_art_themendefinition (wert,beschreibung,dokumentation) VALUES
		('1000', 'alleObjekte', 'Diese Werteart bedeutet eine zwingende Themenbildung. Dabei sind alle in der Themendefinition genannten Objektarten Bestandteil des Themas und die Objektarten teilen sich stets die Geometrien.'),
		('2000', 'anwenderdefiniert', 'Die anwenderdefinierteThemenbildung wird im Erhebungsprozess gesetzt, wenn aus fachlicher Sicht eine Identität zwischen zwei oder mehreren Objektarten zum Ausdruck gebracht werden soll, wie z. B. zwischen Flurstücksgrenze und Gebäudelinie.');
		CREATE TABLE operation (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE operation IS 'Alias: "Operation", UML-Typ: Enumeration';
		INSERT INTO operation (wert,beschreibung,dokumentation) VALUES
		('Lock', NULL, ''),
		('Insert', NULL, ''),
		('Delete', NULL, ''),
		('Unlock', NULL, ''),
		('Reserve', NULL, ''),
		('Replace', NULL, ''),
		('Query', NULL, '');
		CREATE TABLE ap_horizontaleausrichtung (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ap_horizontaleausrichtung IS 'Alias: "AP_HorizontaleAusrichtung", UML-Typ: Enumeration';
		INSERT INTO ap_horizontaleausrichtung (wert,beschreibung,dokumentation) VALUES
		('linksbündig', NULL, 'Text linksbündig am Textpunkt bzw. am ersten Punkt der Linie.'),
		('rechtsbündig', NULL, 'Text rechtsbündig am Textpunkt bzw. am letzten Punkt der Linie.'),
		('zentrisch', NULL, 'Text zentriert am Textpunkt bzw. in der Mitte der Textstandlinie.');
		CREATE TABLE ap_vertikaleausrichtung (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ap_vertikaleausrichtung IS 'Alias: "AP_VertikaleAusrichtung", UML-Typ: Enumeration';
		INSERT INTO ap_vertikaleausrichtung (wert,beschreibung,dokumentation) VALUES
		('Basis', NULL, 'Textgeometrie bezieht sich auf die Basis- bzw. Grundlinie der Buchstaben.'),
		('Mitte', NULL, 'Textgeometrie bezieht sich auf die Mittellinie der Buchstaben.'),
		('oben', NULL, 'Textgeometrie bezieht sich auf die Oberlinie der Großbuchstaben.');
		CREATE TABLE ap_dateityp_3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ap_dateityp_3d IS 'Alias: "AP_DateiTyp_3D", UML-Typ: Enumeration';
		INSERT INTO ap_dateityp_3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'VRML97', ''),
		('2000', '3DSmax', ''),
		('3000', 'autocad DXF', ''),
		('4000', 'autocad DWG', ''),
		('5000', 'shockwave3D', ''),
		('6000', 'X3D', ''),
		('9990', 'unbekannt', '');
		CREATE TABLE ax_artdesnullpunktes_nullpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdesnullpunktes_nullpunkt IS 'Alias: "AX_ArtDesNullpunktes_Nullpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_artdesnullpunktes_nullpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zentraler Nullpunkt', 'Zentraler Nullpunkt ist die Bezeichnung für einen i. d. R. mit O gekennzeichneten Nullpunkt in einem Netzknoten.'),
		('2000', 'Nullpunkt', 'Nullpunkt ist der Anfangs- oder Endpunkt von einem Abschnitt oder Ast.'),
		('3000', 'Fiktiver Nullpunkt', 'Fiktiver Nullpunkt ist ein Nullpunkt, der verhindert, dass zwei verschiedene Äste in einem Nullpunkt beginnen und in einem anderen Nullpunkt wieder zusammenlaufen.');
		CREATE TABLE ax_li_processstep_mitdatenerhebung_description (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_li_processstep_mitdatenerhebung_description IS 'Alias: "AX_LI_ProcessStep_MitDatenerhebung_Description", UML-Typ: Enumeration';
		INSERT INTO ax_li_processstep_mitdatenerhebung_description (wert,beschreibung,dokumentation) VALUES
		('Erhebung', NULL, '');
		CREATE TABLE ax_datenerhebung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_datenerhebung IS 'Alias: "AX_Datenerhebung", UML-Typ: Enumeration';
		INSERT INTO ax_datenerhebung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Aus Katastervermessung ermittelt', ''),
		('1100', 'Aufgrund Anforderungen mit Netzanschluss ermittelt', ''),
		('1200', 'Aufgrund Anforderungen mit Bezug zur Flurstücksgrenze ermittelt', ''),
		('1900', 'Aus sonstiger Vermessung ermittelt', ''),
		('2000', 'Aus Luftbildmessung oder Fernerkundungsdaten ermittelt', ''),
		('4000', 'Aus Katasterunterlagen und Karten für graphische Zwecke ermittelt', ''),
		('4100', 'Aus Katasterzahlen für graphische Zwecke ermittelt', ''),
		('4200', 'Aus Katasterkarten digitalisiert', ''),
		('4210', 'Aus Katasterkarten digitalisiert, Kartenmaßstab M größer gleich 1 zu 1000', ''),
		('4220', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 1000 größer M größer gleich 1 zu 2000', ''),
		('4230', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 2000 größer M größer gleich 1 zu 3000', ''),
		('4240', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 3000 größer M größer gleich 1 zu 5000', ''),
		('4250', 'Aus Katasterkarten  digitalisiert, Kartenmaßstab 1 zu 5000 größer M', ''),
		('4300', 'Aus sonstigen Unterlagen digitalisiert', ''),
		('4310', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab M größer gleich 1 zu 1000', ''),
		('4320', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 1000 größer M größer gleich 1 zu 2000', ''),
		('4330', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 2000 größer M größer gleich 1 zu 3000', ''),
		('4340', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 3000 größer M größer gleich 1 zu 5000', ''),
		('4350', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 5000 größer M', ''),
		('4360', 'Aus sonstigen Unterlagen digitalisiert, mit sonstigen geometrischen Bedingungen und bzw. oder Homogenisierung (M größer gleich 1 zu 1000)', ''),
		('4370', 'Aus sonstigen Unterlagen digitalisiert, mit Berechnung oder Abstandsbedingung (M größer gleich 1 zu 1000)', ''),
		('4380', 'Aus sonstigen Unterlagen digitalisiert, mit sonstigen geometrischen Bedingungen und bzw. oder Homogenisierung (M kleiner 1 zu 1000)', ''),
		('4390', 'Aus sonstigen Unterlagen digitalisiert, mit Berechnung oder Abstandsbedingungen (M kleiner 1 zu 1000)', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung IS 'Alias: "AX_Sportart_BauwerkOderAnlageFuerSportFreizeitUndErholung", UML-Typ: Enumeration';
		INSERT INTO ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung (wert,beschreibung,dokumentation) VALUES
		('1010', 'Ballsport', 'Ballsport bedeutet, dass ein Spielfeld oder Stadion zur Ausübung des Ballsports genutzt wird.'),
		('1011', 'Fußball', 'Fußball bedeutet, dass ein Spielfeld oder Stadion zum Fußball spielen genutzt wird.'),
		('1020', 'Leichtathletik', 'Leichtathletik bedeutet, dass ein Spielfeld oder Stadion zur Ausübung verschiedener Leichtathletikdisziplinen genutzt wird.'),
		('1030', 'Tennis', 'Tennis bedeutet, dass ein Spielfeld oder Stadion zum Tennis spielen genutzt wird.'),
		('1040', 'Reiten', 'Reiten bedeutet, dass ein Stadion oder eine Rennbahn zur  Ausübung des Reitsports genutzt wird.'),
		('1050', 'Schwimmen', 'Schwimmen bedeutet, dass ein Stadion zum  Schwimmen  genutzt wird.'),
		('1060', 'Skisport', 'Skisport bedeutet, dass ein Stadion zur Ausübung des  Skisports genutzt wird.'),
		('1070', 'Eislaufsport, Rollschuhlaufen', 'Eislaufsport, Rollschuhlaufen bedeutet, dass ein Stadion zur  Ausübung des Eislaufsports oder des Rollschuhlaufens genutzt  wird.'),
		('1071', 'Eislaufsport', ''),
		('1072', 'Rollschuhlaufen', ''),
		('1080', 'Skating', 'Skating bedeutet, dass eine Laufbahn zum Skaten genutzt wird.'),
		('1090', 'Motorrennsport', 'Motorrennsport bedeutet, dass eine Rennbahn zur Ausübung  des Motorrennsports genutzt wird.'),
		('1100', 'Radsport', 'Radsport bedeutet, dass ein Stadion oder eine Rennbahn zur  Ausübung des Radsports genutzt wird.'),
		('1110', 'Pferderennsport', 'Pferderennsport bedeutet, dass eine Rennbahn zur Ausübung  des Pferderennsports genutzt wird.'),
		('1115', 'Hunderennsport', 'Hunderennsport bedeutet, dass eine Rennbahn zur Ausübung des Hunderennsports genutzt wird.');
		CREATE TABLE ax_lagezurerdoberflaeche_transportanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagezurerdoberflaeche_transportanlage IS 'Alias: "AX_LageZurErdoberflaeche_Transportanlage", UML-Typ: Enumeration';
		INSERT INTO ax_lagezurerdoberflaeche_transportanlage (wert,beschreibung,dokumentation) VALUES
		('1200', 'Unter der Erdoberfläche', 'Unter der Erdoberfläche bedeutet, dass sich die Transportanlage unter der Erdoberfläche befindet.'),
		('1400', 'Aufgeständert', 'Aufgeständert bedeutet, dass eine Transportanlage durch Tragwerke (Stützen, Pfeiler) über das Niveau der Erdoberfläche geführt wird, um z.B. Hindernisse zu überwinden.'),
		('1700', 'Unter der Wasseroberfläche', 'Unter der Wasseroberfläche bedeutet, dass sich eine Transportanlage unter der Wasseroberfläche befindet.');
		CREATE TABLE ax_produkt_transportanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_produkt_transportanlage IS 'Alias: "AX_Produkt_Transportanlage", UML-Typ: Enumeration';
		INSERT INTO ax_produkt_transportanlage (wert,beschreibung,dokumentation) VALUES
		('1110', 'Erdöl', 'Erdöl ist ein flüssiges und brennbares Kohlenwasserstoffgemisch, das gefördert oder transportiert wird.'),
		('1120', 'Gas', 'Gas ist eine gasförmige und brennbare Materie, die gefördert oder transportiert wird.'),
		('1130', 'Wasser', 'Wasser ist die chemische Verbindung von Wasserstoff mit Sauerstoff, die gefördert oder transportiert wird.'),
		('1131', 'Trinkwasser', 'Trinkwasser ist ein für den menschlichen Genuss und Gebrauch geeignetes Wasser, das transportiert wird.'),
		('1132', 'Brauchwasser', 'Brauchwasser ist ein für technische u.a. Zwecke verwendetes Wasser, das transportiert wird.'),
		('1133', 'Abwasser', 'Abwasser ist ein verunreinigtes Wasser aus Haushaltungen, Gewerbe- und Industriebetrieben sowie Niederschlagswasser, das transportiert wird.'),
		('1140', 'Fernwärme', '');
		CREATE TABLE ax_bauwerksfunktion_turm (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_turm IS 'Alias: "AX_Bauwerksfunktion_Turm", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_turm (wert,beschreibung,dokumentation) VALUES
		('1001', 'Wasserturm', 'Wasserturm ist ein hochgelegenes Bauwerk mit einem Behälter, in dem Wasser für die Wasserversorgung und Konstanthaltung des Wasserdruckes gespeichert wird.'),
		('1002', 'Kirchturm, Glockenturm', 'Kirchturm, Glockenturm ist ein freistehender Turm, der die Glockenstube mit den Glocken aufnimmt.'),
		('1003', 'Aussichtsturm', 'Aussichtsturm ist ein Bauwerk, das ausschließlich der Fernsicht dient.'),
		('1004', 'Kontrollturm', 'Kontrollturm (Tower) ist ein Bauwerk auf dem Fluggelände, in dem die für die Lenkung und Überwachung des Flugverkehrs erforderlichen Anlagen und Einrichtungen untergebracht sind.'),
		('1005', 'Kühlturm', 'Kühlturm ist eine turmartige Kühlanlage (Nass- oder Trockenkühlturm), in der erwärmtes Kühlwasser insbesondere von Kraftwerken rückgekühlt wird.'),
		('1006', 'Leuchtturm', 'Leuchtturm ist ein als Schifffahrtszeichen dienender hoher Turm, ausgerüstet mit einem starken Leuchtfeuer verschiedener Kennungen an der Turmspitze und mit anderen, der Schifffahrt dienenden Signalen.'),
		('1007', 'Feuerwachturm', 'Feuerwachturm ist ein Turm, der zum Erkennen von Gefahren (Feuer) dient.'),
		('1008', 'Sende-, Funkturm, Fernmeldeturm', 'Sende-, Funkturm, Fernmeldeturm ist ein Bauwerk, ausgerüstet mit Sende - und Empfangsantennen zum Übertragen und Empfangen von Nachrichten aller Arten von Telekommunikation.'),
		('1009', 'Stadt-, Torturm', 'Stadtturm ist ein historischer Turm, der das Stadtbild prägt. Torturm ist der auf einem Tor stehende Turm, wobei das Tor allein stehen oder in eine Befestigungsanlage eingebunden sein kann.'),
		('1010', 'Förderturm', 'Förderturm ist ein Turm über einem Schacht. An Förderseile, die über Seilscheiben im Turm geführt werden, werden Lasten in den Schacht gesenkt oder aus dem Schacht gehoben.'),
		('1011', 'Bohrturm', 'Bohrturm ist ein zur Gewinnung von Erdöl und Erdgas verwendetes, meist aus einer Stahlkonstruktion bestehendes Gerüst, in dem das Bohrgestänge aufgehängt ist.'),
		('1012', 'Schloss-, Burgturm', 'Schloss-, Burgturm ist ein Turm innerhalb einer Schloss- bzw. einer Burganlage, auch Bergfried genannt.'),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', 'Nach Quellenlage nicht zu spezifizieren bedeutet, dass zum Zeitpunkt der Erhebung keine Funktion zuweisbar war.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Funktion bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_hydrologischesmerkmal_sonstigesbauwerkodersonstigeeinri (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_sonstigesbauwerkodersonstigeeinri IS 'Alias: "AX_HydrologischesMerkmal_SonstigesBauwerkOderSonstigeEinrichtung", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_sonstigesbauwerkodersonstigeeinri (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ständig Wasser führend', 'Ständig Wasser führend heißt, dass der Brunnen ganzjährig Wasser führt.'),
		('2000', 'Nicht ständig Wasser führend', 'Nicht ständig Wasser führend heißt, dass der Brunnen nicht ganzjährig Wasser führt.'),
		('3000', 'Trocken, versiegt', 'Trocken, versiegt heißt, dass der Brunnen ganzjährig kein Wasser führt.');
		CREATE TABLE ax_zustand_turm (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_turm IS 'Alias: "AX_Zustand_Turm", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_turm (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich der Turm nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('2200', 'Verfallen, zerstört', 'Verfallen, zerstört bedeutet, dass sich der ursprüngliche Zustand des Turmes durch menschliche oder zeitliche Einwirkungen so verändert hat, dass eine Nutzung nicht mehr möglich ist.');
		CREATE TABLE ax_art_heilquellegasquelle (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_heilquellegasquelle IS 'Alias: "AX_Art_HeilquelleGasquelle", UML-Typ: Enumeration';
		INSERT INTO ax_art_heilquellegasquelle (wert,beschreibung,dokumentation) VALUES
		('4010', 'Heilquelle', ''),
		('4020', 'Gasquelle, Mofette', '');
		CREATE TABLE ax_bauwerksfunktion_transportanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_transportanlage IS 'Alias: "AX_Bauwerksfunktion_Transportanlage", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_transportanlage (wert,beschreibung,dokumentation) VALUES
		('1101', 'Rohrleitung, Pipeline', 'Rohrleitung, Pipeline ist ein langgestreckter Hohlkörper zum Transport von Flüssigkeiten und Gasen.'),
		('1102', 'Förderband, Bandstraße', 'Förderband, Bandstraße ist ein mechanisch bewegtes Band zum Transport von Gütern.'),
		('1103', 'Pumpe', 'Pumpe ist eine Vorrichtung zum An-, Absaugen oder Injizieren von Flüssigkeiten oder Gasen; Verdichtungsstation  für Gase.');
		CREATE TABLE ax_lagezurerdoberflaeche_vorratsbehaelterspeicherbauwerk (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagezurerdoberflaeche_vorratsbehaelterspeicherbauwerk IS 'Alias: "AX_LageZurErdoberflaeche_VorratsbehaelterSpeicherbauwerk", UML-Typ: Enumeration';
		INSERT INTO ax_lagezurerdoberflaeche_vorratsbehaelterspeicherbauwerk (wert,beschreibung,dokumentation) VALUES
		('1200', 'Unter der Erdoberfläche', 'Unter der Erdoberfläche bedeutet, dass sich der Vorratsbehälter bzw. das Speicherbauwerk unter der Erdoberfläche befindet.'),
		('1400', 'Aufgeständert', 'Aufgeständert bedeutet, dass der Vorratsbehälter bzw. das  Speicherbauwerk auf Stützen steht.');
		CREATE TABLE ax_speicherinhalt_vorratsbehaelterspeicherbauwerk (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_speicherinhalt_vorratsbehaelterspeicherbauwerk IS 'Alias: "AX_Speicherinhalt_VorratsbehaelterSpeicherbauwerk", UML-Typ: Enumeration';
		INSERT INTO ax_speicherinhalt_vorratsbehaelterspeicherbauwerk (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erze', 'Erze bedeutet, dass die in der Natur vorkommenden, metallhaltigen Mineralien und Mineralgemische gelagert werden.'),
		('1100', 'Treib- und Brennstoffe', 'Treib- und Brennstoffe bedeutet, dass die in der Natur vorkommenden brennbaren organischen und anorganischen Substanzen gelagert werden.'),
		('1110', 'Erdöl', 'Erdöl ist ein flüssiges und brennbares Kohlenwasserstoffgemisch, das gelagert wird.'),
		('1120', 'Gas', 'Gas ist eine gasförmige und brennbare Materie, die  gespeichert wird.'),
		('1130', 'Wasser', 'Wasser ist die chemische Verbindung von Sauerstoff und Wasserstoff, die gespeichert wird.'),
		('1140', 'Gülle', ''),
		('1200', 'Baustoffe', 'Baustoffe sind sämtliche im Bauwesen verwendete Materialien, die gelagert werden.'),
		('1300', 'Chemikalien', 'Chemikalien sind Werkstoffe organischen oder anorganischen Ursprungs, die gespeichert werden.'),
		('1500', 'Lebensmittel', 'Lebensmittel sind alle Nahrungs- und Genussmittel für Menschen, die in Vorratsbehältern zwischengelagert werden.'),
		('1501', 'Getreide', 'Getreide sind die trockenen Kornfrüchte (Weizen, Roggen, Gerste, Hafer), die in Vorratsbehältern zwischengelagert werden.'),
		('1510', 'Futtermittel', 'Futtermittel sind die als Tiernahrung dienenden pflanzlichen oder tierischen Stoffe, die in Vorratsbehältern zwischengelagert werden.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass der Speicherinhalt bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer IS 'Alias: "AX_Bauwerksfunktion_BauwerkOderAnlageFuerIndustrieUndGewerbe", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer (wert,beschreibung,dokumentation) VALUES
		('1210', 'Klärbecken', 'Klärbecken ist ein künstlich errichtetes Becken oder eine Geländevertiefung, in der Feststoffe aus einer Flüssigkeit ausgefällt werden.'),
		('1215', 'Biogasanlage', ''),
		('1220', 'Windrad', 'Windrad ist ein mit Flügeln besetztes Rad, das durch Wind in Rotation versetzt wird und mit Hilfe eines eingebauten  Generators elektrische Energie erzeugt.'),
		('1230', 'Solarzellen', 'Solarzellen sind Flächenelemente aus Halbleitern, die die Energie der Sonnenstrahlen in elektrische Energie umwandeln.'),
		('1240', 'Wasserrad', 'Wasserrad ist ein mit Schaufeln oder Zellen besetztes Rad, das die Energie des strömenden Wassers zum Antrieb,  besonders von Mühlen, ausnutzt oder zum Schöpfen von  Wasser (Schöpfrad) genutzt wird.'),
		('1250', 'Mast', 'Mast ist eine senkrecht stehende Konstruktion mit stützender oder tragender Funktion.'),
		('1251', 'Freileitungsmast', 'Freileitungsmast ist ein Mast, an dem Hochspannungsleitungen befestigt sind.'),
		('1260', 'Funkmast', 'Funkmast ist ein Mast mit Vorrichtungen zum Empfangen, Umformen und Weitersenden von elektromagnetischen Wellen.'),
		('1270', 'Antenne', 'Antenne ist eine Vorrichtung zum Empfang oder zur Ausstrahlung elektromagnetischer Wellen.'),
		('1280', 'Radioteleskop', 'Radioteleskop ist ein Bauwerk mit einer Parabolantenne für den Empfang von elektromagnetischer Strahlung aus dem Weltall.'),
		('1290', 'Schornstein, Schlot, Esse', 'Schornstein, Schlot, Esse ist ein freistehend senkrecht  hochgeführter Abzugskanal für die Rauchgase einer  Feuerungsanlage oder für andere Abgase.'),
		('1310', 'Stollenmundloch', 'Stollenmundloch ist der Eingang eines unterirdischen Gangs, der annähernd horizontal von der Erdoberfläche in das Gebirge führt.'),
		('1320', 'Schachtöffnung', 'Schachtöffnung ist der Eingang auf der Erdoberfläche zu einem Schacht.'),
		('1330', 'Kran', 'Kran ist eine Vorrichtung, die aus einer fahrbaren oder ortsfesten Konstruktion besteht und die zum Heben von Lasten benutzt wird.'),
		('1331', 'Drehkran', ''),
		('1332', 'Portalkran', ''),
		('1333', 'Laufkran, Brückenlaufkran', ''),
		('1340', 'Trockendock', 'Trockendock ist eine Anlage in Werften und Häfen, in der das Schiff zum Ausbessern aus dem Wasser genommen wird.'),
		('1350', 'Hochofen', 'Hochofen ist ein hoher Schachtofen zum Schmelzen von Eisenerz.'),
		('1360', 'Merkzeichen, Merkstein', ''),
		('1370', 'Hydrant', ''),
		('1371', 'Oberflurhydrant', ''),
		('1372', 'Unterflurhydrant', ''),
		('1380', 'Schieberkappe', ''),
		('1390', 'Einsteigeschacht', ''),
		('1400', 'Umformer', ''),
		('1700', 'Bergbaubetrieb', ''),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bauwerkfunktion bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_art_einrichtunginoeffentlichenbereichen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_einrichtunginoeffentlichenbereichen IS 'Alias: "AX_Art_EinrichtungInOeffentlichenBereichen", UML-Typ: Enumeration';
		INSERT INTO ax_art_einrichtunginoeffentlichenbereichen (wert,beschreibung,dokumentation) VALUES
		('1100', 'Kommunikationseinrichtung', ''),
		('1110', 'Fernsprechhäuschen', ''),
		('1120', 'Briefkasten', ''),
		('1130', 'Notrufeinrichtung', ''),
		('1140', 'Feuermelder', ''),
		('1150', 'Polizeirufsäule', ''),
		('1200', 'Kabelkasten, Schaltkasten', ''),
		('1300', 'Verkehrszeichen', ''),
		('1310', 'Verkehrsampel', ''),
		('1320', 'Freistehende Hinweistafel, -zeichen', ''),
		('1330', 'Wegweiser von besonderer Bedeutung', ''),
		('1340', 'Freistehende Warntafel', ''),
		('1350', 'Bushaltestelle', ''),
		('1400', 'Markierungshinweise, -steine', ''),
		('1410', 'Kilometerstein, -tafel', 'Kilometerstein, -tafel ist ein Punkt mit einem festen Wert im Netz der Autobahnen oder Schienenbahnen der in der Örtlichkeit durch eine Markierung (z. B. Kilometerstein) repräsentiert wird.'),
		('1420', 'Ortsdurchfahrtsstein', ''),
		('1430', 'Fischereigrenzstein', ''),
		('1500', 'Bahnübergang, Schranke', ''),
		('1510', 'Tor', ''),
		('1600', 'Laterne, Kandelaber', ''),
		('1610', 'Gaslaterne', ''),
		('1620', 'Laterne, elektrisch', ''),
		('1630', 'Gaskandelaber', ''),
		('1640', 'Kandelaber, elektrisch', ''),
		('1650', 'Hängende Lampe', ''),
		('1700', 'Säule, Werbefläche', ''),
		('1710', 'Leuchtsäule', ''),
		('1910', 'Fahnenmast', ''),
		('2100', 'Straßensinkkasten', ''),
		('2200', 'Müllbox', ''),
		('2300', 'Kehrichtgrube', ''),
		('2400', 'Uhr', ''),
		('2500', 'Richtscheinwerfer', ''),
		('2600', 'Flutlichtmast', ''),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Art bekannt, aber in der Attributwertliste nicht aufgeführt ist.');
		CREATE TABLE ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde IS 'Alias: "AX_Bauwerksfunktion_BauwerkOderAnlageFuerSportFreizeitUndErholung", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde (wert,beschreibung,dokumentation) VALUES
		('1410', 'Spielfeld', 'Spielfeld ist eine abgegrenzte, markierte Fläche, auf der die Sportart unmittelbar ausgeübt wird, z.B. die einzelnen  Fußballfelder (Hauptplatz und Trainingsplätze) einer größeren Anlage. Die zusammenhängenden Spielflächen innerhalb einer Tennisanlage werden zu einem Spielfeld  zusammengefasst'),
		('1411', 'Hartplatz', ''),
		('1412', 'Rasenplatz', ''),
		('1420', 'Rennbahn, Laufbahn, Geläuf', 'Rennbahn, Laufbahn, Geläuf ist eine je nach Art des  Rennens verschiedenartig gestaltete Strecke (oval, gerade,  kurvig), auf der das Rennen stattfindet.'),
		('1430', 'Zuschauertribüne', 'Zuschauertribüne ist ein großes Gerüst oder ein festes, meist überdachtes Bauwerk mit ansteigenden Sitz- oder Stehplatzreihen für Zuschauer.'),
		('1431', 'Zuschauertribüne, überdacht', 'Zuschauertribüne, überdacht bedeutet, dass Zuschauertribüne mit einer Dachfläche ausgestattet ist.'),
		('1432', 'Zuschauertribüne, nicht überdacht', 'Zuschauertribüne, nicht überdacht bedeutet, dass die Zuschauertribüne keine Dachfläche besitzt.'),
		('1440', 'Stadion', 'Stadion ist ein Bauwerk mit Tribünen und entsprechenden  Einrichtungen zur Ausübung von bestimmten Sportarten.'),
		('1450', 'Schwimmbecken', 'Schwimmbecken ist ein mit Wasser gefülltes Becken zum Schwimmen oder Baden.'),
		('1460', 'Liegewiese', ''),
		('1470', 'Sprungschanze (Anlauf)', 'Sprungschanze (Anlauf) ist eine Anlage zum Skispringen mit einer stark abschüssigen, in einem Absprungtisch endenden Bahn zum Anlauf nehmen.'),
		('1480', 'Schießanlage', 'Schießanlage ist eine Anlage mit Schießbahnen für  Schießübungen oder sportliche Wettbewerbe.'),
		('1490', 'Gradierwerk', 'Gradierwerk ist ein mit Reisig bedecktes Gerüst, über das Sole rieselt, die durch erhöhte Verdunstung konzentriert wird.'),
		('1510', 'Wildgehege', 'Wildgehege ist ein eingezäuntes Areal, in dem Wild waidgerecht betreut wird oder beobachtet werden kann.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bauwerkfunktion bekannt, aber in der Attributwertliste nicht aufgeführt ist.');
		CREATE TABLE ax_archaeologischertyp_historischesbauwerkoderhistorischee (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_archaeologischertyp_historischesbauwerkoderhistorischee IS 'Alias: "AX_ArchaeologischerTyp_HistorischesBauwerkOderHistorischeEinrichtung", UML-Typ: Enumeration';
		INSERT INTO ax_archaeologischertyp_historischesbauwerkoderhistorischee (wert,beschreibung,dokumentation) VALUES
		('1000', 'Grab', 'Grab ist eine künstlich geschaffene Bestattungsstätte unter, auf oder über der  Erdoberfläche.'),
		('1010', 'Großsteingrab (Dolmen, Hünenbett)', 'Großsteingrab (Dolmen, Hünenbett) ist ein Grab mit Steineinbau, d. h. es ist ein aus großen Steinen (z.B. Findlingen) errichteter Grabbau.'),
		('1020', 'Grabhügel (Hügelgrab)', 'Grabhügel (Hügelgrab) ist ein meist runder oder ovaler Hügel, der über einer ur- oder frühgeschichtlichen Bestattung aus Erde aufgeschüttet oder aus Plaggen aufgeschichtet  wurde.'),
		('1100', 'Historische Wasserleitung', 'Historische Wasserleitung ist ein meist offenes System von Gräben, Kunstgräben und Kanälen, in dem Wasser transportiert wird.'),
		('1110', 'Aquädukt', 'Aquädukt ist ein brückenartiges Steinbauwerk zur Überführung von Freispiegel-Wasserleitungen mit  natürlichem Gefälle über Täler oder andere Bodenunebenheiten.'),
		('1200', 'Befestigung (Wall, Graben)', 'Befestigung (Wall, Graben) ist ein aus Erde aufgeschütteter Grenz-, Schutz- oder Stadtwall. Zu der Befestigung (Wall) zählen auch Limes und Landwehr.'),
		('1210', 'Wachturm (römisch), Warte', 'Wachtturm (römisch), Warte ist ein allein oder in Verbindung mit einem Befestigungssystem (Limes) stehender Beobachtungsturm.'),
		('1300', 'Steinmal', 'Steinmal ist eine kultische oder rechtliche Kennzeichnung, bestehend aus einzelnen oder Gruppen von Steinen.'),
		('1400', 'Befestigung (Burgruine)', 'Befestigung (Burgruine) ist eine künstliche Anlage zur Sicherung von Leben und Gut.'),
		('1410', 'Burg (Fliehburg, Ringwall)', 'Burg (Fliehburg, Ringwall) ist eine ur- oder frühgeschichtliche runde, ovale oder an Gegebenheiten des Geländes (Böschungskanten) angepasste Befestigungsanlage, die aus einem Erdwall mit oder ohne Holzeinbauten besteht.'),
		('1420', 'Schanze', 'Schanze ist eine mittelalterliche oder neuzeitliche, in der Regel geschlossene, quadratische, rechteckige oder sternförmige Wallanlage mit Außengraben.'),
		('1430', 'Lager', 'Lager ist die Bezeichnung für ein befestigtes Truppenlager in der Römer- oder in der Neuzeit (z.B. bei Belagerungen im 30 jährigen Krieg).'),
		('1500', 'Historische Mauer', 'Historische Mauer ist eine Mauer mit kulturgeschichtlicher Bedeutung.'),
		('1510', 'Stadtmauer', ''),
		('1520', 'Sonstige historische Mauer', ''),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass der archäologische Typ bekannt, aber nicht in der Attributwertliste aufgeführt ist');
		CREATE TABLE ax_hydrologischesmerkmal_heilquellegasquelle (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_heilquellegasquelle IS 'Alias: "AX_HydrologischesMerkmal_HeilquelleGasquelle", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_heilquellegasquelle (wert,beschreibung,dokumentation) VALUES
		('4000', 'Ständig schüttend', ''),
		('5000', 'Nicht ständig schüttend', '');
		CREATE TABLE ax_zustand_bauwerkoderanlagefuerindustrieundgewerbe (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_bauwerkoderanlagefuerindustrieundgewerbe IS 'Alias: "AX_Zustand_BauwerkOderAnlageFuerIndustrieUndGewerbe", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bauwerkoderanlagefuerindustrieundgewerbe (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich Bauwerk oder Anlage für Industrie und Gewerbe nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('2200', 'Verfallen, zerstört', 'Verfallen, zerstört bedeutet, dass sich der ursprüngliche Zustand von Bauwerk oder Anlage für Industrie und Gewerbe durch menschliche oder zeitliche Einwirkungen so verändert hat, dass eine Nutzung nicht mehr möglich ist.'),
		('4100', 'Offen', 'Offen bedeutet, dass Bauwerk oder Anlage für Industrie und Gewerbe allgemein zugänglich ist.'),
		('4200', 'Verschlossen', 'Verschlossen bedeutet, dass Bauwerk oder Anlage für Industrie und Gewerbe nicht allgemein zugänglich ist.');
		CREATE TABLE ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun IS 'Alias: "AX_Bauwerksfunktion_SonstigesBauwerkOderSonstigeEinrichtung", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun (wert,beschreibung,dokumentation) VALUES
		('1610', 'Überdachung', ''),
		('1611', 'Carport', ''),
		('1620', 'Treppe', 'Treppe ist ein stufenförmiges Bauwerk zur Überwindung von Höhenunterschieden.'),
		('1621', 'Freitreppe', ''),
		('1622', 'Rolltreppe', ''),
		('1630', 'Treppenunterkante', ''),
		('1640', 'Kellereingang', 'Kellereingang ist der Eingang zu einem unterirdischen Vorratsraum außerhalb von Gebäuden.'),
		('1641', 'Kellereingang, offen', 'Kellereingang, offen ist der offene Eingang zu einem unterirdischen Vorratsraum außerhalb von Gebäuden.'),
		('1642', 'Kellereingang, geschlossen', 'Kellereingang, geschlossen ist der geschlossene Eingang zu einem unterirdischen Vorratsraum außerhalb von Gebäuden.'),
		('1650', 'Rampe', ''),
		('1670', 'Terrasse', 'Es werden nur unterkellerte Terrassen erfasst.'),
		('1700', 'Mauer', 'Mauer ist ein freistehendes, langgestrecktes Bauwerk, das aus Natur- bzw. Kunststeinen oder anderen Materialien besteht.'),
		('1701', 'Mauerkante, rechts', ''),
		('1702', 'Mauerkante, links', ''),
		('1703', 'Mauermitte', ''),
		('1720', 'Stützmauer', 'Stützmauer ist eine zum Stützen von Erdreich dienende Mauer.'),
		('1721', 'Stützmauer, rechts', ''),
		('1722', 'Stützmauer, links', ''),
		('1723', 'Stützmauermitte', ''),
		('1740', 'Zaun', 'Zaun ist eine Abgrenzung oder Einfriedung aus Holz- oder Metallstäben oder aus Draht bzw. Drahtgeflecht.'),
		('1750', 'Gedenkstätte, Denkmal, Denkstein, Standbild', 'Gedenkstätte, Denkmal, Denkstein, Standbild ist ein zum Gedenken errichtete Anlage oder Bauwerk an eine Person, ein Ereignis oder eine plastische Darstellung.'),
		('1760', 'Bildstock, Wegekreuz, Gipfelkreuz', 'Bildstock, Wegekreuz, Gipfelkreuz ist ein frei stehendes Mal aus Holz oder Stein, das in einem tabernakelartigen Aufbau ein Kruzifix oder eine Heiligendarstellung enthält und als Andachtsbild,  als Erinnerung an Verstorbene oder als Sühnemal errichtet wurde;  ist ein errichtetes Kreuz z.B. an Wegen; ist ein Kreuz auf dem Gipfel eines Berges.'),
		('1761', 'Bildstock', ''),
		('1762', 'Wegekreuz', ''),
		('1763', 'Gipfelkreuz', ''),
		('1770', 'Meilenstein, historischer Grenzstein', 'Meilenstein, historischer Grenzstein sind Steine von kulturgeschichtlicher  Bedeutung, die als Meilensteine (Entfernungsangaben in Meilen) am Rande einer Straße aufgestellt sind oder als Grenzsteine vergangene Eigentumsverhältnisse dokumentieren.'),
		('1780', 'Brunnen', 'Brunnen ist eine Anlage zur Gewinnung von Grundwasser bzw. ein architektonisch ausgestaltetes Bauwerk mit Becken zum Auffangen von Wasser.'),
		('1781', 'Brunnen (Trinkwasserversorgung)', 'Brunnen (Trinkwasserversorgung) bedeutet, dass in dem Brunnen ausschließlich Trinkwasser gewonnen wird.'),
		('1782', 'Springbrunnen, Zierbrunnen', ''),
		('1783', 'Ziehbrunnen', ''),
		('1790', 'Spundwand', 'Spundwand ist ein Sicherungsbauwerk (wasserdichte Wand) aus miteinander verbundenen schmalen, langen Holz-, Stahl- oder Stahlbetonbohlen zum Schutz gegen das Außenwasser. Die Bohlen werden horizontal hinter Pfählen (Bohlwand) oder vertikal als Spundwand eingebaut und meist rückwärtig verankert.'),
		('1791', 'Höckerlinie', 'Höckerlinie bezeichnet die ehemalige Panzersperre Westwall.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bauwerksfunktion bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_funktion_bauwerk (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_bauwerk IS 'Alias: "AX_Funktion_Bauwerk", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_bauwerk (wert,beschreibung,dokumentation) VALUES
		('1000', 'Hochwasser-, Sturmflutschutz', 'Hochwasser-, Sturmflutschutz bedeutet, dass das Bauwerk dem Schutz vor Hochwasser bzw. Sturmflut dient.'),
		('2000', 'Lärmschutz', 'Lärmschutz bedeutet, dass das Bauwerk dem Schutz vor Lärmemissionen dient.');
		CREATE TABLE ax_bauwerksfunktion_leitung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_leitung IS 'Alias: "AX_Bauwerksfunktion_Leitung", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_leitung (wert,beschreibung,dokumentation) VALUES
		('1110', 'Freileitung', 'Freileitung ist eine aus einem oder mehreren Drähten oder  Fasern hergestellte oberirdische Leitung zum Transport von  elektrischer Energie und zur Übertragung von elektrischen  Signalen.'),
		('1111', 'Erdkabel', '');
		CREATE TABLE ax_bauwerksfunktion_vorratsbehaelterspeicherbauwerk (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_vorratsbehaelterspeicherbauwerk IS 'Alias: "AX_Bauwerksfunktion_VorratsbehaelterSpeicherbauwerk", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_vorratsbehaelterspeicherbauwerk (wert,beschreibung,dokumentation) VALUES
		('1201', 'Silo', 'Silo ist ein Großraumbehälter zum Speichern von Schüttgütern (Getreide, Erz, Zement, Sand) oder Gärfutter (gehäckseltes Grüngut).'),
		('1202', 'Fülltrichter', ''),
		('1203', 'Bunker', 'Bunker ist ein Bauwerk, in dem Schüttgut gelagert wird.'),
		('1204', 'Getreideheber', ''),
		('1205', 'Tank', 'Tank ist ein Behälter, in dem Flüssigkeiten gelagert oder Gase gespeichert werden.'),
		('1206', 'Gasometer', 'Gasometer ist ein Vorratsbehälter für Gas.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bauwerkfunktion bekannt, aber  in der Attributwertliste nicht aufgeführt ist.');
		CREATE TABLE ax_befestigung_wegpfadsteig (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_befestigung_wegpfadsteig IS 'Alias: "AX_Befestigung_WegPfadSteig", UML-Typ: Enumeration';
		INSERT INTO ax_befestigung_wegpfadsteig (wert,beschreibung,dokumentation) VALUES
		('1000', 'Befestigt', 'Befestigt bedeutet, dass Weg, Pfad, Steig mit einem festen Unterbau versehen und ganzjährig befahrbar bzw. begehbar ist.'),
		('2000', 'Unbefestigt', 'Unbefestigt bedeutet, dass Weg, Pfad, Steig nicht mit einem festen Unterbau versehen und nicht ganzjährig befahrbar bzw. begehbar ist.');
		CREATE TABLE ax_oberflaechenmaterial_flugverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_oberflaechenmaterial_flugverkehrsanlage IS 'Alias: "AX_Oberflaechenmaterial_Flugverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_oberflaechenmaterial_flugverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('1210', 'Gras, Rasen', 'Gras, Rasen bedeutet, dass die Oberfläche von Flugverkehrsanlage mit Gras bewachsen ist.'),
		('1220', 'Beton', 'Beton bedeutet, dass die Oberfläche von Flugverkehrsanlage aus Beton besteht.'),
		('1230', 'Bitumen, Asphalt', 'Bitumen, Asphalt bedeutet, dass die Oberfläche von Flugverkehrsanlage aus Bitumen bzw. Asphalt besteht.');
		CREATE TABLE ax_art_gleis (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_gleis IS 'Alias: "AX_Art_Gleis", UML-Typ: Enumeration';
		INSERT INTO ax_art_gleis (wert,beschreibung,dokumentation) VALUES
		('1200', 'Drehscheibe', '');
		CREATE TABLE ax_bahnkategorie_gleis (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bahnkategorie_gleis IS 'Alias: "AX_Bahnkategorie_Gleis", UML-Typ: Enumeration';
		INSERT INTO ax_bahnkategorie_gleis (wert,beschreibung,dokumentation) VALUES
		('1100', 'Eisenbahn', ''),
		('1102', 'Güterverkehr', ''),
		('1104', 'S-Bahn', ''),
		('1200', 'Stadtbahn', ''),
		('1201', 'Straßenbahn', ''),
		('1202', 'U-Bahn', ''),
		('1300', 'Bergbahn, Seilbahn', ''),
		('1301', 'Zahnradbahn', ''),
		('1302', 'Standseilbahn', ''),
		('1400', 'Museumsbahn', ''),
		('1500', 'Bahn im Freizeitpark', ''),
		('1600', 'Magnetschwebebahn', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_art_strassenverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_strassenverkehrsanlage IS 'Alias: "AX_Art_Strassenverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_art_strassenverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fahrbahn', ''),
		('1010', 'Fahrbahnbegrenzungslinie', ''),
		('1011', 'Fahrbahnbegrenzungslinie, überdeckt', ''),
		('2000', 'Furt', 'Furt ist eine zum Überqueren geeignete Stelle in einem Gewässer.'),
		('3000', 'Autobahnknoten', 'Autobahnknoten ist ein höhengleicher oder höhenungleicher Knoten, der sich aus der verkehrlichen Verknüpfung zweier Autobahnen sowie an Anschlussstellen mit dem nachgeordneten Straßennetz ergibt.'),
		('3001', 'Kreuz', 'Kreuz ist ein vierarmiger Knotenpunkt in mehreren Ebenen in dem sich zwei Autobahnen kreuzen.'),
		('3002', 'Dreieck', 'Dreieck ist eine Einmündung einer Autobahn in eine durchgehende Autobahn.'),
		('3003', 'Anschlussstelle', 'Anschlussstelle ist die verkehrliche Verknüpfung der Autobahn mit dem nachgeordneten Straßennetz.'),
		('4000', 'Platz', 'Platz ist eine ebene, befestigte oder unbefestigte Fläche.'),
		('5330', 'Raststätte', 'Raststätte ist eine Anlage an Verkehrsstraßen mit Bauwerken und Einrichtungen zur Versorgung und 
		Erholung von Reisenden.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Art bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_markierung_wegpfadsteig (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_markierung_wegpfadsteig IS 'Alias: "AX_Markierung_WegPfadSteig", UML-Typ: Enumeration';
		INSERT INTO ax_markierung_wegpfadsteig (wert,beschreibung,dokumentation) VALUES
		('1401', 'Gekennzeichneter Wanderweg', 'Gekennzeichneter Wanderweg ist ein als Wanderweg eindeutig markierter Weg.'),
		('1402', 'Gekennzeichneter Radwanderweg', 'Gekennzeichneter Radwanderweg ist ein als Radwanderweg eindeutig markierter Weg.'),
		('1403', 'Gekennzeichnete Skaterstrecke', 'Gekennzeichnete Skaterstrecke ist ein als Skaterstrecke eindeutig markierter Weg.');
		CREATE TABLE ax_bahnhofskategorie_bahnverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bahnhofskategorie_bahnverkehrsanlage IS 'Alias: "AX_Bahnhofskategorie_Bahnverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_bahnhofskategorie_bahnverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('1010', 'Bahnhof', 'Bahnhof ist eine Anlage im Netz der Schienenbahnen und der Seilbahnen (Bahnkategorie Schwebebahn) zur Abwicklung des Personen- und Güterverkehrs entsprechend der Angaben des Betreibers.'),
		('1020', 'Haltestelle', 'Haltestelle ist eine Anlage im Netz der Schienenbahnen und der Seilbahnen (Bahnkategorie Schwebebahn) zur Abwicklung des Personen- und Güterverkehrs entsprechend der Angaben des Betreibers.'),
		('1030', 'Haltepunkt', 'Haltepunkt ist eine Anlage im Netz der Schienenbahnen und der Seilbahnen (Bahnkategorie Schwebebahn) zur Abwicklung des Personen- und Güterverkehrs entsprechend der Angaben des Betreibers.');
		CREATE TABLE ax_bahnkategorie_seilbahnschwebebahn (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bahnkategorie_seilbahnschwebebahn IS 'Alias: "AX_Bahnkategorie_SeilbahnSchwebebahn", UML-Typ: Enumeration';
		INSERT INTO ax_bahnkategorie_seilbahnschwebebahn (wert,beschreibung,dokumentation) VALUES
		('2100', 'Luftseilbahn, Großkabinenbahn', 'Luftseilbahn, Großkabinenbahn ist die Bezeichnung für eine Seilbahn, die Personen befördert und Güter transportiert. Die Kabinen und Transporteinrichtungen werden an einem Zugseil über ein Tragseil fortbewegt.'),
		('2200', 'Kabinenbahn, Umlaufseilbahn', 'Kabinenbahn, Umlaufseilbahn ist die Bezeichnung für eine Seilbahn zur Beförderung von Personen und zum Transport von Gütern. Die Wagen oder Kabinen sind an einem umlaufenden Seil festgeklemmt.'),
		('2300', 'Sessellift', 'Sessellift ist die Bezeichnung für eine Seilbahn zur Beförderung von Personen in Sitzen ohne Kabinenverkleidung.'),
		('2400', 'Ski-, Schlepplift', 'Ski-, Schlepplift ist die Bezeichnung für eine Seilbahn, mit der Skifahrer stehend den Berg hinauf gezogen werden.'),
		('2500', 'Schwebebahn', 'Schwebebahn ist die Bezeichnung für eine Bahn, bei der elektrisch angetriebene Fahrzeuge unter einer Fahrschiene hängen.'),
		('2600', 'Materialseilbahn', 'Materialseilbahn ist die Bezeichnung für eine Seilbahn, die ausschließlich Güter transportiert.');
		CREATE TABLE ax_zustand_bahnverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_bahnverkehrsanlage IS 'Alias: "AX_Zustand_Bahnverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bahnverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich die Bahnverkehrsanlage nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass die Bahnverkehrsanlage noch nicht fertiggestellt ist.');
		CREATE TABLE ax_zustand_bauwerkimgewaesserbereich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_bauwerkimgewaesserbereich IS 'Alias: "AX_Zustand_BauwerkImGewaesserbereich", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bauwerkimgewaesserbereich (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich Bauwerk im Gewässerbereich nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass Bauwerk im Gewässerbereich noch nicht fertiggestellt ist.');
		CREATE TABLE ax_art_wegpfadsteig (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_wegpfadsteig IS 'Alias: "AX_Art_WegPfadSteig", UML-Typ: Enumeration';
		INSERT INTO ax_art_wegpfadsteig (wert,beschreibung,dokumentation) VALUES
		('1103', 'Fußweg', 'Fußweg ist ein Weg, der auf Grund seines Ausbauzustandes nur von Fußgängern zu begehen ist.'),
		('1105', 'Karren- und Ziehweg', 'Karrenweg ist ein Weg im Gebirge, der meist sehr steil ist und nur mit einem Gespann befahren werden kann. Ziehweg ist ein Weg, der der Holzabfuhr im Gebirge dient.'),
		('1106', 'Radweg', 'Radweg ist ein Weg, der als besonders gekennzeichneter und abgegrenzter Teil einer Straße oder mit selbständiger Linienführung für den Fahrradverkehr bestimmt ist'),
		('1107', 'Reitweg', 'Reitweg ist ein besonders ausgebauter Weg, auf dem ausschließlich das Reiten zugelassen ist.'),
		('1108', 'Wattenweg', ''),
		('1109', '(Kletter-)Steig im Gebirge', '(Kletter-)Steig im Gebirge ist ein stellenweise mit Drahtseilen gesicherter Pfad, der zur Überwindung besonders steiler Stellen mit Leitern versehen sein kann.'),
		('1110', 'Rad- und Fußweg', 'Rad- und Fußweg ist ein Weg, der als besonders gekennzeichneter und abgegrenzter Teil einer Straße oder mit selbständiger Linienführung ausschließlich für den Fahrrad- und Fußgängerverkehr bestimmt ist.'),
		('1111', 'Skaterstrecke', 'Skaterstrecke ist ein für Skater besonders ausgebauter asphaltierter Weg.');
		CREATE TABLE ax_lagezuroberflaeche_gleis (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagezuroberflaeche_gleis IS 'Alias: "AX_LageZurOberflaeche_Gleis", UML-Typ: Enumeration';
		INSERT INTO ax_lagezuroberflaeche_gleis (wert,beschreibung,dokumentation) VALUES
		('1200', 'Unter der Erdoberfläche', ''),
		('1400', 'Aufgeständert', '');
		CREATE TABLE ax_art_flugverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_flugverkehrsanlage IS 'Alias: "AX_Art_Flugverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_art_flugverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('1310', 'Startbahn, Landebahn', 'Startbahn, Landebahn ist eine Fläche, auf der Flugzeuge starten bzw. landen.'),
		('1320', 'Zurollbahn, Taxiway', 'Zurollbahn, Taxiway ist ein Verbindungsweg zwischen den Terminals bzw. dem Vorfeld und der Start- und/oder Landebahn.'),
		('1330', 'Vorfeld', 'Vorfeld ist ein Bereich, in dem Flugzeuge abgefertigt und abgestellt werden.'),
		('5520', 'Verkehrslandeplatz', 'Verkehrslandeplatz ist ein Flugplatz, der in der Luftfahrtkarte 1:500000 (ICAO) als solcher ausgewiesen ist.'),
		('5531', 'Hubschrauberlandeplatz', 'Hubschrauberlandeplatz ist ein Landeplatz, der in der Luftfahrtkarte 1:500000 (ICAO) als solcher ausgewiesen ist.'),
		('5540', 'Landeplatz, Sonderlandeplatz', 'Landeplatz, Sonderlandeplatz ist eine Fläche, die in der Luftfahrtkarte 1:500000 (ICAO) als Landeplatz, Sonderlandeplatz ausgewiesen ist.'),
		('5550', 'Segelfluggelände', 'Segelfluggelände ist eine Fläche, die in der Luftfahrtkarte 1:500000 (ICAO) als Segelfluggelände ausgewiesen ist.');
		CREATE TABLE ax_bauwerksfunktion_bauwerkimverkehrsbereich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_bauwerkimverkehrsbereich IS 'Alias: "AX_Bauwerksfunktion_BauwerkImVerkehrsbereich", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_bauwerkimverkehrsbereich (wert,beschreibung,dokumentation) VALUES
		('1800', 'Brücke', 'Brücke ist ein Bauwerk zum Zweck der Überführung eines Verkehrsweges über einen anderen Verkehrsweg  oder über ein Gewässer sowie zur Überführung über ein tieferliegendes Gelände.'),
		('1801', 'Mehrstöckige Brücke', 'Mehrstöckige Brücke ist eine Brücke, die mit Verkehrswegen in mehreren Etagen ausgestattet ist.'),
		('1802', 'Bogenbrücke', 'Bogenbrücke ist eine Brücke, bei der das Tragwerk aus Bögen besteht.'),
		('1803', 'Fachwerkbrücke', 'Fachwerkbrücke ist eine Brücke, bei der das Tragwerk aus starr zusammengesetzten Tragbalken (Holz oder Metall) besteht.'),
		('1804', 'Hängebrücke', 'Hängebrücke ist eine Brücke, bei der das Tragwerk von Hängegurten (Kabel) an einem oder mehreren Pylonen gehalten wird.'),
		('1805', 'Pontonbrücke', 'Pontonbrücke ist eine Behelfsbrücke, die sich aus kastenförmigen Schwimmkörpern zusammensetzt.'),
		('1806', 'Drehbrücke', 'Drehbrücke ist eine Brücke, bei der sich das Tragwerk um einen senkrechten Zapfen (Königsstuhl) dreht.'),
		('1807', 'Hebebrücke', 'Hebebrücke ist eine Brücke, bei der das Tragwerk an Seilen oder Ketten emporgehoben wird.'),
		('1808', 'Zugbrücke', 'Zugbrücke ist eine Brücke, bei der das Tragwerk um eine waagerechte Achse hochgeklappt wird.'),
		('1810', 'Landebrücke', ''),
		('1820', 'Steg', 'Steg ist ein Bauwerk, das Fußgängern den Übergang über ein Gewässer ermöglicht.'),
		('1830', 'Hochbahn, Hochstraße', 'Hochbahn, Hochstraße ist ein brückenartiges, aufgeständertes Verkehrsbauwerk.'),
		('1840', 'Brückenpfeiler', ''),
		('1845', 'Widerlager', ''),
		('1850', 'Strompfeiler', ''),
		('1870', 'Tunnel, Unterführung', 'Tunnel, Unterführung ist ein künstlich angelegtes unterirdisches Bauwerk, das im Verlauf von Verkehrswegen durch Bergmassive oder unter Flussläufen, Meerengen, städt. Bebauungen u. a. hindurchführt.'),
		('1880', 'Schutzgalerie, Einhausung', 'Schutzgalerie, Einhausung ist eine bauliche Einrichtung an Verkehrswegen zum Schutz gegen Lawinen, Schneeverwehungen, Steinschlägen sowie zum Schutz  gegen Emission. 
Schutzgalerien sind einseitige Überbauungen an Verkehrswegen,  Einhausungen umschließen die Verkehrswege meist vollständig.'),
		('1890', 'Schleusenkammer', 'Schleusenkammer ist eine Einrichtung zur Überführung von Wasserfahrzeugen zwischen Gewässern mit unterschiedlichen Wasserspiegelhöhen.'),
		('1900', 'Durchfahrt', 'Durchfahrt ist eine Stelle, an der mit Fahrzeugen durch ein Bauwerk (z.B. ein Turm, eine Mauer) hindurch gefahren werden kann.'),
		('1910', 'Anflugbefeuerung', ''),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bauwerksfunktion bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_bauwerksfunktion_bauwerkimgewaesserbereich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauwerksfunktion_bauwerkimgewaesserbereich IS 'Alias: "AX_Bauwerksfunktion_BauwerkImGewaesserbereich", UML-Typ: Enumeration';
		INSERT INTO ax_bauwerksfunktion_bauwerkimgewaesserbereich (wert,beschreibung,dokumentation) VALUES
		('2010', 'Durchlass', 'Durchlass ist ein Bauwerk, in dem ein Gewässer unter einem auf der Erdoberfläche liegenden Hindernis (Verkehrsweg, Siedlungsfläche) hindurchgeführt wird oder unter der Erdoberfläche in freier Feldlage oder abgedeckt (verdolt) auf der Erdoberfläche verläuft.'),
		('2011', 'Rohrdurchlass', 'Rohrdurchlass ist ein Bauwerk zur Unterführung eines Gewässers unter einem Verkehrsweg.'),
		('2012', 'Düker', 'Düker ist ein Kreuzungsbauwerk, in dem ein Gewässer unter einem anderen Gewässer, einem Geländeeinschnitt oder einem tieferliegenden Hindernis unter Druck hindurchgeleitet wird.'),
		('2020', 'Rückhaltebecken', ''),
		('2030', 'Staumauer', 'Staumauer ist ein aus Mauerwerk oder Beton bestehendes Absperrbauwerk zur Erzeugung eines Staus.'),
		('2040', 'Staudamm', 'Staudamm ist ein meist aus natürlichen Baustoffen, meist aufgeschüttetes Absperrbauwerk zur Erzeugung eines Staus.'),
		('2050', 'Wehr', 'Wehr ist ein festes oder mit beweglichen Teilen ausgestattetes Bauwerk im Flussbett zur Regulierung des Wasserabflusses.'),
		('2060', 'Sicherheitstor', 'Sicherheitstor ist ein Bauwerk zum Abschließen von Kanalstrecken, um bei Schäden das Auslaufen der gesamten Kanalhaltung zu verhindern.'),
		('2070', 'Siel', 'Siel ist ein Bauwerk mit Verschlusseinrichtung (gegen rückströmendes Wasser) zum Durchleiten eines oberirdischen Gewässers durch einen Deich.'),
		('2080', 'Sperrwerk', 'Sperrwerk ist ein Bauwerk in einem Tideflussgewässer mit Verschlusseinrichtung zum Absperren bestimmter Tiden, vor allem zum Schutz gegen Sturmfluten auch bei Tidehäfen.'),
		('2090', 'Schöpfwerk', 'Schöpfwerk ist eine Anlage, in der Pumpen Wasser einem höher gelegenen Vorfluter zuführen, u.a. zur künstlichen Entwässerung von landwirtschaftlich genutzten Flächen.'),
		('2110', 'Fischtreppe', ''),
		('2120', 'Pegel', 'Pegel ist eine Messeinrichtung zur Feststellung des Wasserstandes von Gewässern.'),
		('2130', 'Uferbefestigung', 'Uferbefestigung ist eine Anlage zum Schutze des Ufers.'),
		('2131', 'Wellenbrecher, Buhne', 'Wellenbrecher, Buhne ist ein ins Meer oder in den Fluss hinein angelegtes Bauwerk zum Uferschutz aus Buschwerk, Holz, Stein, Stahlbeton oder Asphalt.'),
		('2132', 'Lahnung', 'Lahnung ist ein ins Meer hineingebauter Damm aus Buschwerk, das zwischen Pfahlreihen fest eingepackt und verschnürt ist. Mehrere netzartig angelegte Dämme dienen zur Landgewinnung (z. B. im Watt) indem die Schlickablagerung gefördert wird.'),
		('2133', 'Hafendamm, Mole', 'Hafendamm, Mole ist ein in das Wasser vorgestreckter Steindamm, der eine Hafeneinfahrt begrenzt und das Hafenbecken vor Strömung und Wellenschlag schützt.'),
		('2134', 'Höft', 'Höft ist eine vorspringende Ecke bei Kaimauern in einem Hafen.'),
		('2135', 'Deckwerk', 'Deckwerk ist ein geböschter Uferschutz an Schardeichen (Deiche ohne Vorland).'),
		('2136', 'Ufermauer, Kaimauer', 'Ufermauer, Kaimauer ist eine Mauer entlang der Uferlinie eines Gewässers zum Schutz des Ufers bzw. eine Uferbefestigung im Hafengelände zum Anlegen von Schiffen.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bauwerksfunktion bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_art_einrichtungenfuerdenschiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_einrichtungenfuerdenschiffsverkehr IS 'Alias: "AX_Art_EinrichtungenFuerDenSchiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_art_einrichtungenfuerdenschiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('1410', 'Bake', 'Bake ist ein festgegründetes pfahl- oder gittermastartiges Schifffahrtszeichen mit Kennung durch Form oder Form und Farbe.'),
		('1420', 'Leuchtfeuer', 'Leuchtfeuer sind Anlagen, die ein Feuer tragen, das über den ganzen Horizont oder in festgelegten Sektoren oder Richtungen gezeigt wird und die bei Tage als Körperzeichen dienen.'),
		('1430', 'Kilometerstein', 'Kilometerstein ist ein Punkt mit einem festen Wert im Netz der Gewässer, der in der Örtlichkeit durch eine Markierung (z.B. Kilometerstein) repräsentiert wird.'),
		('1440', 'Tafel an Gewässern', ''),
		('1450', 'Pricke', ''),
		('1460', 'Anleger', 'Anleger ist eine feste oder schwimmende Einrichtung zum Anlegen von Schiffen.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Art bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_zustand_bauwerkimverkehrsbereich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_bauwerkimverkehrsbereich IS 'Alias: "AX_Zustand_BauwerkImVerkehrsbereich", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bauwerkimverkehrsbereich (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich Bauwerk im Verkehrsbereich nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.');
		CREATE TABLE ax_artdergewaesserachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdergewaesserachse IS 'Alias: "AX_ArtDerGewaesserachse", UML-Typ: Enumeration';
		INSERT INTO ax_artdergewaesserachse (wert,beschreibung,dokumentation) VALUES
		('1000', 'Gewässerachse der WSV', 'Gewässerachse der WSV ist eine Gewässerachse, deren Geometrie unverändert aus den Unterlagen der Wasser- und Schifffahrtsverwaltung übernommen wurde.'),
		('2000', 'Genäherte Mittellinie in Gewässern', 'Genäherte Mittellinie in Gewässern ist eine Gewässerachse, die den Spezifikationen der Richtlinie der Gebiets- und Gewässerverschlüsselung der Länderarbeitsgemeinschaft Wasser (LAWA) entspricht.'),
		('3001', 'Fiktive Verbindung in Fließgewässern', 'Fiktive Verbindung in Fließgewässern ist eine Gewässerachse, die ein einmündendes Gewässer mit der Gewässerachse des aufnehmenden Fließgewässers verbindet.'),
		('3002', 'Fiktive Verbindung in Seen und Teichen', 'Fiktive Verbindung in Seen und Teichen ist eine hydrologisch sinnvolle Verbindungslinie in stehenden Gewässern, die für den Aufbau eines geschlossenen topologischen Gewässernetzes benötigt wird.');
		CREATE TABLE ax_art_schifffahrtsliniefaehrverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_schifffahrtsliniefaehrverkehr IS 'Alias: "AX_Art_SchifffahrtslinieFaehrverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_art_schifffahrtsliniefaehrverkehr (wert,beschreibung,dokumentation) VALUES
		('1710', 'Autofährverkehr', 'Autofährverkehr ist ein in der Regel nach festem Fahrplan über Flüsse, Seen, Kanäle, Meerengen oder Meeresarme stattfindender Schiffsverkehr zwischen zwei Anlegestellen speziell für Fahrzeuge des Straßenverkehrs.'),
		('1720', 'Eisenbahnfährverkehr', 'Eisenbahnfährverkehr ist ein in der Regel nach festem Fahrplan über Flüsse, Seen, Kanäle, Meerengen oder Meeresarme stattfindender Schiffsverkehr zwischen zwei Anlegestellen speziell für Fahrzeuge des Schienenverkehrs.'),
		('1730', 'Personenfährverkehr', 'Personenfährverkehr ist ein in der Regel nach festem Fahrplan über Flüsse, Seen, Kanäle, Meerengen oder Meeresarme stattfindender Schiffsverkehr zwischen zwei Anlegestellen für Personenbeförderung.'),
		('1740', 'Linienverkehr', 'Linienverkehr ist die auf einer festgelegten Route nach einem festen Fahrplan verkehrende Güter- und Personenschifffahrt.');
		CREATE TABLE ax_zustand_schleuse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_schleuse IS 'Alias: "AX_Zustand_Schleuse", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_schleuse (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich die Schleuse nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.');
		CREATE TABLE ax_nutzung_hafen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_nutzung_hafen IS 'Alias: "AX_Nutzung_Hafen", UML-Typ: Enumeration';
		INSERT INTO ax_nutzung_hafen (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zivil', 'Zivil bedeutet, dass Hafen privaten oder öffentlichen Zwecken dient und nicht militärisch genutzt wird.'),
		('2000', 'Militärisch', 'Militärisch bedeutet, dass Hafen nur von Streitkräften genutzt wird.'),
		('3000', 'Teils zivil, teils militärisch', 'Teils zivil, teils militärisch bedeutet, dass Hafen sowohl zivil als auch militärisch genutzt wird.');
		CREATE TABLE ax_konstruktionsmerkmalbauart_schleuse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_konstruktionsmerkmalbauart_schleuse IS 'Alias: "AX_KonstruktionsmerkmalBauart_Schleuse", UML-Typ: Enumeration';
		INSERT INTO ax_konstruktionsmerkmalbauart_schleuse (wert,beschreibung,dokumentation) VALUES
		('1010', 'Schiffshebewerk', 'Schiffshebewerk ist ein Bauwerk zum Überwinden einer Fallstufe (in Binnenwasserstraßen und Kanälen) mit Förderung der Schiffe in einem Trog.'),
		('1020', 'Kammerschleuse', 'Kammerschleuse ist ein Bauwerk zum Überwinden einer Fallstufe, in dem durch Füllen oder Leeren der Schleusenkammer Schiffe gehoben oder gesenkt werden.');
		CREATE TABLE ax_hafenkategorie_hafen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hafenkategorie_hafen IS 'Alias: "AX_Hafenkategorie_Hafen", UML-Typ: Enumeration';
		INSERT INTO ax_hafenkategorie_hafen (wert,beschreibung,dokumentation) VALUES
		('1010', 'Containerhafen', 'Containerhafen ist ein Hafen mit speziellen Einrichtungen (z. B. Verladebrücken) für den Umschlag von genormten Containern.'),
		('1020', 'Ölhafen', 'Ölhafen ist ein Hafen mit speziellen Einrichtungen (z. B. Tankanlagen) für den Umschlag von Rohöl und den daraus verarbeiteten Produkten.'),
		('1030', 'Fischereihafen', 'Fischereihafen ist ein Hafen mit speziellen Einrichtungen (z. B. Kühlhäuser) für den Umschlag von frisch gefangenem Fisch.'),
		('1040', 'Sporthafen, Yachthafen', 'Sporthafen, Yachthafen ist ein Hafen für Sport- und Freizeitschiffe.'),
		('1050', 'Fährhafen', 'Fährhafen ist ein Hafen zum Anlegen von Fährschiffen.'),
		('1060', 'Stückguthafen', 'Stückguthafen ist ein Hafen, in dem nur Stückgüter umgeschlagen werden.'),
		('1070', 'Hafen für Massengüter', 'Hafen für Massengüter ist ein Hafen, in dem Massengüter umgeschlagen werden.');
		CREATE TABLE ax_art_gewaessermerkmal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_gewaessermerkmal IS 'Alias: "AX_Art_Gewaessermerkmal", UML-Typ: Enumeration';
		INSERT INTO ax_art_gewaessermerkmal (wert,beschreibung,dokumentation) VALUES
		('1610', 'Quelle', 'Quelle ist eine natürliche, örtlich begrenzte Austrittsstelle von Wasser.'),
		('1620', 'Wasserfall', 'Wasserfall ist ein senkrechter oder nahezu senkrechter Absturz eines Wasserlaufs, der über eine oder mehrere natürliche Stufen verlaufen kann.'),
		('1630', 'Stromschnelle', 'Stromschnelle ist eine Flussstrecke mit höherer Strömungsgeschwindigkeit durch ein besonders starkes Gefälle sowie oft auch geringerer Wassertiefe.'),
		('1640', 'Sandbank', 'Sandbank ist eine vegetationslose Sand- oder Kiesablagerung auf dem Meeresboden oder in Flüssen, die durch Brandung oder Strömung aufgebaut wird.'),
		('1650', 'Watt', 'Watt ist ein aus Sand oder Schlick bestehender Boden an flachen Gezeitenküsten und in Mündungstrichtern von Flüssen, der bei Ebbe ganz oder teilweise trocken fällt und bei Flut vom sogenannten Wattenmeer überspült wird.'),
		('1660', 'Priel', 'Priel ist eine natürliche Rinne im Watt, die auch bei Ebbe Wasser führt.'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_hydrologischesmerkmal_untergeordnetesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_untergeordnetesgewaesser IS 'Alias: "AX_HydrologischesMerkmal_UntergeordnetesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_untergeordnetesgewaesser (wert,beschreibung,dokumentation) VALUES
		('2000', 'Nicht ständig Wasser führend', ''),
		('3000', 'Trocken, versiegt', '');
		CREATE TABLE ax_lagezurerdoberflaeche_untergeordnetesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagezurerdoberflaeche_untergeordnetesgewaesser IS 'Alias: "AX_LageZurErdoberflaeche_UntergeordnetesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_lagezurerdoberflaeche_untergeordnetesgewaesser (wert,beschreibung,dokumentation) VALUES
		('1800', 'Verrohrt, unterirdisch, bedeckt', ''),
		('1810', 'Verdolt', '');
		CREATE TABLE ax_artdespolders (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdespolders IS 'Alias: "AX_ArtDesPolders", UML-Typ: Enumeration';
		INSERT INTO ax_artdespolders (wert,beschreibung,dokumentation) VALUES
		('1000', 'Sommerpolder', 'Sommerpolder (auch Überlaufpolder) ist ein Polder, der durch einen Überlauf- oder Sommerdeich nur gegen niedrige Hochwasser geschützt ist. Der Deich ist so ausgelegt, dass er zeitweise überströmt werden kann.'),
		('2000', 'Entlastungspolder', 'Entlastungspolder (auch Speicherpolder) ist ein Becken, das durch Zurückhalten von Wasser das Schöpfwerk, das Siel, den Vorfluter und/oder die Sperrwerksanlage entlastet.'),
		('3000', 'Flutungspolder', 'Flutungspolder ist eine eingedeichte, meist landwirtschaftlich genutzte Fläche, die beim Eintreten eines kritischen Wasserstandes zur Entlastung der Deiche genutzt wird.');
		CREATE TABLE ax_funktion_polder (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_polder IS 'Alias: "AX_Funktion_Polder", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_polder (wert,beschreibung,dokumentation) VALUES
		(' 7410', 'Gesteuert = 7410', ''),
		(' 7420', 'Ungesteuert = 7420', '');
		CREATE TABLE ax_funktion_untergeordnetesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_untergeordnetesgewaesser IS 'Alias: "AX_Funktion_UntergeordnetesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_untergeordnetesgewaesser (wert,beschreibung,dokumentation) VALUES
		('1010', 'Graben', ''),
		('1011', 'Grabenkante, rechts', ''),
		('1012', 'Grabenkante, links', ''),
		('1013', 'Grabenmitte', ''),
		('1020', 'Fleet', ''),
		('1030', 'Bach', ''),
		('1040', 'Teich', '');
		CREATE TABLE ax_hydrologischesmerkmal_gewaessermerkmal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_gewaessermerkmal IS 'Alias: "AX_HydrologischesMerkmal_Gewaessermerkmal", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_gewaessermerkmal (wert,beschreibung,dokumentation) VALUES
		('2000', 'Nicht ständig Wasser führend', 'Nicht ständig Wasser führend heißt, dass die Quelle nicht ganzjährig Wasser führt.');
		CREATE TABLE ax_funktion_vegetationsmerkmal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_vegetationsmerkmal IS 'Alias: "AX_Funktion_Vegetationsmerkmal", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_vegetationsmerkmal (wert,beschreibung,dokumentation) VALUES
		('1000', 'Windschutz', '');
		CREATE TABLE ax_zustand_vegetationsmerkmal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_vegetationsmerkmal IS 'Alias: "AX_Zustand_Vegetationsmerkmal", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_vegetationsmerkmal (wert,beschreibung,dokumentation) VALUES
		('5000', 'Nass', 'Nass bezeichnet eine Vegetationsfläche, die aufgrund besonderer Bodenbeschaffenheit ganzjährig wassergesättigt ist, zeitweise auch unter Wasser stehen kann.');
		CREATE TABLE ax_bewuchs_vegetationsmerkmal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bewuchs_vegetationsmerkmal IS 'Alias: "AX_Bewuchs_Vegetationsmerkmal", UML-Typ: Enumeration';
		INSERT INTO ax_bewuchs_vegetationsmerkmal (wert,beschreibung,dokumentation) VALUES
		('1011', 'Nadelbaum', 'Nadelbaum beschreibt die Zugehörigkeit eines einzeln stehenden Baumes zur Gruppe der Nadelhölzer.'),
		('1012', 'Laubbaum', 'Laubbaum beschreibt die Zugehörigkeit eines einzeln stehenden Baumes zur Gruppe der Laubhölzer.'),
		('1021', 'Baumbestand, Laubholz', 'Baumbestand, Laubholz beschreibt den Bewuchs einer Vegetationsfläche mit Laubbäumen.'),
		('1022', 'Baumbestand, Nadelholz', 'Baumbestand, Nadelholz beschreibt den Bewuchs einer Vegetationsfläche mit Nadelbäumen.'),
		('1023', 'Baumbestand, Laub- und Nadelholz', 'Baumbestand, Laub- und Nadelholz beschreibt den Bewuchs einer Vegetationsfläche mit Laub- und Nadelbäumen.'),
		('1100', 'Hecke', 'Hecke besteht aus einer Reihe dicht beieinander stehender, meist wildwachsender Sträucher.'),
		('1101', 'Heckenkante, rechts', ''),
		('1102', 'Heckenkante, links', ''),
		('1103', 'Heckenmitte', ''),
		('1210', 'Baumreihe, Laubholz', 'Laubholz beschreibt die Zugehörigkeit einer Baumreihe zur Gruppe der Laubhölzer.'),
		('1220', 'Baumreihe, Nadelholz', 'Nadelholz beschreibt die Zugehörigkeit einer Baumreihe zur Gruppe der Nadelhölzer.'),
		('1230', 'Baumreihe, Laub- und Nadelholz', 'Laub- und Nadelholz beschreibt den Bewuchs einer Baumreihe mit Laub- und Nadelbäumen.'),
		('1250', 'Gehölz', 'Gehölz ist eine Fläche, die mit einzelnen Bäumen, Baumgruppen, Büschen, Hecken und Sträuchern bestockt ist.'),
		('1260', 'Gebüsch', 'Gebüsch beschreibt den Bewuchs einer Vegetationsfläche mit Holzpflanzen, deren Sprossen sich nahe der Bodenoberfläche verzweigen.'),
		('1300', 'Schneise', 'Schneise ist eine künstlich angelegte Waldeinteilungslinie zur dauerhaften Begrenzung forstlicher Wirtschaftsflächen (räumliche Ordnung), die in der Regel geradlinig verläuft.'),
		('1400', 'Röhricht, Schilf', 'Röhricht, Schilf beschreibt den Bewuchs einer Vegetations- oder Wasserfläche mit Schilfrohr- und schilfrohrähnlichen Pflanzen.'),
		('1500', 'Gras', 'Gras beschreibt den Bewuchs einer Vegetationsfläche mit schlanken, krautigen einkeimblättrigen Blütenpflanzen.'),
		('1510', 'Rain', ''),
		('1600', 'Zierfläche', ''),
		('1700', 'Korbweide', ''),
		('1800', 'Reet', 'Reet bezeichnet eine ständig oder zeitweise unter Wasser stehende und mit Reet bewachsene Fläche.'),
		('1900', 'Streuobst', 'Streuobst beschreibt den Bewuchs einer Fläche mit Obstbäumen.');
		CREATE TABLE ax_eigentuemerart_namensnummer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_eigentuemerart_namensnummer IS 'Alias: "AX_Eigentuemerart_Namensnummer", UML-Typ: Enumeration';
		INSERT INTO ax_eigentuemerart_namensnummer (wert,beschreibung,dokumentation) VALUES
		('1000', 'Natürliche Personen', ''),
		('1100', 'Natürliche Person - Alleineigentum oder Ehepartner', ''),
		('1200', 'Natürliche Person - Wohnsitz im Land', ''),
		('1300', 'Natürliche Person - Wohnsitz außerhalb des Landes', ''),
		('1500', 'Natürliche Person - Gemeinschaftseigentum', ''),
		('2000', 'Juristische Personen', ''),
		('2100', 'Gemeinnützige Bau-, Wohnungs- oder Siedlungsgesellschaft oder -genossenschaft einschließlich Heimstätte', ''),
		('2200', 'Sonstige gemeinnützige Institution (Träger von Krankenhäusern, Altenheimen usw.)', ''),
		('2300', 'Privates Wohnungsunternehmen, private Baugesellschaft u.ä.', ''),
		('2400', 'Kreditinstitut', ''),
		('2500', 'Versicherungsunternehmen', ''),
		('2900', 'Andere Unternehmen, Gesellschaften usw.', ''),
		('3000', 'Körperschaften', ''),
		('3100', 'Stiftung', ''),
		('4000', 'Kirchliches Eigentum', ''),
		('4100', 'Evangelische Kirche', ''),
		('4200', 'Katholische Kirche', ''),
		('4900', 'Andere Kirchen, Religionsgemeinschaften usw.', ''),
		('5100', 'Bundesrepublik Deutschland', ''),
		('5101', 'Bundesrepublik Deutschland, Bundesstraßenverwaltung', ''),
		('5102', 'Bundesrepublik Deutschland, Bundeswehrverwaltung', ''),
		('5103', 'Bundesrepublik Deutschland, Forstverwaltung', ''),
		('5104', 'Bundesrepublik Deutschland, Finanzverwaltung', ''),
		('5105', 'Bundesrepublik Deutschland, Zivilschutz', ''),
		('5106', 'Bundesrepublik Deutschland, Wasserstraßenverwaltung', ''),
		('5107', 'Bundesrepublik Deutschland, Bundeseisenbahnvermögen', ''),
		('5210', 'Eigentum des Volkes nach DDR-Recht', ''),
		('5220', 'Eigentum der Genossenschaften und deren Einrichtungen', ''),
		('5230', 'Eigentum der gesellschaftlichen Organisationen und deren Einrichtungen', ''),
		('5240', 'Kommunale Gebietskörperschaften nach DDR-Recht', ''),
		('5300', 'Ausländischer Staat', ''),
		('5400', 'Kreis', ''),
		('5500', 'Gemeinde', ''),
		('5600', 'Kommunale Gebietskörperschaften', ''),
		('5700', 'Andere Gebietskörperschaften, Regionalverbände usw.', ''),
		('5800', 'Zweckverbände, Kommunale Betriebe', ''),
		('5920', 'Eigenes Bundesland', ''),
		('5921', 'Eigenes Bundesland, Denkmalpflege', ''),
		('5922', 'Eigenes Bundesland, Domänenverwaltung', ''),
		('5923', 'Eigenes Bundesland, Eichverwaltung', ''),
		('5924', 'Eigenes Bundesland, Finanzverwaltung', ''),
		('5925', 'Eigenes Bundesland, Forstverwaltung', ''),
		('5926', 'Eigenes Bundesland, Gesundheitswesen', ''),
		('5927', 'Eigenes Bundesland, Polizeiverwaltung', ''),
		('5928', 'Eigenes Bundesland, innere Verwaltung', ''),
		('5929', 'Eigenes Bundesland, Justizverwaltung', ''),
		('5930', 'Eigenes Bundesland, Kultusverwaltung', ''),
		('5931', 'Eigenes Bundesland, Landespflanzenschutzverwaltung', ''),
		('5932', 'Eigenes Bundesland, Arbeitsverwaltung', ''),
		('5933', 'Eigenes Bundesland, Sozialwesen', ''),
		('5934', 'Eigenes Bundesland, Landesbetrieb Straßen und Verkehr', ''),
		('5935', 'Eigenes Bundesland, Umweltverwaltung', ''),
		('5936', 'Eigenes Bundesland, Vermessungs- und Katasterverwaltung', ''),
		('5937', 'Eigenes Bundesland, Wasserwirtschaftsverwaltung', ''),
		('5938', 'Eigenes Bundesland, Wirtschaftsverwaltung', ''),
		('5939', 'Eigenes Bundesland, Liegenschafts- und Baubetreuung (LBB)', ''),
		('6000', 'Anderes Bundesland (allg.)', ''),
		('6001', 'Schleswig-Holstein', ''),
		('6002', 'Hamburg', ''),
		('6003', 'Niedersachsen', ''),
		('6004', 'Bremen', ''),
		('6005', 'Nordrhein-Westfalen', ''),
		('6006', 'Hessen', ''),
		('6007', 'Rheinland-Pfalz', ''),
		('6008', 'Baden-Württemberg', ''),
		('6009', 'Bayern', ''),
		('6010', 'Saarland', ''),
		('6011', 'Berlin', ''),
		('6012', 'Brandenburg', ''),
		('6013', 'Mecklenburg-Vorpommern', ''),
		('6014', 'Sachsen', ''),
		('6015', 'Sachsen-Anhalt', ''),
		('6016', 'Thüringen', ''),
		('7100', 'Deutsche Bahn AG', ''),
		('8000', 'Herrenlos', ''),
		('9000', 'Eigentümer unbekannt', '');
		CREATE TABLE ax_li_processstep_ohnedatenerhebung_description (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_li_processstep_ohnedatenerhebung_description IS 'Alias: "AX_LI_ProcessStep_OhneDatenerhebung_Description", UML-Typ: Enumeration';
		INSERT INTO ax_li_processstep_ohnedatenerhebung_description (wert,beschreibung,dokumentation) VALUES
		('Erhebung', NULL, '');
		CREATE TABLE ax_blattart_buchungsblatt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_blattart_buchungsblatt IS 'Alias: "AX_Blattart_Buchungsblatt", UML-Typ: Enumeration';
		INSERT INTO ax_blattart_buchungsblatt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Grundbuchblatt', 'Ein Grundbuchblatt ist ein Buchungsblatt, das die Buchung im Grundbuch enthält.'),
		('2000', 'Katasterblatt', 'Ein Katasterblatt ist ein Buchungsblatt, das die Buchung im Liegenschaftskataster enthält.'),
		('3000', 'Pseudoblatt', 'Ein Pseudoblatt ist ein Buchungsblatt, das die Buchung, die bereits vor Eintrag im Grundbuch Rechtskraft erlangt hat, enthält (z.B. Übernahme von Flurbereinigungsverfahren, Umlegungsverfahren).'),
		('4000', 'Erwerberblatt', 'Ein Erwerberblatt ist ein Buchungsblatt, das die Buchung, die bereits im Liegenschaftskataster, aber noch nicht im Grundbuch gebucht ist, enthält (Buchungsvorschlag für die Grundbuchverwaltung).
Pseudoblatt und Erwerberblatt werden nach Eintragung in das Grundbuch historisch.'),
		('5000', 'Fiktives Blatt', 'Das fiktive Blatt enthält die aufgeteilten Grundstücke und Rechte als Ganzes. Es bildet um die Miteigentumsanteile eine fachliche Klammer.');
		CREATE TABLE ax_anrede_person (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_anrede_person IS 'Alias: "AX_Anrede_Person", UML-Typ: Enumeration';
		INSERT INTO ax_anrede_person (wert,beschreibung,dokumentation) VALUES
		('1000', 'Frau', ''),
		('2000', 'Herr', ''),
		('3000', 'Firma', '');
		CREATE TABLE ax_artderrechtsgemeinschaft_namensnummer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderrechtsgemeinschaft_namensnummer IS 'Alias: "AX_ArtDerRechtsgemeinschaft_Namensnummer", UML-Typ: Enumeration';
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erbengemeinschaft', ''),
		('2000', 'Gütergemeinschaft', ''),
		('3000', 'BGB-Gesellschaft', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_buchungsart_buchungsstelle (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_buchungsart_buchungsstelle IS 'Alias: "AX_Buchungsart_Buchungsstelle", UML-Typ: Enumeration';
		INSERT INTO ax_buchungsart_buchungsstelle (wert,beschreibung,dokumentation) VALUES
		('1100', 'Grundstück', 'Das Grundstück ist ein räumlich abgegrenzter Teil der Erdoberfläche, der auf einem besonderen Blatt, dem Grundbuchblatt, für sich allein oder auf einem gemeinschaftlichen Grundbuchblatt unter einer eindeutigen Nummer des Bestandsverzeichnisses eingetragen ist (Grundstück im Rechtssinn). Das Grundstück besteht aus einem oder mehreren Flurstücken.'),
		('1101', 'Aufgeteiltes Grundstück WEG', 'Ein aufgeteiltes GrundstückWEG ist die Zusammenfassung  aller in Wohnungs- oder Teileigentum aufgeteilten Anteile eines Grundstücks. Es handelt sich daher um eine Buchungsart für das Fiktive Blatt.'),
		('1102', 'Aufgeteiltes Grundstück Par. 3 Abs. 4 GBO', 'Ein aufgeteiltes Grundstück nach Par. 3  Abs. 4 GBO ist die Zusammenfassung  aller dienenden Miteigentumsanteile eines Grundstücks (Miteigentumsanteil nach  § 3 Abs. 4 GBO).  Es handelt sich daher um eine Buchungsart für das Fiktive Blatt.'),
		('1200', 'Ungetrennter Hofraum', 'Zu einem ungetrennten Hofraum gehören Grundstücke, die zwar in ihren Außengrenzen, nicht aber bezüglich der daran bestehenden Anteile vermessen und katastermäßig erfasst sind. Im Grundbuch werden die nicht ausgemessenen , einzelnen Grundstücksflächen als Anteil an einem ungetrennten Hofraum ausgewiesen. Bis zur Vermessung der einzelnen Grundstücksflächen und Aufnahme in das Liegenschaftsbuch gilt das Gebäudesteuerbuch als amtliches Verzeichnis nach Par. 2 Abs. 2 GBO. Diese Nummer des Gebäudesteuerbuchs ist bis zur Vermessung im Grundbuch eingetragen. Für ungetrennte Hofräume existieren zwei miteinander korrespondierende Eintragungen:
In einem Grundbuchblatt sind alle ungetrennten Hofräume eines Grundbuchbezirks verzeichnet. Im zweiten Grundbuchblatt ist im Bestandsverzeichnis dann der Anteil an einem bestimmten ungetrennten Hofraum eingetragen.
Nach der katasterlichen Erfassung wird die bisherige Eintragung in beiden Grundbüchern gelöscht und das vermessenene Grundstück als normales Grundstück gebucht.'),
		('1301', 'Wohnungs-/Teileigentum', 'Das Wohnungseigentum kann nach Par. 3 Wohnungseigentumsgesetz (WEG) durch Vertrag der Miteigentümer oder nach Par. 8 WEG durch Erklärung des Eigentümers 
begründet werden.
Das entstehende Wohnungseigentum (Teileigentum) ist echtes Eigentum bürgerlichen Rechts in Form einer rechtlichen Verbindung von Miteigentum an Grundstück und Gebäude mit Sondereigentum an einer Wohnung bzw. Teileigentum an nicht zu Wohnzwecken dienenden Räumen.'),
		('1302', 'Miteigentum Par. 3 Abs. 4 GBO', 'Ein Miteigentum nach Par. 3 Abs. 4 der Grundbuchordnung (GBO) ist ein Miteigentum an einem dienenden Grundstück. Ist das Grundstück im wirtschaftlichen Sinn als Zubehör mehrerer anderer Grundstücke anzusehen und steht es im Miteigentum dieser Grundstücke (Bruchteilseigentum nach Par. 1008 ff des Bürgerlichen Gesetzbuchs (BGB), muss das Grundstück nicht in einem separaten Grundbuch geführt werden. Vielmehr wird das dienende Grundstück in ideellen Miteigentumsanteilen auf den Grundbuchblättern der herrschenden Grundstücke gebucht.'),
		('1303', 'Anteil am ungetrennten Hofraum', 'Hierbei handelt es sich um die Buchung des Anteils am ungetrennten Hofraum.'),
		('1401', 'Aufgeteilter Anteil Wohnungs-/Teileigentum', 'Hier wurde der mit dem Sondereigentum verbundene Miteigentumsanteil (Wohnungs-/Teileigentum) nochmals unterteilt. Die vorgenommene Grundbucheintragung deutet auf  eine Untergemeinschaft innerhalb der Gesamtgemeinschaft hin. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('1402', 'Aufgeteilter Anteil Miteigentum Par. 3 Abs. 4 GBO', 'Hier wurde der Miteigentumsanteil nach Par. 3 (4) GBO nochmals unterteilt. Die vorgenommene Grundbucheintragung deutet auf  eine Untergemeinschaft innerhalb der Gesamtgemeinschaft hin. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('1403', 'Aufgeteilter Anteil am ungetrennten Hofraum', 'Hier wurde der Anteil an ungeteiltem Hofraum nochmals unterteilt. Die vorgenommene Grundbucheintragung deutet auf  eine Untergemeinschaft innerhalb der Gesamtgemeinschaft hin. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('1501', 'Anteil an Wohnungs-/Teileigentumsanteil', 'Hier wird der Anteil an dem Wohnungs-/Teileigentumsanteil im Grundbuch eingetragen.'),
		('1502', 'Anteil an Miteigentumsanteil Par. 3 Abs. 4 GBO', 'Hier wird der Anteil an dem Miteigentumsanteil nach Par. 3 Abs. 4 GBO im Grundbuch eingetragen'),
		('1503', 'Anteil am Anteil zum ungetrennten Hofraum', 'Hier wird der Anteil an dem Anteil an dem ungetrennten Hofraum im Grundbuch eingetragen.'),
		('2101', 'Erbbaurecht', 'Veräußerliches und vererbliches grundstücksgleiches Recht, auf oder unter der Erdoberfläche eines (in der Regel) fremden Grundstücks ein Bauwerk zu haben.'),
		('2102', 'Untererbbaurecht', 'Untererbbaurecht ist das Erbbaurecht an einem Erbbaurecht. Hier ist der Belastungsgegenstand nicht das Grundstück, sondern das auf diesem lastenden Erbbaurecht.'),
		('2103', 'Gebäudeeigentum', 'Das Gebäudeeigentum an einem Grundstück als Ganzes zur Errichtung und  Nutzung eines Gebäudes.'),
		('2104', 'Fischereirecht', 'Fischereirecht ist die Befugnis, in einem Binnengewässer (See, Teich, Fluß, Bach) Fische, Krebse und andere nutzbare Wassertiere (z.B. Muscheln, Frösche), die nicht Gegenstand des Jagdrechts sind, zu hegen und sich anzueignen.'),
		('2105', 'Bergwerksrecht', 'Bergwerksrecht ist das ausschließliche Recht, in einem bestimmten Feld die in der Bewilligung bezeichneten Bodenschätze aufzusuchen und zu gewinnen (Par.9 I, Par. 8 BBergG vom 13.08.1980, BGBl. I 1310).'),
		('2106', 'Nutzungsrecht', 'Hierunter sind alle Nutzungsrechte zu verstehen, die im Bestandsverzeichnis eingetragen werden, unabhängig von ihrer öffentlich- oder privatrechtlichen Natur. Die nähere Bezeichnung des Nutzungsrechts ergibt sich aus dem Attribut Buchungstext.'),
		('2107', 'Realgewerberecht', 'Hierbei handelt es sich um die frei veräußerliche und vedrerbliche Befugnis zum Betrieb eines bestimmten Gewerbes, die mit dem Besitz einer Liegenschaft verbunden sein  kann aber nicht zwingend an ein bestimmtes Grundstücks gebunden sein  muss. Die nähere Bezeichnung des Nutzungsrechts ergibt sich aus dem Attribut Buchungstext.'),
		('2108', 'Gemeinderecht', 'Gemeinderecht ist das Recht zur Nutzung eines gemeinschftlichen Grundstücks. Die näheren Angaben zu diesem Recht sind in privatrechtlichen Verträgen enthalten.'),
		('2109', 'Stavenrecht', 'Ist ein mit dem Erbbaurecht vergleichbares Recht in  den nordfriesischen Küstenregionen.'),
		('2110', 'Hauberge', ''),
		('2201', 'Aufgeteiltes Erbbaurecht WEG', 'Diese Buchungsart ist die Zusammenfassung aller Anteile eines Erbbaurechts, die  auf mehreren Grundbuchblättern gebucht sind. Es handelt sich hier um eine Buchungsart für das Fiktive Blatt.'),
		('2202', 'Aufgeteiltes Untererbbaurecht WEG', 'Diese Buchungsart ist die Zusammenfassung aller Anteile eines Untererbbaurechts, die  auf mehreren Grundbuchblättern gebucht sind. Es handelt sich hier um eine Buchungsart für das Fiktive Blatt.'),
		('2203', 'Aufgeteiltes Recht Par. 3 Abs. 4 GBO', 'Diese Buchungsart ist die Zusammenfassung aller dienenden Miteigentumsanteile eines Erbbaurechts. Es handelt sich hier um eine Buchungsart für das Fiktive Blatt.'),
		('2204', 'Aufgeteiltes Recht, Körperschaft', 'Diese Buchungsart ist die Zusammenfassung aller auf den Grundbuchblättern der herrschenden Grundstücke gebuchten Nutzanteile an einer Körperschaft. Es handelt sich hier um eine Buchungsart für das Fiktive Blatt. Eine Körperschaft besteht aus einem Verband von Mitgliedern, deren Mitgliedschaft an landesrechtliche (meistens  altrechtliche ) und persönliche Merkmale gebunden ist; die  Mitglieder haben das Recht zur Nutzung des Grundstücks in einem bestimmten Umfang (z.B. Körperschaftswaldungen).'),
		('2205', 'Aufgeteiltes Gebäudeeigentum', 'Diese Buchungsart ist die Zusammenfassung aller Anteile eines Gebäudeeigentums, die  auf mehreren Grundbuchblättern gebucht sind. Es handelt sich hier um eine  Buchungsart für das Fiktive Blatt.'),
		('2301', 'Wohnungs-/Teilerbbaurecht', 'Wohnungs-/Teilerbaurechte können nach Par. 30 WEG unter Anwendung der Par. 3, 8 WEG begründet werden, wobei an die Stelle des Miteigentums am Grundstück die Mitberechtigung nach Bruchteilen an einem Erbbaurecht tritt, mit welchem das Sondereigentum an der Wohnung bzw. den nicht zu Wohnzwecken dienenden Räumen verbunden wird.'),
		('2302', 'Wohnungs-/Teiluntererbbaurecht', 'Wohnungs-/Teiluntererbbaurecht ist die Aufteilung eines Untererbbaurechts analog Par. 30 WEG.'),
		('2303', 'Erbbaurechtsanteil Par. 3 Abs. 4 GBO', 'Ein Erbbaurechtsanteil nach Par. 3 Abs. 4 der Grundbuchordnung (GBO) ist ein Miteigentum an einem dienenden Erbbaurecht.'),
		('2304', 'Anteiliges Recht, Körperschaft', 'Eintragung eines Anteils an dem  Recht - Körperschaft nach Par. 9 GBO im Grundbuch des jeweils herrschenden Grundstückes, dabei besteht die Körperschaft aus einem Verband von Mitgliedern, deren Mitgliedschaft  an gebietliche und persönliche Merkmale geknüpft ist  (z. B. Körperschaftswaldungen).'),
		('2305', 'Anteil am Gebäudeeigentum', 'Ist der Anteil des Nutzungsberechtigten für die Nutzung des auf dem Grundstück stehenden Gebäudes.'),
		('2401', 'Aufgeteilter Anteil Wohnungs-/Teilerbbaurecht', 'Hierbei wurde der Anteil an einem Wohnungs-/Teilerbbaurecht nochmals unterteilt. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('2402', 'Aufgeteilter Anteil Wohnungs-/Teiluntererbbaurecht', 'Hierbei wurde der Anteil an einem Wohnungs-/Teiluntererbbaurecht nochmals unterteilt. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('2403', 'Aufgeteilter Erbbaurechtsanteil Par. 3 Abs. 4 GBO', 'Hierbei wurde der Anteil an einem Erbbaurechtsanteil nochmals unterteilt. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('2404', 'Aufgeteiltes anteiliges Recht, Körperschaft', 'Hierbei wurde der Anteil an einem anteiligem Recht Körperschaft nochmals unterteilt. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('2405', 'Aufgeteilter Anteil am Gebäudeeigentum', 'Hierbei wurde der Anteil an einem Gebäudeeigentum nochmals unterteilt. Es handelt sich um eine Buchungsart für das Fiktive Blatt.'),
		('2501', 'Anteil am Wohnungs-/Teilerbbaurechtsanteil', 'Hier wird der Anteil an dem Wohnungs-/Teilerbbaurechtsanteil im Grundbuch eingetragen.'),
		('2502', 'Anteil am Wohnungs-/Teiluntererbbaurechtsanteil', 'Hier wird der Anteil an dem Wohnungs-/Teiluntererbbaurechtsanteil im Grundbuch eingetragen.'),
		('2503', 'Anteil am Erbbaurechtsanteil Par. 3 Abs. 4 GBO', 'Hier wird der Anteil an dem Erbbaurechtsanteil  im Grundbuch eingetragen.'),
		('2504', 'Anteil am anteiligen Recht, Körperschaft', 'Hier wird der Anteil an dem anteiligen Recht Körperschaft im Grundbuch eingetragen.'),
		('2505', 'Anteil am Anteil zum Gebäudeeigentum', 'Hier wird der Anteil an dem Anteil zum Gebäudeeigentum im Grundbuch eingetragen.'),
		('3100', 'Vermerk subjektiv dinglicher Rechte (Par. 9 GBO)', 'Der Vermerk ist ein Hinweis auf eine in Abteilung II des Grundbuchs des dienenden Grundstücks eingetragene Belastung. Er selbst ist kein Recht; seine Eintragung sichert lediglich, dass bei einer Aufhebung des Rechts im Grundbuch des dienenden Grundstücks die Bewilligung derer erforderlich ist, die der Rechtsänderung nach Par. 876 S. 2, 877, 888 BGB zustimmen müssen.'),
		('4100', 'Stockwerkseigentum', ''),
		('5101', 'Von Buchungspflicht befreit Par. 3 Abs. 2 GBO', 'Grundstücke nach Par. 3 Abs. 2 sind von der Buchungspflicht befreit und werden auf dem Katasterblatt gebucht.'),
		('5200', 'Anliegerflurstück', 'Ein Flurstück dessen Teilflächen den anliegenden Flurstücken zugerechnet wird.'),
		('5201', 'Anliegerweg', ''),
		('5202', 'Anliegergraben', ''),
		('5203', 'Anliegerwasserlauf, Anliegergewässer', ''),
		('6101', 'Nicht gebuchtes Fischereirecht', 'Das nicht gebuchte Fischereirecht wird nach Wasserrecht im Fischwasserkataster nachgewiesen und ist im Grundbuch nicht gebucht.');
		CREATE TABLE ax_klassifikation_hierarchiestufe3d_lagefestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_klassifikation_hierarchiestufe3d_lagefestpunkt IS 'Alias: "AX_Klassifikation_Hierarchiestufe3D_Lagefestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_klassifikation_hierarchiestufe3d_lagefestpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Hierarchiestufe A', ''),
		('2000', 'Hierarchiestufe B', ''),
		('3000', 'Hierarchiestufe C', ''),
		('4000', 'Hierarchiestufe D', ''),
		('5000', 'Hierarchiestufe E', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', '');
		CREATE TABLE ax_punktstabilitaet (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet IS 'Alias: "AX_Punktstabilitaet", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr gut', ''),
		('2000', 'gut', ''),
		('3000', 'befriedigend', ''),
		('4000', 'ausreichend', ''),
		('5000', 'mangelhaft (ohne Nennung eines Grundes)', ''),
		('5100', 'mangelhaft (Bergsenkungsgebiet)', ''),
		('5200', 'mangelhaft (in rutschgefährdeter Hanglage)', ''),
		('5300', 'mangelhaft (sehr nahe an Gewässer)', ''),
		('5400', 'mangelhaft (instabiler Untergrund)', ''),
		('6000', 'aus Wiederholungsmessungen nachgewiesene Stabilität der Vermarkung', ''),
		('8000', 'mangelhaft', ''),
		('9998', 'Stabilität der Vermarkung nicht untersucht', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_GeologischeStabilitaet", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr gute geologische Stabilität', ''),
		('2000', 'gute geologische Stabilität', ''),
		('3000', 'befriedigende geologische Stabilität', ''),
		('4000', 'ausreichende geologische Stabilität', ''),
		('5000', 'mangelhafte geologische Stabilität', ''),
		('9998', 'geologische Stabilität nicht untersucht', '');
		CREATE TABLE ax_klassifikation_ordnung_lagefestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_klassifikation_ordnung_lagefestpunkt IS 'Alias: "AX_Klassifikation_Ordnung_Lagefestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_klassifikation_ordnung_lagefestpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'TP (1) - Hauptdreieckspunkt, Zwischenpunkt 1. Ordnung', ''),
		('2000', 'TP (2) - Trigonometrischer Punkt 2. Ordnung', ''),
		('3000', 'TP (3) - Trigonometrischer Punkt 3. Ordnung', ''),
		('4000', 'TP (4) - Trigonometrischer Punkt 4. Ordnung', ''),
		('5000', 'TP (5) - Trigonometrischer Punkt 5. Ordnung', ''),
		('6000', 'ÜL - Übergeordneter Lagefestpunkt (Berlin)', ''),
		('9000', 'LFP, der nur eine interne Bedeutung hat', ''),
		('9998', 'Nach Quellenlage nicht zu spezifieren', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_GueteDesVermarkungstraegers", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr gut', ''),
		('2000', 'gut', ''),
		('3000', 'befriedigend', ''),
		('4000', 'ausreichend', ''),
		('5000', 'unzureichend', ''),
		('9998', 'nicht bekannt', '');
		CREATE TABLE ax_ordnung_schwerefestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_ordnung_schwerefestpunkt IS 'Alias: "AX_Ordnung_Schwerefestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_ordnung_schwerefestpunkt (wert,beschreibung,dokumentation) VALUES
		('0500', 'SFP(0) - Schweregrundnetzpunkt', ''),
		('1000', 'SFP(1) - Schwerefestpunkt 1.Ordnung, Hauptschwerenetzpunkt', ''),
		('2000', 'SFP(2) - Schwerefestpunkt 2.Ordnung', ''),
		('3000', 'SFP(3) - Schwerefestpunkt 3.Ordnung', ''),
		('4000', 'SFP(4) - Schwerefestpunkt 4. Ordnung', ''),
		('9000', 'SFP, der nur eine interne Bedeutung hat', ''),
		('9998', 'nach Quellenlage nicht zu spezifizieren', '');
		CREATE TABLE ax_funktion_referenzstationspunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_referenzstationspunkt IS 'Alias: "AX_Funktion_Referenzstationspunkt", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_referenzstationspunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zentrum', ''),
		('2000', 'Exzentrum', '');
		CREATE TABLE ax_funktion_lagefestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_lagefestpunkt IS 'Alias: "AX_Funktion_Lagefestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_lagefestpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zentrum', ''),
		('2000', 'Exzentrum, Stationspunkt, Nebenstand', ''),
		('3000', 'Zwillingspunkt, Orientierungspunkt', ''),
		('4000', 'Versicherungspunkt', '');
		CREATE TABLE ax_skizzenart_skizze (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_skizzenart_skizze IS 'Alias: "AX_Skizzenart_Skizze", UML-Typ: Enumeration';
		INSERT INTO ax_skizzenart_skizze (wert,beschreibung,dokumentation) VALUES
		('1000', 'Lage-/Einmessungsskizze/Ansicht für die Standardausgabe', ''),
		('2000', 'sonstige Lageskizze', ''),
		('2100', 'sonstige Einmessungsskizze', ''),
		('2200', 'sonstige Ansichtszeichnung oder Foto', ''),
		('2300', 'Randzeichnung', ''),
		('3000', 'Ausschnitt aus der Punktübersicht', ''),
		('3100', 'Luftbildausschnitt mit Punkteintrag', ''),
		('4000', 'Diagramm, Tabelle', '');
		CREATE TABLE ax_funktion_schwerefestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_schwerefestpunkt IS 'Alias: "AX_Funktion_Schwerefestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_schwerefestpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zentrum', ''),
		('2000', 'Exzentrum', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_HoehenstabilitaetAusWiederholungsmessungen", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr gut', ''),
		('2000', 'gut', ''),
		('3000', 'befriedigend', ''),
		('4000', 'bedenklich', ''),
		('5000', 'unzureichend', ''),
		('9998', 'nicht bekannt', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_GueteDesBaugrundes", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr gute Stabilität des Baugrundes', ''),
		('2000', 'gute Stabilität des Baugrundes', ''),
		('3000', 'befriedigende Güte des Baugrundes', ''),
		('4000', 'ausreichende Güte des Baugrundes', ''),
		('5000', 'mangelhafte Güte des Baugrundes', ''),
		('9998', 'Güte des Baugrundes nicht untersucht', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_Grundwasserschwankung", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr geringe Grundwasserschwankung (kleiner gleich 0,5 m)', ''),
		('2000', 'geringe Grundwasserschwankung (groesser 0,5 m und kleiner gleich 2 m)', ''),
		('3000', 'mäßige Grundwasserschwankung (groesser 2 m und kleiner gleich 5 m)', ''),
		('4000', 'starke Grundwasserschwankung (groesser 5m und kleiner gleich 10 m)', ''),
		('5000', 'sehr starke Grundwasserschwankung (groesser 10 m)', ''),
		('9998', 'Grundwasserschwankung nicht ermittelt', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_TopographieUndUmwelt", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt (wert,beschreibung,dokumentation) VALUES
		('1000', 'keine Topographie- und Umwelteinflüsse', ''),
		('2000', 'geringe Topographie- und Umwelteinflüsse', ''),
		('3000', 'mäßige Topographie- und Umwelteinflüsse', ''),
		('4000', 'starke Topographie- und Umwelteinflüsse', ''),
		('5000', 'sehr starke Topographie- und Umwelteinflüsse', ''),
		('9998', 'Topographie- und Umwelteinflüsse nicht untersucht', '');
		CREATE TABLE ax_klassifikation_wertigkeit_lagefestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_klassifikation_wertigkeit_lagefestpunkt IS 'Alias: "AX_Klassifikation_Wertigkeit_Lagefestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_klassifikation_wertigkeit_lagefestpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fundamentalpunkt (Punkt auf dem die Position (3D), die schwerebezogene Höhe und die Schwere hoch genau bestimmt worden sind)', ''),
		('2000', 'Übergeordneter Festpunkt', ''),
		('3000', 'Geodätischer Grundnetzpunkt', ''),
		('4000', 'Gebrauchsfestpunkt', ''),
		('5000', 'Untergeordneter Festpunkt', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_gnsstauglichkeit (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_gnsstauglichkeit IS 'Alias: "AX_GNSSTauglichkeit", UML-Typ: Enumeration';
		INSERT INTO ax_gnsstauglichkeit (wert,beschreibung,dokumentation) VALUES
		('1000', 'weitgehende Horizontfreiheit, Mehrwegeffekte nicht wahrscheinlich', ''),
		('1001', 'sehr gute Satelliten-Empfangseigenschaften nachgewiesen', ''),
		('3000', 'eingeschränkte Horizontfreiheit', ''),
		('3001', 'eingeschränkte Horizontfreiheit, Tauglichkeit nachgewiesen', ''),
		('3100', 'Mehrwegeffekte möglich', ''),
		('3101', 'Mehrwegeffekte nachgewiesen', ''),
		('5000', 'Festpunkt nicht geeignet für Satellitenmessverfahren', ''),
		('9998', 'GNSS-Tauglichkeit nicht untersucht', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_Grundwasserstand", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand (wert,beschreibung,dokumentation) VALUES
		('1000', 'Grundwasserstand sehr tief (groesser 10 m)', ''),
		('2000', 'Grundwasserstand tief (groesser 5 m und kleiner gleich 10 m)', ''),
		('3000', 'Grundwasserstand normal (groesser 2 m und kleiner gleich 5 m)', ''),
		('4000', 'Grundwasserstand hoch (groesser 0,5 m und kleiner gleich 2 m)', ''),
		('5000', 'Grundwasserstand sehr hoch (kleiner gleich 0,5 m)', ''),
		('9000', 'Grundwasserstand abgesenkt', ''),
		('9998', 'Grundwasserstand nicht ermittelt', '');
		CREATE TABLE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili IS 'Alias: "AX_Punktstabilitaet_Hoehenfestpunkt_VermuteteHoehenstabilitaet", UML-Typ: Enumeration';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili (wert,beschreibung,dokumentation) VALUES
		('1000', 'sehr gut', ''),
		('2000', 'gut', ''),
		('3000', 'befriedigend', ''),
		('4000', 'ausreichend', ''),
		('5000', 'mangelhaft', ''),
		('9998', 'nicht bekannt', '');
		CREATE TABLE ax_ordnung_hoehenfestpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_ordnung_hoehenfestpunkt IS 'Alias: "AX_Ordnung_Hoehenfestpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_ordnung_hoehenfestpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'NivP(1) - Haupthöhenpunkt, Zwischenlinienpunkt 1.Ordnung', ''),
		('1001', 'NivP(1) - Netzverdichtung GPS (Niedersachsen)', ''),
		('2000', 'NivP(2) - Nivellementpunkt 2. Ordnung', ''),
		('3000', 'NivP(3) - Nivellementpunkt 3. Ordnung', ''),
		('3001', 'NivP(3) - nivellitisch bestimmter Bodenpunkt für Referenzstation', ''),
		('4000', 'NivP(4) - Nivellementpunkt 4. Ordnung', ''),
		('6000', 'ÜH - Übergeordneter Höhenfestpunkt (Berlin)', ''),
		('9000', 'Höhenfestpunkt, der nur eine interne Bedeutung hat', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', '');
		CREATE TABLE ax_horizontfreiheit_grenzpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_horizontfreiheit_grenzpunkt IS 'Alias: "AX_Horizontfreiheit_Grenzpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_horizontfreiheit_grenzpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Uneingeschränkt', ''),
		('2000', 'Eingeschränkt', ''),
		('3000', 'Nicht geeignet', '');
		CREATE TABLE ax_gruendederausgesetztenabmarkung_grenzpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_gruendederausgesetztenabmarkung_grenzpunkt IS 'Alias: "AX_GruendeDerAusgesetztenAbmarkung_Grenzpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_gruendederausgesetztenabmarkung_grenzpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Grenzpunkt durch bauliche Anlage ausreichend gekennzeichnet', ''),
		('2000', 'Grenzpunkt liegt innerhalb einer baulichen Anlage', ''),
		('3000', 'Grenzpunkt in öffentlich-rechtlichem Bodenordnungsverfahren', ''),
		('4000', 'Grenzpunkt liegt innerhalb eines Baugebietes', ''),
		('5000', 'Grenzpunkt liegt innerhalb oder an einem Gewässer', ''),
		('6000', 'Keine Abmarkung aufgrund von anderweitigen Hindernissen', ''),
		('7000', 'Abmarkung würde unzumutbare Schäden verursachen', ''),
		('8000', 'Langfristige gemeinschaftliche Nutzung der angrenzenden  Flurstücke', ''),
		('9000', 'Angrenzende Flurstücke dienen dem Gemeingebrauch', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_bemerkungzurabmarkung_grenzpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bemerkungzurabmarkung_grenzpunkt IS 'Alias: "AX_BemerkungZurAbmarkung_Grenzpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_bemerkungzurabmarkung_grenzpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Abmarkung unterirdisch gesichert', ''),
		('2000', 'Abmarkung exzentrisch gesichert', ''),
		('3000', 'Abmarkung unterirdisch und exzentrisch gesichert', ''),
		('4000', 'Ohne unterirdische oder exzentrische Sicherung', '');
		CREATE TABLE ax_artderflurstuecksgrenze_besondereflurstuecksgrenze (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderflurstuecksgrenze_besondereflurstuecksgrenze IS 'Alias: "AX_ArtDerFlurstuecksgrenze_BesondereFlurstuecksgrenze", UML-Typ: Enumeration';
		INSERT INTO ax_artderflurstuecksgrenze_besondereflurstuecksgrenze (wert,beschreibung,dokumentation) VALUES
		('1000', 'Strittige Grenze', ''),
		('2001', 'Nicht festgestellte Grenze', ''),
		('2002', 'Verwaltungsstreitverfahren (Grenze)', ''),
		('2003', 'Mittellinie in Gewässern', ''),
		('2004', 'Flurstücksgrenze nicht feststellbar', 'Eine "nicht feststellbare Flurstücksgrenze" ist eine bisher nicht festgestellte Flurstücksgrenze, die nach den Daten des Liegenschaftskatasters nicht mit einer für die Grenzfeststellung erforderlichen Genauigkeit und Zuverlässigkeit in die Örtlichkeit übertragen werden kann und für die ein öffentlich-rechtlicher Grenzfeststellungsvertrag zwischen den Eigentümern mangels (positiver) Einigung nicht zustande kommt. Die fehlende Einigung bedeutet nicht zwangsläufig, dass sich die jeweiligen Eigentümer zivilrechtlich streiten.'),
		('2010', 'Topographische Grenzeinrichtung', ''),
		('2100', 'Topographische Gewaesserbegrenzung', ''),
		('2500', 'Grenze der Region', ''),
		('3000', 'Grenze der Flur', ''),
		('7003', 'Grenze der Gemarkung', ''),
		('7101', 'Grenze der Bundesrepublik Deutschland', ''),
		('7102', 'Grenze des Bundeslandes', ''),
		('7103', 'Grenze des Regierungsbezirks', ''),
		('7104', 'Grenze des Landkreises', ''),
		('7106', 'Grenze der Gemeinde', ''),
		('7107', 'Grenze des Gemeindeteils', ''),
		('7108', 'Grenze der Verwaltungsgemeinschaft', '');
		CREATE TABLE ax_horizontfreiheit_netzpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_horizontfreiheit_netzpunkt IS 'Alias: "AX_Horizontfreiheit_Netzpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_horizontfreiheit_netzpunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Uneingeschränkt', ''),
		('2000', 'Eingeschränkt', ''),
		('3000', 'Nicht geeignet', '');
		CREATE TABLE ax_marke (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_marke IS 'Alias: "AX_Marke", UML-Typ: Enumeration';
		INSERT INTO ax_marke (wert,beschreibung,dokumentation) VALUES
		('1000', 'Marke, allgemein', ''),
		('1100', 'Stein', ''),
		('1110', 'Stein, Grenzstein', ''),
		('1111', 'Lochstein', ''),
		('1112', 'Vermessungspunktstein', ''),
		('1120', 'Unbehauener Feldstein', ''),
		('1130', 'Gemeinde- und Waldgrenzstein', ''),
		('1131', 'Gemeindegrenzstein', ''),
		('1132', 'Waldgrenzstein, Forstgrenzstein', ''),
		('1140', 'Kunststoffmarke', ''),
		('1160', 'Landesgrenzstein', ''),
		('1190', 'Stein mit Besonderheiten in Form oder Material', ''),
		('1200', 'Rohr', ''),
		('1201', 'Rohr mit Schutzkappe', ''),
		('1202', 'Rohr mit Kopf', ''),
		('1203', 'Rohr mit Bolzen, oberirdisch', ''),
		('1210', 'Eisenrohr', ''),
		('1211', 'Eisenrohr (mit Schutzkappe)', ''),
		('1212', 'Eisenrohr (ohne Schutzkappe)', ''),
		('1220', 'Kunststoffrohr', ''),
		('1221', 'Kunststoffrohr (mit Schutzkappe)', ''),
		('1222', 'Kunststoffrohr (ohne Schutzkappe)', ''),
		('1230', 'Drainrohr', ''),
		('1240', 'Rohr mit Schutzkasten', ''),
		('1250', 'Zementrohr', ''),
		('1260', 'Glasrohr', ''),
		('1290', 'Tonrohr', ''),
		('1300', 'Bolzen/Nagel', ''),
		('1310', 'Bolzen', ''),
		('1311', 'Adapterbolzen', ''),
		('1320', 'Nagel', ''),
		('1400', 'Meißelzeichen (z. B. Kreuz, Kerbe, Anker)', ''),
		('1410', 'Bohrloch', ''),
		('1500', 'Pfahl', ''),
		('1600', 'Sonstige Marke', ''),
		('1610', 'Marke in Schutzbehälter', ''),
		('1620', 'Flasche', ''),
		('1630', 'Platte', ''),
		('1631', 'Klinkerplatte', ''),
		('1632', 'Granitplatte', ''),
		('1635', 'Platte mit Loch', ''),
		('1640', 'Hohlziegel', ''),
		('1650', 'Klebemarke', ''),
		('1655', 'Schlagmarke', ''),
		('1660', 'Kanaldeckel (Kreuz des Gütesiegels auf Rand)', ''),
		('1670', 'Marke besonderer Ausführung', ''),
		('1700', 'Punkt dauerhaft und gut erkennbar festgelegt', ''),
		('1710', 'Punkt der baulichen Anlage', ''),
		('1711', 'Sockel (roh)', ''),
		('1712', 'Sockel (verputzt)', ''),
		('1713', 'Mauerecke (roh)', ''),
		('1714', 'Mauerecke (verputzt)', ''),
		('1720', 'Grenzsäule', ''),
		('1800', 'Pfeiler', ''),
		('1820', 'Kegel', ''),
		('2100', 'Festlegung 1. Ordnung, Kopf 30x30 cm, Bezugspunkt Platte', ''),
		('2101', 'Festlegung 1. Ordnung, Bezugspunkt Kopf 30x30 cm', ''),
		('2102', 'Festlegung STN 1. Ordnung, Pfeiler-kopf 30x30 cm, Bezugspunkt Platte 60x60 cm, Steinwürfel, Tonkegel', ''),
		('2110', 'Festlegung 2. bis 5. Ordnung, Kopf 16x16 oder 12x12 cm, Bezugspunkt Platte 30x30 cm', ''),
		('2111', 'Festlegung 3. bis 5. Ordnung, Bezugspunkt Kopf 16x16 oder 12x12 cm, Platte 30x30 cm', ''),
		('2120', 'Festlegung 2. bis 4. Ordnung, Kopf 20x20 cm, Bezugspunkt Platte', ''),
		('2121', 'Festlegung 2. bis 4. Ordnung, Bezugspunkt Kopf 20x20 cm,', ''),
		('2130', 'Festlegung 2. bis 4. Ordnung, Kopf 25x25 cm, Bezugspunkt Platte', ''),
		('2131', 'Festlegung 2. bis 4. Ordnung, Bezugspunkt Kopf 25x25 cm,', ''),
		('2132', 'Festlegung STN 3. und 5. Ordnung, Pfeilerkopf 16x16 cm, Bezugspunkt Platte 30x30-40x40 cm', ''),
		('2133', 'Festlegung STN 3. und 5. Ordnung, Pfeilerkopf 16x16 cm, Bezugspunkt Bolzen oder Rotgußkappe im Fels', ''),
		('2134', 'Festlegung TP-Feld, Pfeilerkopf 25x25 cm, Bezugspunkt Platte 35x35 cm', ''),
		('2135', 'Festlegung RBP-Feld, Pfeilerkopf 16x16 cm mit Gravur "TP" und "Dreieck", Bezugspunkt Platte 30x30-35x35 cm', ''),
		('2140', 'Plattformbolzen mit Aufschrift TP', ''),
		('2150', 'Turmbolzen mit Aufschrift TP', ''),
		('2160', 'Leuchtschraube oder -bolzen', ''),
		('2161', 'Schraube (vertikal)', ''),
		('2162', 'Messingmarke oder Messingbolzen', ''),
		('2163', 'Keramikbolzen, oberirdisch', ''),
		('2164', 'Bolzen im Fels, unterirdisch', ''),
		('2165', 'Rotgusskappe im Fels, unterirdisch', ''),
		('2166', 'Messingbolzen (gewölbt), Aufschrift TP und Dreieck', ''),
		('2170', 'Turmbolzen, Festlegungsbolzen oder sonstiger Bolzen, keine weiteren Angaben bekannt oder gespeichert', ''),
		('2180', 'Festlegung 2. Ordnung, Kopf 16x16 cm oder 12x12 cm, Bezugspunkt Platte 60x60 cm', ''),
		('2181', 'Festlegung 2. Ordnung, Bezugspunkt Kopf 16x16 cm oder 12x12 cm, Platte 60x60 cm', ''),
		('2190', 'Festlegung 2. bis 3. Ordnung, Kopf 16x16 cm, Bezugspunkt Platte 40x40 cm', ''),
		('2191', 'Festlegung 2. bis 3. Ordnung, Bezugspunkt Kopf 16x16 cm, Platte 40x40 cm', ''),
		('2192', 'Bergpfeiler ca. 60 cm lang, ohne Platte, Kopf 12x12 cm', ''),
		('2200', 'Pfeiler mit Aufschrift AP', ''),
		('2201', 'Pfeiler mit Aufschrift AP mit Platte, Bezugspunkt Kopf', ''),
		('2210', 'Plattformbolzen mit der Aufschrift AP', ''),
		('2220', 'Turmbolzen mit der Aufschrift AP', ''),
		('2230', 'Festlegung der Wasserstraßenverwaltung, Stein mit Rohr und Stehbolzen, Typ 1', ''),
		('2240', 'Festlegung der Wasserstraßenverwaltung, Stein mit Rohr und Stehbolzen, Typ 2', ''),
		('2250', 'Festlegung der Wasserstraßenverwaltung, Stein mit Rohr und Stehbolzen, Typ 3', ''),
		('2260', 'Festlegung Sachsen-Anhalt SANREF (unterirdischer Granitpfeiler mit Kopfbolzen)', ''),
		('2261', '3D-Bolzen einzementiert in Kopffläche einer Festlegung STN 1. Ordnung', ''),
		('2262', '3D-Bolzen in Kopffläche einer Festle-gung TP-Feld', ''),
		('2263', '3D-Bolzen in Kopffläche einer AF Sachsen 3. Ordnung', ''),
		('2264', '3D-Bolzen in Kopffläche einer AF Sachsen 5. Ordnung', ''),
		('2265', '3D-Bolzen in Granitplatte unter Schutzkasten oder Kunststoff- Schutz-rohr', ''),
		('2266', 'Sondervermarkung, einbetonierter Granitpfeiler 40x40x90 cm mit Zentrumsbolzen in Kopffläche', ''),
		('2300', 'Alte Festlegung der Kgl. Generalkommission und von Kurhessen, Rillenstein', ''),
		('2310', 'Alte Festlegung von Nassau, exz., ehemals 2.O.', ''),
		('2320', 'Alte Festlegung von Nassau, exz., ehemals 3.O.', ''),
		('2330', 'Alte Festlegung von Hessen-Darmstadt, 3.O.', ''),
		('2340', 'Alte Festlegung von Hessen-Darmstadt, 4.O.', ''),
		('2350', 'Alte Festlegung von Hessen-Darmstadt, 3.O. exz.', ''),
		('2360', 'Alte Festlegung von Hessen-Darmstadt, 4.O.exz.', ''),
		('2370', 'Alte Festlegung von Westfalen, 2. O. exz.', ''),
		('2400', 'Alte Festlegung von Württemberg, exz.', ''),
		('2410', 'Alte Festlegung von Württemberg', ''),
		('2420', 'Alte Festlegung von Mecklenburg, ehemals 1. bis 2. Ordnung', ''),
		('2430', 'Alte Festlegung von Mecklenburg, ehemals 2. bis 3. Ordnung', ''),
		('2440', 'Alte Festlegung von Mecklenburg, ehemals 4. Ordnung', ''),
		('2450', 'Alte Festlegung Sachsen, 1. und 2. Ordnung (Nagelsche Säule)', ''),
		('2460', 'Alte Festlegung Sachsen, 3. Ordnung, Pfeilerkopf 35x35 cm mit zentrischer Messingmarke', ''),
		('2470', 'Alte Festlegung Sachsen, 5. Ordnung, Pfeilerkopf 25x25 cm mit zentrischer Messingmarke', ''),
		('2500', 'Alte Festlegung von Baden, exz., Typ 1', ''),
		('2510', 'Alte Festlegung von Baden, exz., Typ 2', ''),
		('2540', 'Alte Festlegung von Baden', ''),
		('2550', 'Rohr mit Schutzkasten, Grundständer', ''),
		('2551', 'Grundständer mit Messingmarke unter Schutzkasten', ''),
		('2552', 'Marke (allgemein) unter Schutzkasten', ''),
		('2553', 'Platte unter Schutzkasten', ''),
		('2560', 'Rohr mit Verschlusskappe und aufgesetztem Lochstein', ''),
		('2600', 'Alte Festlegung in Bayern, exz.', ''),
		('2601', 'gebohrter Granitstein (Bezugspunkt) über Tonrohr', ''),
		('2602', 'gebohrter Granitstein über Tonrohr (Bezugspunkt)', ''),
		('2603', 'gebohrter Granitstein (Bezugspunkt) über Platte', ''),
		('2604', 'gebohrter Granitstein über Platte (Bezugspunkt)', ''),
		('2605', 'gebohrter Granitstein (Bezugspunkt) über Eisenrohr', ''),
		('2606', 'gebohrter Granitstein über Eisenrohr (Bezugspunkt)', ''),
		('2607', 'Betonstein (Bezugspunkt) über Platte', ''),
		('2608', 'Betonstein über Platte (Bezugspunkt)', ''),
		('2609', 'Betonstein mit durchgehendem Bohrloch (Einschaltpunkt-Stein in Bayern)', ''),
		('2610', 'Alte Festlegung in Bayern', ''),
		('2611', 'KT-Stein der österreichischen Katastraltriangulation', ''),
		('2612', 'Stein (Bezugspunkt) über Platte', ''),
		('2613', 'Stein über Platte (Bezugspunkt)', ''),
		('2614', 'Stein (Bezugspunkt) über Tonrohr', ''),
		('2615', 'Stein über Tonrohr (Bezugspunkt)', ''),
		('2616', 'Stein mit Eisenrohr', ''),
		('2620', 'Alte Festlegung in Sachsen-Coburg, 3.O.', ''),
		('2630', 'Alte Festlegung in Sachsen-Coburg, 4.O.', ''),
		('2640', 'Alte Festlegung in Bayern und der Pfalz, HDNP-Stein', ''),
		('2700', 'Festlegung MP-Pfeiler', ''),
		('2710', 'Festlegung Orientierungspunkt', ''),
		('2750', 'Steinpfeiler', ''),
		('2760', 'Betonpfeiler', ''),
		('2770', 'Kreuz (gemeisselt)', ''),
		('2800', 'Knopf', ''),
		('2810', 'Mitte', ''),
		('2820', 'Spitze', ''),
		('2830', 'Kreuz (Mitte)', ''),
		('2840', 'Helmstange', ''),
		('2850', 'Fahnenstange', ''),
		('2860', 'Wetterstange', ''),
		('2870', 'Blitzableiter', ''),
		('2880', 'Antenne', ''),
		('2890', 'Rohrstange', ''),
		('2900', 'Platte, unterirdisch', ''),
		('2901', 'Platte einbetoniert mit zentrischem Messingbolzen', ''),
		('2902', 'Platte einbetoniert mit zentrischem Bohrloch', ''),
		('2903', 'Platte einbetoniert mit zentrischer Keramikmarke', ''),
		('2904', 'Platte einbetoniert mit zentrischer Messingmarke', ''),
		('2910', 'Steinwürfel, unterirdisch', ''),
		('2920', 'Steinplatte, unterirdisch', ''),
		('2930', 'Platte, unterirdisch, 60x60 cm', ''),
		('2940', 'Platte, unterirdisch, 30x30 cm', ''),
		('2950', 'Platte, unterirdisch, mit Stehniet', ''),
		('2951', 'Platte unterirdisch mit Kopfbolzen', ''),
		('2960', 'Platte, unterirdisch, mit Schutzrohr', ''),
		('2970', 'Pfeiler 30x30x90 cm, mit Stehniete', ''),
		('2980', 'Platte, mit Bolzen, unterirdisch, im Schacht', ''),
		('3000', 'Unterirdische Festlegung (des RfL)', ''),
		('3010', 'Unterirdische Festlegung Sonderform', ''),
		('3020', 'Unterirdischer Rammpfahl', ''),
		('3030', 'Unterirdischer Pfeilerbolzen', ''),
		('3040', 'Unterirdischer Bolzen', ''),
		('3050', 'Hamburger Flachpunkt', ''),
		('3060', 'Unterirdische Säule', ''),
		('3070', 'Unterirdischer Rammstab', ''),
		('3100', 'Rohrfestpunkt', ''),
		('3110', 'Rohrfestpunkt, Hamburger Bauart', ''),
		('3120', 'Rohrfestpunkt, Oldenburger Bauart', ''),
		('3130', 'Rohrfestpunkt, Eider Bauart', ''),
		('3140', 'Rohrfestpunkt Nordrhein-Westfalen', ''),
		('3150', 'Rohrfestpunkt Nebenpunkt, flach gegründet', ''),
		('3160', 'Rohrfestpunkt, Celler Bauart', ''),
		('3170', 'Unterirdische Festlegung im Boden', ''),
		('3180', 'Unterirdische Festlegung im Schacht', ''),
		('3190', 'kleine unterirdische Festlegung', ''),
		('3200', 'Mauerbolzen', ''),
		('3210', 'Mauerbolzen, horizontal eingebracht (mit Inschrift)', ''),
		('3220', 'Mauerbolzen, vertikal eingebracht (mit Inschrift)', ''),
		('3230', 'Höhenmarke (des RfL)', ''),
		('3240', 'Kugelbolzen', ''),
		('3250', 'Tonnenbolzen', ''),
		('3260', 'Landeshöhenbolzen', ''),
		('3270', 'Stehbolzen bzw. Bolzen vertikal', ''),
		('3280', 'Stehniete', ''),
		('3290', 'sonstiger horizontaler Bolzen', ''),
		('3300', 'Pfeilerbolzen', ''),
		('3301', 'Pfeilerbolzen, Bezugspunkt Pfeileroberfläche', ''),
		('3310', 'Pfeilerbolzen, Naturstein, Bolzen horizontal', ''),
		('3311', 'Pfeilerbolzen, Naturstein, Bolzen horizontal, Bezugspunkt Pfeileroberfläche', ''),
		('3320', 'Pfeilerbolzen, Naturstein, Bolzen vertikal', ''),
		('3330', 'Pfeilerbolzen, Beton, Bolzen, horizontal', ''),
		('3331', 'Pfeilerbolzen, Beton, Bolzen horizontal, Bezugspunkt Pfeileroberfläche', ''),
		('3340', 'Pfeilerbolzen, Beton, Bolzen vertikal', ''),
		('3350', 'Pfeilerniete, Naturstein, Niete vertikal', ''),
		('3400', 'Rammpfahl', ''),
		('3410', 'Rammpfahl, Bolzen horizontal', ''),
		('3420', 'Rammpfahl, Bolzen vertikal', ''),
		('3810', 'Schraubpfahl', ''),
		('3820', 'Hektometerstein', ''),
		('3830', 'Markstein', ''),
		('3840', 'Schraubbolzen', ''),
		('3845', 'Schraubeisen', ''),
		('3850', 'Lochmarke/-bolzen (ohne Höhentafel)', ''),
		('3860', 'Lochmarke/-bolzen mit Höhentafel', ''),
		('3870', 'Festpunktstein', ''),
		('3880', 'Eichpfahl', ''),
		('4100', 'Gravimeterplatte 80 x 80 oder 60 x 60 cm', ''),
		('4110', 'Gravimeternagel', ''),
		('4120', 'Gravimeterpfeiler 20 x 20 x 100 cm', ''),
		('4130', 'Gravimeterpfeiler 16 x 16 x 60 cm', ''),
		('4140', 'Messingscheibe mit zentrischer Wölbung (Durchm. 8 cm)', ''),
		('4150', 'Stehniete, Messing (Durchmesser 3 cm, Aufschrift SFP)', ''),
		('4160', 'Messplakette, Aufschrift', ''),
		('5100', 'Gewindebolzen (höchste Stelle, Mitte) auf Metallplatte (Betonpfeiler mit Fundament im festen Erdboden)', ''),
		('5150', 'Oberfläche der Metallplatte (höchste Stelle, Mitte) (Betonpfeiler mit Fundament im festen Erdboden)', ''),
		('5200', 'Gewindebolzen (höchste Stelle, Mitte) auf Metallplatte (Gemauerter Pfeiler auf einem Bauwerk)', ''),
		('5250', 'Oberfläche der Metallplatte (höchste Stelle, Mitte) (Gemauerter Pfeiler auf einem Bauwerk)', ''),
		('5300', 'Gewindebolzen (höchste Stelle, Mitte) auf Metallplatte (Stahlpfeiler auf einem Bauwerk)', ''),
		('5350', 'Oberfläche der Metallplatte (höchste Stelle, Mitte) (Stahlpfeiler auf einem Bauwerk)', ''),
		('5400', 'Gewindebolzen (höchste Stelle, Mitte) auf Metallplatte (Seitlich befestigtes Stahlrohr am Bauwerk)', ''),
		('5450', 'Oberfläche der Metallplatte (höchste Stelle, Mitte) (Seitlich befestigtes Stahlrohr am Bauwerk)', ''),
		('5500', 'Gewindebolzen (höchste Stelle, Mitte) auf Metallplatte (Antennenträger)', ''),
		('5550', 'Oberfläche der Metallplatte (höchste Stelle, Mitte) (Antennenträger)', ''),
		('5900', 'GNSS-Antennenhalterung, Oberfläche Platte (Loch) (SL)', ''),
		('9000', 'Marke unter Bemerkung näher definiert', ''),
		('9500', 'Ohne Marke', ''),
		('9600', 'Abmarkung zeitweilig ausgesetzt', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_genauigkeitsstufe_punktort (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_genauigkeitsstufe_punktort IS 'Alias: "AX_Genauigkeitsstufe_Punktort", UML-Typ: Enumeration';
		INSERT INTO ax_genauigkeitsstufe_punktort (wert,beschreibung,dokumentation) VALUES
		('0900', 'Standardabweichung S kleiner 1 mm', ''),
		('1000', 'Standardabweichung S kleiner gleich 2 mm', ''),
		('1100', 'Standardabweichung S kleiner gleich 5 mm', ''),
		('1200', 'Standardabweichung S kleiner gleich 1 cm', ''),
		('1300', 'Standardabweichung S kleiner gleich 1,5 cm', ''),
		('2000', 'Standardabweichung S kleiner gleich 2 cm', ''),
		('2050', 'Standardabweichung S kleiner gleich 2,5 cm', ''),
		('2100', 'Standardabweichung S kleiner gleich 3 cm', ''),
		('2200', 'Standardabweichung S kleiner gleich 6 cm', ''),
		('2300', 'Standardabweichung S kleiner gleich 10 cm', ''),
		('3000', 'Standardabweichung S kleiner gleich 30 cm', ''),
		('3100', 'Standardabweichung S kleiner gleich 60 cm', ''),
		('3200', 'Standardabweichung S kleiner gleich 100 cm', ''),
		('3300', 'Standardabweichung S kleiner gleich 500 cm', ''),
		('5000', 'Standardabweichung S groesser 500 cm', '');
		CREATE TABLE ax_messmethode_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_messmethode_schwere IS 'Alias: "AX_Messmethode_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_messmethode_schwere (wert,beschreibung,dokumentation) VALUES
		('1000', 'Aus Absolutgravimetermessung ermittelt', ''),
		('2000', 'Aus Relativgravimetermessung ermittelt', '');
		CREATE TABLE ax_koordinatenstatus_punktort (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_koordinatenstatus_punktort IS 'Alias: "AX_Koordinatenstatus_Punktort", UML-Typ: Enumeration';
		INSERT INTO ax_koordinatenstatus_punktort (wert,beschreibung,dokumentation) VALUES
		('1000', 'Amtliche Koordinaten bzw. amtliche Höhe', 'Gültiger Wert in einem amtlichen Bezugssystem'),
		('2000', 'Weitere gültige Koordinaten bzw. weitere gültige Höhe', 'Nicht in einem amtlichen Bezugssystem'),
		('3000', 'Vorläufige Koordinaten bzw. vorläufige Höhe', ''),
		('4000', 'Zu keiner Zeit gültig gewesene Koordinaten bzw. Höhe', ''),
		('5000', 'Historische (nicht mehr gültige)  Koordinaten bzw. Höhe', ''),
		('5100', 'Koordinaten bzw. Höhe, die sich als fehlerhaft herausgestellt haben', '');
		CREATE TABLE ax_datenerhebung_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_datenerhebung_schwere IS 'Alias: "AX_Datenerhebung_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_datenerhebung_schwere (wert,beschreibung,dokumentation) VALUES
		('1000', 'Schwerewert direkt gemessen oder mittels Freiluftreduktion über geringe Entfernung abgeleitet (Höhenunterschied bis 1 m, Horizontalabstand bis 5 m)', ''),
		('2000', 'Schwerewert mittels Freiluftreduktion über größere Entfernung abgeleitet', ''),
		('3000', 'Schwerewert mittels Interpolation unter Verwendung einfacher Bougueranomalien ermittelt', ''),
		('3100', 'Schwerewert im System DHSN 96 durch Abschlag ( -19 10-8 m s-2 ) aus Schwerewert im System DHSN 82 ermittelt (alte Bundesländer)', ''),
		('3200', 'Schwerewert DHSN 96 durch Transformation aus System 71 ermittelt (neue Bundesländer)', ''),
		('4000', 'Schwerewert durch andere Methode ermittelt', ''),
		('9998', 'Methode der Datenerhebung Schwere unbekannt', '');
		CREATE TABLE ax_vertrauenswuerdigkeit_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_vertrauenswuerdigkeit_schwere IS 'Alias: "AX_Vertrauenswuerdigkeit_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_vertrauenswuerdigkeit_schwere (wert,beschreibung,dokumentation) VALUES
		('1100', 'Vertrauenswürdigkeitsstufe Ausgleichung', 'Die Identität der Anschlusspunkte ist überprüft. Die Zuverlässigkeitskriterien sind durch Ausgleichung und durch mathematisch-statistiche Testverfahren festgestellt.'),
		('1300', 'Vertrauenswürdigkeitsstufe ohne Ausgleichung kontrolliert', 'Die Zuverlässigkeitskriterien sind auf andere Weise (z.B. durch Vergleich von Schwereanomalien) festgestellt.'),
		('1400', 'Vertrauenswürdigkeitsstufe unkontrolliert', 'Der Schwerewert ist nicht unabhängig überprüft.');
		CREATE TABLE ax_schwereanomalie_schwere_art (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_schwereanomalie_schwere_art IS 'Alias: "AX_Schwereanomalie_Schwere_Art", UML-Typ: Enumeration';
		INSERT INTO ax_schwereanomalie_schwere_art (wert,beschreibung,dokumentation) VALUES
		('1000', 'Geländereduktion (Reliefkorrektion)', ''),
		('2000', 'Freiluftanomalie im System Potsdam 1909 - Normalschwere nach Helmert 1901 - Breite auf dem Krassowski-Ellipsoid', ''),
		('3000', 'Freiluftanomalie im System Potsdam 1909 mit Geländereduktion (Fayeanomalie) - Normalschwere nach Helmert 1901 - Breite auf dem Krassowski-Ellipsoid', ''),
		('3100', 'Freiluftanomalie nach Molodenski: Schwere (im System DHSN 96) im Oberflächenpunkt minus Normalschwere (Formel des GRS 80) im Telluroidpunkt', ''),
		('4000', 'Bougueranomalie im System Potsdam 1909 mit Geländereduktion - Normalschwere nach Helmert 1901 - Breite auf dem Krassowski-Ellipsoid', ''),
		('5000', 'Bougueranomalie im System DHSN 82 mit Freiluft- und Plattenreduktion - Normalschwere im GRS 80', ''),
		('6000', 'Bougueranomalie im System DHSN 96 mit Freiluft- und Plattenreduktion - Normalschwere im GRS 80', ''),
		('9998', 'Art der Anomalie bzw. Reduktion unbekannt', '');
		CREATE TABLE ax_vertrauenswuerdigkeit_punktort (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_vertrauenswuerdigkeit_punktort IS 'Alias: "AX_Vertrauenswuerdigkeit_Punktort", UML-Typ: Enumeration';
		INSERT INTO ax_vertrauenswuerdigkeit_punktort (wert,beschreibung,dokumentation) VALUES
		('1100', 'Vertrauenswürdigkeitsstufe Ausgleichung', 'Vertrauenswürdigkeitsstufe Ausgleichung: Die Vertrauenswürdigkeit ist durch Ausgleichung und durch mathematisch-statistische Testverfahren festgestellt. Bei den örtlichen Ver-messungen sind die Anschlusspunkte auf Identität überprüft.'),
		('1200', 'Vertrauenswürdigkeitsstufe Berechnung', 'Vertrauenswürdigkeitsstufe Berechnung: Die Vertrauenswür-digkeit ist durch Berechnung überprüft. Bei den örtlichen Vermessungen sind die Anschlusspunkte auf Identität überprüft. Die Zuverlässigkeit ist durch Programm festgestellt bzw. ergibt sich durch die rechnerisch wirksam kontrollierte Ermittlung der Position (Doppelbestimmung).'),
		('1300', 'Vertrauenswürdigkeitsstufe Bestimmungsverfahren', 'Vertrauenswürdigkeitsstufe Bestimmungsverfahren: Die Vertrauenswürdigkeit ist durch die Art der Bestimmung der Posi-tion überprüft. Bei den örtlichen Vermessungen sind die Anschlusspunkte auf Identität überprüft. Die Position ist durch wirksame Kontrollen überprüft.'),
		('1400', 'Vertrauenswürdigkeitsstufe ohne Kontrollen', 'Vertrauenswürdigkeitsstufe ohne Kontrollen: Die Berechnung ist nicht überprüft.');
		CREATE TABLE ax_schwerestatus_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_schwerestatus_schwere IS 'Alias: "AX_Schwerestatus_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_schwerestatus_schwere (wert,beschreibung,dokumentation) VALUES
		('1000', 'amtlicher Schwerewert (gültiger Wert im amtlichen Schweresystem)', ''),
		('2000', 'weiterer gültiger Schwerewert (nicht im amtlichen Schweresystem)', ''),
		('3000', 'vorläufiger Schwerewert', ''),
		('4000', 'zu keiner Zeit gültig gewesener Schwerewert', ''),
		('5000', 'historischer (nicht mehr gültiger) Schwerewert', ''),
		('5100', 'Schwerewert, der sich als fehlerhaft herausgestellt hat', '');
		CREATE TABLE ax_li_processstep_punktort_description (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_li_processstep_punktort_description IS 'Alias: "AX_LI_ProcessStep_Punktort_Description", UML-Typ: Enumeration';
		INSERT INTO ax_li_processstep_punktort_description (wert,beschreibung,dokumentation) VALUES
		('Erhebung', NULL, 'Erhebung beschreibt den Erfassungszeitpunkt "dateTime", aus dem z.B. das Messjahr für Position, Lage oder Höhe der AFIS-Standardausgabe abgeleitet wird.'),
		('Berechnung', NULL, 'Berechnung beschreibt den Auswertezeitpunkt "dateTime", z.B. von Position, Lage oder Höhe der AFIS-Punkte.');
		CREATE TABLE ax_genauigkeitsstufe_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_genauigkeitsstufe_schwere IS 'Alias: "AX_Genauigkeitsstufe_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_genauigkeitsstufe_schwere (wert,beschreibung,dokumentation) VALUES
		('1000', 'Standardabweichung S kleiner 20 10-8m s-2', ''),
		('2000', 'Standardabweichung S kleiner gleich 100 10-8m s-2', ''),
		('3000', 'Standardabweichung S groesser 100 10-8m s-2', ''),
		('4000', 'Als Schwereanschlusspunkt ungeeignet', '');
		CREATE TABLE ax_datenerhebung_punktort (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_datenerhebung_punktort IS 'Alias: "AX_Datenerhebung_Punktort", UML-Typ: Enumeration';
		INSERT INTO ax_datenerhebung_punktort (wert,beschreibung,dokumentation) VALUES
		('0100', 'Aus GNSS-Messung', ''),
		('0110', 'Aus langzeitstatischer GNSS-Messung', ''),
		('0120', 'Aus statischer GNSS-Messung', ''),
		('0130', 'Aus Echtzeit-GNSS-Messung', ''),
		('0200', 'Aus trigonometrischer Messung im TP-Netz', ''),
		('0210', 'Aus lokaler trigonometrischer Messung (innerhalb einer Punktgruppe)', ''),
		('0220', 'Aus netzweiser terrestrischer Messung', ''),
		('1000', 'Aus Katastervermessung ermittelt', ''),
		('1010', 'Aus Katastervermessung mit höchster Lagegenauigkeit (NW)', ''),
		('1020', 'Aus Katastervermessung mit hoher Lagegenauigkeit (NW)', ''),
		('1030', 'Aus Katastervermessung mit mittlerer Lagegenauigkeit (NW)', ''),
		('1040', 'Aus Katastervermessung mit unzureichender Lagegenauigkeit (NW)', ''),
		('1060', 'Aus Vermessung mit höchster Positionsgenauigkeit', ''),
		('1070', 'Aus Vermessung mit mittlerer Positionsgenauigkeit', ''),
		('1080', 'Aus Vermessung mit unterer Positionsgenauigkeit', ''),
		('1100', 'Aufgrund Anforderungen mit Netzanschluss ermittelt', ''),
		('1200', 'Aufgrund Anforderungen mit Bezug zur Flurstücksgrenze ermittelt', ''),
		('1300', 'Aufgrund Anforderungen des LiegVermErlasses ermittelt (NI)', ''),
		('1400', 'Aufgrund Anforderungen des Fortführungerlasses II ermittelt (NI)', ''),
		('1500', 'Aufgrund Anforderungen älterer Vorschriften ermittelt', ''),
		('1600', 'Auf einheitlichem und eindeutigem Raumbezug basierend (E-Koord.) (BW)', ''),
		('1610', 'Auf bislang einheitlichem Raumbezug basierend ermittelt (B-Koord.) (BW)', ''),
		('1620', 'Auf früher gültigem Raumbezug basierend ermittelt(T-Koord.) (BW)', ''),
		('1630', 'Aufgrund Anforderungen des AP-Erlasses (M-V)', ''),
		('1640', 'Aufgrund Anforderungen der LiVermA M-V, basierend auf AP-Feld', ''),
		('1650', 'Aufgrund Anforderungen der LiVermA M-V', ''),
		('1700', 'Aufgrund Anforderungen des LiegVermErlasses LSA (LSA)', ''),
		('1710', 'Aufgrund Anforderungen der Anleitung für die Ausführung von Neuvermessungen, 1953, DDR (LSA)', ''),
		('1720', 'Aufgrund Anforderungen der Liegenschaftsvermessungsordnung 112/82, DDR (LSA)', ''),
		('1800', 'Aus Koordinatentransformation ermittelt', ''),
		('1900', 'Aus sonstiger Vermessung ermittelt', ''),
		('2000', 'Aus Luftbildmessung oder Fernerkundungsdaten ermittelt', ''),
		('3000', 'Aus Netzvermessung ermittelt', ''),
		('3100', 'Aufgrund Anforderungen des Festpunktfelderlasses ermittelt (NI, ST)', ''),
		('3200', 'Aufgrund Anforderungen des Polygonpunktfelderlasses ermittelt (NI)', ''),
		('3300', 'Aus Polygonierungsmessung', ''),
		('4000', 'Aus Katasterunterlagen und Karten für graphische Zwecke ermittelt', ''),
		('4100', 'Aus Katasterzahlen für graphische Zwecke ermittelt', ''),
		('4200', 'Aus Katasterkarten digitalisiert', ''),
		('4210', 'Aus Katasterkarten digitalisiert, Kartenmaßstab M größer gleich 1 zu 1000', ''),
		('4220', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 1000 größer M größer gleich 1 zu 2000', ''),
		('4230', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 2000 größer M größer gleich 1 zu 3000', ''),
		('4240', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 3000 größer M größer gleich 1 zu 5000', ''),
		('4250', 'Aus Katasterkarten digitalisiert, Kartenmaßstab 1 zu 5000 größer M', ''),
		('4260', 'Mit  sonstigen geometrischen Bedingungen und/oder Homogenisierung (M größer gleich 1 zu 1000)', ''),
		('4270', 'Mit Berechnung  oder Abstandsbedingung (M größer gleich 1 zu 1000)', ''),
		('4280', 'Mit sonstigen geometrischen  Bedingungen und/oder Homogenisierung (M kleiner 1 zu 1000)', ''),
		('4290', 'Mit  Berechnung oder Abstandsbedingungen (M kleiner 1 zu 1000)', ''),
		('4300', 'Aus sonstigen Unterlagen digitalisiert', ''),
		('4310', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab M größer gleich 1 zu 1000', ''),
		('4320', 'Aus  sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 1000 größer M größer gleich 1 zu 2000', ''),
		('4330', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 2000 größer M größer gleich 1 zu 3000', ''),
		('4340', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 3000 größer M größer gleich 1 zu 5000', ''),
		('4350', 'Aus sonstigen Unterlagen digitalisiert, Kartenmaßstab 1 zu 5000 größer M', ''),
		('4360', 'Aus sonstigen Unterlagen digitalisiert, mit sonstigen geometrischen Bedingungen und/oder Homogenisierung (M größer gleich 1 zu 1000)', ''),
		('4370', 'Aus sonstigen Unterlagen digitalisiert, Mit Berechnung oder Abstandsbedingung (M größer gleich 1 zu 1000)', ''),
		('4380', 'Aus sonstigen Unterlagen digitalisiert, Mit sonstigen geometrischen Bedingungen und/oder Homogenisierung (M kleiner 1 zu 1000)', ''),
		('4390', 'Aus sonstigen Unterlagen digitalisiert, Mit Berechnung oder Abstandsbedingungen (M kleiner 1 zu 1000)', ''),
		('5000', 'Aus Nivellement', ''),
		('5010', 'Aus geometrischem Nivellement', ''),
		('5020', 'Aus trigonometrischer Höhenübertragung', ''),
		('5030', 'Aus trigonometrischer Präzisionshöhenübertragung', ''),
		('5100', 'Aus Präzisionsnivellement', ''),
		('5110', 'Aus Höhenangaben nivellitisch bestimmt, Messgenauigkeit 1.Ordnung', ''),
		('5120', 'Aus  Höhenangaben nivellitisch bestimmt, Messgenauigkeit 2.Ordnung', ''),
		('5130', 'Aus Höhenangaben  nivellitisch bestimmt, Messgenauigkeit 3.Ordnung', ''),
		('5140', 'Aus Höhenangaben nivellitisch bestimmt, Messgenauigkeit 4.Ordnung', ''),
		('5150', 'Aus geometrischem Präzisionsnivellement, Messgenauigkeit  1. Ordnung', ''),
		('5160', 'Aus geometrischem Präzisionsnivellement, Messgenauigkeit  2. Ordnung', ''),
		('5170', 'Aus geometrischem Präzisionsnivellement, Messgenauigkeit  3. Ordnung', ''),
		('5200', 'Aus Präzisionsnivellement (nur eine Messungsrichtung)', ''),
		('5500', 'Höhe aus Laserscannermessung', ''),
		('6000', 'Aus satellitengeodätischer Messung  und Addition einer Undulation', ''),
		('6100', 'Mittels Quasigeoidundulation abgeleitet von gemessener ellipsoidischer Höhe', ''),
		('6200', 'Mittels Quasigeoidundulation abgeleitet von gemessener Normalhöhe', ''),
		('7000', 'Aus trigonometrischer Messung', ''),
		('8000', 'Aus analoger Unterlage abgeleitet', ''),
		('8100', 'Aus näherungsweiser Berechnung oder Transformation', ''),
		('8200', 'Aus Stereo-Auswertung von Luftbildern', ''),
		('8300', 'Graphisch bestimmt', ''),
		('8310', 'Aus der Topographischen Karte 1 zu 10 000 abgegriffen', ''),
		('8320', 'Aus der Topographischen Karte 1 zu 25 000 abgegriffen', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', '');
		CREATE TABLE ax_schweresystem_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_schweresystem_schwere IS 'Alias: "AX_Schweresystem_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_schweresystem_schwere (wert,beschreibung,dokumentation) VALUES
		('1000', 'Schwerewert im System des DHSN 82 (System der Landesvermessung)', ''),
		('1100', 'Schwerewert im System des DSGN 62 (auch als DSN 62 bezeichnet)', ''),
		('1200', 'Schwerewert im System des SGN der DDR (auch als System 71 bezeichnet)', ''),
		('1300', 'Schwerewert im System des DHSN 96 (System der Landesvermessung)', ''),
		('4000', 'Schwerewert im System des ISGN 71 (wissenschaftliches System)', ''),
		('4010', 'Schwerewert im System des DSGN 76 (wissenschaftliches System)', ''),
		('4020', 'Schwerewert im System des DSGN 94 (wissenschaftliches System)', ''),
		('6000', 'Potsdamer Schweresystem 1909', ''),
		('6100', 'Schweresystem der Geophysikalischen Reichsaufnahme 1934 - 1943', '');
		CREATE TABLE ax_blattart_historischesflurstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_blattart_historischesflurstueck IS 'Alias: "AX_Blattart_HistorischesFlurstueck", UML-Typ: Enumeration';
		INSERT INTO ax_blattart_historischesflurstueck (wert,beschreibung,dokumentation) VALUES
		('1000', 'Grundbuchblatt', ''),
		('2000', 'Katasterblatt', '');
		CREATE TABLE ax_qualitaet_hauskoordinate (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_qualitaet_hauskoordinate IS 'Alias: "AX_Qualitaet_Hauskoordinate", UML-Typ: Enumeration';
		INSERT INTO ax_qualitaet_hauskoordinate (wert,beschreibung,dokumentation) VALUES
		('1000', 'gebaeudeumring (A)', ''),
		('2000', 'innerhalbFlurstueck (B)', ''),
		('3000', 'interpoliert (C)', '');
		CREATE TABLE ax_art_punktkennung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_punktkennung IS 'Alias: "AX_Art_Punktkennung", UML-Typ: Enumeration';
		INSERT INTO ax_art_punktkennung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Punktkennung - allgemein', ''),
		('1100', 'Punktkennung - Grenzpunkt', ''),
		('1200', 'Punktkennung - Besonderer Gebäudepunkt', ''),
		('1300', 'Punktkennung - Besonderer topographischer Punkt', ''),
		('1400', 'Punktkennung - Aufnahmepunkt', ''),
		('1500', 'Punktkennung - Sicherungspunkt', ''),
		('1600', 'Punktkennung - Sonstiger Vermessungspunkt', ''),
		('1700', 'Punktkennung - Besonderer Bauwerkspunkt', '');
		CREATE TABLE ax_art_reservierung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_reservierung IS 'Alias: "AX_Art_Reservierung", UML-Typ: Enumeration';
		INSERT INTO ax_art_reservierung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Punktkennung', ''),
		('1300', 'Punktkennung - Grenzpunkt', ''),
		('1400', 'Punktkennung - Besonderer Gebäudepunkt', ''),
		('1500', 'Punktkennung - Besonderer topographischer Punkt', ''),
		('1600', 'Punktkennung - Besonderer Bauwerkspunkt', ''),
		('1700', 'Punktkennung - Aufnahmepunkt', ''),
		('1800', 'Punktkennung - Sicherungspunkt', ''),
		('1900', 'Punktkennung - Sonstiger Vermessungspunkt', ''),
		('2000', 'Punktkennung - Lagefestpunkt', ''),
		('2100', 'Punktkennung - Höhenfestpunkt', ''),
		('2200', 'Punktkennung - Schwerefestpunkt', ''),
		('2300', 'Punktkennung - Referenzstationspunkt', ''),
		('3000', 'Flurstückskennzeichen', 'Eine Reservierung von Folgenummern zu einer Nummer darf sich nur auf aktuelle Flustücke 11001 beziehen und nicht auf dauerhaft reservierte ausfallende Nummern, die keine aktuellen Flustücke haben.'),
		('4000', 'FN-Nummer', ''),
		('5000', 'Abmarkungsprotokollnummer', ''),
		('6000', 'Buchungsblattkennzeichen', ''),
		('6100', 'Katasterblatt', ''),
		('6200', 'Pseudoblatt', ''),
		('6300', 'Erwerberblatt', ''),
		('6400', 'Fiktives Blatt', '');
		CREATE TABLE ax_art_adressat_auszug (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_adressat_auszug IS 'Alias: "AX_Art_Adressat_Auszug", UML-Typ: Enumeration';
		INSERT INTO ax_art_adressat_auszug (wert,beschreibung,dokumentation) VALUES
		('1000', 'Privat', ''),
		('2000', 'Notar', ''),
		('3000', 'Grundbuchamt', ''),
		('4000', 'Finanzamt', ''),
		('5000', 'Bauaufsichtsbehörde', ''),
		('6000', 'Weitere Beteiligte', '');
		CREATE TABLE ax_lagezurerdoberflaeche_bauteil (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagezurerdoberflaeche_bauteil IS 'Alias: "AX_LageZurErdoberflaeche_Bauteil", UML-Typ: Enumeration';
		INSERT INTO ax_lagezurerdoberflaeche_bauteil (wert,beschreibung,dokumentation) VALUES
		('1200', 'Unter der Erdoberfläche', 'Unter der Erdoberfläche bedeutet, dass sich das Bauteil unter der Erdoberfläche befindet. Diese Wertart darf nur mit den Bauarten Keller und Tiefgarage vorkommen.'),
		('1400', 'Aufgeständert', 'Aufgeständert bedeutet, dass ein Bauteil auf Stützen steht.');
		CREATE TABLE ax_lagezurerdoberflaeche_gebaeude (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagezurerdoberflaeche_gebaeude IS 'Alias: "AX_LageZurErdoberflaeche_Gebaeude", UML-Typ: Enumeration';
		INSERT INTO ax_lagezurerdoberflaeche_gebaeude (wert,beschreibung,dokumentation) VALUES
		('1200', 'Unter der Erdoberfläche', 'Unter der Erdoberfläche bedeutet, dass sich das Gebäude unter der Erdoberfläche befindet.'),
		('1400', 'Aufgeständert', 'Aufgeständert bedeutet, dass ein Gebäude auf Stützen steht.');
		CREATE TABLE ax_zustand_gebaeude (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_gebaeude IS 'Alias: "AX_Zustand_Gebaeude", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_gebaeude (wert,beschreibung,dokumentation) VALUES
		('1000', 'In behelfsmäßigem Zustand', ''),
		('2000', 'In ungenutztem Zustand', ''),
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass das Gebäude auf Dauer nicht mehr bewohnt oder genutzt wird.'),
		('2200', 'Verfallen, zerstört', 'Verfallen, zerstört bedeutet, dass sich der ursprüngliche Zustand des Gebäudes durch menschliche oder zeitliche Einwirkungen so verändert hat, dass eine Nutzung nicht mehr möglich ist.'),
		('2300', 'Teilweise zerstört', ''),
		('3000', 'Geplant und beantragt', ''),
		('4000', 'Im Bau', '');
		CREATE TABLE ax_dachgeschossausbau_gebaeude (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dachgeschossausbau_gebaeude IS 'Alias: "AX_Dachgeschossausbau_Gebaeude", UML-Typ: Enumeration';
		INSERT INTO ax_dachgeschossausbau_gebaeude (wert,beschreibung,dokumentation) VALUES
		('1000', 'Nicht ausbaufähig', ''),
		('2000', 'Ausbaufähig', ''),
		('3000', 'Ausgebaut', ''),
		('4000', 'Ausbaufähigkeit unklar', '');
		CREATE TABLE ax_dachform (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dachform IS 'Alias: "AX_Dachform", UML-Typ: Enumeration';
		INSERT INTO ax_dachform (wert,beschreibung,dokumentation) VALUES
		('1000', 'Flachdach', ''),
		('2100', 'Pultdach', ''),
		('2200', 'Versetztes Pultdach', ''),
		('3100', 'Satteldach', ''),
		('3200', 'Walmdach', ''),
		('3300', 'Krüppelwalmdach', ''),
		('3400', 'Mansardendach', ''),
		('3500', 'Zeltdach', ''),
		('3600', 'Kegeldach', ''),
		('3700', 'Kuppeldach', ''),
		('3800', 'Sheddach', ''),
		('3900', 'Bogendach', ''),
		('4000', 'Turmdach', ''),
		('5000', 'Mischform', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_bauweise_gebaeude (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauweise_gebaeude IS 'Alias: "AX_Bauweise_Gebaeude", UML-Typ: Enumeration';
		INSERT INTO ax_bauweise_gebaeude (wert,beschreibung,dokumentation) VALUES
		('1100', 'Freistehendes Einzelgebäude', ''),
		('1200', 'Freistehender Gebäudeblock', ''),
		('1300', 'Einzelgarage', ''),
		('1400', 'Doppelgarage', ''),
		('1500', 'Sammelgarage', ''),
		('2100', 'Doppelhaushälfte', ''),
		('2200', 'Reihenhaus', ''),
		('2300', 'Haus in Reihe', ''),
		('2400', 'Gruppenhaus', ''),
		('2500', 'Gebäudeblock in geschlossener Bauweise', ''),
		('4000', 'Offene Halle', 'Unter einer "Offenen Halle" ist eine Halle zu verstehen, bei der alle vier Seiten offen sind.
Hallen, bei denen eine, zwei oder drei Seiten geschlossen sind, werden nur mit der entsprechenden Gebäudefunktion ohne Belegung der Bauweise erfasst. Die offenen Gebäudeseiten sind mit "Besondere Gebäudelinie" Beschaffenheit "Offene Gebäudelinie" zu belegen'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_gebaeudefunktion (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_gebaeudefunktion IS 'Alias: "AX_Gebaeudefunktion", UML-Typ: Enumeration';
		INSERT INTO ax_gebaeudefunktion (wert,beschreibung,dokumentation) VALUES
		('1000', 'Wohngebäude', 'Wohngebäude ist ein Gebäude, das zum Wohnen genutzt wird.'),
		('1010', 'Wohnhaus', 'Wohnhaus ist ein Gebäude, in dem Menschen ihren Wohnsitz haben.'),
		('1020', 'Wohnheim', 'Wohnheim ist ein Gebäude, das nach seiner baulichen Anlage und Ausstattung zur Unterbringung von Studenten, Arbeitern u.a. bestimmt ist.'),
		('1021', 'Kinderheim', ''),
		('1022', 'Seniorenheim', ''),
		('1023', 'Schwesternwohnheim', ''),
		('1024', 'Studenten-, Schülerwohnheim', ''),
		('1025', 'Schullandheim', 'Schullandheim ist ein Gebäude in ländlicher Region, in dem sich Schulklassen jeweils für einige Tage zur Erholung und zum Unterricht aufhalten.'),
		('1100', 'Gemischt genutztes Gebäude mit Wohnen', 'Gemischt genutztes Gebäude mit Wohnen ist ein Gebäude, in dem sowohl gewohnt wird, als auch Teile des Gebäude zum Anbieten von Dienstleistungen, zur Durchführung von öffentlichen oder privaten Verwaltungsarbeiten, zur gewerblichen oder industriellen Tätigkeit genutzt werden.'),
		('1110', 'Wohngebäude mit Gemeinbedarf', ''),
		('1120', 'Wohngebäude mit Handel und Dienstleistungen', ''),
		('1121', 'Wohn- und Verwaltungsgebäude', ''),
		('1122', 'Wohn- und Bürogebäude', ''),
		('1123', 'Wohn- und Geschäftsgebäude', 'Wohn- und Geschäftsgebäude ist ein Gebäude, in dem gewohnt wird und in dem sich ein oder mehrere Geschäfte befinden, in denen Waren zum Verkauf angeboten werden.'),
		('1130', 'Wohngebäude mit Gewerbe und Industrie', ''),
		('1131', 'Wohn- und Betriebsgebäude', ''),
		('1210', 'Land- und forstwirtschaftliches Wohngebäude', ''),
		('1220', 'Land- und forstwirtschaftliches Wohn- und Betriebsgebäude', ''),
		('1221', 'Bauernhaus', 'Bauernhaus ist das Wohn- und Betriebsgebäude eines Landwirts.'),
		('1222', 'Wohn- und Wirtschaftsgebäude', ''),
		('1223', 'Forsthaus', 'Forsthaus ist ein Gebäude, das gleichzeitig Wohnhaus und Dienststelle der Försterin oder des Försters ist.'),
		('1310', 'Gebäude zur Freizeitgestaltung', ''),
		('1311', 'Ferienhaus', ''),
		('1312', 'Wochenendhaus', 'Wochenendhaus ist ein Gebäude, in dem dauerhaftes Wohnen möglich, aber nicht gestattet ist. Es dient nur zum zeitlich begrenzten Aufenthalt in der Freizeit, beispielsweise am Wochenende oder im Urlaub und steht i.d.R. in einem besonders dafür ausgewiesenen Gebiet (Wochenendhausgebiet).'),
		('1313', 'Gartenhaus', 'Gartenhaus ist ein eingeschossiges Gebäude in einfacher Ausführung, z.B.ohne Feuerstätte und ohne Toilette. Es dient hauptsächlich dem Unterbringen von Gartengeräten oder dem Überwintern von Pflanzen. Stellt es bei der Nutzung des Gartens eine Ruhe oder Erholungsstätte dar, ist es nur zum vorübergehenden Aufenthalt gedacht, nicht jedoch zum Wohnen oder Übernachten.'),
		('2000', 'Gebäude für Wirtschaft oder Gewerbe', 'Gebäude für Wirtschaft oder Gewerbe ist ein Gebäude, das der Produktion von Waren, der Verteilung von Gütern und dem Angebot von Dienstleistungen dient.'),
		('2010', 'Gebäude für Handel und Dienstleistungen', 'Gebäude für Handel und Dienstleistungen ist ein Gebäude, in dem Arbeitsleistungen, die nicht der Produktion von materiellen Gütern dienen, angeboten werden. Dazu gehört u.a. der Handel (Ankauf, Transport, Verkauf) mit Gütern, Kapital oder Wissen.'),
		('2020', 'Bürogebäude', 'Bürogebäude ist ein Gebäude, in dem private Wirtschaftunternehmen ihre Verwaltungsarbeit durchführen.'),
		('2030', 'Kreditinstitut', 'Kreditinstitut ist ein Gebäude, in dem Unternehmen gewerbsmäßig Geldgeschäfte (Verwaltung von Ersparnissen, Vergabe von Krediten) betreiben, die einen kaufmännisch eingerichteten Geschäftsbetrieb erfordern.'),
		('2040', 'Versicherung', 'Versicherung ist ein Gebäude, in dem Versicherungsunternehmen gewerbsmäßige Versicherungsgeschäfte betreiben.'),
		('2050', 'Geschäftsgebäude', 'Geschäftsgebäude ist ein Gebäude, in dem Ein- und Verkauf von Waren stattfindet.'),
		('2051', 'Kaufhaus', 'Kaufhaus ist ein Gebäude, meist mit mehreren Stockwerken, in dem breite Warensortimente zum Kauf angeboten werden.'),
		('2052', 'Einkaufszentrum', 'Einkaufszentrum ist ein Gebäude oder Gebäudekomplex, in dem mehrere Geschäfte untergebracht sind.'),
		('2053', 'Markthalle', ''),
		('2054', 'Laden', ''),
		('2055', 'Kiosk', 'Kiosk ist ein kleines in meist leichter Bauweise errichtetes Gebäude, das als Verkaufseinrichtung für ein beschränktes Warenangebot dient.'),
		('2056', 'Apotheke', 'Apotheke ist ein Geschäft, in dem Arzneimittel hergestellt und verkauft werden.'),
		('2060', 'Messehalle', 'Messehalle ist ein Gebäude, das zur Ausstellung von Kunstgegenständen oder Wirtschaftsgütern dient.'),
		('2070', 'Gebäude für Beherbergung', ''),
		('2071', 'Hotel, Motel, Pension', 'Hotel, Motel, Pension ist ein Gebäude mit Beherbergungs- und/oder Verpflegungsbetrieb nach Service, Ausstattung und Qualität in verschiedene Kategorien eingeteilt. Das Motel ist besonders eingerichtet für Reisende mit Kraftfahrzeug an verkehrsreichen Straßen.'),
		('2072', 'Jugendherberge', 'Jugendherberge ist eine zur Förderung von Jugendreisen dienende Aufenthalts- und Übernachtungsstätte.'),
		('2073', 'Hütte (mit Übernachtungsmöglichkeit)', 'Hütte (mit Übernachtungsmöglichkeit) ist ein Gebäude außerhalb von Ortschaften, meist in den Bergen, in dem Menschen übernachten und Schutz suchen können.'),
		('2074', 'Campingplatzgebäude', ''),
		('2080', 'Gebäude für Bewirtung', ''),
		('2081', 'Gaststätte, Restaurant', 'Gaststätte, Restaurant ist ein Gebäude, in dem gegen Entgelt Mahlzeiten und Getränke zum Verzehr angeboten werden.'),
		('2082', 'Hütte (ohne Übernachtungsmöglichkeit)', ''),
		('2083', 'Kantine', ''),
		('2090', 'Freizeit- und Vergnügungsstätte', 'Freizeit- und Vergnügungsstätte ist ein Gebäude, in dem man in seiner Freizeit bestimmte Angebote wahrnehmen kann.'),
		('2091', 'Festsaal', ''),
		('2092', 'Kino', ''),
		('2093', 'Kegel-, Bowlinghalle', ''),
		('2094', 'Spielkasino', ''),
		('2100', 'Gebäude für Gewerbe und Industrie', 'Gebäude für Gewerbe und Industrie ist ein Gebäude, dass vorwiegend gewerblichen oder industriellen Zwecken dient.'),
		('2110', 'Produktionsgebäude', 'Produktionsgebäude ist ein Gebäude, das zur Herstellung von Wirtschaftsgütern dient.'),
		('2111', 'Fabrik', 'Fabrik ist ein Gebäude mit technischen Anlagen zur Herstellung von Waren in großen Mengen.'),
		('2112', 'Betriebsgebäude', 'Betriebsgebäude ist ein Gebäude, in dem Arbeitskräfte und Produktionsmittel zusammengefasst sind, um Leistungen zu erbringen oder Güter herzustellen.'),
		('2113', 'Brauerei', ''),
		('2114', 'Brennerei', ''),
		('2120', 'Werkstatt', ''),
		('2121', 'Sägewerk', ''),
		('2130', 'Tankstelle', 'Tankstelle ist ein Gebäude, in dem hauptsächlich Kfz-Kraftstoffe, Schmiermittel und Zubehör verkauft werden, meist mit Einrichtungen zur Durchführung von Wartungs- und Pflegearbeiten von Kraftfahrzeugen.'),
		('2131', 'Waschstraße, Waschanlage, Waschhalle', ''),
		('2140', 'Gebäude für Vorratshaltung', ''),
		('2141', 'Kühlhaus', ''),
		('2142', 'Speichergebäude', ''),
		('2143', 'Lagerhalle, Lagerschuppen, Lagerhaus', 'Lagerhalle, Lagerschuppen, Lagerhaus ist ein Gebäude zur Vorratshaltung von Gütern (z. B. Material, Fertigerzeugnissen).'),
		('2150', 'Speditionsgebäude', 'Speditionsgebäude bezeichnet ein Gebäude mit technischen, organisatorischen und wirtschaftlichen Einrichtungen, die der Beförderung von Gütern über räumliche Entfernungen dienen.'),
		('2160', 'Gebäude für Forschungszwecke', 'Gebäude für Forschungszwecke ist ein Gebäude, in dem Forschung betrieben wird.'),
		('2170', 'Gebäude für Grundstoffgewinnung', ''),
		('2171', 'Bergwerk', ''),
		('2172', 'Saline', 'Saline ist eine Anlage zur Gewinnung von Kochsalz.'),
		('2180', 'Gebäude für betriebliche Sozialeinrichtung', ''),
		('2200', 'Sonstiges Gebäude für Gewerbe und Industrie', ''),
		('2210', 'Mühle', ''),
		('2211', 'Windmühle', 'Windmühle ist ein Gebäude, dessen wesentlicher Bestandteil die an einer Achse befestigten Flächen (Flügel, Schaufeln) sind, die von der Windkraft in Drehung versetzt werden. Sie dient zum Mahlen von Getreide, zum Pumpen von Wasser oder zur Erzeugung von Strom.'),
		('2212', 'Wassermühle', 'Wassermühle ist ein Gebäude mit einem Mühlrad, das von Wasser angetrieben wird.'),
		('2213', 'Schöpfwerk', 'Schöpfwerk ist ein Gebäude, in dem Pumpen Wasser einem höher gelegenen Vorfluter zuführen u. a. zur künstlichen Entwässerung von landwirtschaftlich genutzten Flächen.'),
		('2220', 'Wetterstation', 'Wetterstation ist ein Gebäude, in dem meteorologische Daten erfasst und ausgewertet werden.'),
		('2310', 'Gebäude für Handel und Dienstleistung mit Wohnen', ''),
		('2320', 'Gebäude für Gewerbe und Industrie mit Wohnen', ''),
		('2400', 'Betriebsgebäude zu Verkehrsanlagen (allgemein)', ''),
		('2410', 'Betriebsgebäude für Straßenverkehr', ''),
		('2411', 'Straßenmeisterei', 'Straßenmeisterei ist das Verwaltungsgebäude einer Dienststelle, die für den ordnungsgemäßen Zustand von Straßen verantwortlich ist.'),
		('2412', 'Wartehalle', ''),
		('2420', 'Betriebsgebäude für Schienenverkehr', ''),
		('2421', 'Bahnwärterhaus', ''),
		('2422', 'Lokschuppen, Wagenhalle', ''),
		('2423', 'Stellwerk, Blockstelle', 'Stellwerk, Blockstelle ist ein Gebäude, von dem aus die Signale und Weichen im Bahnhof und auf der freien Strecke für die Züge gestellt werden.'),
		('2424', 'Betriebsgebäude des Güterbahnhofs', ''),
		('2430', 'Betriebsgebäude für Flugverkehr', ''),
		('2431', 'Flugzeughalle', 'Flugzeughalle ist ein Gebäude, in dem Flugzeuge abgestellt, inspiziert und repariert werden.'),
		('2440', 'Betriebsgebäude für Schiffsverkehr', ''),
		('2441', 'Werft (Halle)', ''),
		('2442', 'Dock (Halle)', ''),
		('2443', 'Betriebsgebäude zur Schleuse', ''),
		('2444', 'Bootshaus', ''),
		('2450', 'Betriebsgebäude zur Seilbahn', ''),
		('2451', 'Spannwerk zur Drahtseilbahn', ''),
		('2460', 'Gebäude zum Parken', ''),
		('2461', 'Parkhaus', 'Parkhaus ist ein Gebäude, in dem Fahrzeuge auf mehreren Etagen abgestellt werden.'),
		('2462', 'Parkdeck', ''),
		('2463', 'Garage', 'Garage ist ein Gebäude, in dem Fahrzeuge abgestellt werden.'),
		('2464', 'Fahrzeughalle', 'Fahrzeughalle ist ein Gebäude, in dem Fahrzeuge abgestellt, inspiziert und repariert werden.'),
		('2465', 'Tiefgarage', 'Tiefgarage ist ein Bauwerk unter der Erdoberfläche, in dem Fahrzeuge abgestellt werden'),
		('2500', 'Gebäude zur Versorgung', ''),
		('2501', 'Gebäude zur Energieversorgung', ''),
		('2510', 'Gebäude zur Wasserversorgung', ''),
		('2511', 'Wasserwerk', ''),
		('2512', 'Pumpstation', 'Pumpstation ist ein Gebäude an einem Rohrleitungssystem, in dem eine oder mehrere Pumpen eingebaut sind.'),
		('2513', 'Wasserbehälter', 'Wasserbehälter ist ein Gebäude, in dem Wasser gespeichert wird, das zum Ausgleich der Differenz zwischen Wasserzuführung und -abgabe dient.'),
		('2520', 'Gebäude zur Elektrizitätsversorgung', ''),
		('2521', 'Elektrizitätswerk', ''),
		('2522', 'Umspannwerk', ''),
		('2523', 'Umformer', 'Umformer ist ein kleines Gebäude in dem ein Transformator zum Umformen von Gleichstrom in Wechselstrom oder von Gleichstrom in Gleichstrom anderer Spannung untergebracht ist.'),
		('2527', 'Reaktorgebäude', 'Reaktorgebäude ist ein zentrales Gebäude eines Kernkraftwerkes, in dem aus radioaktivem Material mittels Kernspaltung Wärmeenergie erzeugt wird.'),
		('2528', 'Turbinenhaus', 'Turbinenhaus ist ein Gebäude, in dem eine Kraftmaschine die Energie von strömendem Dampf, Gas, Wasser oder Wind unmittelbar in elektrische Energie umsetzt.'),
		('2529', 'Kesselhaus', ''),
		('2540', 'Gebäude für Fernmeldewesen', ''),
		('2560', 'Gebäude an unterirdischen Leitungen', ''),
		('2570', 'Gebäude zur Gasversorgung', ''),
		('2571', 'Gaswerk', ''),
		('2580', 'Heizwerk', ''),
		('2590', 'Gebäude zur Versorgungsanlage', ''),
		('2591', 'Pumpwerk (nicht für Wasserversorgung)', ''),
		('2600', 'Gebäude zur Entsorgung', ''),
		('2610', 'Gebäude zur Abwasserbeseitigung', ''),
		('2611', 'Gebäude der Kläranlage', ''),
		('2612', 'Toilette', ''),
		('2620', 'Gebäude zur Abfallbehandlung', ''),
		('2621', 'Müllbunker', ''),
		('2622', 'Gebäude zur Müllverbrennung', 'Gebäude zur Müllverbrennung ist ein Gebäude in dem Abfälle mit chemisch/physikalischen und biologischen oder thermischen Verfahren oder Kombination dieser Verfahren behandelt werden.'),
		('2623', 'Gebäude der Abfalldeponie', ''),
		('2700', 'Gebäude für Land- und Forstwirtschaft', 'Gebäude für Land- und Forstwirtschaft ist ein Gebäude, das land- und forstwirtschaftlichen Zwecken dient.'),
		('2720', 'Land- und forstwirtschaftliches Betriebsgebäude', ''),
		('2721', 'Scheune', 'Scheune ist ein Gebäude zur Lagerung landwirtschaftlicher Güter (z. B. Stroh, Heu und Getreide).'),
		('2723', 'Schuppen', ''),
		('2724', 'Stall', 'Stall ist ein Gebäude, in dem Tiere untergebracht sind.'),
		('2726', 'Scheune und Stall', ''),
		('2727', 'Stall für Tiergroßhaltung', ''),
		('2728', 'Reithalle', ''),
		('2729', 'Wirtschaftsgebäude', ''),
		('2732', 'Almhütte', 'Almhütte ist ein einfaches, hoch in den Bergen gelegenes Gebäude, das überwiegend weidewirtschaftlichen Zwecken dient und hauptsächlich im Sommer genutzt wird.'),
		('2735', 'Jagdhaus, Jagdhütte', ''),
		('2740', 'Treibhaus, Gewächshaus', 'Treibhaus, Gewächshaus ist ein Gebäude mit lichtdurchlässigem Dach und Wänden, das durch künstliche Klimagestaltung der Aufzucht oder Produktion von Pflanzen dient.'),
		('2741', 'Treibhaus', 'Treibhaus ist ein Gebäude mit lichtdurchlässigem Dach und Wänden, das durch künstliche Klimagestaltung der Aufzucht oder Produktion von Pflanzen dient.'),
		('2742', 'Gewächshaus, verschiebbar', ''),
		('3000', 'Gebäude für öffentliche Zwecke', 'Gebäude für öffentliche Zwecke ist ein Gebäude das der Allgemeinheit dient.'),
		('3010', 'Verwaltungsgebäude', 'Verwaltungsgebäude ist ein Gebäude, in dem Verwaltungstätigkeiten durchgeführt werden.'),
		('3011', 'Parlament', 'Parlament ist ein Gebäude, in dem die gesetzgebende Volksvertretung (Bundestag, Landtag) tagt.'),
		('3012', 'Rathaus', 'Rathaus ist ein Gebäude, in dem der Vorstand einer Gemeinde seinen Amtssitz hat und/oder Teile der Verwaltung untergebracht sind.'),
		('3013', 'Post', 'Post ist ein Gebäude, in dem die Post Dienstleistungen anbietet.'),
		('3014', 'Zollamt', 'Zollamt ist ein Gebäude für die Zollabfertigung an der Staatsgrenze (Grenzzollamt) oder im Inland (Binnenzollamt).'),
		('3015', 'Gericht', 'Gericht ist ein Gebäude, in dem Rechtsprechung und Rechtspflege stattfinden.'),
		('3016', 'Botschaft, Konsulat', 'Botschaft, Konsulat ist ein Gebäude, in dem eine ständige diplomatische Vertretung ersten Rangs eines fremden Staates oder einer  internationalen Organisation untergebracht ist.'),
		('3017', 'Kreisverwaltung', ''),
		('3018', 'Bezirksregierung', ''),
		('3019', 'Finanzamt', ''),
		('3020', 'Gebäude für Bildung und Forschung', 'Gebäude für Bildung und Forschung ist ein Gebäude, in dem durch Ausbildung Wissen und Können auf verschiedenen Gebieten vermittelt werden bzw. wo neues Wissen durch wissenschaftliche Tätigkeit gewonnen wird.'),
		('3021', 'Allgemein bildende Schule', 'Allgemein bildende Schule ist ein Gebäude, in dem Kindern, Jugendlichen und Erwachsenen durch planmäßigen Unterricht Wissen vermittelt wird.'),
		('3022', 'Berufsbildende Schule', ''),
		('3023', 'Hochschulgebäude (Fachhochschule, Universität)', 'Hochschulgebäude (Fachhochschule, Universität) ist ein Gebäude, in dem Wissenschaften gelehrt und Forschung betrieben wird.'),
		('3024', 'Forschungsinstitut', 'Forschungsinstitut ist ein Gebäude, in dem Forschung betrieben wird.'),
		('3030', 'Gebäude für kulturelle Zwecke', 'Gebäude für kulturelle Zwecke ist ein Gebäude, in dem kulturelle Ereignisse stattfinden sowie ein Gebäude von kulturhistorischer Bedeutung.'),
		('3031', 'Schloss', 'Schloss ist ein Gebäude, das als repräsentativer Wohnsitz vor allem des Adels dient oder diente.'),
		('3032', 'Theater, Oper', 'Theater, Oper ist ein Gebäude, in dem Bühnenstücke aufgeführt werden.'),
		('3033', 'Konzertgebäude', 'Konzertgebäude ist ein Gebäude, in dem Musikaufführungen stattfinden.'),
		('3034', 'Museum', 'Museum ist ein Gebäude, in dem Sammlungen von (historischen) Objekten oder Reproduktionen davon ausgestellt werden.'),
		('3035', 'Rundfunk, Fernsehen', 'Rundfunk-, Fernsehen ist ein Gebäude, in dem Radio- und Fernsehprogramme produziert und gesendet werden.'),
		('3036', 'Veranstaltungsgebäude', 'Veranstaltungsgebäude ist ein Gebäude, das hauptsächlich für kulturelle Zwecke wie z.B. Aufführungen, Ausstellungen, Konzerte genutzt wird'),
		('3037', 'Bibliothek, Bücherei', 'Bibliothek, Bücherei ist ein Gebäude, in dem Bücher und Zeitschriften gesammelt, aufbewahrt und ausgeliehen werden.'),
		('3038', 'Burg, Festung', 'Burg, Festung ist ein Gebäude innerhalb einer befestigten Anlage.'),
		('3040', 'Gebäude für religiöse Zwecke', ''),
		('3041', 'Kirche', 'Kirche ist ein Gebäude, in dem sich Christen zu Gottesdiensten versammeln.'),
		('3042', 'Synagoge', ''),
		('3043', 'Kapelle', 'Kapelle ist ein kleines Gebäude (Gebets-, Tauf-, Grabkapelle) für (christliche) gottesdienstliche Zwecke.'),
		('3044', 'Gemeindehaus', ''),
		('3045', 'Gotteshaus', 'Gotteshaus ist ein Gebäude, in dem Gläubige einer nichtchristlichen Religionsgemeinschaft religiöse Handlungen vollziehen.'),
		('3046', 'Moschee', ''),
		('3047', 'Tempel', ''),
		('3048', 'Kloster', ''),
		('3050', 'Gebäude für Gesundheitswesen', 'Gebäude für Gesundheitswesen ist ein Gebäude, das der ambulanten oder stationären Behandlung und Pflege von Patienten dient.'),
		('3051', 'Krankenhaus', 'Krankenhaus ist ein Gebäude, in dem Kranke behandelt und/oder gepflegt werden.'),
		('3052', 'Heilanstalt, Pflegeanstalt, Pflegestation', ''),
		('3053', 'Ärztehaus, Poliklinik', 'Ärztehaus, Poliklinik ist ein Gebäude, in dem mehrere Ärzte unterschiedlicher Fachrichtung Kranke ambulant behandeln und versorgen.'),
		('3060', 'Gebäude für soziale Zwecke', 'Gebäude für soziale Zwecke ist ein Gebäude, in dem ältere Menschen, Obdachlose, Jugendliche oder Kinder betreut werden.'),
		('3061', 'Jugendfreizeitheim', ''),
		('3062', 'Freizeit-, Vereinsheim, Dorfgemeinschafts-, Bürgerhaus', ''),
		('3063', 'Seniorenfreizeitstätte', ''),
		('3064', 'Obdachlosenheim', ''),
		('3065', 'Kinderkrippe, Kindergarten, Kindertagesstätte', 'Kinderkrippe, Kindergarten, Kindertagesstätte ist ein Gebäude, in dem Kinder im Vorschulalter betreut werden.'),
		('3066', 'Asylbewerberheim', ''),
		('3070', 'Gebäude für Sicherheit und Ordnung', 'Gebäude für Sicherheit und Ordnung ist ein Gebäude, das für Personen und Gegenstände dient, die zur Verhütung oder Bekämpfung von Rechtsverletzungen und zum Katastrophenschutz eingesetzt werden, oder zur Unterbringung von Strafgefangenen.'),
		('3071', 'Polizei', 'Polizei ist ein Gebäude für Polizeibedienstete, die in einem bestimmten Gebiet für Sicherheit und Ordnung zuständig sind.'),
		('3072', 'Feuerwehr', 'Feuerwehr ist ein Gebäude der Feuerwehr, in dem Personen und Geräte zur Brandbekämpfung sowie zu anderen Hilfeleistungen untergebracht sind.'),
		('3073', 'Kaserne', 'Kaserne ist ein Gebäude zur ortsfesten Unterbringung von Angehörigen der Bundeswehr und der Polizei sowie deren Ausrüstung.'),
		('3074', 'Schutzbunker', 'Schutzbunker ist ein Gebäude zum Schutz der Zivilbevölkerung vor militärischen Angriffen.'),
		('3075', 'Justizvollzugsanstalt', 'Justizvollzugsanstalt ist ein Gebäude zur Unterbringung von Untersuchungshäftlingen und Strafgefangenen.'),
		('3080', 'Friedhofsgebäude', 'Friedhofsgebäude ist ein Gebäude, das zur Aufrechterhaltung des Friedhofbetriebes dient (z.B. Verwaltung, Leichenhalle, Krematorium).'),
		('3081', 'Trauerhalle', ''),
		('3082', 'Krematorium', ''),
		('3090', 'Empfangsgebäude', 'Empfangsgebäude ist ein Gebäude mit Wartesaal, Fahrkarten- und Gepäckschalter zur Abwicklung des Straßen-, Schienen-, Seilbahn-, Luft- und Schiffsverkehrs.'),
		('3091', 'Bahnhofsgebäude', ''),
		('3092', 'Flughafengebäude', ''),
		('3094', 'Gebäude zum U-Bahnhof', ''),
		('3095', 'Gebäude zum S-Bahnhof', ''),
		('3097', 'Gebäude zum Busbahnhof', 'Gebäude zum Busbahnhof ist ein Gebäude auf dem Busbahnhof, das zur Abwicklung des Busverkehrs dient.'),
		('3098', 'Empfangsgebäude Schifffahrt', ''),
		('3100', 'Gebäude für öffentliche Zwecke mit Wohnen', ''),
		('3200', 'Gebäude für Erholungszwecke', 'Gebäude für Erholungszwecke ist ein Gebäude zur Freizeitgestaltung mit dem Ziel der Erhaltung und Wiederherstellung der Leistungsfähigkeit des Menschen.'),
		('3210', 'Gebäude für Sportzwecke', 'Gebäude für Sportzwecke ist ein Gebäudes, in dem verschiedene Sportarten ausgeübt werden.'),
		('3211', 'Sport-, Turnhalle', 'Sport-, Turnhalle ist ein Gebäude, das für den Turnunterricht und für sportliche Betätigungen in der Freizeit errichtet und dementsprechend ausgestattet ist.'),
		('3212', 'Gebäude zum Sportplatz', ''),
		('3220', 'Badegebäude', ''),
		('3221', 'Hallenbad', 'Hallenbad ist ein Gebäude mit Schwimmbecken und zugehörigen Einrichtungen (z. B. Umkleidekabinen).'),
		('3222', 'Gebäude im Freibad', ''),
		('3230', 'Gebäude im Stadion', ''),
		('3240', 'Gebäude für Kurbetrieb', ''),
		('3241', 'Badegebäude für medizinische Zwecke', ''),
		('3242', 'Sanatorium', 'Sanatorium ist ein Gebäude mit zugehörigen Einrichtungen, das klimagünstig gelegen ist, unter fachärztlicher Leitung steht und zur Behandlung chronisch Kranker und Genesender bestimmt ist, für die kein Krankenhausaufenthalt in Frage kommt.'),
		('3260', 'Gebäude im Zoo', ''),
		('3261', 'Empfangsgebäude des Zoos', ''),
		('3262', 'Aquarium, Terrarium, Voliere', 'Aquarium, Terrarium, Voliere ist ein Gebäude, in dem Fische und Wasserpflanzen, Reptilien und Amphibien oder Vögel gehalten und gezüchtet werden.'),
		('3263', 'Tierschauhaus', ''),
		('3264', 'Stall im Zoo', ''),
		('3270', 'Gebäude im botanischen Garten', ''),
		('3271', 'Empfangsgebäude des botanischen Gartens', ''),
		('3272', 'Gewächshaus (Botanik)', ''),
		('3273', 'Pflanzenschauhaus', ''),
		('3280', 'Gebäude für andere Erholungseinrichtung', ''),
		('3281', 'Schutzhütte', 'Schutzhütte ist ein Gebäude zum Schutz vor Unwetter.'),
		('3290', 'Touristisches Informationszentrum', 'Touristisches Informationszentrum ist eine Auskunftsstelle für Touristen.'),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', 'Nach Quellenlage nicht zu spezifizieren bedeutet, dass keine Aussage über die Werteart gemacht werden kann.');
		CREATE TABLE ax_art_gebaeudepunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_gebaeudepunkt IS 'Alias: "AX_Art_Gebaeudepunkt", UML-Typ: Enumeration';
		INSERT INTO ax_art_gebaeudepunkt (wert,beschreibung,dokumentation) VALUES
		('1100', 'First', ''),
		('1200', 'Traufe', ''),
		('2100', 'Eingang', ''),
		('2200', 'Lichtschacht', '');
		CREATE TABLE ax_weitere_gebaeudefunktion (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_weitere_gebaeudefunktion IS 'Alias: "AX_Weitere_Gebaeudefunktion", UML-Typ: Enumeration';
		INSERT INTO ax_weitere_gebaeudefunktion (wert,beschreibung,dokumentation) VALUES
		('1000', 'Bankfiliale', 'Bankfiliale ist eine Einrichtung in der Geldgeschäfte getätigt werden.'),
		('1010', 'Hotel', 'Hotel ist ein Beherbergungs- und/oder Verpflegungsbetrieb.'),
		('1020', 'Jugendherberge', 'Jugendherberge ist eine zur Förderung von Jugendreisen dienende Aufenthalts- und Übernachtungsstätte.'),
		('1030', 'Gaststätte', 'Gaststätte ist eine Einrichtung, in der gegen Entgelt Mahlzeiten und Getränke zum sofortigen Verzehr angeboten werden.'),
		('1040', 'Kino', 'Kino ist eine Einrichtung, in der alle Arten von Filmen bzw. Lichtspielen für ein Publikum abgespielt werden.'),
		('1050', 'Spielkasino', 'Spielkasino ist eine Einrichtung, in der öffentlich zugänglich staatlich konzessioniertes Glücksspiel betrieben wird.'),
		('1060', 'Tiefgarage', 'Tiefgarage ist ein Bauwerk unterhalb der Erdoberfläche, in dem Fahrzeuge abgestellt werden.'),
		('1070', 'Parkdeck', 'Parkdeck ist eine Fläche auf einem Gebäude, auf der Fahrzeuge abgestellt werden.'),
		('1080', 'Toilette', 'Toilette ist eine Einrichtung mit sanitären Vorrichtungen zum Verrichtung der Notdurft.'),
		('1090', 'Post', 'Post ist eine Einrichtung, von der aus Briefe, Pakete befördert und weitere Dienstleistungen angeboten werden.'),
		('1100', 'Zoll', 'Zoll ist eine Einrichtung der Zollabfertigung.'),
		('1110', 'Theater', 'Theater ist eine Einrichtung, in der Bühnenstücke aufgeführt werden.'),
		('1120', 'Museum', 'Museum ist eine Einrichtung in der Sammlungen von (historischen) Objekten oder Reproduktionen davon ausgestellt werden.'),
		('1130', 'Bibliothek', 'Bibliothek ist eine Einrichtung, in der Bücher und Zeitschriften gesammelt, aufbewahrt und ausgeliehen werden.'),
		('1140', 'Kapelle', 'Kapelle ist eine Einrichtung für (christliche) gottesdienstliche Zwecke .'),
		('1150', 'Moschee', 'Moschee ist ein Einrichtung, in der sich Muslime zu Gottesdiensten versammeln oder zu anderen Zwecken treffen.'),
		('1160', 'Tempel', ''),
		('1170', 'Apotheke', 'Apotheke ist ein Geschäft, in dem Arzneimittel hergestellt und verkauft werden.'),
		('1180', 'Polizeiwache', 'Polizeiwache ist eine Dienststelle der Polizei.'),
		('1190', 'Rettungsstelle', 'Rettungsstelle ist eine Einrichtung zur Aufnahme, Erstbehandlung und gezielten Weiterverlegung von Patienten mit Erkrankungen und Unfällen aller Art.'),
		('1200', 'Touristisches Informationszentrum', 'Touristisches Informationszentrum ist eine Auskunftsstelle für Touristen.'),
		('1210', 'Kindergarten', 'Kindergarten ist eine Einrichtung, in der Kinder im Vorschulalter betreut werden.'),
		('1220', 'Arztpraxis', 'Arztpraxis ist die Arbeitsstätte eines Arztes.'),
		('1230', 'Supermarkt', ''),
		('1240', 'Geschäft', '');
		CREATE TABLE ax_beschaffenheit_besonderegebaeudelinie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_beschaffenheit_besonderegebaeudelinie IS 'Alias: "AX_Beschaffenheit_BesondereGebaeudelinie", UML-Typ: Enumeration';
		INSERT INTO ax_beschaffenheit_besonderegebaeudelinie (wert,beschreibung,dokumentation) VALUES
		('1000', 'Offene Gebäudelinie', ''),
		('2100', 'Unverputzt', ''),
		('2200', 'Verputzt', ''),
		('2300', 'Verklinkert', ''),
		('3100', 'Holz', ''),
		('3200', 'Sichtbeton', ''),
		('3300', 'Naturstein', ''),
		('3400', 'Glas', ''),
		('4000', 'Trennlinie nicht eindeutig festgelegt', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_bauart_bauteil (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bauart_bauteil IS 'Alias: "AX_Bauart_Bauteil", UML-Typ: Enumeration';
		INSERT INTO ax_bauart_bauteil (wert,beschreibung,dokumentation) VALUES
		('1100', 'Geringergeschossiger Gebäudeteil', ''),
		('1200', 'Höhergeschossiger Gebäudeteil (nicht Hochhaus)', ''),
		('1300', 'Hochhausgebäudeteil', ''),
		('1400', 'Abweichende Geschosshöhe', ''),
		('2000', 'Keller', ''),
		('2100', 'Tiefgarage', 'Tiefgarage ist ein Bauwerk unter der Erdoberfläche, in dem Fahrzeuge abgestellt werden'),
		('2300', 'Loggia', ''),
		('2350', 'Wintergarten', ''),
		('2400', 'Arkade', ''),
		('2500', 'Auskragende/zurückspringende Geschosse', ''),
		('2510', 'Auskragende Geschosse', ''),
		('2520', 'Zurückspringende Geschosse', ''),
		('2610', 'Durchfahrt im Gebäude', ''),
		('2620', 'Durchfahrt an überbauter Verkehrsstraße', 'Durchfahrt an überbauter Verkehrsstraße ist eine Stelle, an der mit Fahrzeugen durch Gebäude gefahren werden kann.'),
		('2710', 'Schornstein im Gebäude', 'Schornstein im Gebäude ist ein über das Dach  hinausragender Abzugskanal für die Rauchgase einer  Feuerungsanlage oder für andere Abgase.'),
		('2720', 'Turm im Gebäude', 'Turm im Gebäude ist ein hochaufragendes Bauwerk innerhalb eines Gebäudes.'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_nutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_nutzung IS 'Alias: "AX_Nutzung", UML-Typ: Enumeration';
		INSERT INTO ax_nutzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zivil', 'Zivil wird für ein Gebäude verwendet, das privaten, öffentlichen oder religiösen Zwecken dient und nicht militärisch genutzt wird.'),
		('1100', 'Privat', 'Privat bezeichnet ein Gebäude, das wohn- oder privatwirtschaftlichen Zwecken dient.'),
		('1200', 'Öffentlich', 'Öffentlich bedeutet, dass in einem Gebäude Aufgaben der öffentlichen Hand wahrgenommen werden oder dass das Gebäude für die Nutzung durch die Allgemeinheit vorgesehen ist.'),
		('1300', 'Religiös', 'Religiös bezeichnet ein Gebäude, das religiösen Zwecken dient.'),
		('2000', 'Militärisch', 'Militärisch bedeutet, dass das Gebäude von Streitkräften genutzt wird.');
		CREATE TABLE ax_art_verbandsgemeinde (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_verbandsgemeinde IS 'Alias: "AX_Art_Verbandsgemeinde", UML-Typ: Enumeration';
		INSERT INTO ax_art_verbandsgemeinde (wert,beschreibung,dokumentation) VALUES
		('1000', 'Samtgemeinde', 'Samtgemeinde umfasst in Niedersachsen das Gebiet einer Samtgemeinde.'),
		('2000', 'Verbandsgemeinde', 'Verbandsgemeinde umfasst in Rheinland-Pfalz das Gebiet einer Verbandsgemeinde, das aus benachbarten Gemeinden desselben Landkreises gebildet wird.'),
		('3000', 'Amt', 'Amt umfasst das Gebiet eines Amtes, das aus Gemeinden desselben Landkreises besteht.');
		CREATE TABLE ax_art_baublock (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_baublock IS 'Alias: "AX_Art_Baublock", UML-Typ: Enumeration';
		INSERT INTO ax_art_baublock (wert,beschreibung,dokumentation) VALUES
		('1000', 'Nettobaublockfläche', ''),
		('2000', 'Bruttobaublockfläche', '');
		CREATE TABLE ax_artdergebietsgrenze_gebietsgrenze (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdergebietsgrenze_gebietsgrenze IS 'Alias: "AX_ArtDerGebietsgrenze_Gebietsgrenze", UML-Typ: Enumeration';
		INSERT INTO ax_artdergebietsgrenze_gebietsgrenze (wert,beschreibung,dokumentation) VALUES
		('7101', 'Grenze der Bundesrepublik Deutschland', 'Grenze der Bundesrepublik Deutschland begrenzt das Gebiet der Bundesrepublik Deutschland oder eines Kondominiums.'),
		('7102', 'Grenze des Bundeslandes', 'Grenze des Bundeslandes begrenzt das Gebiet einer Verwaltungseinheit auf der Bundeslandebene.'),
		('7103', 'Grenze des Regierungsbezirks', 'Grenze des Regierungsbezirks begrenzt das Gebiet einer Verwaltungseinheit auf der Regierungsbezirksebene.'),
		('7104', 'Grenze des Kreises/Region', 'Grenze des Kreises/Region begrenzt das Gebiet einer Verwaltungseinheit auf der Kreisebene.'),
		('7105', 'Grenze der Verwaltungsgemeinschaft', 'Grenze der Verwaltungsgemeinschaft begrenzt das Gebiet einer Verwaltungseinheit auf der Verwaltungsgemeinschaftsebene.'),
		('7106', 'Grenze der Gemeinde', 'Grenze der Gemeinde begrenzt ein kommunales Gebiet auf der Gemeindeebene.'),
		('7107', 'Grenze des Gemeindeteils', 'Grenze des Gemeindeteils begrenzt das Gebiet einer Verwaltungseinheit auf der Gemeindeteilebene.');
		CREATE TABLE ax_sonstigeangaben_bodenschaetzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_sonstigeangaben_bodenschaetzung IS 'Alias: "AX_SonstigeAngaben_Bodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_sonstigeangaben_bodenschaetzung (wert,beschreibung,dokumentation) VALUES
		('1100', 'Nass, zu viel Wasser (Wa+)', ''),
		('1200', 'Trocken, zu wenig Wasser (Wa-)', ''),
		('1300', 'Besonders günstige Wasserverhältnisse (Wa gt)', ''),
		('1400', 'Rieselwasser, künstliche Bewässerung (RiWa)', ''),
		('2100', 'Unbedingtes Wiesenland (W)', ''),
		('2200', 'Streuwiese (Str)', ''),
		('2300', 'Hutung (Hu)', ''),
		('2400', 'Acker-Hackrain (A-Hack)', ''),
		('2500', 'Grünland-Hackrain (Gr-Hack)', ''),
		('2600', 'Garten (G)', ''),
		('3000', 'Neukultur (N)', ''),
		('4000', 'Tiefkultur (T)', ''),
		('5000', 'Geringstland (Ger)', ''),
		('9000', 'Nachschätzung erforderlich', '');
		CREATE TABLE ax_kulturart_musterlandesmusterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_kulturart_musterlandesmusterundvergleichsstueck IS 'Alias: "AX_Kulturart_MusterLandesmusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_kulturart_musterlandesmusterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ackerland (A)', ''),
		('2000', 'Acker-Grünland (AGr)', ''),
		('3000', 'Grünland (Gr)', ''),
		('4000', 'Grünland-Acker (GrA)', '');
		CREATE TABLE ax_entstehungsartoderklimastufewasserverhaeltnisse_bodensc (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_entstehungsartoderklimastufewasserverhaeltnisse_bodensc IS 'Alias: "AX_EntstehungsartOderKlimastufeWasserverhaeltnisse_Bodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_entstehungsartoderklimastufewasserverhaeltnisse_bodensc (wert,beschreibung,dokumentation) VALUES
		('1000', 'Diluvium (D)', ''),
		('1100', 'Diluvium über Alluvium (DAl)', ''),
		('1200', 'Diluvium über Löß (DLö)', ''),
		('1300', 'Diluvium über Verwitterung (DV)', ''),
		('1400', 'Diluvium, gesteinig (Dg)', ''),
		('1410', 'Diluvium, gesteinig über Alluvium (DgAl)', ''),
		('1420', 'Diluvium, gesteinig über Löß (DgLö)', ''),
		('1430', 'Diluvium, gesteinig über Verwitterung (DgV)', ''),
		('2000', 'Löß (Lö)', ''),
		('2100', 'Löß über Diluvium (LöD)', ''),
		('2110', 'Löß, Diluvium, Gesteinsböden (LöDg)', ''),
		('2120', 'Löß, Diluvium, Verwitterung (LöDV)', ''),
		('2200', 'Löß über Alluvium (LöAl)', ''),
		('2300', 'Löß über Verwitterung (LöV)', ''),
		('2310', 'Löß, Verwitterung, Gesteinsböden (LöVg)', ''),
		('2400', 'Löß über Verwitterung, gesteinig (LöVg)', ''),
		('3000', 'Alluvium (Al)', ''),
		('3100', 'Alluvium über Diluvium (AlD)', ''),
		('3200', 'Alluvium über Löß (AlLö)', ''),
		('3300', 'Alluvium über Verwitterung (AlV)', ''),
		('3400', 'Alluvium, gesteinig (Alg)', ''),
		('3410', 'Alluvium, gesteinig über Diluvium (AlgD)', ''),
		('3420', 'Alluvium, gesteinig über Löß (AlgLö)', ''),
		('3430', 'Alluvium, gesteinig über Verwitterung (AlgV)', ''),
		('3500', 'Alluvium, Marsch (AlMa)', ''),
		('3610', 'Alluvium, Moor (AlMo)', ''),
		('3620', 'Moor, Alluvium (MoAI)', ''),
		('3700', 'Mergel (Me)', ''),
		('4000', 'Verwitterung (V)', ''),
		('4100', 'Verwitterung über Diluvium (VD)', ''),
		('4200', 'Verwitterung über Alluvium (VAl)', ''),
		('4300', 'Verwitterung über Löß (VLö)', ''),
		('4400', 'Verwitterung, Gesteinsböden (Vg)', ''),
		('4410', 'Verwitterung, Gesteinsböden über Diluvium (VgD)', ''),
		('5000', 'Entstehungsart nicht erkennbar (-)', ''),
		('6100', 'Klimastufe 8° C und darüber (a)', ''),
		('6200', 'Klimastufe 7,9° - 7,0° C (b)', ''),
		('6300', 'Klimastufe 6,9° - 5,7° C (c)', ''),
		('6400', 'Klimastufe 5,6° C und darunter (d)', ''),
		('7100', 'Wasserstufe (1)', ''),
		('7200', 'Wasserstufe (2)', ''),
		('7300', 'Wasserstufe (3)', ''),
		('7400', 'Wasserstufe (4)', ''),
		('7410', 'Wasserstufe (4-)', ''),
		('7500', 'Wasserstufe (5)', ''),
		('7510', 'Wasserstufe (5-)', ''),
		('7520', 'Wasserstufe (3-)', ''),
		('7530', 'Wasserstufe (3+4)', '');
		CREATE TABLE ax_sonstigeangaben_musterlandesmusterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_sonstigeangaben_musterlandesmusterundvergleichsstueck IS 'Alias: "AX_SonstigeAngaben_MusterLandesmusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_sonstigeangaben_musterlandesmusterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1100', 'Nass, zu viel Wasser (Wa+)', ''),
		('1200', 'Trocken, zu wenig Wasser (Wa-)', ''),
		('1300', 'Besonders günstige Wasserverhältnisse (Wa gt)', ''),
		('1400', 'Rieselwasser, künstliche Bewässerung (RiWa)', ''),
		('2100', 'Unbedingtes Wiesenland (W)', ''),
		('2200', 'Streuwiese (Str)', ''),
		('2300', 'Hutung (Hu)', ''),
		('2400', 'Acker-Hackrain (A-Hack)', ''),
		('2500', 'Grünland-Hackrain (Gr-Hack)', ''),
		('2600', 'Garten (G)', ''),
		('5000', 'Geringstland (Ger)', '');
		CREATE TABLE ax_kulturart_bodenschaetzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_kulturart_bodenschaetzung IS 'Alias: "AX_Kulturart_Bodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_kulturart_bodenschaetzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ackerland (A)', ''),
		('2000', 'Acker-Grünland (AGr)', ''),
		('3000', 'Grünland (Gr)', ''),
		('4000', 'Grünland-Acker (GrA)', '');
		CREATE TABLE ax_klassifizierung_bewertung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_klassifizierung_bewertung IS 'Alias: "AX_Klassifizierung_Bewertung", UML-Typ: Enumeration';
		INSERT INTO ax_klassifizierung_bewertung (wert,beschreibung,dokumentation) VALUES
		('1110', 'Unbebautes Grundstück', ''),
		('1120', 'Unbebautes Grundstück mit Gebäude von untergeordneter Bedeutung', ''),
		('1130', 'Unbebautes Grundstück mit einem dem Verfall preisgegebenen Gebäude', ''),
		('1140', 'Unbebautes Grundstück für Erholungs- und Freizeitzwecke', ''),
		('1210', 'Einfamilienhausgrundstück', ''),
		('1220', 'Zweifamilienhausgrundstück', ''),
		('1230', 'Mietwohngrundstück', ''),
		('1240', 'Gemischtgenutztes Grundstück', ''),
		('1250', 'Geschäftsgrundstück', ''),
		('1260', 'Sonstiges bebautes Grundstück', ''),
		('1310', 'Einfamilienhaus auf fremdem Grund und Boden', ''),
		('1320', 'Zweifamilienhaus auf fremdem Grund und Boden', ''),
		('1330', 'Mietwohngrundstück, Mietwohngebäude auf fremdem Grund und Boden', ''),
		('1340', 'Gemischtgenutztes Grundstück, gemischtgenutztes Gebäude auf fremdem Grund und Boden', ''),
		('1350', 'Geschäftsgrundstück, Geschäftsgebäude auf fremdem Grund und Boden', ''),
		('1360', 'Sonstige bebaute Grundstücke, sonstige Gebäude auf fremdem Grund und Boden', ''),
		('2110', 'Landwirtschaftliche Nutzung', ''),
		('2120', 'Hopfen', ''),
		('2130', 'Spargel', ''),
		('2190', 'Sonstige Sonderkulturen', ''),
		('2200', 'Holzung', ''),
		('2300', 'Weingarten (allgemein)', ''),
		('2310', 'Weingarten 1', ''),
		('2320', 'Weingarten 2', ''),
		('2330', 'Weingarten 3', ''),
		('2340', 'Weingarten 4', ''),
		('2350', 'Weingarten 5', ''),
		('2360', 'Weingarten 6', ''),
		('2370', 'Weingarten 7', ''),
		('2380', 'Weingarten 8', ''),
		('2390', 'Weingarten 9', ''),
		('2410', 'Gartenland', ''),
		('2420', 'Obstplantage', ''),
		('2430', 'Baumschule', ''),
		('2440', 'Anbaufläche unter Glas', ''),
		('2450', 'Kleingarten', ''),
		('2510', 'Weihnachtsbaumkultur', ''),
		('2520', 'Saatzucht', ''),
		('2530', 'Teichwirtschaft', ''),
		('2610', 'Abbauland der Land- und Forstwirtschaft', ''),
		('2620', 'Geringstland', 'Geringstland sind Flächen geringster Ertragsfähigkeit ohne Wertzahlen nach dem Bodenschätzungsgesetz, das sind unkultivierte Moor- und Heideflächen (sofern nicht gesondert geführt), ehemals bodengeschätzte Flächen und ehemalige Weinbauflächen, die ihren Kulturzustand verloren haben.'),
		('2630', 'Unland', ''),
		('2640', 'Moor', 'Moor ist eine unkultivierte Fläche mit einer (mindestens 20 cm starken) Auflage aus vertorften und vermoorten Pflanzenresten, soweit sie nicht als Torfstich benutzt wird.'),
		('2650', 'Heide', 'Heide ist eine unkultivierte, sandige, überwiegend mit Heidekraut oder Ginster bewachsene Fläche.'),
		('2700', 'Reet', 'Reet ist eine ständig oder zeitweise unter Wasser stehende und mit Reet bewachsene Fläche.'),
		('2710', 'Reet I', 'Reetfläche, deren Nutzung eingestuft ist in Güteklasse I (gut).'),
		('2720', 'Reet II', 'Reetfläche, deren Nutzung eingestuft ist in Güteklasse II (mittel).'),
		('2730', 'Reet III', 'Reetfläche, deren Nutzung eingestuft ist in Güteklasse III (gering).'),
		('2800', 'Nebenfläche des Betriebs der Land- und Forstwirtschaft', ''),
		('2899', 'Noch nicht klassifiziert', '');
		CREATE TABLE ax_merkmal_musterlandesmusterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_merkmal_musterlandesmusterundvergleichsstueck IS 'Alias: "AX_Merkmal_MusterLandesmusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_merkmal_musterlandesmusterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1000', 'Musterstück (M)', ''),
		('2000', 'Landesmusterstück (L)', ''),
		('3000', 'Vergleichsstück (V)', '');
		CREATE TABLE ax_zustandsstufeoderbodenstufe_bodenschaetzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustandsstufeoderbodenstufe_bodenschaetzung IS 'Alias: "AX_ZustandsstufeOderBodenstufe_Bodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_zustandsstufeoderbodenstufe_bodenschaetzung (wert,beschreibung,dokumentation) VALUES
		('1100', 'Zustandsstufe (1)', ''),
		('1200', 'Zustandsstufe (2)', ''),
		('1300', 'Zustandsstufe (3)', ''),
		('1400', 'Zustandsstufe (4)', ''),
		('1500', 'Zustandsstufe (5)', ''),
		('1600', 'Zustandsstufe (6)', ''),
		('1700', 'Zustandsstufe (7)', ''),
		('1800', 'Zustandsstufe Misch- und Schichtböden sowie künstlichveränderte Böden (-)', ''),
		('2100', 'Bodenstufe (I)', ''),
		('2200', 'Bodenstufe (II)', ''),
		('2300', 'Bodenstufe (III)', ''),
		('2400', 'Bodenstufe Misch- und Schichtböden sowie künstlich veränderte Böden (-)', ''),
		('3100', 'Bodenstufe (II+III)', ''),
		('3200', 'Bodenstufe ("(III)")', ''),
		('3300', 'Bodenstufe (IV)', '');
		CREATE TABLE ax_bedeutung_grablochderbodenschaetzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bedeutung_grablochderbodenschaetzung IS 'Alias: "AX_Bedeutung_GrablochDerBodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_bedeutung_grablochderbodenschaetzung (wert,beschreibung,dokumentation) VALUES
		('1100', 'Grabloch, bestimmend, lagerichtig (innerhalb der Fläche)', ''),
		('1200', 'Grabloch, bestimmend, lagerichtig (außerhalb des Abschnitts)', ''),
		('1300', 'Grabloch, nicht lagerichtig, im Abschnitt nicht vorhanden', ''),
		('2000', 'Grabloch für Muster-, Landesmuster-, Vergleichsstück', ''),
		('3000', 'Grabloch, nicht bestimmend', '');
		CREATE TABLE ax_zustandsstufeoderbodenstufe_musterlandesmusterundvergle (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustandsstufeoderbodenstufe_musterlandesmusterundvergle IS 'Alias: "AX_ZustandsstufeOderBodenstufe_MusterLandesmusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_zustandsstufeoderbodenstufe_musterlandesmusterundvergle (wert,beschreibung,dokumentation) VALUES
		('1100', 'Zustandsstufe (1)', ''),
		('1200', 'Zustandsstufe (2)', ''),
		('1300', 'Zustandsstufe (3)', ''),
		('1400', 'Zustandsstufe (4)', ''),
		('1500', 'Zustandsstufe (5)', ''),
		('1600', 'Zustandsstufe (6)', ''),
		('1700', 'Zustandsstufe (7)', ''),
		('1800', 'Zustandsstufe Misch- und Schichtböden sowie künstlichveränderte Böden (-)', ''),
		('2100', 'Bodenstufe (I)', ''),
		('2200', 'Bodenstufe (II)', ''),
		('2300', 'Bodenstufe (III)', ''),
		('2400', 'Bodenstufe Misch- und Schichtböden sowie künstlich veränderte Böden (-)', '');
		CREATE TABLE ax_entstehungsartoderklimastufewasserverhaeltnisse_musterl (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_entstehungsartoderklimastufewasserverhaeltnisse_musterl IS 'Alias: "AX_EntstehungsartOderKlimastufeWasserverhaeltnisse_MusterLandesmusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_entstehungsartoderklimastufewasserverhaeltnisse_musterl (wert,beschreibung,dokumentation) VALUES
		('1000', 'Diluvium (D)', ''),
		('1100', 'Diluvium über Alluvium (DAl)', ''),
		('1200', 'Diluvium über Löß (DLö)', ''),
		('1300', 'Diluvium über Verwitterung (DV)', ''),
		('1400', 'Diluvium, gesteinig (Dg)', ''),
		('1410', 'Diluvium, gesteinig über Alluvium (DgAl)', ''),
		('1420', 'Diluvium, gesteinig über Löß (DgLö)', ''),
		('1430', 'Diluvium, gesteinig über Verwitterung (DgV)', ''),
		('2000', 'Löß (Lö)', ''),
		('2100', 'Löß über Diluvium (LöD)', ''),
		('2200', 'Löß über Alluvium (LöAl)', ''),
		('2300', 'Löß über Verwitterung (LöV)', ''),
		('3000', 'Alluvium (Al)', ''),
		('3100', 'Alluvium über Diluvium (AlD)', ''),
		('3200', 'Alluvium über Löß (AlLö)', ''),
		('3300', 'Alluvium über Verwitterung (AlV)', ''),
		('3400', 'Alluvium, gesteinig (Alg)', ''),
		('3410', 'Alluvium, gesteinig über Diluvium (AlgD)', ''),
		('3420', 'Alluvium, gesteinig über Löß (AlgLö)', ''),
		('3430', 'Alluvium, gesteinig über Verwitterung (AlgV)', ''),
		('4000', 'Verwitterung (V)', ''),
		('4100', 'Verwitterung über Diluvium (VD)', ''),
		('4200', 'Verwitterung über Alluvium (VAl)', ''),
		('4300', 'Verwitterung über Löß (VLö)', ''),
		('4400', 'Verwitterung, Gesteinsböden (Vg)', ''),
		('4410', 'Verwitterung, Gesteinsböden über Diluvium (VgD)', ''),
		('5000', 'Entstehungsart nicht erkennbar (-)', ''),
		('6100', 'Klimastufe 8 Grad C und darüber (a)', ''),
		('6200', 'Klimastufe 7,9 Grad - 7,0 Grad C (b)', ''),
		('6300', 'Klimastufe 6,9 Grad - 5,7 Grad C (c)', ''),
		('6400', 'Klimastufe 5,6 Grad C und darunter (d)', ''),
		('7100', 'Wasserstufe (1)', ''),
		('7200', 'Wasserstufe (2)', ''),
		('7300', 'Wasserstufe (3)', ''),
		('7400', 'Wasserstufe (4)', ''),
		('7410', 'Wasserstufe (4-)', ''),
		('7500', 'Wasserstufe (5)', ''),
		('7510', 'Wasserstufe (5-)', '');
		CREATE TABLE ax_bodenart_bodenschaetzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bodenart_bodenschaetzung IS 'Alias: "AX_Bodenart_Bodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_bodenart_bodenschaetzung (wert,beschreibung,dokumentation) VALUES
		('1100', 'Sand (S)', ''),
		('1200', 'Anlehmiger Sand (Sl)', ''),
		('2100', 'Lehmiger Sand (lS)', ''),
		('2200', 'Stark lehmiger Sand (SL)', ''),
		('3100', 'Lehm (L)', ''),
		('3200', 'Sandiger Lehm (sL)', ''),
		('4100', 'Ton (T)', ''),
		('4200', 'Schwerer Lehm (LT)', ''),
		('5000', 'Moor (Mo)', ''),
		('6110', 'Sand, Moor (SMo)', ''),
		('6120', 'Lehmiger Sand, Moor (lSMo)', ''),
		('6130', 'Lehm, Moor (LMo)', ''),
		('6140', 'Ton, Moor (TMo)', ''),
		('6210', 'Moor,Sand (MoS)', ''),
		('6220', 'Moor, Lehmiger Sand (MolS)', ''),
		('6230', 'Moor, Lehm (MoL)', ''),
		('6240', 'Moor, Ton (MoT)', ''),
		('7110', 'Sand auf sandigem Lehm (S/sL)', ''),
		('7120', 'Sand auf Lehm (S/L)', ''),
		('7130', 'Sand auf schwerem Lehm (S/LT)', ''),
		('7140', 'Sand auf Ton (S/T)', ''),
		('7210', 'Anlehmiger Sand auf Lehm (Sl/L)', ''),
		('7220', 'Anlehmiger Sand auf schwerem Lehm (Sl/LT)', ''),
		('7230', 'Anlehmiger Sand auf Ton (Sl/T)', ''),
		('7310', 'Lehmiger Sand auf schwerem Lehm (lS/LT)', ''),
		('7320', 'Lehmiger Sand auf Sand (lS/S)', ''),
		('7330', 'Lehmiger Sand auf Ton (lS/T)', ''),
		('7400', 'Stark lehmiger Sand auf Ton (SL/T)', ''),
		('7510', 'Ton auf stark lehmigen Sand (T/SL)', ''),
		('7520', 'Ton auf lehmigen Sand (T/lS)', ''),
		('7530', 'Ton auf anlehmigen Sand (T/Sl)', ''),
		('7540', 'Ton auf Sand (T/S)', ''),
		('7610', 'Schwerer Lehm auf lehmigen Sand (LT/lS)', ''),
		('7620', 'Schwerer Lehm auf anlehmigen Sand (LT/Sl)', ''),
		('7630', 'Schwerer Lehm auf Sand (LT/S)', ''),
		('7710', 'Lehm auf anlehmigen Sand (L/Sl)', ''),
		('7720', 'Lehm auf Sand (L/S)', ''),
		('7800', 'Sandiger Lehm auf Sand (sL/S)', ''),
		('8110', 'Sand auf Moor (S/Mo)', ''),
		('8120', 'Lehmiger Sand auf Moor (lS/Mo)', ''),
		('8130', 'Lehm auf Moor (L/Mo)', ''),
		('8140', 'Ton auf Moor (T/Mo)', ''),
		('8210', 'Moor auf Sand (Mo/S)', ''),
		('8220', 'Moor auf lehmigen Sand (Mo/lS)', ''),
		('8230', 'Moor auf Lehm (Mo/L)', ''),
		('8240', 'Moor auf Ton (Mo/T)', ''),
		('9120', 'Bodenwechsel vom Lehm zu Moor (L+Mo)', ''),
		('9130', 'Lehmiger Sand mit starkem Steingehalt (lSg)', ''),
		('9140', 'Lehm mit starkem Steingehalt (Lg)', ''),
		('9150', 'lehmiger Sand mit Steinen und Blöcken (lS+St)', ''),
		('9160', 'Lehm mit Steinen und Blöcken L+St)', ''),
		('9170', 'Steine und Blöcke mit  lehmigem Sand (St+lS)', ''),
		('9180', 'Steine und Blöcke mit  Lehm (St+L)', ''),
		('9190', 'lehmiger Sand mit Felsen (lS+Fe)', ''),
		('9200', 'Lehm mit Felsen (L+Fe)', ''),
		('9210', 'Felsen mit lehmigem Sand (Fe+lS)', ''),
		('9220', 'Felsen mit Lehm (Fe+L)', ''),
		('9310', 'Sand auf lehmigen Sand (S/lS)', ''),
		('9320', 'Anlehmiger Sand auf Mergel (Sl/Me)', ''),
		('9330', 'Anlehmiger Sand auf sandigem Lehm (Sl/sL)', ''),
		('9340', 'Lehmiger Sand auf Lehm (lS/L)', ''),
		('9350', 'Lehmiger Sand auf Mergel (lS/Me)', ''),
		('9360', 'Lehmiger Sand auf sandigem Lehm (lS/sL)', ''),
		('9370', 'Lehmiger Sand, Mergel (lSMe)', ''),
		('9380', 'Lehmiger Sand, Moor auf Mergel (lSMo/Me)', ''),
		('9390', 'Anlehmiger Sand, Moor (SlMo)', ''),
		('9410', 'Lehm auf Mergel (L/Me)', ''),
		('9420', 'Lehm, Moor auf Mergel (LMo/Me)', ''),
		('9430', 'Schwerer Lehm auf Moor (LT/Mo)', ''),
		('9440', 'Ton auf Mergel (T/Me)', ''),
		('9450', 'Moor auf Mergel (Mo/Me)', ''),
		('9460', 'Moor, Lehm auf Mergel (MoL/Me)', ''),
		('9470', 'Moor, Mergel (MoMe)', ''),
		('9480', 'LößDiluvium(LöD)', ''),
		('9490', 'AlluviumDiluvium(AlD)', '');
		CREATE TABLE ax_bodenart_musterlandesmusterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bodenart_musterlandesmusterundvergleichsstueck IS 'Alias: "AX_Bodenart_MusterLandesmusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_bodenart_musterlandesmusterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1100', 'Sand (S)', ''),
		('1200', 'Anlehmiger Sand (Sl)', ''),
		('2100', 'Lehmiger Sand (lS)', ''),
		('2200', 'Stark lehmiger Sand (SL)', ''),
		('3100', 'Lehm (L)', ''),
		('3200', 'Sandiger Lehm (sL)', ''),
		('4100', 'Ton (T)', ''),
		('4200', 'Schwerer Lehm (LT)', ''),
		('5000', 'Moor (Mo)', ''),
		('6110', 'Sand, Moor (SMo)', ''),
		('6120', 'Lehmiger Sand, Moor (lSMo)', ''),
		('6130', 'Lehm, Moor (LMo)', ''),
		('6140', 'Ton, Moor (TMo)', ''),
		('6210', 'Moor, Sand (MoS)', ''),
		('6220', 'Moor, Lehmiger Sand (MolS)', ''),
		('6230', 'Moor, Lehm (MoL)', ''),
		('6240', 'Moor, Ton (MoT)', ''),
		('7110', 'Sand auf sandigem Lehm (S/sL)', ''),
		('7120', 'Sand auf Lehm (S/L)', ''),
		('7130', 'Sand auf schwerem Lehm (S/LT)', ''),
		('7140', 'Sand auf Ton (S/T)', ''),
		('7210', 'Anlehmiger Sand auf Lehm (Sl/L)', ''),
		('7220', 'Anlehmiger Sand auf schwerem Lehm (Sl/LT)', ''),
		('7230', 'Anlehmiger Sand auf Ton (Sl/T)', ''),
		('7310', 'Lehmiger Sand auf schwerem Lehm (lS/LT)', ''),
		('7320', 'Lehmiger Sand auf Ton (lS/T)', ''),
		('7400', 'Stark lehmiger Sand auf Ton (SL/T)', ''),
		('7510', 'Ton auf stark lehmigen Sand (T/SL)', ''),
		('7520', 'Ton auf lehmigen Sand (T/lS)', ''),
		('7530', 'Ton auf anlehmigen Sand (T/Sl)', ''),
		('7540', 'Ton auf Sand (T/S)', ''),
		('7610', 'Schwerer Lehm auf lehmigen Sand (LT/lS)', ''),
		('7620', 'Schwerer Lehm auf anlehmigen Sand (LT/Sl)', ''),
		('7630', 'Schwerer Lehm auf Sand (LT/S)', ''),
		('7710', 'Lehm auf anlehmigen Sand (L/Sl)', ''),
		('7720', 'Lehm auf Sand (L/S)', ''),
		('7800', 'Sandiger Lehm auf Sand (sL/S)', ''),
		('8110', 'Sand auf Moor (S/Mo)', ''),
		('8120', 'Lehmiger Sand auf Moor (lS/Mo)', ''),
		('8130', 'Lehm auf Moor (L/Mo)', ''),
		('8140', 'Ton auf Moor (T/Mo)', ''),
		('8210', 'Moor auf Sand (Mo/S)', ''),
		('8220', 'Moor auf lehmigen Sand (Mo/lS)', ''),
		('8230', 'Moor auf Lehm (Mo/L)', ''),
		('8240', 'Moor auf Ton (Mo/T)', '');
		CREATE TABLE ax_landschaftstyp (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_landschaftstyp IS 'Alias: "AX_Landschaftstyp", UML-Typ: Enumeration';
		INSERT INTO ax_landschaftstyp (wert,beschreibung,dokumentation) VALUES
		('1100', 'Gebirge', 'Gebirge bezeichnet eine zusammenhängende größere Erhebung der Erdoberfläche. Es besteht aus einzelnen Bergen und Hochflächen, die durch Täler und Senken gegliedert sind.'),
		('1200', 'Berg', 'Berg bezeichnet eine über die Umgebung deutlich herausragende Geländeerhebung, einzeln oder als Teil eines Gebirges.'),
		('1300', 'Niederung/Senke', 'Niederung/Senke bezeichnet ein tief liegendes Land an Flussläufen und Küsten.'),
		('1400', 'Tal', 'Tal bezeichnet eine langgestreckte, offene Hohlform der Erdoberfläche.'),
		('1500', 'Tiefebene', 'Tiefebene bezeichnet einen Teil der Erdoberfläche mit fehlenden oder kaum wahrnehmbaren Höhenunterschieden in einer Höhenlage bis etwa 200 m über NN.'),
		('1600', 'Plateau/Hochebene', 'Plateau/Hochebene, bezeichnet einen Teil der Erdoberfläche mit fehlenden oder kaum wahrnehmbaren Höhenunterschieden in einer Höhenlage ab etwa 200 m über NN.'),
		('1700', 'Mündungsgebiet', 'Mündungsgebiet bezeichnet die typische, durch Ablagerung von Schwebestoffen entstandene Landschaft im Bereich der Mündung eines fließenden Gewässers in ein anderes Binnengewässer oder in ein Meer.'),
		('1800', 'Dünenlandschaft', 'Dünenlandschaft ist eine, vom Wind gebildete, durch Sandanhäufungen geprägte Landschaft.'),
		('1900', 'Waldlandschaft', 'Waldlandschaft ist eine größere und zusammenhängende Landschaft, bestehend aus mit Forstpflanzen bestockten Flächen (Wald) sowie mit dem Wald verbundene und ihm dienende Flächen.'),
		('2000', 'Inselgruppe', 'Inselgruppe ist eine Gruppe mehrerer nahe beieinander liegender Inseln geologisch gleicher Entstehung.'),
		('2100', 'Seenlandschaft', 'Seenlandschaft ist eine durch zahlreiche, nahe beieinander liegende Binnenseen geprägte Landschaft.'),
		('2200', 'Siedlungslandschaft', 'Siedlungslandschaft ist eine durch Siedlungen geprägte Landschaft.'),
		('2300', 'Moorlandschaft', 'Moorlandschaft ist eine durch Moore geprägte Landschaft.'),
		('2400', 'Heidelandschaft', 'Heidelandschaft ist eine waldfreie Landschaft der unteren Höhenstufen, die von einer mehr oder weniger lockeren Zwergstrauchformation geprägt wird.'),
		('2500', 'Wattlandschaft', 'Wattlandschaft ist ein ebener, im Wirkungsbereich der Gezeiten liegender Küstenstreifen, der bei Hochwasser überflutet wird, bei Niedrigwasser jedoch trocken fällt, wobei das Wasser durch oft tiefe Furchen (Priele) abfließt.');
		CREATE TABLE ax_art_verband (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_verband IS 'Alias: "AX_Art_Verband", UML-Typ: Enumeration';
		INSERT INTO ax_art_verband (wert,beschreibung,dokumentation) VALUES
		('1000', 'Planungsverband', ''),
		('2000', 'Region', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_behoerde (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_behoerde IS 'Alias: "AX_Behoerde", UML-Typ: Enumeration';
		INSERT INTO ax_behoerde (wert,beschreibung,dokumentation) VALUES
		('1000', 'Grundbuchamt', ''),
		('1100', 'Katasteramt', ''),
		('1200', 'Finanzamt', ''),
		('1300', 'Flurbereinigungsbehörde', ''),
		('1400', 'Forstamt', ''),
		('1500', 'Wasserwirtschaftsamt', ''),
		('1600', 'Straßenbauamt', ''),
		('1700', 'Gemeindeamt', ''),
		('1800', 'Landratsamt', ''),
		('1900', 'Kreis- oder Stadtverwaltung', ''),
		('2000', 'Wasser- und Bodenverband', ''),
		('2100', 'Umlegungsstelle', ''),
		('2200', 'Landesvermessungsverwaltung', 'Landesvermessungsverwaltung ist eine Fachstelle, die für die Aufgaben des amtlichen  Vermessungswesens, insbesondere für die Landesvermessung und des Liegenschaftskatasters in einem Bundesland zuständig ist.'),
		('2300', 'ÖbVI', ''),
		('2400', 'Bundeseisenbahnvermögen', ''),
		('2500', 'Landwirtschaftskammer', '');
		CREATE TABLE ax_administrative_funktion (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_administrative_funktion IS 'Alias: "AX_Administrative_Funktion", UML-Typ: Enumeration';
		INSERT INTO ax_administrative_funktion (wert,beschreibung,dokumentation) VALUES
		('1001', 'Bundesrepublik', ''),
		('2001', 'Land', ''),
		('2002', 'Freistaat', ''),
		('2003', 'Freie und Hansestadt', ''),
		('3001', 'Regierungsbezirk', ''),
		('3002', 'Freie Hansestadt', ''),
		('3003', 'Bezirk', ''),
		('3004', 'Stadt (Bremerhaven)', ''),
		('4001', 'Kreis', ''),
		('4002', 'Landkreis', ''),
		('4003', 'Kreisfreie Stadt', ''),
		('4007', 'Ursprünglich gemeindefreies Gebiet', ''),
		('4008', 'Ortsteil', ''),
		('4009', 'Region', ''),
		('5002', 'Verbandsfreie Gemeinde', ''),
		('5004', 'Große kreisangehörige Stadt', ''),
		('5006', 'Verwaltungsgemeinschaft', ''),
		('5007', 'Amt', ''),
		('5008', 'Samtgemeinde', ''),
		('5012', 'Gemeinde, die sich einer erfüllenden Gemeinde bedient', ''),
		('5013', 'Erfüllende Gemeinde', ''),
		('6001', 'Gemeinde', ''),
		('6002', 'Ortsgemeinde', ''),
		('6003', 'Stadt', ''),
		('6004', 'Kreisangehörige Stadt', ''),
		('6005', 'Große Kreisstadt', ''),
		('6006', 'Amtsangehörige Stadt', ''),
		('6007', 'Amtsangehörige Landgemeinde', ''),
		('6008', 'Amtsangehörige Gemeinde', ''),
		('6009', 'Kreisangehörige Gemeinde', ''),
		('6010', 'Mitgliedsgemeinde einer Verwaltungsgemeinschaft', ''),
		('6011', 'Mitgliedsgemeinde', ''),
		('6012', 'Markt', ''),
		('6013', 'Große kreisangehoerige Stadt', ''),
		('6014', 'Kreisangehörige Gemeinde, die die Bezeichnung Stadt führt', ''),
		('6015', 'Gemeindefreies Gebiet', ''),
		('7001', 'Gemeindeteil', ''),
		('7003', 'Gemarkung', ''),
		('7004', 'Stadtteil', ''),
		('7005', 'Stadtbezirk', ''),
		('7007', 'Ortsteil (Gemeinde)', ''),
		('8001', 'Kondominium', '');
		CREATE TABLE ax_bezeichnung_verwaltungsgemeinschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bezeichnung_verwaltungsgemeinschaft IS 'Alias: "AX_Bezeichnung_Verwaltungsgemeinschaft", UML-Typ: Enumeration';
		INSERT INTO ax_bezeichnung_verwaltungsgemeinschaft (wert,beschreibung,dokumentation) VALUES
		('1000', 'Samtgemeinde', 'Samtgemeinde umfasst in Niedersachsen das Gebiet einer Samtgemeinde.'),
		('2000', 'Verbandsgemeinde', 'Verbandsgemeinde umfasst in Rheinland-Pfalz das Gebiet einer Verbandsgemeinde, das aus benachbarten Gemeinden desselben Landkreises 
		gebildet wird.'),
		('3000', 'Amt', 'Amt umfasst das Gebiet eines Amtes, das aus Gemeinden desselben Landkreises besteht.'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_funktion_schutzgebietnachwasserrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_schutzgebietnachwasserrecht IS 'Alias: "AX_Funktion_SchutzgebietNachWasserrecht", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_schutzgebietnachwasserrecht (wert,beschreibung,dokumentation) VALUES
		('2111', 'Öffentliche Wasserversorgung', 'Öffentliche Wasserversorgung ist die Aufgabe eines Wasserschutzgebietes. Ziel ist es, die Gewässer der öffentlichen Wasserversorgung vor nachteiligen Einwirkungen zu schützen.'),
		('2112', 'Grundwasseranreicherung', 'Grundwasseranreicherung ist eine Methode, das Grundwasser durch Infiltration (Zugang von Wasser in die Erdrinde) in einem fest definierten Gebiet (Wasserschutzgebiet) anzureichern.'),
		('2113', 'Verhütung von schädlichem Abfluss', 'Verhütung von schädlichem Abfluss ist eine Aufgabe eines Wasserschutzgebietes. In diesem Gebiet soll das schädliche Abfließen von Niederschlagswasser sowie das Abschwemmen und der Eintrag von Bodenbestandteilen, Dünge- oder Pflanzenbehandlungsmitteln in Gewässer verhindert werden.');
		CREATE TABLE ax_artderfestlegung_schutzgebietnachnaturumweltoderbodensc (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_schutzgebietnachnaturumweltoderbodensc IS 'Alias: "AX_ArtDerFestlegung_SchutzgebietNachNaturUmweltOderBodenschutzrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_schutzgebietnachnaturumweltoderbodensc (wert,beschreibung,dokumentation) VALUES
		('1670', 'Nationalpark', 'Nationalpark ist ein rechtsverbindlich festgesetztes einheitlich zu schützendes Gebiet, das großräumig und von besonderer Eigenart ist, im überwiegenden Teil die Voraussetzungen eines Naturschutzgebietes erfüllt und sich in einem vom Menschen nicht oder nur wenig beeinflussten Zustand befindet.'),
		('1680', 'Lärmschutzbereich', ''),
		('1690', 'Biosphärenreservat', 'Biosphärenreservat ist ein rechtsverbindlich festgesetztes einheitlich zu schützendes und zu entwickelndes Gebiet, das 
		1. großräumig und für bestimmte Landschaftstypen charakteristisch ist, 
		2. in wesentlichen Teilen seines Gebietes die Voraussetzungen eines Naturschutzgebietes, im Übrigen überwiegend eines Landschaftsschutzgebietes erfüllt, 
		3. vornehmlich der Erhaltung, Entwicklung oder Wiederherstellung einer durch hergebrachte vielfältige Nutzung geprägten Landschaft und der darin historisch gewachsenen Arten- und Biotopvielfalt, einschließlich Wild- und frühere Kulturformen wirtschaftlich genutzter oder nutzbarer Tier- und Pflanzenarten dient und 
		4. beispielhaft der Entwicklung und Erprobung von Naturgütern besonders schonenden Wirtschaftsweise dient.');
		CREATE TABLE ax_artderfestlegung_anderefestlegungnachstrassenrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_anderefestlegungnachstrassenrecht IS 'Alias: "AX_ArtDerFestlegung_AndereFestlegungNachStrassenrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_anderefestlegungnachstrassenrecht (wert,beschreibung,dokumentation) VALUES
		('1210', 'Bundesfernstraßengesetz', ''),
		('1220', 'Anbauverbot', ''),
		('1230', 'Anbauverbot nach Bundesfernstraßengesetz', ''),
		('1231', 'Anbauverbot (40m)', ''),
		('1232', 'Anbauverbot (20m)', ''),
		('1240', 'Anbaubeschränkung', ''),
		('1241', 'Anbaubeschränkung (100m)', ''),
		('1242', 'Anbaubeschränkung (40m)', ''),
		('1250', 'Veränderungssperre nach Bundesfernstraßengesetz', ''),
		('1260', 'Landesstraßengesetz', ''),
		('1270', 'Anbauverbot nach Landesstraßengesetz', ''),
		('1280', 'Veränderungssperre', '');
		CREATE TABLE ax_artderfestlegung_schutzgebietnachwasserrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_schutzgebietnachwasserrecht IS 'Alias: "AX_ArtDerFestlegung_SchutzgebietNachWasserrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_schutzgebietnachwasserrecht (wert,beschreibung,dokumentation) VALUES
		('1510', 'Wasserschutzgebiet', 'Wasserschutzgebiet ist ein Schutzgebiet von Wassergewinnungsanlagen mit Nutzungsbeschränkungen, um ober- und unterirdisches Wasser vor Verunreinigungen zu schützen.'),
		('1520', 'Heilquellenschutzgebiet', 'Heilquellenschutzgebiet ist ein Schutzgebiet, in dem Handlungen untersagt sind, die den Bestand oder die Beschaffenheit der staatlich anerkannten Heilquellen gefährden.');
		CREATE TABLE ax_besonderefunktion_forstrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_besonderefunktion_forstrecht IS 'Alias: "AX_BesondereFunktion_Forstrecht", UML-Typ: Enumeration';
		INSERT INTO ax_besonderefunktion_forstrecht (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ohne besondere gesetzliche Bindung', ''),
		('1010', 'Ohne besondere gesetzliche Bindung nach LWaldG- Holzboden', ''),
		('2000', 'Schutzwald', ''),
		('2010', 'Schutzwald - Holzboden', ''),
		('3000', 'Erholungswald', ''),
		('3010', 'Erholungswald - Holzboden', ''),
		('4000', 'Bannwald', ''),
		('4010', 'Nationalpark - Holzboden', ''),
		('5010', 'Naturschutzgebiet - Holzboden', ''),
		('6000', 'Schutz- und Erholungswald', ''),
		('6010', 'Schutz- und Erholungswald - Holzboden', ''),
		('7010', 'Nationalpark - Nichtholzboden', ''),
		('8010', 'Naturschutzgebiet - Nichtholzboden', ''),
		('9000', 'Andere Forstbetriebsfläche', ''),
		('9010', 'Nichtholzboden', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_zone_schutzzone (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zone_schutzzone IS 'Alias: "AX_Zone_Schutzzone", UML-Typ: Enumeration';
		INSERT INTO ax_zone_schutzzone (wert,beschreibung,dokumentation) VALUES
		('1010', 'Zone I', 'Zone I ist eine räumlich begrenzte Fläche eines Schutzgebiets, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1020', 'Zone II', 'Zone II ist eine räumlich begrenzte Fläche eines Schutzgebiets, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1030', 'Zone III', 'Zone III ist eine räumlich begrenzte Fläche eines Schutzgebiets, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1031', 'Zone IIIa', 'Zone IIIa ist eine räumlich begrenzte Fläche eines Wasser- oder Heilquellenschutzgebietes, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1032', 'Zone IIIb', 'Zone IIIb ist eine räumlich begrenzte Fläche eines Wasser- oder Heilquellenschutzgebietes, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1040', 'Zone IV', 'Zone IV ist eine räumlich begrenzte Fläche eines Wasser- oder Heilquellenschutzgebietes, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1060', 'Kernzone', 'Kernzone ist eine räumlich begrenzte Fläche eines Biosphärenreservats, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1070', 'Pflegezone', 'Pflegezone ist eine räumlich begrenzte Fläche eines Biosphärenreservates, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1080', 'Entwicklungszone', 'Entwicklungszone ist eine räumlich begrenzte Fläche eines Biosphärenreservates, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('1090', 'Regenerationszone', 'Regenerationszone ist eine räumlich begrenzte Fläche eines Biosphärenreservates, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.'),
		('9997', 'Attribut trifft nicht zu', 'Attribut trifft nicht zu bedeutet, dass keiner der in der Werteliste aufgeführten Attributwerte dem vorliegenden Sachverhalt entspricht.');
		CREATE TABLE ax_artderfestlegung_klassifizierungnachstrassenrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_klassifizierungnachstrassenrecht IS 'Alias: "AX_ArtDerFestlegung_KlassifizierungNachStrassenrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_klassifizierungnachstrassenrecht (wert,beschreibung,dokumentation) VALUES
		('1100', 'Klassifizierung nach Bundes- oder Landesstraßengesetz', ''),
		('1110', 'Bundesautobahn', ''),
		('1120', 'Bundesstraße', ''),
		('1130', 'Landes- oder Staatsstraße', ''),
		('1140', 'Kreisstraße', ''),
		('1150', 'Gemeindestraße', ''),
		('1160', 'Ortsstraße', ''),
		('1170', 'Gemeindeverbindungsstraße', ''),
		('1180', 'Sonstige öffentliche Straße', ''),
		('1190', 'Privatstraße', '');
		CREATE TABLE ax_artderfestlegung_denkmalschutzrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_denkmalschutzrecht IS 'Alias: "AX_ArtDerFestlegung_Denkmalschutzrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_denkmalschutzrecht (wert,beschreibung,dokumentation) VALUES
		('2700', 'Kulturdenkmal', ''),
		('2710', 'Bau- und Kunstdenkmal nach Landesdenkmalschutzgesetz', ''),
		('2711', 'Baudenkmal', 'Baudenkmal ist eine bauliche Anlage, an deren Erhaltung wegen ihrer geschichtlichen Bedeutung ein öffentliches Interesse besteht.'),
		('2712', 'Kunstdenkmal', ''),
		('2713', 'Gartendenkmal', ''),
		('2800', 'Archäologisches Denkmal (auch Bodendenkmal) nach Landesdenkmalschutzgesetz', ''),
		('2810', 'Archäologisches Denkmal', 'Archäologisches Denkmal ist ein Ort, an dem Reste vor-  oder frühgeschichtlicher Kulturen oder früheren menschlichen Wirkens entdeckt wurden.'),
		('2820', 'Bodendenkmal', 'Bodendenkmal ist eine mit dem Boden verbundene oder im Boden verborgene Sache, die von Menschen geschaffen oder bearbeitet wurde oder Aufschluss über menschliches Leben in vergangenen Zeiten gibt und deshalb erhaltenswert ist.'),
		('2900', 'Schutzgebiet oder -bereiche nach Landesdenkmalschutzgesetz', ''),
		('2910', 'Denkmalzone oder -bereich', ''),
		('2920', 'Geschützter Baubereich', ''),
		('2930', 'Grabungsschutzgebiet', ''),
		('3100', 'Befestigungen', ''),
		('3110', 'Befestigung (Burg)', 'Befestigung (Burg) ist eine Anlage zum Schutz der Menschen vor äußerer Bedrohung.'),
		('3111', 'Burg (Fliehburg, Ringwall)', 'Burg (Fliehburg, Ringwall) ist eine ur- oder frühgeschichtliche runde, ovale oder an Gegebenheiten des Geländes (Böschungskanten) angepasste Befestigungsanlage, die aus einem Erdwall mit oder ohne Holzeinbauten besteht.'),
		('3112', 'Erdwerk', ''),
		('3113', 'Ringwall', ''),
		('3114', 'Steinwerk', ''),
		('3115', 'Festung', ''),
		('3116', 'Gräftenanlage', ''),
		('3117', 'Schanze', 'Schanze ist eine mittelalterliche oder neuzeitliche, in der Regel geschlossene, quadratische, rechteckige oder sternförmige Wallanlage mit Außengraben.'),
		('3118', 'Lager', 'Lager ist die Bezeichnung für ein befestigtes Truppenlager in der Römer- oder in der Neuzeit (z.B. bei Belagerungen im 30 jährigen Krieg).'),
		('3120', 'Wachturm (römisch), Warte', 'Wachtturm (römisch), Warte ist ein allein oder in Verbindung mit einem Befestigungssystem (Limes) stehender Beobachtungsturm.'),
		('3121', 'Wachturm', ''),
		('3122', 'Warte', ''),
		('3130', 'Befestigung (Wall, Graben)', 'Befestigung (Wall, Graben) ist ein aus Erde aufgeschütteter Grenz-, Schutz- oder Stadtwall. Zu der Befestigung (Wall) zählen auch Limes und Landwehr.'),
		('3131', 'Grenzwall, Schutzwall', 'Grenzwall, Schutzwall ist ein aus Erde aufgeschütteter Wall.'),
		('3132', 'Limes', ''),
		('3133', 'Landwehr', 'Landwehr ist eine mittelalterliche Verteidigungslinie aus ein- bis mehrfachem Wallgrabensystem.'),
		('3134', 'Stadtwall', ''),
		('3135', 'Historischer Wall', ''),
		('3200', 'Historische Siedlung', 'Historische Siedlung ist eine Stelle, an der sich eine ur- oder frühgeschichtliche Siedlung befunden hat.'),
		('3210', 'Pfahlbau', 'Pfahlbau ist ein auf eingerammte Pfähle gestelltes, frei über dem Untergrund (Wasser oder Land) stehendes Gebäude.'),
		('3220', 'Wüstung', ''),
		('3230', 'Wurt', ''),
		('3240', 'Abri', ''),
		('3250', 'Höhle', ''),
		('3300', 'Historische Bestattung', ''),
		('3310', 'Großsteingrab (Dolmen, Hünenbett)', 'Großsteingrab (Dolmen, Hünenbett) ist ein Grab mit Steineinbau, d.h. es ist ein aus großen Steinen (z.B. Findlingen) errichteter Grabbau.'),
		('3320', 'Grabhügel (Hügelgrab)', 'Grabhügel (Hügelgrab) ist ein meist runder oder ovaler Hügel, der über einer ur- oder frühgeschichtlichen Bestattung aus Erde aufgeschüttet oder aus Plaggen aufgeschichtet wurde.'),
		('3330', 'Grabhügelfeld', 'Grabhügelfeld ist eine abgegrenzte Fläche, auf der sich mehrere Grabhügel befinden.'),
		('3340', 'Urnenfriedhof', ''),
		('3350', 'Körpergräberfeld', ''),
		('3360', 'Reihengräberfriedhof', ''),
		('3400', 'Historisches land- oder forstwirtschaftliches Objekt', ''),
		('3410', 'Historischer Pflanzkamp', ''),
		('3420', 'Historisches Viehgehege', ''),
		('3430', 'Sandfang', ''),
		('3440', 'Historisches Ackersystem', ''),
		('3500', 'Historische Bergbau-, Verhüttungs- oder sonstige Produktionsstätte', ''),
		('3510', 'Historisches Bergbaurelikt', ''),
		('3520', 'Historischer Meiler', ''),
		('3530', 'Historischer Ofen', ''),
		('3540', 'Historischer Verhüttungsplatz', ''),
		('3600', 'Historische Straße oder Weg', ''),
		('3610', 'Heerstraße', ''),
		('3620', 'Hohlweg', ''),
		('3630', 'Moorweg', ''),
		('3640', 'Wegespur', ''),
		('3700', 'Historisches wasserwirtschaftliches Objekt', ''),
		('3710', 'Historische Wasserleitung', 'Historische Wasserleitung ist ein meist offenes System von Gräben, Kunstgräben und Kanälen, in dem Wasser transportiert wird.'),
		('3720', 'Aquädukt', 'Aquädukt ist ein brückenartiges Steinbauwerk zur Überführung von Freispiegel-Wasserleitungen mit natürlichem Gefälle über Täler oder andere Bodenunebenheiten.'),
		('3730', 'Historischer Deich', ''),
		('3740', 'Historischer Damm', ''),
		('3750', 'Historischer Graben', ''),
		('3800', 'Steinmal', 'Steinmal ist eine kultische oder rechtliche Kennzeichnung, bestehend aus einzelnen oder Gruppen von Steinen.'),
		('3810', 'Schalenstein', ''),
		('3820', 'Rillenstein', ''),
		('3830', 'Wetzrillen', ''),
		('3840', 'Kreuzstein', ''),
		('3850', 'Historischer Grenzstein', ''),
		('3860', 'Menhir', '');
		CREATE TABLE ax_artderfestlegung_klassifizierungnachwasserrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_klassifizierungnachwasserrecht IS 'Alias: "AX_ArtDerFestlegung_KlassifizierungNachWasserrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_klassifizierungnachwasserrecht (wert,beschreibung,dokumentation) VALUES
		('1300', 'Klassifizierung nach Bundes- oder Landeswassergesetz', ''),
		('1310', 'Gewässer I. Ordnung - Bundeswasserstraße', ''),
		('1320', 'Gewässer I. Ordnung - nach Landesrecht', ''),
		('1330', 'Gewässer II. Ordnung', ''),
		('1340', 'Gewässer III. Ordnung', '');
		CREATE TABLE ax_rechtszustand_schutzzone (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_rechtszustand_schutzzone IS 'Alias: "AX_Rechtszustand_Schutzzone", UML-Typ: Enumeration';
		INSERT INTO ax_rechtszustand_schutzzone (wert,beschreibung,dokumentation) VALUES
		('1000', 'Amtlich festgestellt', 'Amtlich festgestellt bedeutet, dass der Zustand von Schutzzone durch einen Verwaltungsstelle festgelegt wird.'),
		('2000', 'Im Verfahren befindlich', 'Im Verfahren befindlich bedeutet, dass das Genehmigungsverfahren für die Festlegung eines Wasserschutz-, Heilquellenschutzgebietes begonnen aber noch nicht abgeschlossen ist.'),
		('3000', 'In Planung', 'In Planung bedeutet, dass ein Wasserschutz-, Heilquellenschutzgebiet geplant ist, aber das Genehmigungsverfahren noch nicht begonnen hat.');
		CREATE TABLE ax_artderfestlegung_bauraumoderbodenordnungsrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_bauraumoderbodenordnungsrecht IS 'Alias: "AX_ArtDerFestlegung_BauRaumOderBodenordnungsrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_bauraumoderbodenordnungsrecht (wert,beschreibung,dokumentation) VALUES
		('1700', 'Festlegung nach Baugesetzbuch - Allgemeines Städtebaurecht', ''),
		('1710', 'Bebauungsplan', ''),
		('1720', 'Veränderungssperre nach Baugesetzbuch', ''),
		('1730', 'Vorkaufrechtssatzung', ''),
		('1740', 'Enteignungsverfahren', ''),
		('1750', 'Umlegung nach dem BauGB', ''),
		('1760', 'Bauland', ''),
		('1770', 'Vereinfachte Umlegung', ''),
		('1780', 'Vorhaben- und Erschließungsplan', ''),
		('1790', 'Flächennutzungsplan', ''),
		('1800', 'Festlegung nach Baugesetzbuch - Besonderes Städtebaurecht', ''),
		('1810', 'Städtebauliche Entwicklungsmaßnahme', ''),
		('1811', 'Städtebauliche Entwicklungsmaßnahme (Beschluss zu vorbereitenden Untersuchungen gefasst)', ''),
		('1820', 'Erhaltungssatzung', ''),
		('1821', 'Städtebauliches Erhaltungsgebiet', ''),
		('1822', 'Soziales Erhaltungsgebiet', ''),
		('1823', 'Erhaltungsgebiet zur städtebaulichen Umstrukturierung', ''),
		('1824', 'Soziales Erhaltungsgebiet (Aufstellungsbeschluss gefasst)', ''),
		('1830', 'Städtebauliche Gebote', ''),
		('1840', 'Sanierung', ''),
		('1841', 'Sanierung (Beschluss zu vorbereitenden Untersuchungen gefasst)', ''),
		('1900', 'Wohnungsbauerleichterungsgesetz', ''),
		('2100', 'Flurbereinigungsgesetz', ''),
		('2110', 'Flurbereinigung (Par. 1, 37 FlurbG)', ''),
		('2120', 'Vereinfachtes Flurbereinigungsverfahren (Par. 86 FlurbG)', ''),
		('2130', 'Unternehmensflurbereinigung (nach Par. 87 oder 90 FlurbG)', ''),
		('2140', 'Beschleunigtes Zusammenlegungsverfahren (Par. 91 FlurbG)', ''),
		('2150', 'Freiwilliger Landtausch (Par. 103a FlurbG)', ''),
		('2160', 'Verfahren nach dem Gemeinheitsteilungsgesetz', ''),
		('2170', 'Verfahren nach dem Gemeinschaftswaldgesetz', ''),
		('2180', 'Freiwilliger Nutzungstausch', ''),
		('2200', 'Verfahren nach dem Landwirtschaftsanpassungsgesetz', ''),
		('2210', 'Flurneuordnung', ''),
		('2220', 'Freiwilliger Landtausch (Par. 54 LwAnpG)', ''),
		('2230', 'Bodenordnungsverfahren (Par. 56 LwAnpG)', ''),
		('2240', 'Zusammenführung von Boden- und Gebäudeeigentum (Par. 64 LwAnpG)', ''),
		('2300', 'Bodensonderungsgesetz', ''),
		('2310', 'Unvermessenes Eigentum', ''),
		('2320', 'Unvermessenes Nutzungsrecht', ''),
		('2330', 'Ergänzende Bodenneuordnung', ''),
		('2340', 'Komplexe Bodenneuordnung', ''),
		('2400', 'Vermögenszuordnungsgesetz', ''),
		('2410', 'Vermögenszuordnung nach Plan', ''),
		('2411', 'Vermögenszuordnung nach dem Aufteilungsplan', ''),
		('2412', 'Vermögenszuordnung nach dem Zuordnungsplan', ''),
		('2500', 'Landesraumordnungsgesetz', ''),
		('2510', 'Wasservorranggebiete', ''),
		('2600', 'Bauordnung', ''),
		('2610', 'Baulast', ''),
		('2611', 'Begünstigende Baulast', ''),
		('2612', 'Belastende Baulast', ''),
		('2700', 'Grenzfeststellungsverfahren nach Hamb. Wassergesetz', ''),
		('2800', 'Verkehrsflächenbereinigung', '');
		CREATE TABLE ax_artderfestlegung_anderefestlegungnachwasserrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_anderefestlegungnachwasserrecht IS 'Alias: "AX_ArtDerFestlegung_AndereFestlegungNachWasserrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_anderefestlegungnachwasserrecht (wert,beschreibung,dokumentation) VALUES
		('1410', 'Wasserstraßengesetz', ''),
		('1420', 'Veränderungssperre', ''),
		('1421', 'Veränderungssperre nach Bundeswasserstraßengesetz', ''),
		('1430', 'Landeswassergesetz', ''),
		('1440', 'Überschwemmungsgebiet', 'Überschwemmungsgebiet ist ein durch Rechtsverordnung festgesetztes oder natürliches Gebiet, das bei Hochwasser überschwemmt werden kann bzw. überschwemmt wird.'),
		('1441', 'Festgesetztes Überschwemmungsgebiet', 'Festgesetztes Überschwemmungsgebiet ist ein zur Sicherung des schadlosen Hochwasserabflusses durch Rechtsverordnung festgesetztes Gebiet.'),
		('1442', 'Natürliches Überschwemmungsgebiet', 'Natürliches Überschwemmungsgebiet ist ein Gebiet, das bei Hochwasser überschwemmt wird.'),
		('1450', 'Pegelschutzgebiet', ''),
		('1460', 'Wasser- und Bodenverbandsgebiet', ''),
		('1470', 'Deichgebiet', ''),
		('1480', 'Unterhaltungsverbandsgebiet', '');
		CREATE TABLE ax_artderfestlegung_forstrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_forstrecht IS 'Alias: "AX_ArtDerFestlegung_Forstrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_forstrecht (wert,beschreibung,dokumentation) VALUES
		('3900', 'Klassifizierung nach Bundes- oder Landeswaldgesetz', ''),
		('3910', 'Staatswald Bund', ''),
		('3920', 'Staatswald Land', ''),
		('3930', 'Kommunalwald', ''),
		('3940', 'Anstalts- und Stiftungswald', ''),
		('3950', 'Anderer öffentlicher Wald', ''),
		('3960', 'Privater Gemeinschaftswald', ''),
		('3970', 'Großprivatwald', ''),
		('3980', 'Kleinprivatwald', ''),
		('3990', 'Anderer Privatwald', '');
		CREATE TABLE ax_zustand_naturumweltoderbodenschutzrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_naturumweltoderbodenschutzrecht IS 'Alias: "AX_Zustand_NaturUmweltOderBodenschutzrecht", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_naturumweltoderbodenschutzrecht (wert,beschreibung,dokumentation) VALUES
		('1000', 'Amtlich festgestellt', 'Amtlich festgestellt bedeutet, dass der Zustand für eine dem Natur-, Umwelt- oder Bodenschutzrecht unterliegende Fläche durch eine Verwaltungsstelle festgelegt wird.'),
		('2000', 'Einstweilig sicher gestellt', 'Einstweilig sicher gestellt bedeutet, dass durch die zuständige Fachbehörde eine dem Natur-, Umwelt- oder Bodenschutzrecht unterliegende Fläche eine Veränderungssperre erlassen wurde.');
		CREATE TABLE ax_artderfestlegung_sonstigesrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_sonstigesrecht IS 'Alias: "AX_ArtDerFestlegung_SonstigesRecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_sonstigesrecht (wert,beschreibung,dokumentation) VALUES
		('4100', 'Luftverkehrsgesetz', ''),
		('4110', 'Bauschutzbereich', ''),
		('4120', 'Beschränkter Bauschutzbereich', ''),
		('4200', 'Bundeskleingartengesetz', ''),
		('4210', 'Dauerkleingarten', ''),
		('4300', 'Berggesetz', ''),
		('4301', 'Bodenbewegungsgebiet', 'Bodenbewegungsgebiet ist ein Gebiet, in dem sich die oberen Erdschichten auf Grund verschiedener Einflüsse (z.B. geologische Kräfte, Bergbau) lage- oder höhenmäßig verändern.'),
		('4302', 'Bruchfeld', 'Bruchfeld ist ein durch Bergbau unterhöhltes Gebiet, das teilweise bereits eingebrochen ist oder sich in Absenkung befindet.'),
		('4310', 'Baubeschränkung', ''),
		('4400', 'Reichsheimstättengesetz', ''),
		('4410', 'Reichsheimstätte', ''),
		('4500', 'Schutzbereichsgesetz', ''),
		('4510', 'Schutzbereich', ''),
		('4600', 'Eisenbahnneuordnungsgesetz', ''),
		('4610', 'Übergabebescheidverfahren', ''),
		('4710', 'Baubeschränkungen durch Richtfunkverbindungen', ''),
		('4720', 'Truppenübungsplatz, Standortübungsplatz', 'Truppenübungsplatz, Standortübungsplatz ist ein Gelände zur militärischen Ausbildung.'),
		('4800', 'Vermessungs- und Katasterrecht', ''),
		('4810', 'Schutzfläche Festpunkt', ''),
		('4811', 'Schutzfläche Festpunkt, 1 m Radius', ''),
		('4812', 'Schutzfläche Festpunkt, 2 m Radius', ''),
		('4813', 'Schutzfläche Festpunkt, 5 m Radius', ''),
		('4814', 'Schutzfläche Festpunkt, 10 m Radius', ''),
		('4815', 'Schutzfläche Festpunkt, 30 m Radius', ''),
		('4820', 'Marksteinschutzfläche', ''),
		('4830', 'Liegenschaftskatastererneuerung', ''),
		('4900', 'Fischereirecht', ''),
		('5100', 'Jagdkataster', ''),
		('5200', 'Landesgrundbesitzkataster', ''),
		('5300', 'Bombenblindgängerverdacht', ''),
		('5400', 'Rieselfeld', 'Rieselfeld ist eine Fläche, auf der organisch verunreinigtes Wasser zum Zwecke der biologischen Reinigung verrieselt wird.'),
		('5500', 'Sicherungsstreifen', ''),
		('5600', 'Grenzbereinigung', ''),
		('5700', 'Hochwasserdeich', 'Hochwasserdeich ist die Eigenschaft (Widmung) eines Deiches, die durch die obere Deichbehörde festgelegt wird.'),
		('5710', 'Hauptdeich, 1. Deichlinie', 'Hauptdeich, 1. Deichlinie ist die Eigenschaft (Widmung) eines Deiches, die durch die obere Deichbehörde festgelegt wird.'),
		('5720', '2. Deichlinie', '2. Deichlinie ist die Eigenschaft (Widmung) eines Deiches, die durch die obere Deichbehörde festgelegt wird.'),
		('6000', 'Beregnungsverband', ''),
		('7000', 'Weinlage', ''),
		('7100', 'Weinbausteillage', ''),
		('7200', 'Weinbergsrolle', ''),
		('7300', 'Weinbausteilstlage', ''),
		('8000', 'Benachteiligtes landwirtschaftliches Gebiet', ''),
		('9100', 'Mitverwendung Hochwasserschutz, Oberirdische Anlagen', ''),
		('9200', 'Mitverwendung Hochwasserschutz, Unterirdische Anlagen', ''),
		('9300', 'Hafennutzungsgebiet', ''),
		('9400', 'Hafenerweiterungsgebiet', ''),
		('9450', 'Hafenbecken', 'Hafenbecken ist ein rechtlich definierter Teil eines Gewässers, in dem Schiffe be- und entladen werden'),
		('9500', 'Bohrung verfüllt', ''),
		('9600', 'Zollgrenze', ''),
		('9700', 'Belastung nach §7 Abs. 2 GBO', ''),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass Art der Festlegung bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_artderfestlegung_naturumweltoderbodenschutzrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderfestlegung_naturumweltoderbodenschutzrecht IS 'Alias: "AX_ArtDerFestlegung_NaturUmweltOderBodenschutzrecht", UML-Typ: Enumeration';
		INSERT INTO ax_artderfestlegung_naturumweltoderbodenschutzrecht (wert,beschreibung,dokumentation) VALUES
		('1610', 'Schutzfläche nach Europarecht', ''),
		('1611', 'Flora-Fauna-Habitat-Gebiet', 'Flora-Fauna-Habitat-Gebiet ist ein Schutzgebiet von gemeinschaftlicher Bedeutung im Sinne der Richtlinie 92/43/EWG des Rates der Europäischen Wirtschaftsgemeinschaft zur Erhaltung der natürlichen Lebensräume sowie der wildlebenden Pflanzen und Tiere.'),
		('1612', 'Vogelschutzgebiet', 'Vogelschutzgebiet ist ein besonderes Schutzgebiet (Special Protected Area, SPA) im Sinne Artikel 4 Abs. 1 der Richtlinie 79/409/EWG des Rates der Europäischen Wirtschaftsgemeinschaft über die Erhaltung der wildlebenden Vogelarten (Vogelschutzrichtlinie).'),
		('1620', 'Schutzflächen nach Landesnaturschutzgesetz', ''),
		('1621', 'Naturschutzgebiet', 'Naturschutzgebiet ist ein rechtsverbindlich festgesetztes Gebiet, in dem ein besonderer Schutz von Natur und Landschaft in ihrer Ganzheit oder in einzelnen Teilen zur Erhaltung von Lebensgemeinschaften oder Biotopen bestimmter wildlebender Tier- und Pflanzenarten, aus wissenschaftlichen, naturgeschichtlichen oder landeskundlichen Gründen oder wegen ihrer Seltenheit, besonderen Eigenart oder hervorragenden Schönheit erforderlich ist.'),
		('1622', 'Geschützter Landschaftsbestandteil', 'Geschützter Landschaftsbestandteil ist ein rechtsverbindlich festgesetzter Teil von Natur und Landschaft, dessen besonderer Schutz zur Sicherstellung der Leistungsfähigkeit des Naturhaushalts, zur Belebung, Gliederung oder Pflege des Orts- und Landschaftsbildes oder zur Abwehr schädlicher Einwirkungen erforderlich ist.'),
		('1623', 'Landschaftsschutzgebiet', 'Landschaftsschutzgebiet ist ein rechtsverbindlich festgesetztes Gebiet, in dem ein besonderer Schutz von Natur und Landschaft zur Erhaltung oder Wiederherstellung der Leistungsfähigkeit des Naturhaushalts oder der Nutzungsfähigkeit der Naturgüter, wegen der Vielfalt, Eigenart oder Schönheit des Landschaftsbildes oder wegen der besonderen Bedeutung für die Erholung erforderlich ist.'),
		('1624', 'Naturpark', 'Naturpark ist ein einheitlich zu entwickelndes und zu pflegendes Gebiet, das großräumig ist, überwiegend Landschaftsschutzgebiet oder Naturschutzgebiet ist, sich wegen seiner landschaftlichen Voraussetzungen für die Erholung besonders eignet und nach den Grundsätzen und Zielen der Raumordnung und der Landesplanung für die Erholung oder den Fremdenverkehr vorgesehen ist.'),
		('1630', 'Bundesbodenschutzgesetz', ''),
		('1631', 'Verdachtsfläche auf schädliche Bodenveränderung', ''),
		('1632', 'Schädliche Bodenveränderung', ''),
		('1633', 'Altlastenverdächtige Fläche', ''),
		('1634', 'Altlast', ''),
		('1640', 'Bundesimmisionsschutzgesetz', ''),
		('1641', 'Belastungsgebiet', ''),
		('1642', 'Schutzbedürftiges Gebiet', ''),
		('1643', 'Gefährdetes Gebiet', ''),
		('1650', 'Naturschutzgesetz', ''),
		('1651', 'Besonders geschütztes Biotop', ''),
		('1652', 'Besonders geschütztes Feuchtgrünland', ''),
		('1653', 'Naturdenkmal', 'Naturdenkmal ist eine rechtsverbindlich festgesetzte Einzelschöpfung der Natur, deren besonderer Schutz erforderlich ist (z.B. Baum).'),
		('1654', 'Einstweilige Sicherstellung, Veränderungssperre', ''),
		('1655', 'Vorkaufsrecht', ''),
		('1656', 'Ausgleichs- oder Kompensationsfläche', ''),
		('1660', 'Bodenschutzgesetz', ''),
		('1661', 'Dauerbeobachtungsflächen', ''),
		('1662', 'Bodenschutzgebiet', '');
		CREATE TABLE ax_liniendarstellung_topographischelinie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_liniendarstellung_topographischelinie IS 'Alias: "AX_Liniendarstellung_TopographischeLinie", UML-Typ: Enumeration';
		INSERT INTO ax_liniendarstellung_topographischelinie (wert,beschreibung,dokumentation) VALUES
		('1000', 'Durchgezogen', ''),
		('2000', 'Lang gestrichelt', ''),
		('3000', 'Kurz gestrichelt', '');
		CREATE TABLE ax_darstellung_gebaeudeausgestaltung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_darstellung_gebaeudeausgestaltung IS 'Alias: "AX_Darstellung_Gebaeudeausgestaltung", UML-Typ: Enumeration';
		INSERT INTO ax_darstellung_gebaeudeausgestaltung (wert,beschreibung,dokumentation) VALUES
		('0251', 'Topographische Begrenzungslinie', ''),
		('0252', 'Überdeckte topographische Begrenzungslinie', ''),
		('1011', 'Hochhausbegrenzungslinie', ''),
		('1012', 'Begrenzungslinie eines öffentlichen Gebäudes', ''),
		('1013', 'Begrenzungslinie eines nicht öffentlichen Gebäudes', ''),
		('1014', 'Offene Begrenzungslinie eines Gebäudes', ''),
		('1016', 'Begrenzungslinie eines unterirdischen Gebäudes', ''),
		('1041', 'Durchfahrt im Gebäude', ''),
		('1042', 'Durchfahrt an überbauter Straße', ''),
		('1043', 'Arkade', ''),
		('1044', 'Freitreppe', ''),
		('1045', 'Überdachung', ''),
		('1046', 'Aufgeständertes Gebäude', ''),
		('1047', 'Begrenzungslinie auskragendes Geschoss, aufgehendes Mauerwerk', ''),
		('1048', 'Rampe', '');
		CREATE TABLE ax_datenformat_benutzer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_datenformat_benutzer IS 'Alias: "AX_Datenformat_Benutzer", UML-Typ: Enumeration';
		INSERT INTO ax_datenformat_benutzer (wert,beschreibung,dokumentation) VALUES
		('1000', 'NAS', ''),
		('2000', 'DXF', ''),
		('3000', 'TIFF', ''),
		('4000', 'GeoTIFF', '');
		CREATE TABLE ax_art_bereichzeitlich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_bereichzeitlich IS 'Alias: "AX_Art_BereichZeitlich", UML-Typ: Enumeration';
		INSERT INTO ax_art_bereichzeitlich (wert,beschreibung,dokumentation) VALUES
		('1000', 'Stichtagsbezogen ohne Historie', ''),
		('1100', 'Stichtagsbezogen mit Historie', ''),
		('3000', 'Fallbezogen ohne Historie', ''),
		('3100', 'Fallbezogen mit Historie', '');
		CREATE TABLE ax_letzteabgabeart (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_letzteabgabeart IS 'Alias: "AX_LetzteAbgabeArt", UML-Typ: Enumeration';
		INSERT INTO ax_letzteabgabeart (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zeitintervall', 'Standardabgabe: LAZ + Abgabeintervall'),
		('1100', 'NBA auf Abruf', 'Zwischenabgabe: LAZ bis heute.'),
		('2000', 'Wiederholungslauf', 'Identische Wiederholung des fehlerhaften Laufs: VAZ bis LAZ.'),
		('2100', 'Aufholungslauf auf Abruf', 'Wiederholungslauf zuzüglich der Änderungsdaten bis heute: VAZ bis heute.'),
		('2200', 'Aufholungslauf bis Intervallende', 'Zusammenfassung mehrerer Abgabeintervalle: VAZ bis Intervallende nach heute.');
		CREATE TABLE ax_ausgabemedium_benutzer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_ausgabemedium_benutzer IS 'Alias: "AX_Ausgabemedium_Benutzer", UML-Typ: Enumeration';
		INSERT INTO ax_ausgabemedium_benutzer (wert,beschreibung,dokumentation) VALUES
		('1000', 'Analog', ''),
		('2000', 'CD-R', ''),
		('3000', 'DVD', ''),
		('4000', 'E-Mail', '');
		CREATE TABLE ax_identifikation (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_identifikation IS 'Alias: "AX_Identifikation", UML-Typ: Enumeration';
		INSERT INTO ax_identifikation (wert,beschreibung,dokumentation) VALUES
		('5400', 'Sicher', ''),
		('5410', 'Unsicher', '');
		CREATE TABLE ax_dqerfassungsmethodemarkantergelaendepunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dqerfassungsmethodemarkantergelaendepunkt IS 'Alias: "AX_DQErfassungsmethodeMarkanterGelaendepunkt", UML-Typ: Enumeration';
		INSERT INTO ax_dqerfassungsmethodemarkantergelaendepunkt (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5010', 'Interaktive photogrammetrische Datenerfassung', ''),
		('5020', 'Laserscanning', ''),
		('5030', 'Digitalisierung analoger Vorlagen', '');
		CREATE TABLE ax_dqerfassungsmethodestrukturiertegelaendepunkte (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dqerfassungsmethodestrukturiertegelaendepunkte IS 'Alias: "AX_DQErfassungsmethodeStrukturierteGelaendepunkte", UML-Typ: Enumeration';
		INSERT INTO ax_dqerfassungsmethodestrukturiertegelaendepunkte (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5010', 'Interaktive photogrammetrische Datenerfassung', ''),
		('5030', 'Digitalisierung analoger Vorlagen', '');
		CREATE TABLE ax_dqerfassungsmethode (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dqerfassungsmethode IS 'Alias: "AX_DQErfassungsmethode", UML-Typ: Enumeration';
		INSERT INTO ax_dqerfassungsmethode (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5010', 'Interaktive photogrammetrische Datenerfassung', ''),
		('5020', 'Laserscanning', ''),
		('5030', 'Digitalisierung analoger Vorlagen', ''),
		('5040', 'Bildkorrelation', ''),
		('5050', 'IfSAR', '');
		CREATE TABLE ax_besonderebedeutung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_besonderebedeutung IS 'Alias: "AX_BesondereBedeutung", UML-Typ: Enumeration';
		INSERT INTO ax_besonderebedeutung (wert,beschreibung,dokumentation) VALUES
		('1600', 'Höhenpunkt auf Wasserfläche', ''),
		('1610', 'Wegepunkt', '');
		CREATE TABLE ax_dqerfassungsmethodebesondererhoehenpunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dqerfassungsmethodebesondererhoehenpunkt IS 'Alias: "AX_DQErfassungsmethodeBesondererHoehenpunkt", UML-Typ: Enumeration';
		INSERT INTO ax_dqerfassungsmethodebesondererhoehenpunkt (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5010', 'Interaktive photogrammetrische Aufnahme', ''),
		('5020', 'Laserscanning', ''),
		('5030', 'Digitalisierung analoger Vorlagen', ''),
		('5060', 'Amtliche Festlegung', '');
		CREATE TABLE ax_artdergeripplinie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdergeripplinie IS 'Alias: "AX_ArtDerGeripplinie", UML-Typ: Enumeration';
		INSERT INTO ax_artdergeripplinie (wert,beschreibung,dokumentation) VALUES
		('1300', 'Muldenlinie', ''),
		('1310', 'Wasserführende Muldenlinie', ''),
		('1320', 'Rückenlinie', '');
		CREATE TABLE ax_artdergelaendekante (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdergelaendekante IS 'Alias: "AX_ArtDerGelaendekante", UML-Typ: Enumeration';
		INSERT INTO ax_artdergelaendekante (wert,beschreibung,dokumentation) VALUES
		('1200', 'Allgemeine Geländekante', 'Allgemeine Geländekante ist die einzelne Kante unterschiedlich geneigter Geländeflächen und keine Obergruppe anderer Geländekanten.'),
		('1210', 'Steilrand, Kliffkante', 'Steilrand, Kliffkante begrenzt den von der Brandung beständig abgetragenen Steilhang einer Küste.'),
		('1220', 'Böschungsoberkante', 'Böschungsoberkante ist der eindeutig identifizierbare Geländeknick an der oberen Kante einer Böschung.'),
		('1230', 'Böschungsunterkante', 'Böschungsunterkante ist der eindeutig identifizierbare Geländeknick an der unteren Kante einer Böschung.'),
		('1240', 'Sonstige Begrenzungskante', 'Sonstige Begrenzungskante sind alle Kanten, die nicht anderen Kanten zugeordnet werden können (z.B. Trennschraffe).');
		CREATE TABLE ax_artderstrukturierung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderstrukturierung IS 'Alias: "AX_ArtDerStrukturierung", UML-Typ: Enumeration';
		INSERT INTO ax_artderstrukturierung (wert,beschreibung,dokumentation) VALUES
		('1700', 'Höhenlinien', ''),
		('1710', 'Dynamisch gemessene Profile', '');
		CREATE TABLE ax_dqerfassungsmethodegewaesserbegrenzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dqerfassungsmethodegewaesserbegrenzung IS 'Alias: "AX_DQErfassungsmethodeGewaesserbegrenzung", UML-Typ: Enumeration';
		INSERT INTO ax_dqerfassungsmethodegewaesserbegrenzung (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5010', 'Interaktive photogrammetrische Datenerfassung', ''),
		('5020', 'Laserscanning', ''),
		('5030', 'Digitalisierung analoger Vorlagen', ''),
		('5040', 'Bildkorrelation', ''),
		('5050', 'IfSAR', ''),
		('5060', 'Amtliche Festlegung', '');
		CREATE TABLE ax_artdernichtgelaendepunkte (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdernichtgelaendepunkte IS 'Alias: "AX_ArtDerNichtGelaendepunkte", UML-Typ: Enumeration';
		INSERT INTO ax_artdernichtgelaendepunkte (wert,beschreibung,dokumentation) VALUES
		('1000', 'Brückenpunkte', ''),
		('1010', 'Gebäudepunkte', ''),
		('1020', 'Vegetationspunkte', '');
		CREATE TABLE ax_artdesmarkantengelaendepunktes (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artdesmarkantengelaendepunktes IS 'Alias: "AX_ArtDesMarkantenGelaendepunktes", UML-Typ: Enumeration';
		INSERT INTO ax_artdesmarkantengelaendepunktes (wert,beschreibung,dokumentation) VALUES
		('1400', 'Kuppenpunkt', ''),
		('1410', 'Kesselpunkt', ''),
		('1420', 'Sattelpunkt', '');
		CREATE TABLE ax_artderaussparung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderaussparung IS 'Alias: "AX_ArtDerAussparung", UML-Typ: Enumeration';
		INSERT INTO ax_artderaussparung (wert,beschreibung,dokumentation) VALUES
		('1500', 'DGM-Aussparung', ''),
		('1510', 'Kartographische Aussparung', '');
		CREATE TABLE ax_besondereartdergewaesserbegrenzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_besondereartdergewaesserbegrenzung IS 'Alias: "AX_BesondereArtDerGewaesserbegrenzung", UML-Typ: Enumeration';
		INSERT INTO ax_besondereartdergewaesserbegrenzung (wert,beschreibung,dokumentation) VALUES
		('1350', 'Gleichzeitig Böschungsunterkante', '');
		CREATE TABLE ax_ursprung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_ursprung IS 'Alias: "AX_Ursprung", UML-Typ: Enumeration';
		INSERT INTO ax_ursprung (wert,beschreibung,dokumentation) VALUES
		('1100', 'Natürlich entstanden', ''),
		('1110', 'Künstlich entstanden', '');
		CREATE TABLE ax_funktion_dammwalldeich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_dammwalldeich IS 'Alias: "AX_Funktion_DammWallDeich", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_dammwalldeich (wert,beschreibung,dokumentation) VALUES
		('3001', 'Hochwasserschutz, Sturmflutschutz', 'Hochwasserschutz, Sturmflutschutz bedeutet, dass Damm, Wall, Deich dem Schutz vor Hochwasser bzw. Sturmflut dient.'),
		('3002', 'Verkehrsführung', 'Verkehrsführung bedeutet, dass auf Damm, Wall, Deich ein Verkehrsweg verläuft.'),
		('3003', 'Hochwasserschutz, Sturmflutschutz zugleich Verkehrsführung', 'Hochwasserschutz, Sturmflutschutz zugleich Verkehrsführung bedeutet, dass Damm, Wall, Deich dem Schutz vor Hochwasser dient und auf dem gleichzeitig ein Verkehrsweg verläuft.'),
		('3004', 'Lärmschutz', 'Lärmschutz bedeutet, dass Damm, Wall, Deich dem Schutz vor Lärmemissionen dient.');
		CREATE TABLE ax_art_dammwalldeich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_dammwalldeich IS 'Alias: "AX_Art_DammWallDeich", UML-Typ: Enumeration';
		INSERT INTO ax_art_dammwalldeich (wert,beschreibung,dokumentation) VALUES
		('1910', 'Hochwasserdeich', 'Hochwasserdeich ist ein Deich an einem Fliessgewässer oder im Küstengebiet, der dem Schutz eines Gebietes vor Hochwasser oder gegen Sturmfluten dient.'),
		('1920', 'Hauptdeich, Landesschutzdeich', 'Hauptdeich, Landesschutzdeich ist ein Deich der ersten Deichlinie zum Schutz der Küsten- und Inselgebiete gegen Sturmflut.'),
		('1930', 'Überlaufdeich', 'Überlaufdeich ist ein Deich vor dem Hauptdeich, der in erster Linie dem Schutz landwirtschaftlich genutzter Flächen gegen leichte Sturmtiden dient und der bei höheren Sturmtiden überströmt wird.'),
		('1940', 'Leitdeich', 'Leitdeich ist ein dammartiges Bauwerk im Watt, um strömendes Wasser in bestimmte Richtungen zu lenken und zum Schutz von Wasserläufen im Watt (Außentiefs) vor Versandung.'),
		('1950', 'Polderdeich', 'Polderdeich ist ein vor dem Hauptdeich liegender Deich, der landwirtschaftlich nutzbares Land (z. B. Marschland) schützt.'),
		('1960', 'Schlafdeich', 'Schlafdeich ist ein ehemaliger Hauptdeich, der infolge einer Vorverlegung der Deichlinie zu einem Binnendeich geworden ist und keine unmittelbare Schutzaufgabe mehr zu erfüllen hat.'),
		('1970', 'Mitteldeich', 'Mitteldeich ist ein Deich der 2. Deichlinie, auch an größeren Flüssen. Er soll Überschwemmungen beim Bruch des Deiches der ersten Deichlinie verhindern.'),
		('1980', 'Binnendeich', 'Binnendeich ist ein Deich an kleineren Flüssen, der Überschwemmungen durch ablaufendes Oberflächenwasser verhindern soll.'),
		('1990', 'Wall', ''),
		('1991', 'Wallkante, rechts', ''),
		('1992', 'Wallkante, links', ''),
		('1993', 'Wallmitte', ''),
		('2000', 'Knick', 'Knick ist ein bewachsener Erdwall, der als Einfriedung und zum Windschutz von Wiesen und Äckern dient.'),
		('2001', 'Knickkante, rechts', ''),
		('2002', 'Knickkante, links', ''),
		('2003', 'Knickmitte', ''),
		('2010', 'Graben mit Wall, rechts', ''),
		('2011', 'Graben mit Wall, links', ''),
		('2012', 'Graben mit Knick, rechts', ''),
		('2013', 'Graben mit Knick, links', '');
		CREATE TABLE ax_funktion_einschnitt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_einschnitt IS 'Alias: "AX_Funktion_Einschnitt", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_einschnitt (wert,beschreibung,dokumentation) VALUES
		('3002', 'Verkehrsführung', 'Verkehrsführung bedeutet, dass im Einschnitt ein Verkehrsweg verläuft.');
		CREATE TABLE ax_zustand_boeschungkliff (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_boeschungkliff IS 'Alias: "AX_Zustand_BoeschungKliff", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_boeschungkliff (wert,beschreibung,dokumentation) VALUES
		('2400', 'Befestigt', ''),
		('2500', 'Unbefestigt', '');
		CREATE TABLE ax_zustand_hoehleneingang (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_hoehleneingang IS 'Alias: "AX_Zustand_Hoehleneingang", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_hoehleneingang (wert,beschreibung,dokumentation) VALUES
		('2200', 'Verfallen, zerstört', 'Verfallen, zerstört bedeutet, dass sich der ursprüngliche Zustand von Höhleneingang durch menschliche oder zeitliche Einwirkungen so verändert hat, dass eine Nutzung nicht mehr möglich ist.'),
		('4100', 'Offen', 'Offen bedeutet, dass Höhleneingang allgemein zugänglich ist.'),
		('4200', 'Verschlossen', 'Verschlossen bedeutet, dass  Höhleneingang nicht allgemein zugänglich ist.');
		CREATE TABLE ax_berechnungsmethode (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_berechnungsmethode IS 'Alias: "AX_Berechnungsmethode", UML-Typ: Enumeration';
		INSERT INTO ax_berechnungsmethode (wert,beschreibung,dokumentation) VALUES
		('5300', 'Einfache Mittelbildung', ''),
		('5310', 'Gewichtete Mittelbildung', ''),
		('5320', 'Gleitende Schrägebene', ''),
		('5330', 'Prädiktion', ''),
		('5340', 'Polynomasatz', ''),
		('5350', 'Finite Elemente', ''),
		('5360', 'Dreiecksvermaschung', '');
		CREATE TABLE ax_verwendeteobjekte (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_verwendeteobjekte IS 'Alias: "AX_VerwendeteObjekte", UML-Typ: Enumeration';
		INSERT INTO ax_verwendeteobjekte (wert,beschreibung,dokumentation) VALUES
		('5111', 'Geländepunkte', ''),
		('5121', 'Geländekanten', ''),
		('5122', 'Gewässerbegrenzung', ''),
		('5123', 'Geripplinien', ''),
		('5124', 'Markante Geländepunkte', ''),
		('5131', 'Aussparungsflächen', ''),
		('5211', 'DGM-Gitter', '');
		CREATE TABLE ax_berechnungsmethodehoehenlinie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_berechnungsmethodehoehenlinie IS 'Alias: "AX_BerechnungsmethodeHoehenlinie", UML-Typ: Enumeration';
		INSERT INTO ax_berechnungsmethodehoehenlinie (wert,beschreibung,dokumentation) VALUES
		('5211', 'Aus sekundärem DGM-Gitter', ''),
		('5360', 'Über Dreiecksvermaschung abgeleitet', '');
		CREATE TABLE ax_dqerfassungsmethodesekundaeresdgm (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_dqerfassungsmethodesekundaeresdgm IS 'Alias: "AX_DQErfassungsmethodeSekundaeresDGM", UML-Typ: Enumeration';
		INSERT INTO ax_dqerfassungsmethodesekundaeresdgm (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5010', 'Interaktive photogrammetrische Aufnahme', ''),
		('5020', 'Laserscanning', ''),
		('5030', 'Digitalisierung analoger Vorlagen', ''),
		('5040', 'Bildkorrelation', ''),
		('5050', 'IfSAR', ''),
		('5060', 'Amtliche Festlegung', '');
		CREATE TABLE ax_zustand_kanal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_kanal IS 'Alias: "AX_Zustand_Kanal", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_kanal (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich der Kanal nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass der Kanal noch nicht fertiggestellt ist.');
		CREATE TABLE ax_funktion_stehendesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_stehendesgewaesser IS 'Alias: "AX_Funktion_StehendesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_stehendesgewaesser (wert,beschreibung,dokumentation) VALUES
		('8610', 'See', 'See ist eine natürliche oder künstlich angelegte, größere, stehende oder nahezu stehende Wasserfläche, die nach allgemeiner Verkehrsauffassung als See anzuse-hen ist.'),
		('8620', 'Teich', 'Teich ist eine natürliche oder künstlich angelegte, stehende oder nahezu stehende Wasserfläche, die nach allgemeiner Verkehrsauffassung als Teich anzusehen ist.'),
		('8630', 'Stausee', 'Stausee ist eine mit Wasser gefüllte, allseitig umschlossene Hohlform der Landoberfläche ohne unmittelbaren Zusammenhang mit Meer.'),
		('8631', 'Speicherbecken', 'Speicherbecken ist eine zeitweise mit Wasser gefüllte, allseitig umschlossene Hohlform der Landoberfläche ohne unmittelbaren Zusammenhang mit Meer'),
		('8640', 'Baggersee', 'Baggersee ist ein künstlich geschaffenes Gewässer, aus dem Bodenmaterial gefördert wird.'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_schifffahrtskategorie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_schifffahrtskategorie IS 'Alias: "AX_Schifffahrtskategorie", UML-Typ: Enumeration';
		INSERT INTO ax_schifffahrtskategorie (wert,beschreibung,dokumentation) VALUES
		('1000', 'Binnenwasserstraße', 'Binnenwasserstraße ist ein oberirdisches Gewässer oder Küstengewässer, das gesetzlich für den Personen- und/oder Güterverkehr mit Schiffen bestimmt ist. Binnengewässer im Küstengebiet sind gegen das Küstengewässer gesetzlich abgegrenzt.'),
		('2000', 'Seewasserstraße', 'Seewasserstraße ist ein als Wasserstraße gesetzlich festgelegter Teil eines Küstengewässers.'),
		('3000', 'Landesgewässer mit Verkehrsordnung', 'Landesgewässer mit Verkehrsordnung ist eine Wasserstraße, die keine Binnenwasserstraße ist. Die Schiffbarkeit wird durch eine Landesverkehrsordnung geregelt.');
		CREATE TABLE ax_hydrologischesmerkmal_fliessgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_fliessgewaesser IS 'Alias: "AX_HydrologischesMerkmal_Fliessgewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_fliessgewaesser (wert,beschreibung,dokumentation) VALUES
		('2000', 'Nicht ständig Wasser führend', 'Nicht ständig Wasser führend heißt, dass ein Gewässer nicht ganzjährig Wasser führt.');
		CREATE TABLE ax_schifffahrtskategorie_kanal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_schifffahrtskategorie_kanal IS 'Alias: "AX_Schifffahrtskategorie_Kanal", UML-Typ: Enumeration';
		INSERT INTO ax_schifffahrtskategorie_kanal (wert,beschreibung,dokumentation) VALUES
		('1000', 'Binnenwasserstraße', 'Binnenwasserstraße ist ein oberirdisches Gewässer oder Küstengewässer, das gesetzlich für den Personen- und/oder Güterverkehr mit Schiffen bestimmt ist. Binnengewässer im Küstengebiet sind gegen das Küstengewässer gesetzlich abgegrenzt.'),
		('2000', 'Seewasserstraße', 'Seewasserstraße ist ein als Wasserstraße gesetzlich festgelegter Teil eines Küstengewässers.'),
		('3000', 'Landesgewässer mit Verkehrsordnung', 'Landesgewässer mit Verkehrsordnung ist eine Wasserstraße, die keine Binnenwasserstraße ist. Die Schiffbarkeit wird durch eine Landesverkehrsordnung geregelt.');
		CREATE TABLE ax_funktion_fliessgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_fliessgewaesser IS 'Alias: "AX_Funktion_Fliessgewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_fliessgewaesser (wert,beschreibung,dokumentation) VALUES
		('8200', 'Fluss', 'Fluss ist ein natürliches, fließendes Gewässer (ggf. auch mit begradigten, kanalisierten Teilstücken), das wegen seiner Größe und Bedeutung nach allgemeiner Verkehrsauffassung als Fluss angesprochen wird.'),
		('8210', 'Altwasser', 'Altwasser ist ein Teil eines Fließgewässers, der bei einer Begradigung vom fließenden Gewässer abgeschnitten wurde und wichtiger Lebensraum für z. B. Wasser-vögel, Amphibien und Libellen ist.'),
		('8220', 'Altarm', ''),
		('8230', 'Flussmündungstrichter', 'Flussmündungstrichter ist der Bereich des Flusses im Übergang zum Meer. Er beginnt dort, wo die bis dahin etwa parallel verlaufenden Ufer des Flusses sich trichterförmig zur offenen See hin erweitern. Die Abgrenzungen der Flussmündungstrichter ergeben sich aus dem Bundeswasserstraßengesetz (meerseitig) und den Bekanntmachungen der Wasser- und Schifffahrtsverwaltung sowie höchst-richterlicher Rechtsprechung (binnenseitig).'),
		('8300', 'Kanal', 'Kanal ist ein für die Schifffahrt angelegter, künstlicher Wasserlauf.'),
		('8400', 'Graben', 'Graben ist ein ständig oder zeitweise fließendes, künstlich angelegtes oder natürliches Gewässer, das nach allgemeiner Verkehrsauffassung als Graben anzusehen ist.'),
		('8410', 'Fleet', ''),
		('8500', 'Bach', 'Bach ist ein natürliches, fließendes Gewässer, das wegen seiner geringen Größe und Bedeutung nach allgemeiner Verkehrsauffassung als Bach anzusehen ist.');
		CREATE TABLE ax_widmung_wasserlauf (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_widmung_wasserlauf IS 'Alias: "AX_Widmung_Wasserlauf", UML-Typ: Enumeration';
		INSERT INTO ax_widmung_wasserlauf (wert,beschreibung,dokumentation) VALUES
		('1310', 'Gewässer I. Ordnung - Bundeswasserstraße', 'Gewässer I. Ordnung - Bundeswasserstraße ist ein Gewässer, das der Zuständigkeit des Bundes obliegt.'),
		('1320', 'Gewässer I. Ordnung - nach Landesrecht', 'Gewässer I. Ordnung - nach Landesrecht ist ein Gewässer, das der Zuständigkeit des Landes obliegt.'),
		('1330', 'Gewässer II. Ordnung', 'Gewässer II. Ordnung ist ein Gewässer, für das die Unterhaltungsverbände zuständig sind.'),
		('1340', 'Gewässer III. Ordnung', 'Gewässer III. Ordnung ist ein Gewässer, das weder zu den Gewässern I. noch II. Ordnung zählt.');
		CREATE TABLE ax_funktion_meer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_meer IS 'Alias: "AX_Funktion_Meer", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_meer (wert,beschreibung,dokumentation) VALUES
		('8710', 'Küstengewässer', 'Küstengewässer ist die Fläche zwischen der Küstenlinie bei mittlerem Hochwasser oder der seewärtigen Begrenzung der oberirdischen Gewässer und der seewärtigen Begrenzung des deutschen Hoheitsgebietes. Dem mittleren Hochwasser ist der mittlere Wasserstand der Ostsee gleichzusetzen.');
		CREATE TABLE ax_hydrologischesmerkmal_gewaesserachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_gewaesserachse IS 'Alias: "AX_HydrologischesMerkmal_Gewaesserachse", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_gewaesserachse (wert,beschreibung,dokumentation) VALUES
		('2000', 'Nicht ständig Wasser führend', 'Nicht ständig Wasser führend heißt, dass ein Gewässer nicht ganzjährig Wasser führt.'),
		('3000', 'Trocken, versiegt', 'Trocken, versiegt heißt, dass ein Gewässerbett ganzjährig kein Wasser führt.');
		CREATE TABLE ax_tidemerkmal_meer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_tidemerkmal_meer IS 'Alias: "AX_Tidemerkmal_Meer", UML-Typ: Enumeration';
		INSERT INTO ax_tidemerkmal_meer (wert,beschreibung,dokumentation) VALUES
		('1000', 'Mit Tideeinfluss', 'Mit Tideeinfluss sind periodische Änderungen des Wasserspiegels und horizontale Bewegungen des Wassers, hervorgerufen durch die Massenanziehungs- und Fliehkräfte des Systems Sonne, Mond und Erde in Verbindung mit der Erdrotation.');
		CREATE TABLE ax_nutzung_hafenbecken (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_nutzung_hafenbecken IS 'Alias: "AX_Nutzung_Hafenbecken", UML-Typ: Enumeration';
		INSERT INTO ax_nutzung_hafenbecken (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zivil', 'Zivil bedeutet, dass Hafenbecken privaten oder öffentlichen Zwecken dient und nicht militärisch genutzt wird.'),
		('2000', 'Militärisch', 'Militärisch bedeutet, dass Hafenbecken nur von Streitkräften genutzt wird.'),
		('3000', 'Teils zivil, teils militärisch', 'Teils zivil, teils militärisch bedeutet, dass Hafenbecken sowohl zivil als auch militärisch genutzt wird.');
		CREATE TABLE ax_hydrologischesmerkmal_stehendesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_hydrologischesmerkmal_stehendesgewaesser IS 'Alias: "AX_HydrologischesMerkmal_StehendesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_hydrologischesmerkmal_stehendesgewaesser (wert,beschreibung,dokumentation) VALUES
		('2000', 'Nicht ständig Wasser führend', 'Nicht ständig Wasser führend heißt, dass ein Gewässer nicht ganzjährig Wasser führt.');
		CREATE TABLE ax_widmung_stehendesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_widmung_stehendesgewaesser IS 'Alias: "AX_Widmung_StehendesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_widmung_stehendesgewaesser (wert,beschreibung,dokumentation) VALUES
		('1310', 'Gewässer I. Ordnung - Bundeswasserstraße', 'Gewässer I. Ordnung - Bundeswasserstraße ist ein Gewässer, das der Zuständigkeit  des Bundes obliegt.'),
		('1320', 'Gewässer I. Ordnung - nach Landesrecht', 'Gewässer I. Ordnung - nach Landesrecht ist ein Gewässer, das der Zuständigkeit des Landes obliegt.'),
		('1330', 'Gewässer II. Ordnung', 'Gewässer II. Ordnung ist ein Gewässer, für das die Unterhaltungsverbände zuständig sind.'),
		('1340', 'Gewässer III. Ordnung', 'Gewässer III. Ordnung ist ein Gewässer, das weder zu den Gewässern I. noch II. Ordnung zählt.');
		CREATE TABLE ax_funktion_gewaesserachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_gewaesserachse IS 'Alias: "AX_Funktion_Gewaesserachse", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_gewaesserachse (wert,beschreibung,dokumentation) VALUES
		('8300', 'Kanal', 'Kanal ist ein für die Schifffahrt angelegter künstlicher Wasserlauf.');
		CREATE TABLE ax_funktion_hafenbecken (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_hafenbecken IS 'Alias: "AX_Funktion_Hafenbecken", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_hafenbecken (wert,beschreibung,dokumentation) VALUES
		('8810', 'Sportboothafenbecken', '');
		CREATE TABLE ax_widmung_kanal (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_widmung_kanal IS 'Alias: "AX_Widmung_Kanal", UML-Typ: Enumeration';
		INSERT INTO ax_widmung_kanal (wert,beschreibung,dokumentation) VALUES
		('1310', 'Gewässer I. Ordnung - Bundeswasserstraße', 'Gewässer I. Ordnung -Bundeswasserstraße ist ein Gewässer, das der Zuständigkeit  des Bundes obliegt.'),
		('1320', 'Gewässer I. Ordnung - nach Landesrecht', 'Gewässer I. Ordnung - nach Landesrecht ist ein Gewässer, das der Zuständigkeit des Landes obliegt.'),
		('1330', 'Gewässer II. Ordnung', 'Gewässer II. Ordnung ist ein Gewässer, für das die Unterhaltungsverbände zuständig sind.'),
		('1340', 'Gewässer III. Ordnung', 'Gewässer III. Ordnung ist ein Gewässer, das weder zu den Gewässern I. noch II. Ordnung zählt.');
		CREATE TABLE ax_zustand_wohnbauflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_wohnbauflaeche IS 'Alias: "AX_Zustand_Wohnbauflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_wohnbauflaeche (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_artderbebauung_wohnbauflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderbebauung_wohnbauflaeche IS 'Alias: "AX_ArtDerBebauung_Wohnbauflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_artderbebauung_wohnbauflaeche (wert,beschreibung,dokumentation) VALUES
		('1000', 'Offen', 'Offen beschreibt die Bebauung von Wohnbaufläche, die vorwiegend durch einzelstehende Gebäude charakterisiert wird.'),
		('2000', 'Geschlossen', 'Geschlossen beschreibt die Bebauung von Wohnbaufläche, die vorwiegend durch zusammenhängende Gebäude charakterisiert wird. Die Gebäudeabdeckung ist in der Regel >50 Prozent der Wohnbaufläche.');
		CREATE TABLE ax_zustand_flaechebesondererfunktionalerpraegung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_flaechebesondererfunktionalerpraegung IS 'Alias: "AX_Zustand_FlaecheBesondererFunktionalerPraegung", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_flaechebesondererfunktionalerpraegung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich die Fläche funktionaler Prägung nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_funktion_flaechegemischternutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_flaechegemischternutzung IS 'Alias: "AX_Funktion_FlaecheGemischterNutzung", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_flaechegemischternutzung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Gebäude- und Freifläche, Mischnutzung mit Wohnen', ''),
		('2110', 'Wohnen mit Öffentlich', ''),
		('2120', 'Wohnen mit Handel und Dienstleistungen', ''),
		('2130', 'Wohnen mit Gewerbe und Industrie', ''),
		('2140', 'Öffentlich mit Wohnen', ''),
		('2150', 'Handel und Dienstleistungen mit Wohnen', ''),
		('2160', 'Gewerbe und Industrie mit Wohnen', ''),
		('2700', 'Gebäude- und Freifläche Land- und Forstwirtschaft', 'Gebäude- und Freifläche Land- und Forstwirtschaft ist eine Fläche, die der Land- und Forstwirtschaft dient.'),
		('2710', 'Wohnen', ''),
		('2720', 'Betrieb', ''),
		('2730', 'Wohnen und Betrieb', ''),
		('6800', 'Landwirtschaftliche Betriebsfläche', 'Landwirtschaftliche Betriebsfläche ist eine bebaute und unbebaute Fläche, die dem landwirtschaftlichen Betrieb dient.'),
		('7600', 'Forstwirtschaftliche Betriebsfläche', 'Forstwirtschaftliche Betriebsfläche ist eine bebaute und unbebaute Fläche, die dem forstwirtschaftlichen Betrieb dient.');
		CREATE TABLE ax_foerdergut_industrieundgewerbeflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_foerdergut_industrieundgewerbeflaeche IS 'Alias: "AX_Foerdergut_IndustrieUndGewerbeflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_foerdergut_industrieundgewerbeflaeche (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erdöl', 'Erdöl ist ein flüssiges und brennbares Kohlenwasserstoffgemisch, das gefördert wird.'),
		('2000', 'Erdgas', 'Erdgas ist ein in der Erdkruste vorkommendes brennbares Naturgas, das gefördert wird.'),
		('3000', 'Sole, Lauge', 'Sole, Lauge ist ein kochsalzhaltiges Wasser, das gefördert wird.'),
		('4000', 'Kohlensäure', 'Kohlensäure ist eine schwache Säure, die durch Lösung von Kohlendioxid in Wasser entsteht und gefördert wird.'),
		('5000', 'Erdwärme', 'Erdwärme ist eine auf natürlichem Wege sich erneuernde Wärmeenergie, die aus einer geothermisch geringen Tiefenstufe der Erdkruste gefördert wird.');
		CREATE TABLE ax_artderbebauung_flaechegemischternutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderbebauung_flaechegemischternutzung IS 'Alias: "AX_ArtDerBebauung_FlaecheGemischterNutzung", UML-Typ: Enumeration';
		INSERT INTO ax_artderbebauung_flaechegemischternutzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Offen', 'Offen beschreibt die Bebauung von Fläche gemischter Nutzung, die vorwiegend durch einzelstehende Gebäude charakterisiert wird.'),
		('2000', 'Geschlossen', 'Geschlossen beschreibt die Bebauung von Fläche gemischter Nutzung, die vorwiegend durch zusammenhängende Gebäude charakterisiert wird. Die Gebäudeabdeckung ist in der Regel > 50 Prozent der Fläche.');
		CREATE TABLE ax_zustand_sportfreizeitunderholungsflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_sportfreizeitunderholungsflaeche IS 'Alias: "AX_Zustand_SportFreizeitUndErholungsflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_sportfreizeitunderholungsflaeche (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', ''),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_funktion_flaechebesondererfunktionalerpraegung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_flaechebesondererfunktionalerpraegung IS 'Alias: "AX_Funktion_FlaecheBesondererFunktionalerPraegung", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_flaechebesondererfunktionalerpraegung (wert,beschreibung,dokumentation) VALUES
		('1100', 'Öffentliche Zwecke', 'Öffentliche Zwecke bezeichnet eine Fläche, die der Erfüllung öffentlicher Aufgaben und der Allgemeinheit dient.'),
		('1110', 'Verwaltung', 'Verwaltung bezeichnet eine Fläche auf der vorwiegend Gebäude der öffentlichen Verwaltung, z. B. Rathaus, Gericht, Kreisverwaltung stehen.'),
		('1120', 'Bildung und Forschung', 'Bildung und Forschung bezeichnet eine Fläche, auf der vorwiegend Gebäude stehen, in denen geistige, kulturelle und soziale Fähigkeiten vermittelt werden und/oder wissenschaftliche Forschung betrieben wird (z.B. Schulen, Universitäten, Forschungsinstitute).'),
		('1130', 'Kultur', 'Kultur bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude für kulturelle Zwecke, z.B. Konzert- und Museumsgebäude, Bibliotheken, Theater, Schlösser und Burgen sowie Rundfunk- und Fernsehgebäude stehen.'),
		('1140', 'Religiöse Einrichtung', 'Religiöse Einrichtung bezeichnet eine Fläche auf der vorwiegend religiöse Gebäude stehen.'),
		('1150', 'Gesundheit, Kur', 'Gesundheit, Kur bezeichnet eine Fläche auf der vorwiegend Gebäude des Gesundheitswesens stehen, z.B. Krankenhäuser, Heil- und Pflegeanstalten.'),
		('1160', 'Soziales', 'Soziales bezeichnet eine Fläche auf der vorwiegend Gebäude des Sozialwesens stehen, z. B. Kindergärten, Jugend- und Senioreneinrichtungen, Freizeit-, Fremden- und Obdachlosenheime.'),
		('1170', 'Sicherheit und Ordnung', 'Sicherheit und Ordnung bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude der Polizei, der Bundeswehr, der Feuerwehr und der Justizvollzugsbehörden stehen.'),
		('1200', 'Parken', 'Parken bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude zum vorübergehenden Abstellen von Fahrzeugen stehen.'),
		('1300', 'Historische Anlage', 'Historische Anlage ist eine Fläche mit historischen Anlagen, z. B. historische Stadtmauern und -türme, Denkmälern und Ausgrabungsstätten.'),
		('1310', 'Burg-, Festungsanlage', ''),
		('1320', 'Schlossanlage', '');
		CREATE TABLE ax_funktion_sportfreizeitunderholungsflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_sportfreizeitunderholungsflaeche IS 'Alias: "AX_Funktion_SportFreizeitUndErholungsflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_sportfreizeitunderholungsflaeche (wert,beschreibung,dokumentation) VALUES
		('4001', 'Gebäude- und Freifläche Sport, Freizeit und Erholung', 'Gebäude- und Freifläche Sport, Freizeit und Erholung ist eine bebaute Fläche, die dem Sport, der Freizeitgestaltung oder der Erholung dient.'),
		('4100', 'Sportanlage', 'Sportanlage ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung von (Wettkampf-)sport und für Zuschauer bestimmt ist.'),
		('4101', 'Gebäude- u. Freifläche Erholung, Sport', ''),
		('4110', 'Golfplatz', 'Golfplatz ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Golfsports genutzt wird.'),
		('4120', 'Sportplatz', ''),
		('4130', 'Rennbahn', ''),
		('4140', 'Reitplatz', ''),
		('4150', 'Schießanlage', ''),
		('4160', 'Eis-, Rollschuhbahn', ''),
		('4170', 'Tennisplatz', ''),
		('4200', 'Freizeitanlage', 'Freizeitanlage ist eine Fläche mit Bauwerken und Einrichtungen, die zur Freizeitgestaltung bestimmt ist.'),
		('4210', 'Zoo', 'Zoo ist ein Gelände mit Tierschauhäusern und umzäunten Gehegen, auf dem Tiere gehalten und gezeigt werden.'),
		('4211', 'Gebäude- u. Freifläche Erholung, Zoologie', ''),
		('4220', 'Safaripark, Wildpark', 'Safaripark, Wildpark, ist ein Gelände mit umzäunten Gehegen, in denen Tiere im Freien gehalten und gezeigt werden.'),
		('4230', 'Freizeitpark', 'Freizeitpark ist ein Gelände mit Karussells, Verkaufs- und Schaubuden und/oder Wildgattern, das der Freizeitgestaltung dient.'),
		('4240', 'Freilichttheater', 'Freilichttheater ist eine Anlage mit Bühne und Zuschauerbänken für Theateraufführungen im Freien.'),
		('4250', 'Freilichtmuseum', 'Freilichtmuseum ist eine volkskundliche Museumsanlage, in der Wohnformen oder historische 
Betriebsformen in ihrer natürlichen Umgebung im Freien dargestellt sind.'),
		('4260', 'Autokino, Freilichtkino', 'Autokino, Freilichtkino ist ein Lichtspieltheater im Freien, in dem der Film im Allgemeinen vom Auto aus angesehen wird.'),
		('4270', 'Verkehrsübungsplatz', 'Verkehrsübungsplatz ist eine Fläche, die Übungs- und Erprobungszwecken dient.'),
		('4280', 'Hundeübungsplatz', 'Hundeübungsplatz ist eine Fläche, auf der Übungen mit Hunden durchgeführt werden.'),
		('4290', 'Modellflugplatz', 'Modellflugplatz ist eine Fläche, die zur Ausübung des Modellflugsports dient.'),
		('4300', 'Erholungsfläche', 'Erholungsfläche ist eine Fläche mit Bauwerken und Einrichtungen, die zur Erholung bestimmt ist.'),
		('4301', 'Gebäude- und Freifläche Erholung', ''),
		('4310', 'Wochenend- und Ferienhausfläche', 'Wochenend- und Ferienhausfläche bezeichnet eine extra dafür ausgewiesene Fläche auf der vorwiegend Wochenend- und Ferienhäuser stehen dürfen.'),
		('4320', 'Schwimmbad, Freibad', 'Schwimmbad, Freibad ist eine Anlage mit Schwimmbecken oder Anlage an Ufern von Gewässern für den Badebetrieb und Schwimmsport.'),
		('4321', 'Gebäude- u. Freifläche Erholung, Bad', ''),
		('4330', 'Campingplatz', 'Campingplatz ist eine Fläche für den Aufbau einer größeren Zahl von Zelten oder zum Abstellen und Benutzen von Wohnwagen mit ortsfesten Anlagen und Einrichtungen.'),
		('4331', 'Gebäude- u. Freifläche Erholung, Camping', ''),
		('4400', 'Grünanlage', 'Grünanlage ist eine Anlage mit Bäumen, Sträuchern, Rasenflächen, Blumenrabatten und Wegen, die vor allem der Erholung und Verschönerung des Stadtbildes dient.'),
		('4410', 'Grünfläche', 'Grünfläche ist eine unbebaute Wiese, Rasenfläche und Parkanlage in Städten und Siedlungen.'),
		('4420', 'Park', 'Park ist eine landschaftsgärtnerisch gestaltete Grünanlage, die der Repräsentation und der Erholung dient.'),
		('4430', 'Botanischer Garten', 'Botanischer Garten ist ein der Öffentlichkeit zugänglicher Garten zum Studium der Pflanzenwelt; systematisch geordnete Sammlung in Freiland und Gewächs-häusern (Warmhäuser).'),
		('4431', 'Gebäude- u. Freifläche Erholung, Botanik', ''),
		('4440', 'Kleingarten', 'Kleingarten (Schrebergarten) ist eine Anlage von Gartengrundstücken, die von Vereinen verwaltet und verpachtet werden.'),
		('4450', 'Wochenendplatz', ''),
		('4460', 'Garten', ''),
		('4470', 'Spielplatz, Bolzplatz', 'Spielplatz, Bolzplatz ist ein Platz an dem körperliche oder geistige Tätigkeit aus eigenem Antrieb ohne Zweckbestimmung ausgeübt wird.'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_lagergut_industrieundgewerbeflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagergut_industrieundgewerbeflaeche IS 'Alias: "AX_Lagergut_IndustrieUndGewerbeflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_lagergut_industrieundgewerbeflaeche (wert,beschreibung,dokumentation) VALUES
		('1000', 'Baustoffe', ''),
		('2000', 'Kohle', ''),
		('3000', 'Öl', ''),
		('4000', 'Erde', ''),
		('5000', 'Schutt', ''),
		('6000', 'Schlacke', ''),
		('7000', 'Abraum', ''),
		('8000', 'Schrott, Altmaterial', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_zustand_halde (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_halde IS 'Alias: "AX_Zustand_Halde", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_halde (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich die Halde nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_zustand_bergbaubetrieb (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_bergbaubetrieb IS 'Alias: "AX_Zustand_Bergbaubetrieb", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bergbaubetrieb (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich der Bergbaubetrieb nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_abbaugut_tagebaugrubesteinbruch (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_abbaugut_tagebaugrubesteinbruch IS 'Alias: "AX_Abbaugut_TagebauGrubeSteinbruch", UML-Typ: Enumeration';
		INSERT INTO ax_abbaugut_tagebaugrubesteinbruch (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erden, Lockergestein', 'Erden, Lockergestein bedeutet, dass feinkörnige Gesteine abgebaut werden.'),
		('1001', 'Ton', 'Ton ist ein Abbaugut, das aus gelblichem bis grauem Lockergestein besteht und durch Verwitterung älterer Gesteine entsteht.'),
		('1002', 'Bentonit', 'Bentonit ist ein tonartiges Abbaugut, das durch Verwitterung vulkanischer Asche (Tuffe) entstanden ist.'),
		('1003', 'Kaolin', 'Kaolin ist ein Abbaugut, das aus weißem, erdigem Gestein, fast reinem Aluminiumsilikat (kieselsaure Tonerde) besteht.'),
		('1004', 'Lehm', 'Lehm ist ein Abbaugut, das durch Verwitterung entstanden ist und aus gelb bis braun gefärbtem sandhaltigem Ton besteht.'),
		('1005', 'Löß, Lößlehm', 'Löß, Lößlehm ist ein Abbaugut das aus feinsten gelblichen Sedimenten besteht und eine hohe Wasserspeicherfähigkeit aufweist.'),
		('1006', 'Mergel', 'Mergel ist ein Abbaugut das aus kalk- und tonartigem Sedimentgestein besteht.'),
		('1007', 'Kalk, Kalktuff, Kreide', 'Kalk, Kalktuff, Kreide ist ein Abbaugut, das aus erdigem weißen Kalkstein besteht.'),
		('1008', 'Sand', 'Sand ist ein Abbaugut, das aus kleinen, losen Mineralkörnern (häufig Quarz) besteht.'),
		('1009', 'Kies, Kiessand', 'Kies, Kiessand ist ein Abbaugut, das aus vom Wasser rund geschliffenen Gesteinsbrocken besteht.'),
		('1011', 'Farberden', 'Farberden ist ein Abbaugut, das durch Verwitterung entstanden ist und vorrangig aus eisenhaltigem Gestein besteht.'),
		('1012', 'Quarzsand', 'Quarzsand ist ein Abbaugut, das vorwiegend aus kleinen, losen Quarzkörnern besteht.'),
		('1013', 'Kieselerde', 'Kieselerde ist ein Abbaugut, das durch tertiäre Binnenseeablagerungen aus Kieselschalen toter Kieselalgen entstanden ist.'),
		('2000', 'Steine, Gestein, Festgestein', 'Steine, Gestein, Festgestein bedeutet, dass grobkörnige oder feste Gesteine abgebaut werden.'),
		('2001', 'Tonstein', 'Tonstein ist ein gelblich bis graues Abbaugut, das überwiegend aus Tonmineralien besteht.'),
		('2002', 'Schiefer, Dachschiefer', 'Schiefer, Dachschiefer ist ein toniges Abbaugut, das in dünne ebene Platten spaltbar ist.'),
		('2003', 'Metamorpher Schiefer', 'Metamorpher Schiefer ist ein Abbaugut, dessen ursprüngliche Zusammensetzung und Struktur durch Wärme und Druck innerhalb der Erdkruste verändert worden ist.'),
		('2004', 'Mergelstein', 'Mergelstein ist ein Abbaugut, das sich größtenteils aus Ton und Kalk zusammensetzt.'),
		('2005', 'Kalkstein', 'Kalkstein ist ein Abbaugut, das als weit verbreitetes Sedimentgestein überwiegend aus Calciumcarbonat besteht.'),
		('2006', 'Dolomitstein', 'Dolomitstein ist ein Abbaugut, das überwiegend aus calcium- und magnesiumhaltigen Mineralien besteht.'),
		('2007', 'Travertin', 'Travertin ist ein Abbaugut, das aus gelblichen Kiesel- oder Kalktuffen besteht.'),
		('2008', 'Marmor', 'Marmor ist ein Abbaugut, das als rein weißer kristalliner, körniger Kalkstein (Calciumcarbonat) vorkommt.'),
		('2009', 'Sandstein', 'Sandstein ist ein Abbaugut, das aus verfestigtem Sedimentgestein besteht.'),
		('2010', 'Grauwacke', 'Grauwacke ist ein Abbaugut, das aus tonhaltigem Sandstein besteht und mit Gesteinsbruchstücken angereichert sein kann.'),
		('2011', 'Quarzit', 'Quarzit ist ein sehr hartes metamorphes Abbaugut, das vorwiegend aus feinkörnigen Quarzmineralien besteht.'),
		('2012', 'Gneis', 'Gneis ist ein metamorphes Abbaugut mit Schieferung, das aus Feldspat, Quarz und Glimmer besteht.'),
		('2013', 'Basalt, Diabas', 'Basalt, Diabas ist ein Abbaugut, das aus basischem Ergussgestein besteht.'),
		('2014', 'Andesit', 'Andesit ist ein Abbaugut, das aus Ergussgestein besteht.'),
		('2015', 'Porphyr, Quarzporphyr', 'Porphyr, Quarzporphyr ist ein eruptiv entstandenes Abbaugut, das aus einer dichten Grundmasse und groben Einsprenglingen besteht.'),
		('2016', 'Granit', 'Granit ist ein eruptiv entstandenes Abbaugut, das aus körnigem Feldspat, Quarz, Glimmer besteht.'),
		('2017', 'Granodiorit', 'Granodiorit ist ein hell- bis dunkelgraues Abbaugut. Es ist ein mittelkörniges Tiefengestein mit den Hauptbestandteilen Feldspat, Quarz, Hornblende und Biotit.'),
		('2018', 'Tuff-, Bimsstein', 'Tuff-, Bimsstein ist ein helles, sehr poröses Abbaugut, das durch rasches Erstarren der Lava entstanden ist.'),
		('2019', 'Trass', 'Trass ist ein Abbaugut, das aus vulkanischem Aschentuff (Bimsstein) besteht.'),
		('2020', 'Lavaschlacke', 'Lavaschlacke ist ein Abbaugut, das aus ausgestoßenem, geschmolzenen Vulkangestein besteht.'),
		('2021', 'Talkschiefer, Speckstein', 'Talkschiefer, Speckstein ist ein farbloses bis graugrünes, sich fettig anfühlendes Abbaugut, das aus dem weichen Mineral Talk besteht.'),
		('4000', 'Treib- und Brennstoffe', 'Treib- und Brennstoffe bedeutet, dass die in der Natur vorkommenden brennbaren organischen und anorganischen Substanzen abgebaut oder gewonnen werden.'),
		('4010', 'Torf', 'Torf ist ein Abbaugut, das aus der unvollkommenen Zersetzung abgestorbener pflanzlicher Substanz unter Luftabschluss in Mooren entstanden ist.'),
		('4020', 'Kohle', 'Kohle ist ein Abbaugut, das durch Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.'),
		('4021', 'Braunkohle', 'Braunkohle ist ein Abbaugut, das durch einen bestimmten Grad von Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.'),
		('4022', 'Steinkohle', 'Steinkohle ist ein Abbaugut, das durch vollständige Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.'),
		('4030', 'Ölschiefer', 'Ölschiefer ist ein Abbaugut, das aus dunklem, bitumenhaltigen, tonigen Gestein besteht.'),
		('5000', 'Industrieminerale, Salze', 'Industrieminerale, Salze bedeutet, dass die in der Natur vorkommenden Mineralien abgebaut werden.'),
		('5001', 'Gipsstein', 'Gipsstein ist ein natürliches Abbaugut.'),
		('5002', 'Anhydritstein', 'Anhydritstein ist ein Abbaugut, das aus wasserfreiem Gips besteht.'),
		('5005', 'Kalkspat', 'Kalkspat ist ein weißes oder hell gefärbtes Abbaugut (Calciumcarbonat).'),
		('5007', 'Schwerspat', 'Schwerspat ist ein formenreiches, rhombisches weißes bis farbiges Abbaugut.'),
		('5008', 'Quarz', 'Quarz ist ein Abbaugut, das aus verschiedenen Gesteinsarten (Granit, Gneis, Sandstein) gewonnen wird.'),
		('5009', 'Feldspat', 'Feldspat ist ein weiß bis grauweißes gesteinsbildendes Mineral von blättrigem Bruch, das abgebaut wird.'),
		('5010', 'Pegmatitsand', 'Pegmatitsand ist ein Abbaugut, das durch Verwitterung von Granit und Gneis entstanden ist.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass das Abbaugut bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_primaerenergie_industrieundgewerbeflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_primaerenergie_industrieundgewerbeflaeche IS 'Alias: "AX_Primaerenergie_IndustrieUndGewerbeflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_primaerenergie_industrieundgewerbeflaeche (wert,beschreibung,dokumentation) VALUES
		('1000', 'Wasser', 'Wasser bedeutet, dass das Kraftwerk potentielle und kinetische Energie des Wasserkreislaufs in elektrische Energie umwandelt.'),
		('2000', 'Kernkraft', 'Kernkraft bedeutet, dass das Kraftwerk die durch Kernspaltung gewonnene Energie in eine andere Energieform umwandelt.'),
		('3000', 'Sonne', 'Sonne bedeutet, dass das Kraftwerk bzw. Heizwerk Sonnenenergie in eine andere Energieform umwandelt.'),
		('4000', 'Wind', 'Wind bedeutet, dass das Kraftwerk die Strömungsenergie des Windes in elektrische Energie umwandelt.'),
		('5000', 'Gezeiten', 'Gezeiten bedeutet, dass das Kraftwerk die kinetische Energie der Meeresgezeiten in elektrische Energie umwandelt.'),
		('6000', 'Erdwärme', 'Erdwärme bedeutet, dass das Heizwerk die geothermische Energie der Erde nutzt.'),
		('7000', 'Verbrennung', 'Verbrennung bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7100', 'Kohle', 'Kohle bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Kohle freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7200', 'Öl', 'Öl bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Öl freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7300', 'Gas', 'Gas bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Gas freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7400', 'Müll, Abfall', 'Müll, Abfall bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Müll bzw. Abfall freiwerdende Energie in eine andere Energieform umwandelt.');
		CREATE TABLE ax_abbaugut_bergbaubetrieb (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_abbaugut_bergbaubetrieb IS 'Alias: "AX_Abbaugut_Bergbaubetrieb", UML-Typ: Enumeration';
		INSERT INTO ax_abbaugut_bergbaubetrieb (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erden, Lockergestein', 'Erden, Lockergestein bedeutet, dass feinkörnige Gesteine abgebaut werden.'),
		('1001', 'Ton', 'Ton ist ein Abbaugut, das aus gelblichem bis grauem Lockergestein besteht und durch Verwitterung älterer Gesteine entsteht.'),
		('1007', 'Kalk, Kalktuff, Kreide', 'Kalk, Kalktuff, Kreide ist ein Abbaugut, das aus erdigem weißen Kalkstein besteht.'),
		('2000', 'Steine, Gestein, Festgestein', 'Steine, Gestein, Festgestein bedeutet, dass grobkörnige oder feste Gesteine abgebaut werden.'),
		('2002', 'Schiefer, Dachschiefer', 'Schiefer, Dachschiefer ist ein toniges Abbaugut, das in dünne ebene Platten spaltbar ist.'),
		('2003', 'Metamorpher Schiefer', 'Metamorpher Schiefer ist ein Abbaugut, dessen ursprüngliche Zusammensetzung und Struktur durch Wärme und Druck innerhalb der Erdkruste verändert worden ist.'),
		('2005', 'Kalkstein', 'Kalkstein ist ein Abbaugut, das als weit verbreitetes Sedimentgestein überwiegend aus Calciumcarbonat besteht.'),
		('2006', 'Dolomitstein', 'Dolomitstein ist ein Abbaugut, das überwiegend aus calcium- und magnesiumhaltigen Mineralien besteht.'),
		('2013', 'Basalt, Diabas', 'Basalt, Diabas ist ein Abbaugut, das aus basischem Ergussgestein besteht.'),
		('2021', 'Talkschiefer, Speckstein', 'Talkschiefer, Speckstein ist ein farbloses bis graugrünes, sich fettig anfühlendes Abbaugut, das aus dem weichen Mineral Talk besteht.'),
		('3000', 'Erze', 'Erze bedeutet, dass die in der Natur vorkommenden, metallhaltigen Mineralien und Mineralgemische abgebaut oder gespeichert werden.'),
		('3001', 'Eisen', 'Eisen wird als Eisenerz abgebaut und durch Verhüttung gewonnen.'),
		('3002', 'Buntmetallerze', 'Buntmetallerze ist das Abbaugut, das alle Nichteisenmetallerze als Sammelbegriff umfasst.'),
		('3003', 'Kupfer', 'Kupfer wird als Kupfererz abgebaut und durch Verhüttung gewonnen.'),
		('3004', 'Blei', 'Blei wird als Bleierz abgebaut und durch spezielle Verfahren gewonnen.'),
		('3005', 'Zink', 'Zink wird als Zinkerz abgebaut und durch spezielle Verfahren gewonnen.'),
		('3006', 'Zinn', 'Zinn wird als Zinnerz abgebaut und durch spezielle Verfahren gewonnen.'),
		('3007', 'Wismut, Kobalt, Nickel', 'Wismut, Kobalt, Nickel werden als Erze abgebaut und durch spezielle Verfahren gewonnen.'),
		('3008', 'Uran', 'Uran wird als Uranerz abgebaut und durch spezielle Verfahren gewonnen.'),
		('3009', 'Mangan', 'Mangan wird als Manganerz abgebaut und durch spezielle Verfahren gewonnen.'),
		('3010', 'Antimon', 'Antimon wird als Antimonerz abgebaut und durch spezielle Verfahren gewonnen.'),
		('3011', 'Edelmetallerze', 'Edelmetallerze ist das Abbaugut, aus dem Edelmetalle (z. B. Gold, Silber) gewonnen werden.'),
		('4000', 'Treib- und Brennstoffe', 'Treib- und Brennstoffe bedeutet, dass die in der Natur vorkommenden brennbaren organischen und anorganischen Substanzen abgebaut oder gewonnen werden.'),
		('4020', 'Kohle', 'Kohle ist ein Abbaugut, das durch Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.'),
		('4021', 'Braunkohle', 'Braunkohle ist ein Abbaugut, das durch einen bestimmten Grad von Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.'),
		('4022', 'Steinkohle', 'Steinkohle ist ein Abbaugut, das durch vollständige Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.'),
		('4030', 'Ölschiefer', 'Ölschiefer ist ein Abbaugut, das aus dunklem, bitumenhaltigem, tonigem Gestein besteht.'),
		('5000', 'Industrieminerale, Salze', 'Industrieminerale, Salze bedeutet, dass die in der Natur vorkommenden Mineralien abgebaut werden.'),
		('5001', 'Gipsstein', 'Gipsstein ist ein natürliches Abbaugut.'),
		('5002', 'Anhydritstein', 'Anhydritstein ist ein Abbaugut, das aus wasserfreiem Gips besteht.'),
		('5003', 'Steinsalz', 'Steinsalz ist ein Abbaugut, das aus Salzstöcken gewonnen wird und aus Natriumchlorid besteht.'),
		('5004', 'Kalisalz', 'Kalisalz ist ein Abbaugut, das aus Salzstöcken gewonnen wird und aus Chloriden und Sulfaten besteht.'),
		('5005', 'Kalkspat', 'Kalkspat ist ein weißes oder hell gefärbtes Abbaugut (Calciumcarbonat).'),
		('5006', 'Flussspat', 'Flussspat ist ein Abbaugut, das aus Calciumfluorid besteht.'),
		('5007', 'Schwerspat', 'Schwerspat ist ein formenreiches, rhombisches weißes bis farbiges Abbaugut.'),
		('5011', 'Graphit', 'Graphit ist ein bleigraues, weiches, metallglänzendes Abbaugut, das aus fast reinem Kohlenstoff besteht.');
		CREATE TABLE ax_zustand_flaechegemischternutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_flaechegemischternutzung IS 'Alias: "AX_Zustand_FlaecheGemischterNutzung", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_flaechegemischternutzung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', ''),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_zustand_industrieundgewerbeflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_industrieundgewerbeflaeche IS 'Alias: "AX_Zustand_IndustrieUndGewerbeflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_industrieundgewerbeflaeche (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_funktion_friedhof (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_friedhof IS 'Alias: "AX_Funktion_Friedhof", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_friedhof (wert,beschreibung,dokumentation) VALUES
		('9401', 'Gebäude- und Freifläche Friedhof', ''),
		('9402', 'Friedhof (ohne Gebäude)', ''),
		('9403', 'Friedhof (Park)', 'Friedhof (Park) ist ein Friedhof, der als Park angelegt ist.'),
		('9404', 'Historischer Friedhof', 'Historischer Friedhof ist ein Friedhof, der als historisch gilt.');
		CREATE TABLE ax_zustand_friedhof (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_friedhof IS 'Alias: "AX_Zustand_Friedhof", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_friedhof (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', ''),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_lagergut_halde (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_lagergut_halde IS 'Alias: "AX_Lagergut_Halde", UML-Typ: Enumeration';
		INSERT INTO ax_lagergut_halde (wert,beschreibung,dokumentation) VALUES
		('1000', 'Baustoffe', ''),
		('2000', 'Kohle', ''),
		('4000', 'Erde', ''),
		('5000', 'Schutt', ''),
		('6000', 'Schlacke', ''),
		('7000', 'Abraum', ''),
		('8000', 'Schrott, Altmaterial', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_funktion_industrieundgewerbeflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_industrieundgewerbeflaeche IS 'Alias: "AX_Funktion_IndustrieUndGewerbeflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_industrieundgewerbeflaeche (wert,beschreibung,dokumentation) VALUES
		('1400', 'Handel und Dienstleistung', 'Handel und Dienstleistung bezeichnet eine Fläche, auf der vorwiegend Gebäude stehen, in denen Handels- und/oder Dienstleistungsbetriebe ansässig sind.'),
		('1410', 'Verwaltung, freie Berufe', ''),
		('1420', 'Bank, Kredit', ''),
		('1430', 'Versicherung', ''),
		('1440', 'Handel', 'Handel bezeichnet Anlagen mit Einzelhandels- und Dienstleistungsbetrieben, die durch einheitliche 
Verwaltung, auf das Einzugsgebiet abgestimmter Anbieter und durch große Parkplatzflächen geprägt sind.'),
		('1450', 'Ausstellung, Messe', 'Ausstellung, Messe bezeichnet eine Fläche mit Ausstellungshallen und sonstigen Einrichtungen zur 
Präsentation von Warenmustern.'),
		('1460', 'Beherbergung', ''),
		('1470', 'Restauration', ''),
		('1480', 'Vergnügung', ''),
		('1490', 'Gärtnerei', 'Gärtnerei bezeichnet eine Fläche mit Gebäuden, Gewächshäusern und sonstigen Einrichtungen, zur Aufzucht von Blumen und Gemüsepflanzen.'),
		('1700', 'Industrie und Gewerbe', 'Industrie und Gewerbe bezeichnet Flächen, auf denen vorwiegend Industrie- und Gewerbebetriebe vorhanden sind.  Darin sind Gebäude- und Freiflächen und die Betriebsläche Lagerplatz enthalten.'),
		('1701', 'Gebäude- und Freifläche Industrie und Gewerbe', 'Darin sind die Gebäude- und Freiflächen der folgenden Differenzierung enthalten ohne die Betriebsfläche Lagerplatz.'),
		('1710', 'Produktion', ''),
		('1720', 'Handwerk', ''),
		('1730', 'Tankstelle', ''),
		('1740', 'Lagerplatz', 'Lagerplatz bezeichnet Flächen, auf denen inner- und außerhalb von Gebäuden wirtschaftliche Güter gelagert werden.'),
		('1750', 'Transport', ''),
		('1760', 'Forschung', ''),
		('1770', 'Grundstoff', ''),
		('1780', 'Betriebliche Sozialeinrichtung', ''),
		('1790', 'Werft', 'Werft ist eine Betriebsfläche mit Bauwerken und sonstigen Einrichtungen zum Bau oder zur Reparatur von Schiffen.'),
		('2500', 'Versorgungsanlage', 'Versorgungsanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Versorgung der Allgemeinheit mit Elektrizität, Wärme und Wasser vorhanden sind.'),
		('2501', 'Gebäude- und Freifläche Versorgungsanlage', 'Gebäude- und Freifläche Versorgungsanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Versorgung der Allgemeinheit mit Elektrizität, Wärme und Wasser vorhanden sind.'),
		('2502', 'Betriebsfläche Versorgungsanlage', 'Betriebsfläche Versorgungsanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Versorgung der Allgemeinheit mit Elektrizität, Wärme und Wasser vorhanden sind.'),
		('2510', 'Förderanlage', 'Förderanlage bezeichnet eine Fläche mit Einrichtungen zur Förderung von Erdöl, Erdgas, Sole, Kohlensäure oder Erdwärme aus dem Erdinneren.'),
		('2520', 'Wasserwerk', 'Wasserwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Gewinnung und/ oder zur Aufbereitung von (Trink-)wasser.'),
		('2521', 'Gebäude- und Freifläche Versorgungsanlage, Wasser', 'Gebäude- und Freifläche Versorgungsanlage, Wasser ist Teil von Wasserwerk. Wasserwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Gewinnung und/ oder zur Aufbereitung von (Trink-)wasser.'),
		('2522', 'Betriebsfläche Versorgungsanlage, Wasser', 'Betriebsfläche Versorgungsanlage, Wasser ist Teil von Wasserwerk. Wasserwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Gewinnung und/ oder zur Aufbereitung von (Trink-)wasser.'),
		('2530', 'Kraftwerk', 'Kraftwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von elektrischer Energie.'),
		('2531', 'Gebäude- und Freifläche Versorgungsanlage, Elektrizität', 'Gebäude- und Freifläche Versorgungsanlage, Elektrizität ist Teil von Kraftwerk. Kraftwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von elektrischer Energie.'),
		('2532', 'Betriebsfläche Versorgungsanlage, Elektrizität', 'Betriebsfläche Versorgungsanlage, Elektrizität ist Teil von Kraftwerk. Kraftwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeu-gung von elektrischer Energie.'),
		('2540', 'Umspannstation', 'Umspannstation bezeichnet eine Fläche mit Gebäuden und sonstigen Einrichtungen, um Strom auf eine andere Spannungsebene zu transformieren.'),
		('2550', 'Raffinerie', 'Raffinerie bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Aufbereitung von Erdöl.'),
		('2551', 'Gebäude- und Freifläche Versorgungsanlage, Öl', 'Gebäude- und Freifläche Versorgungsanlage, Öl ist Teil von Raffinerie. Raffinerie bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Aufbereitung von Erdöl.'),
		('2552', 'Betriebsfläche Versorganlage, Öl', 'Betriebsfläche Versorgungsanlage, Öl ist Teil von Raffinerie. Raffinerie bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Aufbereitung von Erdöl.'),
		('2560', 'Gaswerk', ''),
		('2561', 'Gebäude- und Freifläche Versorgungsanlage, Gas', 'Gebäude- und Freifläche Versorgungsanlage, Gas ist Teil von Gaswerk. Gaswerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Aufbe-reitung von Gas.'),
		('2562', 'Betriebsfläche Versorgungsanlage, Gas', 'Betriebsfläche Versorgungsanlage, Gas ist Teil von Gaswerk. Gaswerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Aufbereitung von Gas.'),
		('2570', 'Heizwerk', 'Heizwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von Wärmeenergie zu Heizzwecken.'),
		('2571', 'Gebäude- und Freifläche Versorgungsanlage, Wärme', 'Gebäude- und Freifläche Versorgungsanlage, Wärme ist Teil von Heizwerk. Heizwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Er-zeugung von Wärmeenergie zu Heizzwecken.'),
		('2572', 'Betriebsfläche Versorgungsanlage, Wärme', 'Betriebsfläche Versorgungsanlage, Wärme ist Teil von Heizwerk. Heizwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von Wärmeenergie zu Heizzwecken.'),
		('2580', 'Funk- und Fernmeldeanlage', 'Funk- und Fernmeldeanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur elektronischen Informationenvermittlung stehen.'),
		('2581', 'Gebäude- und Freifläche Versorgungsanlage, Funk- und Fernmeldewesen', 'Gebäude- und Freifläche Versorgungsanlage, Funk- und Fernmeldewesen ist Teil von Funk- und Fernmeldeanlage. Funk- und Fernmeldeanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur elektronischen Informationenvermittlung stehen.'),
		('2582', 'Betriebsfläche Versorgungsanlage, Funk- und Fernmeldewesen', 'Betriebsfläche Versorgungsanlage, Funk- und Fernmeldewesen ist Teil von Funk- und Fernmeldeanlage. Funk- und Fernmeldeanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur elektronischen Informationenvermittlung stehen.'),
		('2600', 'Entsorgung', 'Entsorgung bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Verwertung und Entsorgung von Abwasser und festen Abfallstoffen vorhanden sind.'),
		('2601', 'Gebäude- und Freifläche Entsorgungsanlage', 'Gebäude- und Freifläche Entsorgungsanlage ist Teil von Entsorgung. Entsorgung bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Verwertung und Entsorgung von Abwasser und festen Abfallstoffen vorhanden sind.'),
		('2602', 'Betriebsfläche Entsorgungsanlage', 'Betriebsfläche Entsorgungsanlage ist Teil von Entsorgung. Entsorgung bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Verwertung und Entsorgung von Abwasser und festen Abfallstoffen vorhanden sind.'),
		('2610', 'Kläranlage, Klärwerk', 'Kläranlage, Klärwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Reinigung von Abwasser.'),
		('2611', 'Gebäude- und Freifläche Entsorgungsanlage, Abwasserbeseitigung', 'Gebäude- und Freifläche Entsorgungsanlage, Abwasserbeseitigung ist Teil von Kläranlage, Klärwerk. Kläranlage, Klärwerk bezeichnet eine Fläche mit Bauwer-ken und sonstigen Einrichtungen zur Reinigung von Abwasser.'),
		('2612', 'Betriebsfläche Entsorgungsanlage, Abwasserbeseitigung', 'Betriebsfläche Entsorgungsanlage, Abwasserbeseitigung ist Teil von Kläranlage, Klärwerk. Kläranlage, Klärwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Reinigung von Abwasser.'),
		('2620', 'Abfallbehandlungsanlage', 'Abfallbehandlungsanlage bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen, auf der Abfälle mit chemisch/physikalischen und biologischen oder thermischen Verfahren oder Kombinationen dieser Verfahren behandelt werden.'),
		('2621', 'Gebäude- und Freifläche Entsorgungsanlage, Abfallbeseitigung', 'Gebäude- und Freifläche Entsorgungsanlage, Abfallbeseitigung ist Teil von Abfallbehandlungsanlage. Abfallbehandlungsanlage bezeichnet eine Fläche mit Bau-werken und sonstigen Einrichtungen, auf der Abfälle mit chemisch/physikalischen und biologischen oder thermischen Verfahren oder Kombinationen dieser Ver-fahren behandelt werden.'),
		('2622', 'Betriebsfläche Entsorgungsanlage, Abfallbeseitigung', 'Betriebsfläche Entsorgungsanlage, Abfallbeseitigung ist Teil von Abfallbehandlungsanlage. Abfallbehandlungsanlage bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen, auf der Abfälle mit chemisch/physikalischen und biologischen oder thermischen Verfahren oder Kombinationen dieser Verfahren behan-delt werden.'),
		('2623', 'Betriebsfläche Entsorgungsanlage, Schlamm', 'Betriebsfläche Entsorgungsanlage, Schlamm ist Teil von Abfallbehandlungsanlage. Abfallbehandlungsanlage bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen, auf der Abfälle mit chemisch/physikalischen und biologischen oder thermischen Verfahren oder Kombinationen dieser Verfahren behandelt wer-den.'),
		('2630', 'Deponie (oberirdisch)', 'Deponie (oberirdisch) bezeichnet eine Fläche, auf der oberirdisch Abfallstoffe gelagert werden.'),
		('2640', 'Deponie (untertägig)', 'Deponie (untertägig) bezeichnet eine oberirdische Betriebsfläche, unter der  Abfallstoffe eingelagert werden (Untertagedeponie).');
		CREATE TABLE ax_zustand_tagebaugrubesteinbruch (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_tagebaugrubesteinbruch IS 'Alias: "AX_Zustand_TagebauGrubeSteinbruch", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_tagebaugrubesteinbruch (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich Tagebau, Grube, Steinbruch nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', '');
		CREATE TABLE ax_artderbebauung_siedlungsflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderbebauung_siedlungsflaeche IS 'Alias: "AX_ArtDerBebauung_Siedlungsflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_artderbebauung_siedlungsflaeche (wert,beschreibung,dokumentation) VALUES
		('1000', 'Offen', 'Offen beschreibt die Bebauung von Fläche gemischter Nutzung, die vorwiegend durch einzelstehende Gebäude charakterisiert wird.'),
		('2000', 'Geschlossen', 'Geschlossen beschreibt die Bebauung von Siedlungsfläche, die vorwiegend durch zusammenhängende Gebäude charakterisiert wird. Die Gebäudeabdeckung ist in der Regel  > 50 Prozent der Fläche.');
		CREATE TABLE ax_artderbebauung_flaechebesondererfunktionalerpraegung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_artderbebauung_flaechebesondererfunktionalerpraegung IS 'Alias: "AX_ArtDerBebauung_FlaecheBesondererFunktionalerPraegung", UML-Typ: Enumeration';
		INSERT INTO ax_artderbebauung_flaechebesondererfunktionalerpraegung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Offen', 'Offen beschreibt die Bebauung von Fläche besonderer funktionaler Prägung, die vorwiegend durch einzelstehende Gebäude charakterisiert wird.'),
		('2000', 'Geschlossen', 'Geschlossen beschreibt die Bebauung von Fläche besonderer funktionaler Prägung, die vorwiegend durch zusammenhängende Gebäude charakterisiert wird. Die Gebäudeabdeckung ist in der Regel > 50 Prozent der Fläche.');
		CREATE TABLE ax_vegetationsmerkmal_gehoelz (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_vegetationsmerkmal_gehoelz IS 'Alias: "AX_Vegetationsmerkmal_Gehoelz", UML-Typ: Enumeration';
		INSERT INTO ax_vegetationsmerkmal_gehoelz (wert,beschreibung,dokumentation) VALUES
		('1400', 'Latschenkiefer', '');
		CREATE TABLE ax_vegetationsmerkmal_wald (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_vegetationsmerkmal_wald IS 'Alias: "AX_Vegetationsmerkmal_Wald", UML-Typ: Enumeration';
		INSERT INTO ax_vegetationsmerkmal_wald (wert,beschreibung,dokumentation) VALUES
		('1100', 'Laubholz', 'Laubholz beschreibt den Bewuchs einer Vegetationsfläche mit Laubbäumen.'),
		('1200', 'Nadelholz', 'Nadelholz beschreibt den Bewuchs einer Vegetationsfläche mit Nadelbäumen.'),
		('1300', 'Laub- und Nadelholz', 'Laub- und Nadelholz beschreibt den Bewuchs einer Vegetationsfläche mit Laub- und Nadelbäumen.'),
		('1310', 'Laubwald mit Nadelholz', ''),
		('1320', 'Nadelwald mit Laubholz', '');
		CREATE TABLE ax_vegetationsmerkmal_landwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_vegetationsmerkmal_landwirtschaft IS 'Alias: "AX_Vegetationsmerkmal_Landwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ax_vegetationsmerkmal_landwirtschaft (wert,beschreibung,dokumentation) VALUES
		('1010', 'Ackerland', 'Ackerland ist eine Fläche für den Anbau von Feldfrüchten (z.B. Getreide, Hülsenfrüchte, Hackfrüchte) und Beerenfrüchten (z.B. Erdbeeren). 
Zum Ackerland gehören auch die Rotationsbrachen, Dauerbrachen sowie Flächen, die zur Erlangung der Ausgleichszahlungen der EU stillgelegt worden sind.'),
		('1011', 'Streuobstacker', 'Streuobstacker beschreibt den Bewuchs einer Ackerfläche mit Obstbäumen.'),
		('1012', 'Hopfen', 'Hopfen ist eine mit speziellen Vorrichtungen ausgestattete Agrarfläche für den Anbau von Hopfen.'),
		('1013', 'Spargel', ''),
		('1020', 'Grünland', 'Grünland ist eine Grasfläche, die gemäht oder beweidet wird.'),
		('1021', 'Streuobstwiese', 'Streuobstwiese beschreibt den Bewuchs einer Grünlandfläche mit Obstbäumen.'),
		('1030', 'Gartenland', 'Gartenland ist eine Fläche für den Anbau von Gemüse, Obst und Blumen sowie für die Aufzucht von Kulturpflanzen.'),
		('1031', 'Baumschule', 'Baumschule ist eine Fläche, auf der Holzgewächse aus Samen, Ablegern oder Stecklingen unter mehrmaligem Umpflanzen (Verschulen) gezogen werden.'),
		('1040', 'Weingarten', 'Weingarten ist eine mit speziellen Vorrichtungen ausgestattete Agrarfläche auf der Weinstöcke angepflanzt sind.'),
		('1050', 'Obstplantage', 'Obstplantage ist eine landwirtschaftliche Fläche, die mit Obstbäumen und Obststräuchern bepflanzt ist'),
		('1051', 'Obstbaumplantage', 'Obstbaumplantage ist eine landwirtschaftliche Fläche, die ausschließlich mit Obstbäumen bepflanzt ist.'),
		('1052', 'Obststrauchplantage', ''),
		('1200', 'Brachland', 'Brachland ist eine Fläche der Landwirtschaft, die seit längerem nicht mehr zu Produktionszwecken genutzt wird.');
		CREATE TABLE ax_oberflaechenmaterial_unlandvegetationsloseflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_oberflaechenmaterial_unlandvegetationsloseflaeche IS 'Alias: "AX_Oberflaechenmaterial_UnlandVegetationsloseFlaeche", UML-Typ: Enumeration';
		INSERT INTO ax_oberflaechenmaterial_unlandvegetationsloseflaeche (wert,beschreibung,dokumentation) VALUES
		('1010', 'Fels', 'Fels bedeutet, dass die Erdoberfläche aus einer festen Gesteinsmasse besteht.'),
		('1020', 'Steine, Schotter', 'Steine, Schotter bedeutet, dass die Erdoberfläche mit zerkleinertem Gestein unterschiedlicher Größe bedeckt ist.'),
		('1030', 'Geröll', 'Geröll bedeutet, dass die Erdoberfläche mit durch fließendes Wasser abgerundeten Gesteinen bedeckt ist.'),
		('1040', 'Sand', 'Sand bedeutet, dass die Erdoberfläche mit kleinen, losen Gesteinskörnern bedeckt ist.'),
		('1110', 'Schnee', 'Schnee bedeutet, dass die Erdoberfläche für die größte Zeit des Jahres mit Schnee bedeckt ist.'),
		('1120', 'Eis, Firn', 'Eis, Firn bedeutet, dass die Erdoberfläche mit altem, grobkörnigem, mehrjährigem Schnee im Hochgebirge bedeckt ist, der unter zunehmendem Druck zu Gletschereis wird.');
		CREATE TABLE ax_funktion_unlandvegetationsloseflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_unlandvegetationsloseflaeche IS 'Alias: "AX_Funktion_UnlandVegetationsloseFlaeche", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_unlandvegetationsloseflaeche (wert,beschreibung,dokumentation) VALUES
		('1000', 'Vegetationslose Fläche', 'Vegetationslose Fläche ist eine Fläche ohne nennenswerten Bewuchs aufgrund besonderer Bodenbeschaffenheit.'),
		('1100', 'Gewässerbegleitfläche', 'Gewässerbegleitfläche bezeichnet eine bebaute oder unbebaute Fläche, die einem Gewässer zugeordnet wird. Die Gewässerbegleitfläche ist nicht Bestandteil der Gewässerfläche.'),
		('1110', 'Bebaute Gewässerbegleitfläche', ''),
		('1120', 'Unbebaute Gewässerbegleitfläche', ''),
		('1200', 'Sukzessionsfläche', 'Sukzessionsfläche ist eine Fläche, die dauerhaft aus der landwirtschaftlichen oder sonstigen bisherigen Nutzung herausgenommen ist und die in den Urzustand z. B. Gehölz, Moor, Heide übergeht.'),
		('1300', 'Naturnahe Fläche', 'Naturnahe Fläche ist eine nicht zum Anbau von Kulturpflanzen genutzte Fläche, die mit Gras, Wildkräutern und anderen Pflanzen bewachsen ist.');
		CREATE TABLE ax_funktion_gehoelz (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_gehoelz IS 'Alias: "AX_Funktion_Gehoelz", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_gehoelz (wert,beschreibung,dokumentation) VALUES
		('1000', 'Windschutz', '');
		CREATE TABLE ax_bahnkategorie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_bahnkategorie IS 'Alias: "AX_Bahnkategorie", UML-Typ: Enumeration';
		INSERT INTO ax_bahnkategorie (wert,beschreibung,dokumentation) VALUES
		('1100', 'Eisenbahn', 'Eisenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr Personen befördert und Güter transportiert werden.'),
		('1102', 'Güterverkehr', 'Güterverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr ausschließlich Güter transportiert werden.'),
		('1104', 'S-Bahn', 'S-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, der zur schnellen Personenbeförderung in Ballungsräumen dient und meist auf eigenen Gleisen verläuft.'),
		('1200', 'Stadtbahn', 'Stadtbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung im öffentlichen Nahverkehr fährt. Sie kann sowohl ober- als auch unterirdisch verlaufen.'),
		('1201', 'Straßenbahn', 'Straßenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienbahn zur Personenbeförderung fährt. Sie verläuft i. d. R. oberirdisch.'),
		('1202', 'U-Bahn', 'U-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung in Großstädten fährt. Sie verläuft i. d. R. unterirdisch.'),
		('1300', 'Seilbahn, Bergbahn', 'Seilbahn, Bergbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn große Höhenunterschiede überwindet.'),
		('1301', 'Zahnradbahn', 'Zahnradbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn mittels Zahnradantrieb große Höhenunterschiede in stark geneigtem Gelände überwindet.'),
		('1302', 'Standseilbahn', 'Standseilbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn auf einer stark geneigten, meist kurzen und geraden Strecke verläuft. Mit Hilfe eines oder mehrerer Zugseile wird ein Schienenfahrzeug bergauf gezogen und gleichzeitig ein zweites bergab gelassen.'),
		('1400', 'Museumsbahn', 'Museumsbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem ausschließlich Touristen in alten, meist restaurierten Zügen befördert werden.'),
		('1500', 'Bahn im Freizeitpark', 'Bahn im Freizeitpark ist die Bezeichnung für einen schienengebundenen Verkehrsweg innerhalb eines Freizeitparks.'),
		('1600', 'Magnetschwebebahn', 'Magnetschwebebahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem  räderlose Schienenfahrzeuge mit Hilfe von Magnetfeldern an oder auf einer Fahrschiene schwebend entlanggeführt werden.');
		CREATE TABLE ax_funktion_weg (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_weg IS 'Alias: "AX_Funktion_Weg", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_weg (wert,beschreibung,dokumentation) VALUES
		('5210', 'Fahrweg', ''),
		('5211', 'Hauptwirtschaftsweg', ''),
		('5212', 'Wirtschaftsweg', ''),
		('5220', 'Fußweg', 'Fußweg ist ein Weg, der auf Grund seines Ausbauzustandes nur von Fußgängern zu begehen ist.'),
		('5230', 'Gang', ''),
		('5240', 'Radweg', 'Radweg ist ein Weg, der als besonders gekennzeichneter und abgegrenzter Teil einer Straße oder mit selbständiger Linienführung für den Fahrradverkehr bestimmt ist.'),
		('5250', 'Rad- und Fußweg', 'Rad- und Fußweg ist ein Weg, der als besonders gekennzeichneter und abgegrenzter Teil einer Straße oder mit selbständiger Linienführung ausschließlich für den Fahrrad- und Fußgängerverkehr bestimmt ist.'),
		('5260', 'Reitweg', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_funktion_bahnverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_bahnverkehr IS 'Alias: "AX_Funktion_Bahnverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_bahnverkehr (wert,beschreibung,dokumentation) VALUES
		('2321', 'Gebäude- und Freifläche zu Verkehrsanlagen, Schiene', 'Gebäude- und Freifläche zu Verkehrsanlage, Schiene dient der Abwicklung und Sicherheit des Verkehrs sowie der Unterhaltung der Verkehrsfläche'),
		('2322', 'Verkehrsbegleitfläche Bahnverkehr', 'Verkehrsbegleitfläche Bahnverkehr bezeichnet eine bebaute oder unbebaute, an den Bahnkörper 
angrenzende Fläche, die dem Schienenverkehr dient.');
		CREATE TABLE ax_verkehrsbedeutunginneroertlich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_verkehrsbedeutunginneroertlich IS 'Alias: "AX_VerkehrsbedeutungInneroertlich", UML-Typ: Enumeration';
		INSERT INTO ax_verkehrsbedeutunginneroertlich (wert,beschreibung,dokumentation) VALUES
		('1000', 'Durchgangsverkehr', 'Durchgangsverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer innerörtlichen Straße (Durchgangsstraße), unabhängig von gesetzlichen Festlegungen (z.B. Landesstraßengesetz) Als Durchgangsstraße wird die Straße bezeichnet, auf der aufgrund des Ausbauzustandes und der örtlichen Verkehrsregelung der überörtliche Verkehr durch ein bebautes Gebiet geleitet wird. Der Durchgangsverkehr kann sowohl auf Gemeindestraßen als auch auf höherwertig klassifizierten Straßen liegen.'),
		('2000', 'Ortsverkehr', 'Ortsverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer innerörtlichen Straße (Ortsstraße), unabhängig von örtlichen Festlegungen (z.B. Ortssatzungen). Ortsstraße ist in der Regel eine als Gemeindestraße gewidmete Straße, auf der kein Durchgangsverkehr verläuft.'),
		('2001', 'Sammelverkehr', 'Sammelverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer innerörtlichen Straße (Sammelstraße), unabhängig von örtlichen Festlegungen (z.B. Ortssatzungen). Die Sammelstraße leitet hauptsächlich den innerörtlichen Verkehr von den Anliegerstrassen zur Durchgangsstraße.'),
		('2002', 'Anliegerverkehr', 'Anliegerverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer innerörtlichen Straße (Anliegerstraße), unabhängig von örtlichen Festlegungen (z.B. Ortssatzungen). Die Anliegerstraße ist eine Straße auf die jeder Straßenanlieger von seinem Anwesen aus freie Zufahrt hat und die nicht die Funktion einer Sammelstraße übernimmt.');
		CREATE TABLE ax_internationalebedeutung_strasse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_internationalebedeutung_strasse IS 'Alias: "AX_InternationaleBedeutung_Strasse", UML-Typ: Enumeration';
		INSERT INTO ax_internationalebedeutung_strasse (wert,beschreibung,dokumentation) VALUES
		('2001', 'Europastraße', 'Europastraßen sind Abschnitte von Bundesfernstraßen, die einen Teil des von der Europäischen Konferenz der Verkehrsminister beschlossenen internationalen europäischen Straßennetzes bilden.');
		CREATE TABLE ax_besonderefahrstreifen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_besonderefahrstreifen IS 'Alias: "AX_BesondereFahrstreifen", UML-Typ: Enumeration';
		INSERT INTO ax_besonderefahrstreifen (wert,beschreibung,dokumentation) VALUES
		('1000', 'Mit Radweg', 'Mit Radweg bedeutet, dass parallel zur <Objektart> ein Radweg verläuft, der aber nicht als eigenständiges Objekt erfasst wird.'),
		('2000', 'Mit Fußweg', 'Mit Fußweg bedeutet, dass parallel zur <Objektart> ein Fußweg verläuft, der aber nicht als eigenständiges Objekt erfasst wird.'),
		('3000', 'Mit Rad- und Fußweg', 'Mit Rad- und Fußweg bedeutet, dass parallel zur <Objektart> ein Rad- und Fußweg verläuft, der aber nicht als eigenständiges Objekt erfasst wird.');
		CREATE TABLE ax_zustand_bahnverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_bahnverkehr IS 'Alias: "AX_Zustand_Bahnverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bahnverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', ''),
		('4000', 'Im Bau', '');
		CREATE TABLE ax_befestigung_fahrwegachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_befestigung_fahrwegachse IS 'Alias: "AX_Befestigung_Fahrwegachse", UML-Typ: Enumeration';
		INSERT INTO ax_befestigung_fahrwegachse (wert,beschreibung,dokumentation) VALUES
		('1000', 'Befestigt', 'Befestigt bedeutet, dass Fahrwegachse mit einem festen Unterbau versehen und ganzjährig befahrbar bzw. begehbar ist.'),
		('2000', 'Unbefestigt', 'Unbefestigt bedeutet, dass Fahrwegachse nicht mit einem festen Unterbau versehen und nicht ganzjährig befahrbar bzw. begehbar ist.');
		CREATE TABLE ax_spurweite (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_spurweite IS 'Alias: "AX_Spurweite", UML-Typ: Enumeration';
		INSERT INTO ax_spurweite (wert,beschreibung,dokumentation) VALUES
		('1000', 'Normalspur (Regelspur, Vollspur)', 'Normalspur (Regelspur, Vollspur) hat eine Spurweite von 1435 mm. Das ist das Innenmaß zwischen den Innenkanten der Schienenköpfe eines Gleises.'),
		('2000', 'Schmalspur', 'Schmalspur ist eine Spurweite, die kleiner ist als 1435 mm.'),
		('3000', 'Breitspur', 'Breitspur ist eine Spurweite, die größer ist als 1435 mm.');
		CREATE TABLE ax_zustand_schiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_schiffsverkehr IS 'Alias: "AX_Zustand_Schiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_schiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich Schiffsverkehr nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass Schiffsverkehr noch nicht fertiggestellt ist.');
		CREATE TABLE ax_funktion_platz (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_platz IS 'Alias: "AX_Funktion_Platz", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_platz (wert,beschreibung,dokumentation) VALUES
		('5130', 'Fußgängerzone', 'Fußgängerzone ist ein dem Fußgängerverkehr vorbehaltener Bereich, in dem ausnahmsweise öffentlicher Personenverkehr, Lieferverkehr oder Fahrradverkehr zulässig sein kann.'),
		('5310', 'Parkplatz', 'Parkplatz ist eine zum vorübergehenden Abstellen von Fahrzeugen bestimmte Fläche.'),
		('5320', 'Rastplatz', 'Rastplatz ist eine Anlage zum Halten, Parken oder Rasten der Verkehrsteilnehmer mit unmittelbarem Anschluss zur Straße ohne Versorgungseinrichtung, ggf. mit Toiletten.'),
		('5330', 'Raststätte', 'Raststätte ist eine Anlage an Verkehrsstraßen mit Bauwerken und Einrichtungen zur Versorgung und 
Erholung von Reisenden.'),
		('5340', 'Marktplatz', ''),
		('5350', 'Festplatz', 'Festplatz ist eine Fläche, auf der zeitlich begrenzte Festveranstaltungen stattfinden.');
		CREATE TABLE ax_art_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_art_flugverkehr IS 'Alias: "AX_Art_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_art_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('5510', 'Flughafen', 'Flughafen ist eine Anlage mit Gebäuden, Bauwerken, Start- und Landebahnen sowie sonstigen  flugtechnischen Einrichtungen zur Abwicklung des Flugverkehrs.'),
		('5511', 'Internationaler Flughafen', 'Internationaler Flughafen ist ein Flughafen, der in der Luftfahrtkarte 1 : 500000 (ICAO) als solcher ausgewiesen ist.'),
		('5512', 'Regionalflughafen', 'Regionalflughafen ist ein Flughafen der gemäß Raumordnungsgesetz als Regionalflughafen eingestuft ist.'),
		('5520', 'Verkehrslandeplatz', 'Verkehrslandeplatz ist ein Flugplatz, der in der Luftfahrtkarte 1:500000 (ICAO) als solcher ausgewiesen ist.'),
		('5530', 'Hubschrauberflugplatz', 'Hubschrauberflugplatz ist ein Flugplatz, der in der Luftfahrtkarte 1:500000 (ICAO) als solcher ausgewiesen ist.'),
		('5540', 'Landeplatz, Sonderlandeplatz', 'Landeplatz, Sonderlandeplatz ist eine Fläche, die in der Luftfahrtkarte 1:500000 (ICAO) als Landeplatz, Sonderlandeplatz ausgewiesen ist.'),
		('5550', 'Segelfluggelände', 'Segelfluggelände ist eine Fläche, die in der Luftfahrtkarte 1:500000 (ICAO) als Segelfluggelände ausgewiesen ist.');
		CREATE TABLE ax_elektrifizierung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_elektrifizierung IS 'Alias: "AX_Elektrifizierung", UML-Typ: Enumeration';
		INSERT INTO ax_elektrifizierung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Elektrifiziert', 'Elektrifiziert bedeutet, dass den Schienenfahrzeugen über eine Oberleitung oder eine Stromschiene längs des Fahrweges elektrische Energie zugeführt wird.'),
		('2000', 'Nicht elektrifiziert', 'Nicht elektrifiziert bedeutet, dass die Schienenfahrzeuge ohne elektrische Energie angetrieben werden.');
		CREATE TABLE ax_zustand (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand IS 'Alias: "AX_Zustand", UML-Typ: Enumeration';
		INSERT INTO ax_zustand (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich <Objektart> nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass <Objektart> noch nicht fertiggestellt ist.');
		CREATE TABLE ax_fahrbahntrennung_strasse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_fahrbahntrennung_strasse IS 'Alias: "AX_Fahrbahntrennung_Strasse", UML-Typ: Enumeration';
		INSERT INTO ax_fahrbahntrennung_strasse (wert,beschreibung,dokumentation) VALUES
		('2000', 'Getrennt', 'Getrennt bedeutet, dass sich ein Grünstreifen, eine Leitplanke oder ein sonstiges Hindernis zwischen zwei Fahrbahnen befindet.');
		CREATE TABLE ax_funktion_fahrbahnachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_fahrbahnachse IS 'Alias: "AX_Funktion_Fahrbahnachse", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_fahrbahnachse (wert,beschreibung,dokumentation) VALUES
		('1808', 'Fußgängerzone', 'Fußgängerzone ist ein dem Fußgängerverkehr vorbehaltener Bereich, in dem ausnahmsweise öffentlicher Personenverkehr, Lieferverkehr oder Fahrradverkehr zulässig sein kann.');
		CREATE TABLE ax_oberflaechenmaterial_strasse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_oberflaechenmaterial_strasse IS 'Alias: "AX_Oberflaechenmaterial_Strasse", UML-Typ: Enumeration';
		INSERT INTO ax_oberflaechenmaterial_strasse (wert,beschreibung,dokumentation) VALUES
		('1220', 'Beton', 'Beton bedeutet, dass die Oberfläche von <Objektart> aus Beton besteht.'),
		('1230', 'Bitumen, Asphalt', 'Bitumen, Asphalt bedeutet, dass die Oberfläche von <Objektart> aus Bitumen bzw. Asphalt besteht.'),
		('1240', 'Pflaster', 'Pflaster bedeutet, dass die Oberfläche von <Objektart> gepflastert ist.'),
		('1250', 'Gestein, zerkleinert', 'Gestein, zerkleinert bedeutet, dass die Oberfläche von <Objektart> aus Schotter, Splitt, Sand oder aus einem Gemisch dieser Materialen besteht.');
		CREATE TABLE ax_funktion_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_flugverkehr IS 'Alias: "AX_Funktion_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('5501', 'Gebäude- und Freifläche zu Verkehrsanlagen, Luftfahrt', 'Gebäude- und Freifläche zu Verkehrsanlagen, Luftfahrt ist eine besondere Flugverkehrsfläche.');
		CREATE TABLE ax_funktion_wegachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_wegachse IS 'Alias: "AX_Funktion_Wegachse", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_wegachse (wert,beschreibung,dokumentation) VALUES
		('5211', 'Hauptwirtschaftsweg', 'Hauptwirtschaftsweg ist ein Weg mit fester Fahrbahndecke zur Erschließung eines oder mehrerer Grundstücke, der für den Kraftverkehr zu jeder Jahreszeit befahrbar ist.'),
		('5212', 'Wirtschaftsweg', 'Wirtschaftsweg ist ein leicht- oder unbefestigter Weg zur Erschließung  land- und forstwirtschaftlicher Flächen.');
		CREATE TABLE ax_zustand_strasse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_strasse IS 'Alias: "AX_Zustand_Strasse", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_strasse (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', ''),
		('4000', 'Im Bau', '');
		CREATE TABLE ax_markierung_wegachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_markierung_wegachse IS 'Alias: "AX_Markierung_Wegachse", UML-Typ: Enumeration';
		INSERT INTO ax_markierung_wegachse (wert,beschreibung,dokumentation) VALUES
		('1401', 'Gekennzeichneter Wanderweg', 'Gekennzeichneter Wanderweg ist ein als Wanderweg eindeutig markierter Weg.'),
		('1402', 'Gekennzeichneter Rad(wander)weg', 'Gekennzeichneter Rad(wander)weg ist ein als Rad(wander)weg eindeutig markierter Weg.'),
		('1403', 'Gekennzeichnete Skaterstrecke', 'Gekennzeichnete Skaterstrecke ist ein als Skaterstrecke eindeutig markierter Weg.');
		CREATE TABLE ax_zustand_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_zustand_flugverkehr IS 'Alias: "AX_Zustand_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt; verlassen bedeutet, dass sich Flugverkehr nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass Flugverkehr noch nicht fertiggestellt ist.');
		CREATE TABLE ax_funktion_strassenachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_strassenachse IS 'Alias: "AX_Funktion_Strassenachse", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_strassenachse (wert,beschreibung,dokumentation) VALUES
		('1808', 'Fußgängerzone', 'Fußgängerzone ist ein dem Fußgängerverkehr vorbehaltener Bereich, in dem ausnahmsweise öffentlicher Personenverkehr, Lieferverkehr oder Fahrradverkehr zulässig sein kann.');
		CREATE TABLE ax_verkehrsbedeutungueberoertlich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_verkehrsbedeutungueberoertlich IS 'Alias: "AX_VerkehrsbedeutungUeberoertlich", UML-Typ: Enumeration';
		INSERT INTO ax_verkehrsbedeutungueberoertlich (wert,beschreibung,dokumentation) VALUES
		('1000', 'Überörtlicher Verkehr', 'Überörtlicher Verkehr umfasst die Verkehrswege des Fern-, Regional- und Nahverkehrs.'),
		('1001', 'Fernverkehr', 'Fernverkehr findet hauptsächlich auf dem zusammenhängenden Verkehrsnetz der Bundesautobahnen und Bundesstraßen statt.'),
		('1002', 'Regionalverkehr', 'Regionalverkehr findet hauptsächlich auf Landes- und Kreisstraßen statt.'),
		('1003', 'Nahverkehr, zwischenörtlicher Verkehr', 'Nahverkehr, zwischenörtlicher Verkehr findet hauptsächlich auf Kreis- und Gemeindestraßen statt.');
		CREATE TABLE ax_nutzung_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_nutzung_flugverkehr IS 'Alias: "AX_Nutzung_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_nutzung_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zivil', 'Zivil bedeutet, dass Flugverkehr privaten, öffentlichen oder religiösen Zwecken dient und nicht militärisch genutzt wird.'),
		('2000', 'Militärisch', 'Militärisch bedeutet, dass Flugverkehr nur von Streitkräften genutzt wird.'),
		('3000', 'Teils zivil, teils militärisch', 'Teils zivil, teils militärisch bedeutet dass Flugverkehr sowohl zivil als auch militärisch genutzt wird.');
		CREATE TABLE ax_funktion_schiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_schiffsverkehr IS 'Alias: "AX_Funktion_Schiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_schiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('2341', 'Gebäude und Freifläche zu Verkehrsanlagen, Schifffahrt', 'Gebäude- und Freifläche zu Verkehrsanlagen, Schifffahrt ist eine Fläche, die dem Schiffsverkehr dient.'),
		('5610', 'Hafenanlage (Landfläche)', 'Hafenanlage (Landfläche) bezeichnet die Fläche innerhalb von Hafen, die nicht von Wasser bedeckt ist und die ausschließlich zum Betrieb des Hafens dient.'),
		('5620', 'Schleuse (Landfläche)', 'Schleuse (Landfläche) bezeichnet die Fläche innerhalb von Schleuse, die nicht von Wasser bedeckt ist und die ausschließlich zum Betrieb der Schleuse dient..'),
		('5630', 'Anlegestelle', 'Anlegestelle umfasst mehr als den überlagernden landseitigen Anleger, der eine feste oder schwimmende Einrichtung zum Anlegen von Schiffen ist.'),
		('5640', 'Fähranlage', 'Fähranlage ist eine besondere Landfläche von der in der Regel nach festem Fahrplan über Flüsse, Seen, Kanäle, Meerengen oder Meeresarme ein Schiffsverkehr stattfindet.');
		CREATE TABLE ax_funktion_strasse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktion_strasse IS 'Alias: "AX_Funktion_Strasse", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_strasse (wert,beschreibung,dokumentation) VALUES
		('2311', 'Gebäude- und Freifläche zu Verkehrsanlagen, Straße', 'Gebäude- und Freifläche zu Verkehrsanlagen, Straße ist eine Fläche. die der Abwicklung und Sicherheit des Verkehrs sowie der Unterhaltung der Verkehrsfläche dient.'),
		('2312', 'Verkehrsbegleitfläche Straße', 'Verkehrsbegleitfläche Straße bezeichnet eine bebaute oder unbebaute Fläche, die einer Straße zugeordnet wird. Die Verkehrsbegleitfläche Straße ist nicht Bestandteil der Fahrbahn.'),
		('2313', 'Straßenentwässerungsanlage', ''),
		('5130', 'Fußgängerzone', 'Fußgängerzone ist ein dem Fußgängerverkehr vorbehaltener Bereich, in dem ausnahmsweise öffentlicher Personenverkehr, Lieferverkehr oder Fahrradverkehr zulässig sein kann.');
		CREATE TABLE ax_widmung_strasse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_widmung_strasse IS 'Alias: "AX_Widmung_Strasse", UML-Typ: Enumeration';
		INSERT INTO ax_widmung_strasse (wert,beschreibung,dokumentation) VALUES
		('1301', 'Bundesautobahn', 'Bundesautobahn ist eine durch Verwaltungsakt zur Bundesautobahn gewidmete Bundesfernstraße.'),
		('1303', 'Bundesstraße', 'Bundesstraße ist eine durch Verwaltungsakt zur Bundesstraße gewidmete Bundesfernstraße.'),
		('1305', 'Landesstraße, Staatsstraße', 'Landesstraße, Staatsstraße ist eine durch Verwaltungsakt zur Landesstraße bzw. Staatsstraße gewidmete Straße.'),
		('1306', 'Kreisstraße', 'Kreisstraße ist eine durch Verwaltungsakt zur Kreisstraße gewidmete Straße.'),
		('1307', 'Gemeindestraße', 'Gemeindestraße ist eine durch Verwaltungsakt zur Gemeindestrasse gewidmete Straße.'),
		('9997', 'Attribut trifft nicht zu', 'Attribut trifft nicht zu bedeutet, dass keiner der in der Werteliste aufgeführten Attributwerte dem vorliegenden Sachverhalt entspricht.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Straße eine Widmung aufweist, die bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_anzahlderstreckengleise (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_anzahlderstreckengleise IS 'Alias: "AX_AnzahlDerStreckengleise", UML-Typ: Enumeration';
		INSERT INTO ax_anzahlderstreckengleise (wert,beschreibung,dokumentation) VALUES
		('1000', 'Eingleisig', 'Eingleisig bedeutet, dass für Bahnstrecke nur ein Gleis für beide Fahrtrichtungen zur Verfügung steht.'),
		('2000', 'Zweigleisig', 'Zweigleisig bedeutet, dass für Bahnstrecke je ein Gleis für eine Fahrtrichtung zur Verfügung steht.');
		CREATE TABLE ax_funktionoa_k_tngr_all (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktionoa_k_tngr_all IS 'Alias: "AX_FunktionOA_K_TNGR_all", UML-Typ: Enumeration';
		INSERT INTO ax_funktionoa_k_tngr_all (wert,beschreibung,dokumentation) VALUES
		('Wohnbaufläche', NULL, ''),
		('Industrie- und Gewerbefläche', NULL, ''),
		('Straßenverkehr', NULL, ''),
		('Gehölz', NULL, ''),
		('Wald', NULL, ''),
		('Friedhof', NULL, ''),
		('Halde', NULL, ''),
		('Moor', NULL, ''),
		('Schiffsverkehr', NULL, ''),
		('Sport-, Freizeit- und Erholungsfläche', NULL, ''),
		('Bergbaubetrieb', NULL, ''),
		('Hafenbecken', NULL, ''),
		('Platz', NULL, ''),
		('Flugverkehr', NULL, ''),
		('Heide', NULL, ''),
		('Fließgewässer', NULL, ''),
		('Fläche besonderer funktionaler Prägung', NULL, ''),
		('Meer', NULL, ''),
		('Landwirtschaft', NULL, ''),
		('Tagebau, Grube, Steinbruch', NULL, ''),
		('Sumpf', NULL, ''),
		('Bahnverkehr', NULL, ''),
		('UnlandVegetationslose Fläche', NULL, ''),
		('Weg', NULL, ''),
		('Stehendes Gewässer', NULL, ''),
		('Fläche gemischter Nutzung', NULL, '');
		CREATE TABLE ax_klassifizierunggr_k_bewgr (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_klassifizierunggr_k_bewgr IS 'Alias: "AX_KlassifizierungGr_K_BEWGR", UML-Typ: Enumeration';
		INSERT INTO ax_klassifizierunggr_k_bewgr (wert,beschreibung,dokumentation) VALUES
		('Forstwirtschaftliche Nutzung', NULL, ''),
		('Weinbauliche Nutzung', NULL, ''),
		('Landwirtschaftliche Nutzung', NULL, ''),
		('Gärtnerische Nutzung', NULL, ''),
		('Nebenflächen des Betriebs der Land- und Forstwirtschaft', NULL, ''),
		('Andere Nutzung', NULL, ''),
		('Noch nicht klassifiziert', NULL, ''),
		('Waldflächen', NULL, ''),
		('Gewässerflächen', NULL, ''),
		('Straßenflächen', NULL, ''),
		('Sonstige Land- und forstwirtschaftliche Nutzung', NULL, '');
		CREATE TABLE ax_funktionoa_k_tnfl (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktionoa_k_tnfl IS 'Alias: "AX_FunktionOA_K_TNFL", UML-Typ: Enumeration';
		INSERT INTO ax_funktionoa_k_tnfl (wert,beschreibung,dokumentation) VALUES
		('Fließgewässer', NULL, ''),
		('Wald', NULL, ''),
		('Hafenbecken', NULL, ''),
		('Versorgungsanlage', NULL, ''),
		('Fläche gemischter Nutzung', NULL, ''),
		('Flugverkehr', NULL, ''),
		('Heide', NULL, ''),
		('Wohnbaufläche', NULL, ''),
		('Sport-, Freizeit- und Erholungsfläche', NULL, ''),
		('Industrie- und Gewerbefläche', NULL, ''),
		('Meer', NULL, ''),
		('Friedhof', NULL, ''),
		('Grünanlage', NULL, ''),
		('Straßenverkehr', NULL, ''),
		('Bahnverkehr', NULL, ''),
		('Entsorgung', NULL, ''),
		('Landwirtschaft', NULL, ''),
		('Fläche besonderer funktionaler Prägung', NULL, ''),
		('Halde', NULL, ''),
		('Sumpf', NULL, ''),
		('Weg', NULL, ''),
		('Gehölz', NULL, ''),
		('Bergbaubetrieb', NULL, ''),
		('StehendesGewässer', NULL, ''),
		('UnlandVegetationslose Fläche', NULL, ''),
		('Platz', NULL, ''),
		('Industrie und Gewerbe', NULL, ''),
		('Tagebau, Grube, Steinbruch', NULL, ''),
		('Moor', NULL, ''),
		('Schiffsverkehr', NULL, ''),
		('Handel und Dienstleistungen', NULL, '');
		CREATE TABLE ax_klassifizierungobg_k_bewfl (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_klassifizierungobg_k_bewfl IS 'Alias: "AX_KlassifizierungOBG_K_BEWFL", UML-Typ: Enumeration';
		INSERT INTO ax_klassifizierungobg_k_bewfl (wert,beschreibung,dokumentation) VALUES
		('Grünland-Acker', NULL, ''),
		('Hutung', NULL, ''),
		('Weingarten 4', NULL, ''),
		('Unland', NULL, ''),
		('Baumschule', NULL, ''),
		('Hopfen', NULL, ''),
		('Obstplantage', NULL, ''),
		('Ackerland-Grünland', NULL, ''),
		('Holzung', NULL, ''),
		('Wiese', NULL, ''),
		('Weihnachtsbaumkultur', NULL, ''),
		('Gartenland', NULL, ''),
		('Saatzucht', NULL, ''),
		('Nebenflächen des Betriebs der Land- und Forstwirtschaft', NULL, ''),
		('Anbaufläche unter Glas', NULL, ''),
		('Weingarten (allgemein)', NULL, ''),
		('Weingarten 1', NULL, ''),
		('Weingarten 2', NULL, ''),
		('Ackerland', NULL, ''),
		('Spargel', NULL, ''),
		('Grünland-Hackrain', NULL, ''),
		('Teichwirtschaft', NULL, ''),
		('Weingarten 6', NULL, ''),
		('Geringstland', NULL, ''),
		('Kleingarten', NULL, ''),
		('Acherland-Hackrain', NULL, ''),
		('Grünland', NULL, ''),
		('Weingarten 5', NULL, ''),
		('Weingarten 7', NULL, ''),
		('Weingarten 3', NULL, ''),
		('Abbauland der Land- und Forstwirtschaft', NULL, ''),
		('Streuwiese', NULL, '');
		CREATE TABLE ax_funktionoa_k_tngrerweitert_all (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktionoa_k_tngrerweitert_all IS 'Alias: "AX_FunktionOA_K_TNGRerweitert_all", UML-Typ: Enumeration';
		INSERT INTO ax_funktionoa_k_tngrerweitert_all (wert,beschreibung,dokumentation) VALUES
		('Schleuse (Landfläche)', NULL, ''),
		('Obstbaumplantage', NULL, ''),
		('Campingplatz', NULL, ''),
		('Straßenverkehr', NULL, ''),
		('Betriebsfläche Entsorgungsanlage', NULL, ''),
		('Handel', NULL, ''),
		('Friedhof (ohne Geb äude)', NULL, ''),
		('Freizeitpark', NULL, ''),
		('Verkehrsübungsplatz', NULL, ''),
		('Freizeitanlage', NULL, ''),
		('Gebäude- und Freifläche Sport, Freizeit und Erholung', NULL, ''),
		('Reitweg', NULL, ''),
		('Hopfen', NULL, ''),
		('Soziales', NULL, ''),
		('Flugverkehr', NULL, ''),
		('Gebäude- und Freifläche Erholung, Camping', NULL, ''),
		('Sonstiges (Sport-, Freizeit- und Erholungsfläche)', NULL, ''),
		('Betriebsfläche Entsorgungsanlage, Abwasserbeseitigung', NULL, ''),
		('Kleingarten', NULL, ''),
		('Rastplatz', NULL, ''),
		('Anlegestelle', NULL, ''),
		('Historischer Friedhof', NULL, ''),
		('Tennisplatz', NULL, ''),
		('Grünland', NULL, ''),
		('Burg-, Festungsanlage', NULL, ''),
		('Sonstiges (Weg)', NULL, ''),
		('Nadelwald mit Laubholz', NULL, ''),
		('Gebäude- und Freifläche zu Verkehrsanlagen, Straße', NULL, ''),
		('Autokino, Freilichtkino', NULL, ''),
		('Bergbaubetrieb', NULL, ''),
		('Kläranlage, Klärwerk', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage, Elektrizität', NULL, ''),
		('Wohnen und Betrieb', NULL, ''),
		('Versicherung', NULL, ''),
		('Radweg', NULL, ''),
		('Betrieb', NULL, ''),
		('Deponie (untertägig)', NULL, ''),
		('Raststätte', NULL, ''),
		('Kultur', NULL, ''),
		('See', NULL, ''),
		('Beherbergung', NULL, ''),
		('Betriebsfläche Entsorgungsanlage, Schlamm', NULL, ''),
		('Obststrauchplantage', NULL, ''),
		('Transport', NULL, ''),
		('Abfallbehandlungsanlage', NULL, ''),
		('Versorgungsanlage', NULL, ''),
		('Betriebsfläche Versorgungsanlage', NULL, ''),
		('Golfplatz', NULL, ''),
		('Weingarten', NULL, ''),
		('Windschutz', NULL, ''),
		('Gebäude- und Freifläche Land- und Forstwirtschaft', NULL, ''),
		('Festplatz', NULL, ''),
		('Lagerplatz', NULL, ''),
		('Spargel', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage, Wasser', NULL, ''),
		('Gebäude- und Freifläche Entsorgungsanlage, Abwasserbeseitigung', NULL, ''),
		('Hafenbecken', NULL, ''),
		('Gebäude- und Freifläche Erholung, Botanik', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage', NULL, ''),
		('Wasserwerk', NULL, ''),
		('Sportplatz', NULL, ''),
		('Ackerland', NULL, ''),
		('Funk- und Fernmeldeanlage', NULL, ''),
		('Obstplantage', NULL, ''),
		('Grundstoff', NULL, ''),
		('Fußweg', NULL, ''),
		('Entsorgung', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage, Öl', NULL, ''),
		('Stausee', NULL, ''),
		('Gebäude- und Freifläche Erholung, Zoologie', NULL, ''),
		('Fluss', NULL, ''),
		('Tagebau, Grube, Steinbruch', NULL, ''),
		('Förderanlage', NULL, ''),
		('Gebäude- und Freifläche Erholung', NULL, ''),
		('Hauptwirtschaftsweg', NULL, ''),
		('Gärtnerei', NULL, ''),
		('Modellflugplatz', NULL, ''),
		('Baumschule', NULL, ''),
		('Garten', NULL, ''),
		('Wohnen', NULL, ''),
		('Forschung', NULL, ''),
		('Bildung und Forschung', NULL, ''),
		('Kanal', NULL, ''),
		('Industrie und Gewerbe', NULL, ''),
		('Betriebsfläche Versorgungsanlage, Wärme', NULL, ''),
		('Brachland', NULL, ''),
		('Handwerk', NULL, ''),
		('Flussmündungstrichter', NULL, ''),
		('Altarm', NULL, ''),
		('Verkehrsbegleitfläche Straße', NULL, ''),
		('Wohnbaufläche', NULL, ''),
		('Fortswirtschaftliche Betriebsfläche', NULL, ''),
		('Sporthafenbecken', NULL, ''),
		('Laubholz', NULL, ''),
		('Restauration', NULL, ''),
		('Safaripark, Wildpark', NULL, ''),
		('Gebäude- und Freifläche zu Verkehrsanlagen, Luftfahrt', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage, Funk- und Fernmeldewesen', NULL, ''),
		('Rad- und Fußweg', NULL, ''),
		('Grünanlage', NULL, ''),
		('Raffinerie', NULL, ''),
		('Sukzessionsfläche', NULL, ''),
		('Fähranlage', NULL, ''),
		('Sport-, Freizeit- und Erholungsfläche', NULL, ''),
		('Landwirtschaftliche Betriebsfläche', NULL, ''),
		('Gebäude- und Freifläche zu Verkehrsanlagen, Schifffahrt', NULL, ''),
		('Verwaltung', NULL, ''),
		('Gebäude- und Freifläche, Mischnutzung mit Wohnen', NULL, ''),
		('Reitplatz', NULL, ''),
		('Betriebsfläche Entsorguingsanlage, Abfallbeseitigung', NULL, ''),
		('Gebäude- und Freifläche Entsorgungsanlage, Abfallbeseitigung', NULL, ''),
		('Straßenentwässerungsanlage', NULL, ''),
		('Wald', NULL, ''),
		('Moor', NULL, ''),
		('Heizwerk', NULL, ''),
		('Gewerbe und Industrie mit Wohnen', NULL, ''),
		('Betriebsfläche Versorgungsanlage, Wasser', NULL, ''),
		('Fleet', NULL, ''),
		('Bebaute Gewässerbegleitfläche', NULL, ''),
		('Meer', NULL, ''),
		('Betriebsfläche Versorgungsanlage, Gas', NULL, ''),
		('Wirtschaftsweg', NULL, ''),
		('Gebäude- und Freifläche Friedhof', NULL, ''),
		('Küstengewässer', NULL, ''),
		('Fußgängerzone (Straßenverkehr)', NULL, ''),
		('Betriebsfläche Versorgungsanlage, Öl', NULL, ''),
		('Gang', NULL, ''),
		('Schlossanlage', NULL, ''),
		('Freilichttheater', NULL, ''),
		('Gebäude- und Freifläche Entsorgungsanlage', NULL, ''),
		('Marktplatz', NULL, ''),
		('Gaswerk', NULL, ''),
		('Schießanlage', NULL, ''),
		('Baggersee', NULL, ''),
		('Gebäude- und Freifläche Industrie und Gewerbe', NULL, ''),
		('Deponie (oberirdisch)', NULL, ''),
		('Speicherbecken', NULL, ''),
		('Handel und Dienstleistung', NULL, ''),
		('Vegetationslose Fläche', NULL, ''),
		('Erholungsfläche', NULL, ''),
		('Fließgewässer', NULL, ''),
		('Wochenend- und Ferienhausfläche', NULL, ''),
		('Gesundheit, Kur', NULL, ''),
		('Tankstelle', NULL, ''),
		('Wohnen mit Handel und Dienstleistungen', NULL, ''),
		('Religiöse Einrichtung', NULL, ''),
		('Vergnügen', NULL, ''),
		('Ausstellung, Messe', NULL, ''),
		('Betriebsfläche Versorgungsanlage, Funkt- und Fernmeldewesen', NULL, ''),
		('Handel und Dienstleistungen mit Wohnen', NULL, ''),
		('Historische Anlage', NULL, ''),
		('Weg', NULL, ''),
		('Wohnen mit Gewerbe und Industrie', NULL, ''),
		('Halde', NULL, ''),
		('Produktion', NULL, ''),
		('Betriebsfläche Versorgungsanlage, Elektrizität', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage, Wärme', NULL, ''),
		('Spielplatz, Bolzplatz', NULL, ''),
		('Öffentlich mit Wohnen', NULL, ''),
		('Industrie- und Gewerbefläche', NULL, ''),
		('Streuobstwiese', NULL, ''),
		('Laubwald mit Nadelholz', NULL, ''),
		('Schwimmbad, Freibad', NULL, ''),
		('Gebäude- und Freifläche Versorgungsanlage, Gas', NULL, ''),
		('Betriebliche Sozialeinrichtungen', NULL, ''),
		('Verkehrsbegleitfläche Bahnverkehr', NULL, ''),
		('Fläche gemischter Nutzung', NULL, ''),
		('Sicherheit und Ordnung', NULL, ''),
		('Umspannstation', NULL, ''),
		('Bank, Kredit', NULL, ''),
		('Hafenanlage (Landfläche)', NULL, ''),
		('Werft', NULL, ''),
		('Nadelholz', NULL, ''),
		('Wohnen mit Öffentlich', NULL, ''),
		('Bahnverkehr', NULL, ''),
		('Gebäude- und Freifläche Erholung, Sport', NULL, ''),
		('Gartenland', NULL, ''),
		('Grünfläche', NULL, ''),
		('Sportanlage', NULL, ''),
		('Landwirtschaft', NULL, ''),
		('Heide', NULL, ''),
		('Latschenkiefer', NULL, ''),
		('Gehölz', NULL, ''),
		('Gewässerbegleitfläche', NULL, ''),
		('Teich', NULL, ''),
		('Unbebaute Gewässerbegleitfläche', NULL, ''),
		('Zoo', NULL, ''),
		('Gebäude- und Freifläche Erholung, Bad', NULL, ''),
		('Kraftwerk', NULL, ''),
		('Parkplatz', NULL, ''),
		('Freilichtmuseum', NULL, ''),
		('Parken', NULL, ''),
		('Streuobstacker', NULL, ''),
		('Park', NULL, ''),
		('Hundeübungsplatz', NULL, ''),
		('Fläche besonderer funktionaler Prägung', NULL, ''),
		('Graben', NULL, ''),
		('UnlandVegetationslose Fläche', NULL, ''),
		('Platz', NULL, ''),
		('Bach', NULL, ''),
		('Öffentliche Zwecke', NULL, ''),
		('Fahrweg', NULL, ''),
		('Stehendes Gewässer', NULL, ''),
		('Rennbahn', NULL, ''),
		('Laub- und Nadelholz', NULL, ''),
		('Altwasser', NULL, ''),
		('Friedhof', NULL, ''),
		('Eis-, Rollschuhbahn', NULL, ''),
		('Schiffsverkehr', NULL, ''),
		('Friedhof (Park)', NULL, ''),
		('Sumpf', NULL, ''),
		('Fußgängerzone (Platz)', NULL, ''),
		('Verwaltung, freie Berufe', NULL, ''),
		('Wochenendplatz', NULL, ''),
		('Botanischer Garten', NULL, ''),
		('Gebäude- und Freifläche zu Verkehrtsanlagen, Schiene', NULL, '');
		CREATE TABLE ax_funktionhgr_k_tnhgr (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_funktionhgr_k_tnhgr IS 'Alias: "AX_FunktionHGr_K_TNHGR", UML-Typ: Enumeration';
		INSERT INTO ax_funktionhgr_k_tnhgr (wert,beschreibung,dokumentation) VALUES
		('Gewässer', NULL, ''),
		('Siedlung', NULL, ''),
		('Vegetation', NULL, ''),
		('Verkehr', NULL, '');
		CREATE TABLE ax_wirtschaftsart (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_wirtschaftsart IS 'Alias: "AX_Wirtschaftsart", UML-Typ: Enumeration';
		INSERT INTO ax_wirtschaftsart (wert,beschreibung,dokumentation) VALUES
		('Friedhof', NULL, ''),
		('Historische Anlage', NULL, ''),
		('Waldfläche', NULL, ''),
		('Verkehrsfläche', NULL, ''),
		('Betriebsfläche', NULL, ''),
		('Wasserfläche', NULL, ''),
		('Gebäude- und Freifläche', NULL, ''),
		('Erholungsfläche', NULL, ''),
		('Unland', NULL, ''),
		('Übungsgelände', NULL, ''),
		('Landwirtschaftsfläche', NULL, '');
		CREATE TABLE ax_punktart_k_punkte (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_punktart_k_punkte IS 'Alias: "AX_Punktart_K_PUNKTE", UML-Typ: Enumeration';
		INSERT INTO ax_punktart_k_punkte (wert,beschreibung,dokumentation) VALUES
		('Gebäudepunkt', NULL, ''),
		('Sicherungspunkt', NULL, ''),
		('Lagefestpunkt', NULL, ''),
		('Topographischer Punkt', NULL, ''),
		('Vermessungspunkt', NULL, ''),
		('Bauwerkspunkt', NULL, ''),
		('Aufnahmepunkt', NULL, '');
		CREATE TABLE ax_k_zeile_punktart (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);

		COMMENT ON TABLE ax_k_zeile_punktart IS 'Alias: "AX_K_ZEILE_Punktart", UML-Typ: Enumeration';
		INSERT INTO ax_k_zeile_punktart (wert,beschreibung,dokumentation) VALUES
		('Sonstiger Vermessungspunkt', NULL, ''),
		('Sicherungspunkt', NULL, ''),
		('Grenzpunkt', NULL, ''),
		('Aufnahmepunkt', NULL, ''),
		('Besonderer Bauwerkspunkt', NULL, ''),
		('Besonderer Gebäudepunkt', NULL, ''),
		('Besonderer topographischer Punkt', NULL, '');
		CREATE TABLE aa_besonderemeilensteinkategorie (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);

		COMMENT ON TABLE aa_besonderemeilensteinkategorie IS 'Alias: "AA_BesondereMeilensteinkategorie", UML-Typ: Code Liste';
		CREATE TABLE aa_anlassart (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);

		COMMENT ON TABLE aa_anlassart IS 'Alias: "AA_Anlassart", UML-Typ: Code Liste';
		CREATE TABLE aa_levelofdetail (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);

		COMMENT ON TABLE aa_levelofdetail IS 'Alias: "AA_LevelOfDetail", UML-Typ: Code Liste';
		CREATE TABLE aa_anlassart_benutzungsauftrag (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);

		COMMENT ON TABLE aa_anlassart_benutzungsauftrag IS 'Alias: "AA_Anlassart_Benutzungsauftrag", UML-Typ: Code Liste';
		CREATE TABLE aa_weiteremodellart (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);

		COMMENT ON TABLE aa_weiteremodellart IS 'Alias: "AA_WeitereModellart", UML-Typ: Code Liste';
		CREATE TABLE aa_instanzenthemen (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);

		COMMENT ON TABLE aa_instanzenthemen IS 'Alias: "AA_Instanzenthemen", UML-Typ: Code Liste';

		INSERT INTO aa_anlassart (id, value) VALUES ('000000', 'Ersteinrichtung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010307', 'Eintragung des Flurstückes');
		INSERT INTO aa_anlassart (id, value) VALUES ('010308', 'Löschen des Flurstückes');
		INSERT INTO aa_anlassart (id, value) VALUES ('010309', 'Veränderung der Gemeindezugehörigkeit einzelner Flurstücke');
		INSERT INTO aa_anlassart (id, value) VALUES ('010310', 'Veränderung der Gemeindezugehörigkeit');
		INSERT INTO aa_anlassart (id, value) VALUES ('010312', 'Veränderung der Flurstücksnummer ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010317', 'Gebäudeeinmessung nach § 14 Abs. 2 Satz 2 VermGeoG LSA');
		INSERT INTO aa_anlassart (id, value) VALUES ('010401', 'Veränderung der besonderen Flurstücksgrenze');
		INSERT INTO aa_anlassart (id, value) VALUES ('010402', 'Veränderung der Lage');
		INSERT INTO aa_anlassart (id, value) VALUES ('010403', 'Veränderung der tatsächlichen Nutzung mit Änderung der Wirtschaftsart');
		INSERT INTO aa_anlassart (id, value) VALUES ('010404', 'Veränderung des Anliegervermerks');
		INSERT INTO aa_anlassart (id, value) VALUES ('010405', 'Veränderung der tatsächlichen Nutzung ohne Änderung der Wirtschaftsart ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010501', 'Berichtigung der Flächenangabe');
		INSERT INTO aa_anlassart (id, value) VALUES ('010502', 'Berichtigung eines Zeichenfehlers');
		INSERT INTO aa_anlassart (id, value) VALUES ('010503', 'Berichtigung eines Katastrierungsfehlers');
		INSERT INTO aa_anlassart (id, value) VALUES ('300420', 'Veränderung der Bodenschätzung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010511', 'Berichtigung der Flächenangabe mit Veränderung des Flurstückskennzeichens');
		INSERT INTO aa_anlassart (id, value) VALUES ('050300', 'Berichtigung aufgrund Erwerbsvorgängen außerhalb des Grundbuchs');
		INSERT INTO aa_anlassart (id, value) VALUES ('060000', 'Grundstücke buchen');
		INSERT INTO aa_anlassart (id, value) VALUES ('060100', 'Abschreibung');
		INSERT INTO aa_anlassart (id, value) VALUES ('060101', 'Abschreibung auf neues Buchungsblatt');
		INSERT INTO aa_anlassart (id, value) VALUES ('010601', 'Verfahren nach dem Flurbereinigungsgesetz');
		INSERT INTO aa_anlassart (id, value) VALUES ('010602', 'Verfahren nach dem Baugesetzbuch');
		INSERT INTO aa_anlassart (id, value) VALUES ('010611', 'Flurbereinigung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010615', 'Übernahme von wichtigen Terminen im Ablauf eines Bodenordnungsverfahrens ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010616', 'Vermessung der Verfahrensgrenze des Flurbereinigungsgebietes');
		INSERT INTO aa_anlassart (id, value) VALUES ('010619', 'Übernahme von Flurbereinigungsergebnissen');
		INSERT INTO aa_anlassart (id, value) VALUES ('010621', 'Umlegung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010622', 'Umlegung nach § 76 BauGB');
		INSERT INTO aa_anlassart (id, value) VALUES ('010623', 'Vereinfachte Umlegung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010700', 'Katastererneuerung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010701', 'Katastererneuerung - vereinfachte Neuvermessung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010702', 'Erneuerung der Lagekoordinaten ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010703', 'Veränderung aufgrund der Qualitätsverbesserung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010704', 'Qualitätssicherung und Datenpflege');
		INSERT INTO aa_anlassart (id, value) VALUES ('010801', 'Zuschreibung eines Flurstückes (Gebietsreform)');
		INSERT INTO aa_anlassart (id, value) VALUES ('010802', 'Abschreibung eines Flurstückes (Gebietsreform)');
		INSERT INTO aa_anlassart (id, value) VALUES ('010900', 'Grenzfeststellung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010901', 'Grenzvermessung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010902', 'Grenzwiederherstellung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010903', 'Grenzbestimmung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010904', 'Grenzabmarkung ');
		INSERT INTO aa_anlassart (id, value) VALUES ('020100', 'Katasterliche Buchungsdaten fortführen');
		INSERT INTO aa_anlassart (id, value) VALUES ('020102', 'Katasterliche Buchung eines buchungsfreien Grundstücks');
		INSERT INTO aa_anlassart (id, value) VALUES ('020200', 'Namensnummer von katasterlichen Buchungsstellen verändern');
		INSERT INTO aa_anlassart (id, value) VALUES ('020201', 'Katasterliche Namensnummer und Rechtsgemeinschaft fortführen');
		INSERT INTO aa_anlassart (id, value) VALUES ('020301', 'Veränderung der Personendaten');
		INSERT INTO aa_anlassart (id, value) VALUES ('020302', 'Veränderung der Personengruppe');
		INSERT INTO aa_anlassart (id, value) VALUES ('020304', 'Veränderung der Verwaltung');
		INSERT INTO aa_anlassart (id, value) VALUES ('020305', 'Veränderung der Vertretung ');
		INSERT INTO aa_anlassart (id, value) VALUES ('030000', 'Grundbuchblattbezeichnung ändern');
		INSERT INTO aa_anlassart (id, value) VALUES ('030100', 'Umnummerierung (infolge Zuständigkeitsänderungen am Grundbuch)');
		INSERT INTO aa_anlassart (id, value) VALUES ('040000', 'Beschreibung der Buchungsstelle ändern');
		INSERT INTO aa_anlassart (id, value) VALUES ('040100', 'Änderungen am Wohnungseigentum');
		INSERT INTO aa_anlassart (id, value) VALUES ('040200', 'Änderungen am Wohnungserbbaurecht');
		INSERT INTO aa_anlassart (id, value) VALUES ('040500', 'Änderungen an den Beziehungen zwischen den Buchungsstellen');
		INSERT INTO aa_anlassart (id, value) VALUES ('040600', 'Änderungen in der Ergänzung, Beschreibung sowie der Bemerkung zu Buchungen');
		INSERT INTO aa_anlassart (id, value) VALUES ('050000', 'Angaben zu Eigentümer oder Erbbauberechtigten verändern');
		INSERT INTO aa_anlassart (id, value) VALUES ('050100', 'Eigentumsänderung');
		INSERT INTO aa_anlassart (id, value) VALUES ('050101', 'Kompletter Eigentumswechsel im Grundbuchblatt');
		INSERT INTO aa_anlassart (id, value) VALUES ('050102', 'Teilweiser Eigentumswechsel im Grundbuchblatt');
		INSERT INTO aa_anlassart (id, value) VALUES ('050200', 'Berichtigung aufgrund Erbnachweis');
		INSERT INTO aa_anlassart (id, value) VALUES ('060102', 'Abschreibung auf bestehendes Buchungsblatt');
		INSERT INTO aa_anlassart (id, value) VALUES ('060200', 'Teilung');
		INSERT INTO aa_anlassart (id, value) VALUES ('060201', 'Buchung der neuen Grundstücke in einem bestehenden Buchungsblatt');
		INSERT INTO aa_anlassart (id, value) VALUES ('060600', 'Vollziehung einer Verschmelzung');
		INSERT INTO aa_anlassart (id, value) VALUES ('060700', 'Buchung aufgrund Veränderung der Grundstücksbezeichnung oder der Größe (Spalten 3 + 4 des BV)');
		INSERT INTO aa_anlassart (id, value) VALUES ('060801', 'Buchung des Grundstücks auf ein neues Buchungsblatt (1)');
		INSERT INTO aa_anlassart (id, value) VALUES ('060802', 'Buchung des Grundstücks auf ein bestehendes Buchungsblatt der Miteigentümer');
		INSERT INTO aa_anlassart (id, value) VALUES ('060900', 'Aufhebung eines Wohnungseigentums');
		INSERT INTO aa_anlassart (id, value) VALUES ('062000', 'Grundbuchblatt schließen');
		INSERT INTO aa_anlassart (id, value) VALUES ('070000', 'Rechte buchen');
		INSERT INTO aa_anlassart (id, value) VALUES ('070100', 'Erbbaurecht anlegen');
		INSERT INTO aa_anlassart (id, value) VALUES ('070200', 'Erbbaurecht aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('070300', 'Herrschvermerk buchen');
		INSERT INTO aa_anlassart (id, value) VALUES ('070400', 'Herrschvermerk aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('070500', 'Untererbbaurecht anlegen');
		INSERT INTO aa_anlassart (id, value) VALUES ('070600', 'Untererbbaurecht aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('070700', 'Sonstige Rechte anlegen');
		INSERT INTO aa_anlassart (id, value) VALUES ('070800', 'Sonstige Rechte aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('070900', 'Wohnungserbbaurecht aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('071000', 'Wohnungsuntererbbaurecht aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('071100', 'Teilung Herrschvermerk aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('071200', 'Teilung sonstiges Recht aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('080000', 'Anteile buchen');
		INSERT INTO aa_anlassart (id, value) VALUES ('080200', 'Anlegen von Wohnungseigentum');
		INSERT INTO aa_anlassart (id, value) VALUES ('080300', 'Anlegen von Wohnungserbbaurecht');
		INSERT INTO aa_anlassart (id, value) VALUES ('080400', 'Anlegen von Wohnungsuntererbbaurecht');
		INSERT INTO aa_anlassart (id, value) VALUES ('080500', 'Teilung eines Herrschvermerks');
		INSERT INTO aa_anlassart (id, value) VALUES ('080600', 'Teilung eines sonstigen Rechts');
		INSERT INTO aa_anlassart (id, value) VALUES ('080650', 'Auflösung ungetrennter Hofräume');
		INSERT INTO aa_anlassart (id, value) VALUES ('080700', 'Teilung am ungetrennten Hofraum aufheben');
		INSERT INTO aa_anlassart (id, value) VALUES ('080800', 'Teilung einer Buchung § 3 Abs. 4 GBO nach Wohnungseigentumsgesetz');
		INSERT INTO aa_anlassart (id, value) VALUES ('080900', 'Teilung eines Anteils am ungetrennten Hofraum nach Wohnungseigentumsgesetz');
		INSERT INTO aa_anlassart (id, value) VALUES ('090000', 'Ändern in Verzeichnissen ohne Grundbucheintragung');
		INSERT INTO aa_anlassart (id, value) VALUES ('090100', 'Verwaltung eintragen oder ändern');
		INSERT INTO aa_anlassart (id, value) VALUES ('090200', 'Personengruppe eintragen oder ändern');
		INSERT INTO aa_anlassart (id, value) VALUES ('090300', 'Änderung der Anschrift');
		INSERT INTO aa_anlassart (id, value) VALUES ('090400', 'Änderung der Personendaten');
		INSERT INTO aa_anlassart (id, value) VALUES ('090500', 'Entstehung eines Festpunkts (erstmalige Aufnahme in AFIS)');
		INSERT INTO aa_anlassart (id, value) VALUES ('090510', 'Änderung von Koordinaten, Höhe und/oder Schwerewert eines Festpunkts');
		INSERT INTO aa_anlassart (id, value) VALUES ('090520', 'Veränderung der Vermarkung und/oder der beschreibenden Angaben eines Festpunkts');
		INSERT INTO aa_anlassart (id, value) VALUES ('090530', 'Zerstörung der Vermarkung eines Festpunkts');
		INSERT INTO aa_anlassart (id, value) VALUES ('090540', 'Untergang eines Festpunktes');
		INSERT INTO aa_anlassart (id, value) VALUES ('001000', 'Grundaktualisierung');
		INSERT INTO aa_anlassart (id, value) VALUES ('100000', 'Veränderung der Angaben zu den Nutzerprofilen');
		INSERT INTO aa_anlassart (id, value) VALUES ('002000', 'Spitzenaktualisierung');
		INSERT INTO aa_anlassart (id, value) VALUES ('200000', 'Veränderung von Gebäudedaten');
		INSERT INTO aa_anlassart (id, value) VALUES ('200100', 'Eintragen eines Gebäudes');
		INSERT INTO aa_anlassart (id, value) VALUES ('200200', 'Veränderung der Gebäudeeigenschaften');
		INSERT INTO aa_anlassart (id, value) VALUES ('200300', 'Löschen eines Gebäudes');
		INSERT INTO aa_anlassart (id, value) VALUES ('300000', 'Sonstige Daten fortführen');
		INSERT INTO aa_anlassart (id, value) VALUES ('300100', 'Veränderungen der Angaben zum Netzpunkt');
		INSERT INTO aa_anlassart (id, value) VALUES ('300410', 'Veränderung der öffentlich-rechtlichen und sonstigen Festsetzungen');
		INSERT INTO aa_anlassart (id, value) VALUES ('300421', 'Erfassung der Bodenschätzung ');
		INSERT INTO aa_anlassart (id, value) VALUES ('300430', 'Veränderung der Bewertung');
		INSERT INTO aa_anlassart (id, value) VALUES ('300440', 'Veränderung der Gebietseinheiten');
		INSERT INTO aa_anlassart (id, value) VALUES ('300501', 'Veränderung aufgrund der Homogenisierung ');
		INSERT INTO aa_anlassart (id, value) VALUES ('300600', 'Veränderung der Reservierung von Fachkennzeichen');
		INSERT INTO aa_anlassart (id, value) VALUES ('300700', 'Veränderung von Katalogeinträgen ');
		INSERT INTO aa_anlassart (id, value) VALUES ('300800', 'Veränderung von Metadaten');
		INSERT INTO aa_anlassart (id, value) VALUES ('300900', 'Veränderung der Geometrie durch Implizitbehandlung');
		INSERT INTO aa_anlassart (id, value) VALUES ('004100', 'Automatische Kartographische Generalisierung mit Konflikt');
		INSERT INTO aa_anlassart (id, value) VALUES ('005000', 'Interaktive Kartographische Generalisierung');
		INSERT INTO aa_anlassart (id, value) VALUES ('006000', 'Veränderung an der Landesgrenze und des Gebietes');
		INSERT INTO aa_anlassart (id, value) VALUES ('009999', 'Sonstiges');
		INSERT INTO aa_anlassart (id, value) VALUES ('003000', 'Angaben zur Grundbuchfortführung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010101', 'Zerlegung oder Sonderung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010102', 'Verschmelzung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010103', 'Zerlegung und Verschmelzung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010104', 'Flurstückszerlegung mit Eigentumsübergang nach Straßengesetzen');
		INSERT INTO aa_anlassart (id, value) VALUES ('010105', 'Zerlegung ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010107', 'Sonderung ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010199', 'Verschmelzung von Flurstücken auf unterschiedlichen Beständen/Buchungsstellen');
		INSERT INTO aa_anlassart (id, value) VALUES ('010201', 'Veränderung aufgrund der Vorschriften des Straßenrechts');
		INSERT INTO aa_anlassart (id, value) VALUES ('010202', 'Veränderung aufgrund der Vorschriften des Wasserrechts');
		INSERT INTO aa_anlassart (id, value) VALUES ('010203', 'Veränderung am Flurstück mit Änderung der Umfangsgrenzen ');
		INSERT INTO aa_anlassart (id, value) VALUES ('010205', 'Veränderung aufgrund Berichtigung eines Aufnahmefehlers');
		INSERT INTO aa_anlassart (id, value) VALUES ('010206', 'Veränderung aufgrund gerichtlicher Entscheidung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010207', 'Veränderung aufgrund Berichtigung eines Grenzbestimmungsfehlers');
		INSERT INTO aa_anlassart (id, value) VALUES ('010301', 'Veränderung der Flurstücksbezeichnung');
		INSERT INTO aa_anlassart (id, value) VALUES ('010303', 'Veränderung der Gemeindezugehörigkeit ganzer Gemarkungen');
		INSERT INTO aa_anlassart (id, value) VALUES ('010305', 'Veränderung der Flurzugehörigkeit');
		INSERT INTO aa_anlassart (id, value) VALUES ('050400', 'Namensänderung');
		INSERT INTO aa_anlassart (id, value) VALUES ('060901', 'Buchung des Grundstücks auf ein neues Buchungsblatt (2)');
		INSERT INTO aa_anlassart (id, value) VALUES ('060902', 'Buchung des Grundstücks auf ein bestehendes Buchungsblatt');
		INSERT INTO aa_anlassart (id, value) VALUES ('061000', 'Umschreibung des Grundbuchs (§§ 28 ff, 68 GBV)');
		INSERT INTO aa_anlassart (id, value) VALUES ('061100', 'Neufassung des Grundbuchs (§§ 33, 69 GBV)');
		INSERT INTO aa_anlassart (id, value) VALUES ('061200', 'Erstbuchung eines Grundstücks');
		INSERT INTO aa_anlassart (id, value) VALUES ('061400', 'Aufhebung von Anteilen am ungetrennten Hofraum');

		CREATE TABLE ax_benutzer (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art character varying,
		  direkt character varying,
		  email character varying,
		  http character varying,
		  manuell character varying,
		  ausgabemasstab double precision,
		  ausgabemedium integer,
		  datenformat integer,
		  formatangabe character varying,
		  letzteabgabeart integer,
		  letzteabgabezugriff character(20),
		  nbaquittierungerhalten character(20),
		  nbauebernahmeerfolgreich character varying,
		  profilkennung character varying NOT NULL,
		  vorletzteabgabezugriff character(20),
		  zahlungsweise character varying,
		  zeitlicheberechtigung date,
		  istteilvon character(16)[],
		  ist character(16) NOT NULL,
		  gehoertzu character(16) NOT NULL,
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_benutzer_gml ON ax_benutzer USING btree (gml_id,beginnt);
		CREATE INDEX ax_benutzer_endet ON ax_benutzer USING btree (endet);
		CREATE INDEX ax_benutzer_ist ON ax_benutzer USING btree (ist);
		CREATE INDEX ax_benutzer_gehoertzu ON ax_benutzer USING btree (gehoertzu);
		CREATE INDEX ax_benutzer_istteilvon ON ax_benutzer USING gin (istteilvon);

		COMMENT ON TABLE ax_benutzer IS 'FeatureType: "AX_Benutzer"';
		COMMENT ON COLUMN ax_benutzer.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_benutzer.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_benutzer.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_benutzer.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_benutzer.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_benutzer.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_benutzer.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_benutzer.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_benutzer.art IS 'art   0..1';
		COMMENT ON COLUMN ax_benutzer.direkt IS 'empfaenger|AA_Empfaenger|direkt  Boolean 0..1';
		COMMENT ON COLUMN ax_benutzer.email IS 'empfaenger|AA_Empfaenger|email  URI 0..1';
		COMMENT ON COLUMN ax_benutzer.http IS 'empfaenger|AA_Empfaenger|http  URI 0..1';
		COMMENT ON COLUMN ax_benutzer.manuell IS 'empfaenger|AA_Empfaenger|manuell   0..1';
		COMMENT ON COLUMN ax_benutzer.ausgabemasstab IS 'folgeverarbeitung|AX_FOLGEVA|ausgabemasstab  Real 0..1';
		COMMENT ON COLUMN ax_benutzer.ausgabemedium IS 'folgeverarbeitung|AX_FOLGEVA|ausgabemedium enumeration AX_Ausgabemedium_Benutzer 0..1';
		COMMENT ON COLUMN ax_benutzer.datenformat IS 'folgeverarbeitung|AX_FOLGEVA|datenformat enumeration AX_Datenformat_Benutzer 0..1';
		COMMENT ON COLUMN ax_benutzer.formatangabe IS 'folgeverarbeitung|AX_FOLGEVA|formatangabe   0..1';
		COMMENT ON COLUMN ax_benutzer.letzteabgabeart IS 'letzteAbgabeArt enumeration AX_LetzteAbgabeArt 0..1';
		COMMENT ON COLUMN ax_benutzer.letzteabgabezugriff IS 'letzteAbgabeZugriff  DateTime 0..1';
		COMMENT ON COLUMN ax_benutzer.nbaquittierungerhalten IS 'nBAQuittierungErhalten  DateTime 0..1';
		COMMENT ON COLUMN ax_benutzer.nbauebernahmeerfolgreich IS 'nBAUebernahmeErfolgreich  Boolean 0..1';
		COMMENT ON COLUMN ax_benutzer.profilkennung IS 'profilkennung   1';
		COMMENT ON COLUMN ax_benutzer.vorletzteabgabezugriff IS 'vorletzteAbgabeZugriff  DateTime 0..1';
		COMMENT ON COLUMN ax_benutzer.zahlungsweise IS 'zahlungsweise   0..1';
		COMMENT ON COLUMN ax_benutzer.zeitlicheberechtigung IS 'zeitlicheBerechtigung  Date 0..1';
		COMMENT ON COLUMN ax_benutzer.ist IS 'Assoziation zu: FeatureType AX_Person (ax_person) 1';
		COMMENT ON COLUMN ax_benutzer.gehoertzu IS 'Assoziation zu: FeatureType AX_Benutzergruppe (ax_benutzergruppe) 1';
		CREATE TABLE ax_benutzergruppemitzugriffskontrolle (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying NOT NULL,
		  koordinatenreferenzsystem character varying,
		  land character varying NOT NULL,
		  stelle character varying NOT NULL,
		  selektionskriterien character varying[] NOT NULL,
		  zugriffhistorie character varying NOT NULL,
		  zugriffsartfortfuehrungsanlass character varying[],
		  zugriffsartproduktkennungbenutzung character varying[],
		  zugriffsartproduktkennungfuehrung character varying[],
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_benutzergruppemitzugriffskontrolle_gml ON ax_benutzergruppemitzugriffskontrolle USING btree (gml_id,beginnt);
		CREATE INDEX ax_benutzergruppemitzugriffskontrolle_endet ON ax_benutzergruppemitzugriffskontrolle USING btree (endet);
		CREATE INDEX ax_benutzergruppemitzugriffskontrolle_bestehtaus ON ax_benutzergruppemitzugriffskontrolle USING gin (bestehtaus);
		CREATE INDEX ax_benutzergruppemitzugriffskontrolle_istteilvon ON ax_benutzergruppemitzugriffskontrolle USING gin (istteilvon);

		COMMENT ON TABLE ax_benutzergruppemitzugriffskontrolle IS 'FeatureType: "AX_BenutzergruppeMitZugriffskontrolle"';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.bezeichnung IS 'bezeichnung   1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.koordinatenreferenzsystem IS 'koordinatenreferenzsystem  SC_CRS 0..1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.land IS 'zustaendigeStelle|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.stelle IS 'zustaendigeStelle|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.selektionskriterien IS 'selektionskriterien   1..*';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zugriffhistorie IS 'zugriffHistorie  Boolean 1';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zugriffsartfortfuehrungsanlass IS 'zugriffsartFortfuehrungsanlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zugriffsartproduktkennungbenutzung IS 'zugriffsartProduktkennungBenutzung codelist AA_Anlassart_Benutzungsauftrag 0..*';
		COMMENT ON COLUMN ax_benutzergruppemitzugriffskontrolle.zugriffsartproduktkennungfuehrung IS 'zugriffsartProduktkennungFuehrung codelist AA_Anlassart 0..*';
		CREATE TABLE ax_benutzergruppenba (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying NOT NULL,
		  koordinatenreferenzsystem character varying,
		  land character varying NOT NULL,
		  stelle character varying NOT NULL,
		  bereichzeitlich_art integer,
		  bereichzeitlich_ersterstichtag date,
		  bereichzeitlich_intervall date,
		  seitenlaenge integer,
		  quittierung character varying,
		  selektionskriterien character varying[] NOT NULL,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_benutzergruppenba_gml ON ax_benutzergruppenba USING btree (gml_id,beginnt);
		CREATE INDEX ax_benutzergruppenba_endet ON ax_benutzergruppenba USING btree (endet);
		CREATE INDEX ax_benutzergruppenba_bestehtaus ON ax_benutzergruppenba USING gin (bestehtaus);
		CREATE INDEX ax_benutzergruppenba_istteilvon ON ax_benutzergruppenba USING gin (istteilvon);

		COMMENT ON TABLE ax_benutzergruppenba IS 'FeatureType: "AX_BenutzergruppeNBA"';
		COMMENT ON COLUMN ax_benutzergruppenba.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_benutzergruppenba.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_benutzergruppenba.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_benutzergruppenba.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.bezeichnung IS 'bezeichnung   1';
		COMMENT ON COLUMN ax_benutzergruppenba.koordinatenreferenzsystem IS 'koordinatenreferenzsystem  SC_CRS 0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.land IS 'zustaendigeStelle|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_benutzergruppenba.stelle IS 'zustaendigeStelle|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_benutzergruppenba.bereichzeitlich_art IS 'bereichZeitlich|AX_BereichZeitlich|art enumeration AX_Art_BereichZeitlich 1';
		COMMENT ON COLUMN ax_benutzergruppenba.bereichzeitlich_ersterstichtag IS 'bereichZeitlich|AX_BereichZeitlich|ersterStichtag  Date 1';
		COMMENT ON COLUMN ax_benutzergruppenba.bereichzeitlich_intervall IS 'bereichZeitlich|AX_BereichZeitlich|intervall  TM_Duration 1';
		COMMENT ON COLUMN ax_benutzergruppenba.seitenlaenge IS 'portionierungsparameter|AX_Portionierungsparameter|seitenlaenge  Integer 1';
		COMMENT ON COLUMN ax_benutzergruppenba.quittierung IS 'quittierung  Boolean 0..1';
		COMMENT ON COLUMN ax_benutzergruppenba.selektionskriterien IS 'selektionskriterien   1..*';
		CREATE TABLE ax_personengruppe (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  namederpersonengruppe character varying NOT NULL,
		  istteilvon character(16)[],
		  bestehtaus character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_personengruppe_gml ON ax_personengruppe USING btree (gml_id,beginnt);
		CREATE INDEX ax_personengruppe_endet ON ax_personengruppe USING btree (endet);
		CREATE INDEX ax_personengruppe_bestehtaus ON ax_personengruppe USING gin (bestehtaus);
		CREATE INDEX ax_personengruppe_istteilvon ON ax_personengruppe USING gin (istteilvon);

		COMMENT ON TABLE ax_personengruppe IS 'FeatureType: "AX_Personengruppe"';
		COMMENT ON COLUMN ax_personengruppe.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_personengruppe.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_personengruppe.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_personengruppe.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_personengruppe.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_personengruppe.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_personengruppe.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_personengruppe.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_personengruppe.namederpersonengruppe IS 'nameDerPersonengruppe   1';
		COMMENT ON COLUMN ax_personengruppe.bestehtaus IS 'Assoziation zu: FeatureType AX_Person (ax_person) 0..*';
		CREATE TABLE ax_skizze (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bemerkungen character varying,
		  skizzenart integer,
		  skizzenname character varying NOT NULL,
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_skizze_gml ON ax_skizze USING btree (gml_id,beginnt);
		CREATE INDEX ax_skizze_endet ON ax_skizze USING btree (endet);
		CREATE INDEX ax_skizze_istteilvon ON ax_skizze USING gin (istteilvon);

		COMMENT ON TABLE ax_skizze IS 'FeatureType: "AX_Skizze"';
		COMMENT ON COLUMN ax_skizze.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_skizze.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_skizze.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_skizze.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_skizze.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_skizze.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_skizze.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_skizze.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_skizze.bemerkungen IS 'bemerkungen   0..1';
		COMMENT ON COLUMN ax_skizze.skizzenart IS 'skizzenart enumeration AX_Skizzenart_Skizze 0..1';
		COMMENT ON COLUMN ax_skizze.skizzenname IS 'skizzenname  URI 1';
		CREATE TABLE ax_schwere (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  aufstellhoehe double precision,
		  hinweise character varying,
		  bestimmungsdatum date,
		  datenerhebung integer,
		  genauigkeitsstufe integer,
		  genauigkeitswert integer,
		  messmethode integer,
		  vertrauenswuerdigkeit integer,
		  schwereanomalie_art integer[],
		  schwereanomalie_wert character varying[],
		  schwerestatus integer,
		  schweresystem integer NOT NULL,
		  schwerewert double precision NOT NULL,
		  ueberpruefungsdatum date,
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_schwere_gml ON ax_schwere USING btree (gml_id,beginnt);
		CREATE INDEX ax_schwere_endet ON ax_schwere USING btree (endet);
		CREATE INDEX ax_schwere_istteilvon ON ax_schwere USING gin (istteilvon);

		COMMENT ON TABLE ax_schwere IS 'FeatureType: "AX_Schwere"';
		COMMENT ON COLUMN ax_schwere.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_schwere.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_schwere.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_schwere.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_schwere.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_schwere.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_schwere.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_schwere.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_schwere.aufstellhoehe IS 'aufstellhoehe  Distance 0..1';
		COMMENT ON COLUMN ax_schwere.hinweise IS 'hinweise   0..1';
		COMMENT ON COLUMN ax_schwere.bestimmungsdatum IS 'qualitaetsangaben|AX_DQSchwere|bestimmungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_schwere.datenerhebung IS 'qualitaetsangaben|AX_DQSchwere|datenerhebung enumeration AX_Datenerhebung_Schwere 0..1';
		COMMENT ON COLUMN ax_schwere.genauigkeitsstufe IS 'qualitaetsangaben|AX_DQSchwere|genauigkeitsstufe enumeration AX_Genauigkeitsstufe_Schwere 0..1';
		COMMENT ON COLUMN ax_schwere.genauigkeitswert IS 'qualitaetsangaben|AX_DQSchwere|genauigkeitswert  Integer 0..1';
		COMMENT ON COLUMN ax_schwere.messmethode IS 'qualitaetsangaben|AX_DQSchwere|messmethode enumeration AX_Messmethode_Schwere 0..1';
		COMMENT ON COLUMN ax_schwere.vertrauenswuerdigkeit IS 'qualitaetsangaben|AX_DQSchwere|vertrauenswuerdigkeit enumeration AX_Vertrauenswuerdigkeit_Schwere 0..1';
		COMMENT ON COLUMN ax_schwere.schwereanomalie_art IS 'schwereanomalie|AX_Schwereanomalie_Schwere|art enumeration AX_Schwereanomalie_Schwere_Art 1';
		COMMENT ON COLUMN ax_schwere.schwereanomalie_wert IS 'schwereanomalie|AX_Schwereanomalie_Schwere|wert  Measure 1';
		COMMENT ON COLUMN ax_schwere.schwerestatus IS 'schwerestatus enumeration AX_Schwerestatus_Schwere 0..1';
		COMMENT ON COLUMN ax_schwere.schweresystem IS 'schweresystem enumeration AX_Schweresystem_Schwere 1';
		COMMENT ON COLUMN ax_schwere.schwerewert IS 'schwerewert  Real 1';
		COMMENT ON COLUMN ax_schwere.ueberpruefungsdatum IS 'ueberpruefungsdatum  Date 0..1';
		CREATE TABLE ax_punktkennungvergleichend (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  antragsnummer character varying NOT NULL,
		  art integer,
		  endgueltigepunktkennung character varying NOT NULL,
		  vorlaeufigepunktkennung character varying NOT NULL,
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_punktkennungvergleichend_gml ON ax_punktkennungvergleichend USING btree (gml_id,beginnt);
		CREATE INDEX ax_punktkennungvergleichend_endet ON ax_punktkennungvergleichend USING btree (endet);
		CREATE INDEX ax_punktkennungvergleichend_istteilvon ON ax_punktkennungvergleichend USING gin (istteilvon);

		COMMENT ON TABLE ax_punktkennungvergleichend IS 'FeatureType: "AX_PunktkennungVergleichend"';
		COMMENT ON COLUMN ax_punktkennungvergleichend.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_punktkennungvergleichend.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.antragsnummer IS 'antragsnummer   1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.art IS 'art enumeration AX_Art_Punktkennung 0..1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.endgueltigepunktkennung IS 'endgueltigePunktkennung   1';
		COMMENT ON COLUMN ax_punktkennungvergleichend.vorlaeufigepunktkennung IS 'vorlaeufigePunktkennung   1';
		CREATE TABLE ax_verband (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  administrativefunktion integer[],
		  art integer,
		  bezeichnung character varying NOT NULL,
		  gemeinde character varying[] NOT NULL,
		  gemeindeteil character varying[],
		  kreis character varying[] NOT NULL,
		  land character varying[] NOT NULL,
		  regierungsbezirk character varying[],
		  schluesselgesamt character varying NOT NULL,
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_verband_gml ON ax_verband USING btree (gml_id,beginnt);
		CREATE INDEX ax_verband_endet ON ax_verband USING btree (endet);
		CREATE INDEX ax_verband_istteilvon ON ax_verband USING gin (istteilvon);

		COMMENT ON TABLE ax_verband IS 'FeatureType: "AX_Verband"';
		COMMENT ON COLUMN ax_verband.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_verband.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_verband.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_verband.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_verband.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_verband.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_verband.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_verband.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_verband.administrativefunktion IS 'administrativeFunktion enumeration AX_Administrative_Funktion 0..*';
		COMMENT ON COLUMN ax_verband.art IS 'art enumeration AX_Art_Verband 0..1';
		COMMENT ON COLUMN ax_verband.bezeichnung IS 'bezeichnung  CharacterString 1';
		COMMENT ON COLUMN ax_verband.gemeinde IS 'enthaelt|AX_Gemeindekennzeichen|gemeinde   1';
		COMMENT ON COLUMN ax_verband.gemeindeteil IS 'enthaelt|AX_Gemeindekennzeichen|gemeindeteil   0..1';
		COMMENT ON COLUMN ax_verband.kreis IS 'enthaelt|AX_Gemeindekennzeichen|kreis   1';
		COMMENT ON COLUMN ax_verband.land IS 'enthaelt|AX_Gemeindekennzeichen|land   1';
		COMMENT ON COLUMN ax_verband.regierungsbezirk IS 'enthaelt|AX_Gemeindekennzeichen|regierungsbezirk   0..1';
		COMMENT ON COLUMN ax_verband.schluesselgesamt IS 'schluesselGesamt  CharacterString 1';
		CREATE TABLE ax_nationalstaat (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  administrativefunktion integer[],
		  bezeichnung character varying NOT NULL,
		  schluessel character varying NOT NULL,
		  schluesselgesamt character varying NOT NULL,
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_nationalstaat_gml ON ax_nationalstaat USING btree (gml_id,beginnt);
		CREATE INDEX ax_nationalstaat_endet ON ax_nationalstaat USING btree (endet);
		CREATE INDEX ax_nationalstaat_istteilvon ON ax_nationalstaat USING gin (istteilvon);

		COMMENT ON TABLE ax_nationalstaat IS 'FeatureType: "AX_Nationalstaat"';
		COMMENT ON COLUMN ax_nationalstaat.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_nationalstaat.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_nationalstaat.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_nationalstaat.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_nationalstaat.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_nationalstaat.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_nationalstaat.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_nationalstaat.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_nationalstaat.administrativefunktion IS 'administrativeFunktion enumeration AX_Administrative_Funktion 0..*';
		COMMENT ON COLUMN ax_nationalstaat.bezeichnung IS 'bezeichnung  CharacterString 1';
		COMMENT ON COLUMN ax_nationalstaat.schluessel IS 'schluessel   1';
		COMMENT ON COLUMN ax_nationalstaat.schluesselgesamt IS 'schluesselGesamt  CharacterString 1';
		CREATE TABLE ax_netzknoten (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying NOT NULL,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_netzknoten_gml ON ax_netzknoten USING btree (gml_id,beginnt);
		CREATE INDEX ax_netzknoten_endet ON ax_netzknoten USING btree (endet);
		CREATE INDEX ax_netzknoten_bestehtaus ON ax_netzknoten USING gin (bestehtaus);
		CREATE INDEX ax_netzknoten_istteilvon ON ax_netzknoten USING gin (istteilvon);

		COMMENT ON TABLE ax_netzknoten IS 'FeatureType: "AX_Netzknoten"';
		COMMENT ON COLUMN ax_netzknoten.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_netzknoten.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_netzknoten.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_netzknoten.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_netzknoten.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_netzknoten.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_netzknoten.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_netzknoten.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_netzknoten.bezeichnung IS 'bezeichnung   1';
		COMMENT ON COLUMN ax_netzknoten.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_netzknoten.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_netzknoten.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_netzknoten.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_netzknoten.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_netzknoten.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_netzknoten.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_referenzstationspunkt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  darstellungshinweis character varying,
		  frueherepunktnummer character varying[],
		  gemarkung_gemarkungsnummer character varying,
		  gemarkung_land character varying,
		  gemeinde character varying NOT NULL,
		  gemeinde_gemeindeteil character varying,
		  kreis character varying NOT NULL,
		  gemeinde_land character varying NOT NULL,
		  gemeinde_regierungsbezirk character varying,
		  internebemerkungen character varying[],
		  katasteramt_land character varying,
		  katasteramt_stelle character varying,
		  land_land character varying NOT NULL,
		  namelagebeschreibung character varying,
		  nutzerspezifischebemerkungen character varying[],
		  punktkennung character varying NOT NULL,
		  punktvermarkung integer NOT NULL,
		  relativehoehe double precision,
		  beginn character(20),
		  ende character(20),
		  funkfrequenz double precision,
		  funktion integer,
		  gnssantenne_abbaudatum character varying,
		  antennenhoehe double precision NOT NULL,
		  antennenreferenzpunkt character varying NOT NULL,
		  aufbaudatum character varying NOT NULL,
		  azimutaleabweichung double precision NOT NULL,
		  gnssantennenundradometyp character varying NOT NULL,
		  hoehenoffsetl1 double precision NOT NULL,
		  hoehenoffsetl2 double precision NOT NULL,
		  seriennummer character varying NOT NULL,
		  gnssantenne_zusaetzlicheinformationen character varying,
		  gnssempfaenger_abbaudatum character varying,
		  gnssempfaenger_aufbaudatum character varying,
		  gnssempfaenger_firmwareversion character varying,
		  gnssempfaenger_gnssempfaengertyp character varying,
		  gnssempfaenger_seriennummer character varying,
		  gnssempfaenger_zusaetzlicheinformationen character varying,
		  isdnnummer character varying,
		  offsetl1_east double precision NOT NULL,
		  offsetl1_height double precision NOT NULL,
		  offsetl1_north double precision NOT NULL,
		  offsetl2_east double precision NOT NULL,
		  offsetl2_height double precision NOT NULL,
		  offsetl2_north double precision NOT NULL,
		  phasenzentrumsvariationl1_zeile character varying[],
		  phasenzentrumsvariationl2_zeile character varying[],
		  befund character varying,
		  gnsstauglichkeit integer,
		  punktstabilitaet integer,
		  ueberwachungsdatum date,
		  tcpipnummer character varying,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  istidentischmitlfp character(16),
		  istidentischmithfp character(16),
		  unterschiedlicherbezugspunktmitsfp character(16),
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_referenzstationspunkt_gml ON ax_referenzstationspunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_referenzstationspunkt_endet ON ax_referenzstationspunkt USING btree (endet);
		CREATE INDEX ax_referenzstationspunkt_istidentischmitlfp ON ax_referenzstationspunkt USING btree (istidentischmitlfp);
		CREATE INDEX ax_referenzstationspunkt_istidentischmithfp ON ax_referenzstationspunkt USING btree (istidentischmithfp);
		CREATE INDEX ax_r_unterschiedlicherbezugspunktmitsfp ON ax_referenzstationspunkt USING btree (unterschiedlicherbezugspunktmitsfp);
		CREATE INDEX ax_referenzstationspunkt_bestehtaus ON ax_referenzstationspunkt USING gin (bestehtaus);
		CREATE INDEX ax_referenzstationspunkt_istteilvon ON ax_referenzstationspunkt USING gin (istteilvon);

		COMMENT ON TABLE ax_referenzstationspunkt IS 'FeatureType: "AX_Referenzstationspunkt"';
		COMMENT ON COLUMN ax_referenzstationspunkt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_referenzstationspunkt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.darstellungshinweis IS 'darstellungshinweis  Boolean 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.frueherepunktnummer IS 'frueherePunktnummer   0..*';
		COMMENT ON COLUMN ax_referenzstationspunkt.gemarkung_gemarkungsnummer IS 'gemarkung|AX_Gemarkung_Schluessel|gemarkungsnummer   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gemarkung_land IS 'gemarkung|AX_Gemarkung_Schluessel|land   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gemeinde IS 'gemeinde|AX_Gemeindekennzeichen|gemeinde   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gemeinde_gemeindeteil IS 'gemeinde|AX_Gemeindekennzeichen|gemeindeteil   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.kreis IS 'gemeinde|AX_Gemeindekennzeichen|kreis   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gemeinde_land IS 'gemeinde|AX_Gemeindekennzeichen|land   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gemeinde_regierungsbezirk IS 'gemeinde|AX_Gemeindekennzeichen|regierungsbezirk   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.internebemerkungen IS 'interneBemerkungen   0..*';
		COMMENT ON COLUMN ax_referenzstationspunkt.katasteramt_land IS 'katasteramt|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.katasteramt_stelle IS 'katasteramt|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.land_land IS 'land|AX_Bundesland_Schluessel|land   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.namelagebeschreibung IS 'nameLagebeschreibung   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.nutzerspezifischebemerkungen IS 'nutzerspezifischeBemerkungen   0..*';
		COMMENT ON COLUMN ax_referenzstationspunkt.punktkennung IS 'punktkennung   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.punktvermarkung IS 'punktvermarkung enumeration AX_Marke 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.relativehoehe IS 'relativeHoehe  Length 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.beginn IS 'beginn  DateTime 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.ende IS 'ende  DateTime 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.funkfrequenz IS 'funkfrequenz  Real 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.funktion IS 'funktion enumeration AX_Funktion_Referenzstationspunkt 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssantenne_abbaudatum IS 'gnssAntenne|AX_GNSSAntenne|abbaudatum   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.antennenhoehe IS 'gnssAntenne|AX_GNSSAntenne|antennenhoehe  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.antennenreferenzpunkt IS 'gnssAntenne|AX_GNSSAntenne|antennenreferenzpunkt   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.aufbaudatum IS 'gnssAntenne|AX_GNSSAntenne|aufbaudatum   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.azimutaleabweichung IS 'gnssAntenne|AX_GNSSAntenne|azimutaleAbweichung  Angle 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssantennenundradometyp IS 'gnssAntenne|AX_GNSSAntenne|gnssAntennenUndRadomeTyp   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.hoehenoffsetl1 IS 'gnssAntenne|AX_GNSSAntenne|hoehenoffsetL1  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.hoehenoffsetl2 IS 'gnssAntenne|AX_GNSSAntenne|hoehenoffsetL2  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.seriennummer IS 'gnssAntenne|AX_GNSSAntenne|seriennummer   1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssantenne_zusaetzlicheinformationen IS 'gnssAntenne|AX_GNSSAntenne|zusaetzlicheInformationen   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssempfaenger_abbaudatum IS 'gnssEmpfaenger|AX_GNSSEmpfaenger|abbaudatum   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssempfaenger_aufbaudatum IS 'gnssEmpfaenger|AX_GNSSEmpfaenger|aufbaudatum   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssempfaenger_firmwareversion IS 'gnssEmpfaenger|AX_GNSSEmpfaenger|firmwareversion   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssempfaenger_gnssempfaengertyp IS 'gnssEmpfaenger|AX_GNSSEmpfaenger|gnssEmpfaengertyp   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssempfaenger_seriennummer IS 'gnssEmpfaenger|AX_GNSSEmpfaenger|seriennummer   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnssempfaenger_zusaetzlicheinformationen IS 'gnssEmpfaenger|AX_GNSSEmpfaenger|zusaetzlicheInformationen   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.isdnnummer IS 'isdnNummer   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.offsetl1_east IS 'offsetL1|AX_Offsetkomponenten_Referenzstationspunkt|east  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.offsetl1_height IS 'offsetL1|AX_Offsetkomponenten_Referenzstationspunkt|height  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.offsetl1_north IS 'offsetL1|AX_Offsetkomponenten_Referenzstationspunkt|north  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.offsetl2_east IS 'offsetL2|AX_Offsetkomponenten_Referenzstationspunkt|east  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.offsetl2_height IS 'offsetL2|AX_Offsetkomponenten_Referenzstationspunkt|height  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.offsetl2_north IS 'offsetL2|AX_Offsetkomponenten_Referenzstationspunkt|north  Distance 1';
		COMMENT ON COLUMN ax_referenzstationspunkt.phasenzentrumsvariationl1_zeile IS 'phasenzentrumsvariationL1|AX_Phasenzentrumsvariation_Referenzstationspunkt|zeile  doubleList *';
		COMMENT ON COLUMN ax_referenzstationspunkt.phasenzentrumsvariationl2_zeile IS 'phasenzentrumsvariationL2|AX_Phasenzentrumsvariation_Referenzstationspunkt|zeile  doubleList *';
		COMMENT ON COLUMN ax_referenzstationspunkt.befund IS 'qualitaetsangaben|AX_DQFestpunkt|befund   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.gnsstauglichkeit IS 'qualitaetsangaben|AX_DQFestpunkt|gnssTauglichkeit enumeration AX_GNSSTauglichkeit 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.punktstabilitaet IS 'qualitaetsangaben|AX_DQFestpunkt|punktstabilitaet enumeration AX_Punktstabilitaet 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.ueberwachungsdatum IS 'qualitaetsangaben|AX_DQFestpunkt|ueberwachungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.tcpipnummer IS 'tcpipNummer   0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.istidentischmitlfp IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.istidentischmithfp IS 'Assoziation zu: FeatureType AX_Hoehenfestpunkt (ax_hoehenfestpunkt) 0..1';
		COMMENT ON COLUMN ax_referenzstationspunkt.unterschiedlicherbezugspunktmitsfp IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..1';
		CREATE TABLE ax_lagefestpunkt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  darstellungshinweis character varying,
		  frueherepunktnummer character varying[],
		  gemarkung_gemarkungsnummer character varying,
		  gemarkung_land character varying,
		  gemeinde character varying NOT NULL,
		  gemeinde_gemeindeteil character varying,
		  kreis character varying NOT NULL,
		  gemeinde_land character varying NOT NULL,
		  gemeinde_regierungsbezirk character varying,
		  internebemerkungen character varying[],
		  katasteramt_land character varying,
		  katasteramt_stelle character varying,
		  land_land character varying NOT NULL,
		  namelagebeschreibung character varying,
		  nutzerspezifischebemerkungen character varying[],
		  punktkennung character varying NOT NULL,
		  punktvermarkung integer NOT NULL,
		  relativehoehe double precision,
		  funktion integer,
		  hierarchiestufe3d integer,
		  ordnung integer,
		  wertigkeit integer,
		  abstand double precision,
		  messung date,
		  befund character varying,
		  gnsstauglichkeit integer,
		  punktstabilitaet integer,
		  ueberwachungsdatum date,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  istidentischmitrsp character(16),
		  istexzentrumzu character(16),
		  istzentrumzu character(16)[],
		  unterschiedlicherbezugspunktmithfp character(16),
		  istidentischmithfp character(16),
		  unterschiedlicherbezugspunktmitsfp character(16),
		  istidentischmitsfp character(16),
		  istidentischmitgrenzpunkt character(16),
		  unterschiedlicherbezugspunktmitgrenzpunkt character(16),
		  istidentischmitap character(16),
		  unterschiedlicherbezugspunktmitap character(16),
		  unterschiedlicherbezugspunktmitsvp character(16),
		  istidentischmitsvp character(16),
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_lagefestpunkt_gml ON ax_lagefestpunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_lagefestpunkt_endet ON ax_lagefestpunkt USING btree (endet);
		CREATE INDEX ax_lagefestpunkt_istidentischmitrsp ON ax_lagefestpunkt USING btree (istidentischmitrsp);
		CREATE INDEX ax_lagefestpunkt_istexzentrumzu ON ax_lagefestpunkt USING btree (istexzentrumzu);
		CREATE INDEX ax_lagefestpunkt_istzentrumzu ON ax_lagefestpunkt USING gin (istzentrumzu);
		CREATE INDEX ax_lagefestpunkt_unterschiedlicherbezugspunktmithfp ON ax_lagefestpunkt USING btree (unterschiedlicherbezugspunktmithfp);
		CREATE INDEX ax_lagefestpunkt_istidentischmithfp ON ax_lagefestpunkt USING btree (istidentischmithfp);
		CREATE INDEX ax_lagefestpunkt_unterschiedlicherbezugspunktmitsfp ON ax_lagefestpunkt USING btree (unterschiedlicherbezugspunktmitsfp);
		CREATE INDEX ax_lagefestpunkt_istidentischmitsfp ON ax_lagefestpunkt USING btree (istidentischmitsfp);
		CREATE INDEX ax_lagefestpunkt_istidentischmitgrenzpunkt ON ax_lagefestpunkt USING btree (istidentischmitgrenzpunkt);
		CREATE INDEX ax_lagefestpunkt_unterschiedlicherbezugspunktmitgrenzpunkt ON ax_lagefestpunkt USING btree (unterschiedlicherbezugspunktmitgrenzpunkt);
		CREATE INDEX ax_lagefestpunkt_istidentischmitap ON ax_lagefestpunkt USING btree (istidentischmitap);
		CREATE INDEX ax_lagefestpunkt_unterschiedlicherbezugspunktmitap ON ax_lagefestpunkt USING btree (unterschiedlicherbezugspunktmitap);
		CREATE INDEX ax_lagefestpunkt_unterschiedlicherbezugspunktmitsvp ON ax_lagefestpunkt USING btree (unterschiedlicherbezugspunktmitsvp);
		CREATE INDEX ax_lagefestpunkt_istidentischmitsvp ON ax_lagefestpunkt USING btree (istidentischmitsvp);
		CREATE INDEX ax_lagefestpunkt_bestehtaus ON ax_lagefestpunkt USING gin (bestehtaus);
		CREATE INDEX ax_lagefestpunkt_istteilvon ON ax_lagefestpunkt USING gin (istteilvon);

		COMMENT ON TABLE ax_lagefestpunkt IS 'FeatureType: "AX_Lagefestpunkt"';
		COMMENT ON COLUMN ax_lagefestpunkt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_lagefestpunkt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_lagefestpunkt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_lagefestpunkt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.darstellungshinweis IS 'darstellungshinweis  Boolean 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.frueherepunktnummer IS 'frueherePunktnummer   0..*';
		COMMENT ON COLUMN ax_lagefestpunkt.gemarkung_gemarkungsnummer IS 'gemarkung|AX_Gemarkung_Schluessel|gemarkungsnummer   1';
		COMMENT ON COLUMN ax_lagefestpunkt.gemarkung_land IS 'gemarkung|AX_Gemarkung_Schluessel|land   1';
		COMMENT ON COLUMN ax_lagefestpunkt.gemeinde IS 'gemeinde|AX_Gemeindekennzeichen|gemeinde   1';
		COMMENT ON COLUMN ax_lagefestpunkt.gemeinde_gemeindeteil IS 'gemeinde|AX_Gemeindekennzeichen|gemeindeteil   0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.kreis IS 'gemeinde|AX_Gemeindekennzeichen|kreis   1';
		COMMENT ON COLUMN ax_lagefestpunkt.gemeinde_land IS 'gemeinde|AX_Gemeindekennzeichen|land   1';
		COMMENT ON COLUMN ax_lagefestpunkt.gemeinde_regierungsbezirk IS 'gemeinde|AX_Gemeindekennzeichen|regierungsbezirk   0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.internebemerkungen IS 'interneBemerkungen   0..*';
		COMMENT ON COLUMN ax_lagefestpunkt.katasteramt_land IS 'katasteramt|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_lagefestpunkt.katasteramt_stelle IS 'katasteramt|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_lagefestpunkt.land_land IS 'land|AX_Bundesland_Schluessel|land   1';
		COMMENT ON COLUMN ax_lagefestpunkt.namelagebeschreibung IS 'nameLagebeschreibung   0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.nutzerspezifischebemerkungen IS 'nutzerspezifischeBemerkungen   0..*';
		COMMENT ON COLUMN ax_lagefestpunkt.punktkennung IS 'punktkennung   1';
		COMMENT ON COLUMN ax_lagefestpunkt.punktvermarkung IS 'punktvermarkung enumeration AX_Marke 1';
		COMMENT ON COLUMN ax_lagefestpunkt.relativehoehe IS 'relativeHoehe  Length 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.funktion IS 'funktion enumeration AX_Funktion_Lagefestpunkt 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.hierarchiestufe3d IS 'klassifikation|AX_Klassifikation_Lagefestpunkt|hierarchiestufe3D enumeration AX_Klassifikation_Hierarchiestufe3D_Lagefestpunkt 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.ordnung IS 'klassifikation|AX_Klassifikation_Lagefestpunkt|ordnung enumeration AX_Klassifikation_Ordnung_Lagefestpunkt 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.wertigkeit IS 'klassifikation|AX_Klassifikation_Lagefestpunkt|wertigkeit enumeration AX_Klassifikation_Wertigkeit_Lagefestpunkt 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.abstand IS 'pfeilerhoehe|AX_Pfeilerhoehe_Lagefestpunkt|abstand  Distance 1';
		COMMENT ON COLUMN ax_lagefestpunkt.messung IS 'pfeilerhoehe|AX_Pfeilerhoehe_Lagefestpunkt|messung  Date 1';
		COMMENT ON COLUMN ax_lagefestpunkt.befund IS 'qualitaetsangaben|AX_DQFestpunkt|befund   0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.gnsstauglichkeit IS 'qualitaetsangaben|AX_DQFestpunkt|gnssTauglichkeit enumeration AX_GNSSTauglichkeit 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.punktstabilitaet IS 'qualitaetsangaben|AX_DQFestpunkt|punktstabilitaet enumeration AX_Punktstabilitaet 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.ueberwachungsdatum IS 'qualitaetsangaben|AX_DQFestpunkt|ueberwachungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istidentischmitrsp IS 'Assoziation zu: FeatureType AX_Referenzstationspunkt (ax_referenzstationspunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istexzentrumzu IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istzentrumzu IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..*';
		COMMENT ON COLUMN ax_lagefestpunkt.unterschiedlicherbezugspunktmithfp IS 'Assoziation zu: FeatureType AX_Hoehenfestpunkt (ax_hoehenfestpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istidentischmithfp IS 'Assoziation zu: FeatureType AX_Hoehenfestpunkt (ax_hoehenfestpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.unterschiedlicherbezugspunktmitsfp IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istidentischmitsfp IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istidentischmitgrenzpunkt IS 'Assoziation zu: FeatureType AX_Grenzpunkt (ax_grenzpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.unterschiedlicherbezugspunktmitgrenzpunkt IS 'Assoziation zu: FeatureType AX_Grenzpunkt (ax_grenzpunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istidentischmitap IS 'Assoziation zu: FeatureType AX_Aufnahmepunkt (ax_aufnahmepunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.unterschiedlicherbezugspunktmitap IS 'Assoziation zu: FeatureType AX_Aufnahmepunkt (ax_aufnahmepunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.unterschiedlicherbezugspunktmitsvp IS 'Assoziation zu: FeatureType AX_SonstigerVermessungspunkt (ax_sonstigervermessungspunkt) 0..1';
		COMMENT ON COLUMN ax_lagefestpunkt.istidentischmitsvp IS 'Assoziation zu: FeatureType AX_SonstigerVermessungspunkt (ax_sonstigervermessungspunkt) 0..1';
		CREATE TABLE ax_hoehenfestpunkt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  darstellungshinweis character varying,
		  frueherepunktnummer character varying[],
		  gemarkung_gemarkungsnummer character varying,
		  gemarkung_land character varying,
		  gemeinde character varying NOT NULL,
		  gemeinde_gemeindeteil character varying,
		  kreis character varying NOT NULL,
		  gemeinde_land character varying NOT NULL,
		  gemeinde_regierungsbezirk character varying,
		  internebemerkungen character varying[],
		  katasteramt_land character varying,
		  katasteramt_stelle character varying,
		  land_land character varying NOT NULL,
		  namelagebeschreibung character varying,
		  nutzerspezifischebemerkungen character varying[],
		  punktkennung character varying NOT NULL,
		  punktvermarkung integer NOT NULL,
		  relativehoehe double precision,
		  nivlinie character varying[],
		  ordnung integer,
		  befund character varying,
		  gnsstauglichkeit integer,
		  geologischestabilitaet integer,
		  grundwasserschwankung integer,
		  grundwasserstand integer,
		  guetedesbaugrundes integer,
		  guetedesvermarkungstraegers integer,
		  hoehenstabilitaetauswiederholungsmessungen integer,
		  topographieundumwelt integer,
		  vermutetehoehenstabilitaet integer,
		  ueberwachungsdatum date,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  istidentischmitrsp character(16),
		  unterschiedlicherbezugspunktmitlfp character(16),
		  istidentischmitlfp character(16),
		  istidentischmitsfp character(16),
		  unterschiedlicherbezugspunktmitsfp character(16),
		  unterschiedlicherbezugspunktmitap character(16),
		  unterschiedlicherbezugspunktmitsvp character(16),
		  unterschiedlicherbezugspunktmitsp character(16),
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_hoehenfestpunkt_gml ON ax_hoehenfestpunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_hoehenfestpunkt_endet ON ax_hoehenfestpunkt USING btree (endet);
		CREATE INDEX ax_hoehenfestpunkt_istidentischmitrsp ON ax_hoehenfestpunkt USING btree (istidentischmitrsp);
		CREATE INDEX ax_hoehenfestpunkt_unterschiedlicherbezugspunktmitlfp ON ax_hoehenfestpunkt USING btree (unterschiedlicherbezugspunktmitlfp);
		CREATE INDEX ax_hoehenfestpunkt_istidentischmitlfp ON ax_hoehenfestpunkt USING btree (istidentischmitlfp);
		CREATE INDEX ax_hoehenfestpunkt_istidentischmitsfp ON ax_hoehenfestpunkt USING btree (istidentischmitsfp);
		CREATE INDEX ax_hoehenfestpunkt_unterschiedlicherbezugspunktmitsfp ON ax_hoehenfestpunkt USING btree (unterschiedlicherbezugspunktmitsfp);
		CREATE INDEX ax_hoehenfestpunkt_unterschiedlicherbezugspunktmitap ON ax_hoehenfestpunkt USING btree (unterschiedlicherbezugspunktmitap);
		CREATE INDEX ax_hoehenfestpunkt_unterschiedlicherbezugspunktmitsvp ON ax_hoehenfestpunkt USING btree (unterschiedlicherbezugspunktmitsvp);
		CREATE INDEX ax_hoehenfestpunkt_unterschiedlicherbezugspunktmitsp ON ax_hoehenfestpunkt USING btree (unterschiedlicherbezugspunktmitsp);
		CREATE INDEX ax_hoehenfestpunkt_bestehtaus ON ax_hoehenfestpunkt USING gin (bestehtaus);
		CREATE INDEX ax_hoehenfestpunkt_istteilvon ON ax_hoehenfestpunkt USING gin (istteilvon);

		COMMENT ON TABLE ax_hoehenfestpunkt IS 'FeatureType: "AX_Hoehenfestpunkt"';
		COMMENT ON COLUMN ax_hoehenfestpunkt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_hoehenfestpunkt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.darstellungshinweis IS 'darstellungshinweis  Boolean 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.frueherepunktnummer IS 'frueherePunktnummer   0..*';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gemarkung_gemarkungsnummer IS 'gemarkung|AX_Gemarkung_Schluessel|gemarkungsnummer   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gemarkung_land IS 'gemarkung|AX_Gemarkung_Schluessel|land   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gemeinde IS 'gemeinde|AX_Gemeindekennzeichen|gemeinde   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gemeinde_gemeindeteil IS 'gemeinde|AX_Gemeindekennzeichen|gemeindeteil   0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.kreis IS 'gemeinde|AX_Gemeindekennzeichen|kreis   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gemeinde_land IS 'gemeinde|AX_Gemeindekennzeichen|land   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gemeinde_regierungsbezirk IS 'gemeinde|AX_Gemeindekennzeichen|regierungsbezirk   0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.internebemerkungen IS 'interneBemerkungen   0..*';
		COMMENT ON COLUMN ax_hoehenfestpunkt.katasteramt_land IS 'katasteramt|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.katasteramt_stelle IS 'katasteramt|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.land_land IS 'land|AX_Bundesland_Schluessel|land   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.namelagebeschreibung IS 'nameLagebeschreibung   0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.nutzerspezifischebemerkungen IS 'nutzerspezifischeBemerkungen   0..*';
		COMMENT ON COLUMN ax_hoehenfestpunkt.punktkennung IS 'punktkennung   1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.punktvermarkung IS 'punktvermarkung enumeration AX_Marke 1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.relativehoehe IS 'relativeHoehe  Length 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.nivlinie IS 'nivlinie   0..*';
		COMMENT ON COLUMN ax_hoehenfestpunkt.ordnung IS 'ordnung enumeration AX_Ordnung_Hoehenfestpunkt 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.befund IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|befund   0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.gnsstauglichkeit IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|gnssTauglichkeit enumeration AX_GNSSTauglichkeit 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.geologischestabilitaet IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|geologischeStabilitaet enumeration AX_Punktstabilitaet_Hoehenfestpunkt_GeologischeStabilitaet 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.grundwasserschwankung IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|grundwasserschwankung enumeration AX_Punktstabilitaet_Hoehenfestpunkt_Grundwasserschwankung 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.grundwasserstand IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|grundwasserstand enumeration AX_Punktstabilitaet_Hoehenfestpunkt_Grundwasserstand 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.guetedesbaugrundes IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|gueteDesBaugrundes enumeration AX_Punktstabilitaet_Hoehenfestpunkt_GueteDesBaugrundes 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.guetedesvermarkungstraegers IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|gueteDesVermarkungstraegers enumeration AX_Punktstabilitaet_Hoehenfestpunkt_GueteDesVermarkungstraegers 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.hoehenstabilitaetauswiederholungsmessungen IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|hoehenstabilitaetAusWiederholungsmessungen enumeration AX_Punktstabilitaet_Hoehenfestpunkt_HoehenstabilitaetAusWiederholungsmessungen 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.topographieundumwelt IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|topographieUndUmwelt enumeration AX_Punktstabilitaet_Hoehenfestpunkt_TopographieUndUmwelt 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.vermutetehoehenstabilitaet IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|punktstabilitaet|AX_Punktstabilitaet_Hoehenfestpunkt|vermuteteHoehenstabilitaet enumeration AX_Punktstabilitaet_Hoehenfestpunkt_VermuteteHoehenstabilitaet 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.ueberwachungsdatum IS 'qualitaetsangaben|AX_DQHoehenfestpunkt|ueberwachungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.istidentischmitrsp IS 'Assoziation zu: FeatureType AX_Referenzstationspunkt (ax_referenzstationspunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.unterschiedlicherbezugspunktmitlfp IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.istidentischmitlfp IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.istidentischmitsfp IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.unterschiedlicherbezugspunktmitsfp IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.unterschiedlicherbezugspunktmitap IS 'Assoziation zu: FeatureType AX_Aufnahmepunkt (ax_aufnahmepunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.unterschiedlicherbezugspunktmitsvp IS 'Assoziation zu: FeatureType AX_SonstigerVermessungspunkt (ax_sonstigervermessungspunkt) 0..1';
		COMMENT ON COLUMN ax_hoehenfestpunkt.unterschiedlicherbezugspunktmitsp IS 'Assoziation zu: FeatureType AX_Sicherungspunkt (ax_sicherungspunkt) 0..1';
		CREATE TABLE ax_schwerefestpunkt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  darstellungshinweis character varying,
		  frueherepunktnummer character varying[],
		  gemarkung_gemarkungsnummer character varying,
		  gemarkung_land character varying,
		  gemeinde character varying NOT NULL,
		  gemeinde_gemeindeteil character varying,
		  kreis character varying NOT NULL,
		  gemeinde_land character varying NOT NULL,
		  gemeinde_regierungsbezirk character varying,
		  internebemerkungen character varying[],
		  katasteramt_land character varying,
		  katasteramt_stelle character varying,
		  land_land character varying NOT NULL,
		  namelagebeschreibung character varying,
		  nutzerspezifischebemerkungen character varying[],
		  punktkennung character varying NOT NULL,
		  punktvermarkung integer NOT NULL,
		  relativehoehe double precision,
		  funktion integer,
		  ordnung integer,
		  befund character varying,
		  gnsstauglichkeit integer,
		  punktstabilitaet integer,
		  ueberwachungsdatum date,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  unterschiedlicherbezugspunktmitrsp character(16),
		  unterschiedlicherbezugspunktmitlfp character(16),
		  istidentischmitlfp character(16),
		  istidentischmithfp character(16),
		  unterschiedlicherbezugspunktmithfp character(16),
		  istzentrumzu character(16)[],
		  istexzentrumzu character(16),
		  istidentischmitgrenzpunkt character(16),
		  istidentischmitap character(16),
		  istidentischmitsvp character(16),
		  istidentischmitsp character(16),
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_schwerefestpunkt_gml ON ax_schwerefestpunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_schwerefestpunkt_endet ON ax_schwerefestpunkt USING btree (endet);
		CREATE INDEX ax_schwerefestpunkt_unterschiedlicherbezugspunktmitrsp ON ax_schwerefestpunkt USING btree (unterschiedlicherbezugspunktmitrsp);
		CREATE INDEX ax_schwerefestpunkt_unterschiedlicherbezugspunktmitlfp ON ax_schwerefestpunkt USING btree (unterschiedlicherbezugspunktmitlfp);
		CREATE INDEX ax_schwerefestpunkt_istidentischmitlfp ON ax_schwerefestpunkt USING btree (istidentischmitlfp);
		CREATE INDEX ax_schwerefestpunkt_istidentischmithfp ON ax_schwerefestpunkt USING btree (istidentischmithfp);
		CREATE INDEX ax_schwerefestpunkt_unterschiedlicherbezugspunktmithfp ON ax_schwerefestpunkt USING btree (unterschiedlicherbezugspunktmithfp);
		CREATE INDEX ax_schwerefestpunkt_istzentrumzu ON ax_schwerefestpunkt USING gin (istzentrumzu);
		CREATE INDEX ax_schwerefestpunkt_istexzentrumzu ON ax_schwerefestpunkt USING btree (istexzentrumzu);
		CREATE INDEX ax_schwerefestpunkt_istidentischmitgrenzpunkt ON ax_schwerefestpunkt USING btree (istidentischmitgrenzpunkt);
		CREATE INDEX ax_schwerefestpunkt_istidentischmitap ON ax_schwerefestpunkt USING btree (istidentischmitap);
		CREATE INDEX ax_schwerefestpunkt_istidentischmitsvp ON ax_schwerefestpunkt USING btree (istidentischmitsvp);
		CREATE INDEX ax_schwerefestpunkt_istidentischmitsp ON ax_schwerefestpunkt USING btree (istidentischmitsp);
		CREATE INDEX ax_schwerefestpunkt_bestehtaus ON ax_schwerefestpunkt USING gin (bestehtaus);
		CREATE INDEX ax_schwerefestpunkt_istteilvon ON ax_schwerefestpunkt USING gin (istteilvon);

		COMMENT ON TABLE ax_schwerefestpunkt IS 'FeatureType: "AX_Schwerefestpunkt"';
		COMMENT ON COLUMN ax_schwerefestpunkt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_schwerefestpunkt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_schwerefestpunkt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_schwerefestpunkt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.darstellungshinweis IS 'darstellungshinweis  Boolean 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.frueherepunktnummer IS 'frueherePunktnummer   0..*';
		COMMENT ON COLUMN ax_schwerefestpunkt.gemarkung_gemarkungsnummer IS 'gemarkung|AX_Gemarkung_Schluessel|gemarkungsnummer   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.gemarkung_land IS 'gemarkung|AX_Gemarkung_Schluessel|land   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.gemeinde IS 'gemeinde|AX_Gemeindekennzeichen|gemeinde   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.gemeinde_gemeindeteil IS 'gemeinde|AX_Gemeindekennzeichen|gemeindeteil   0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.kreis IS 'gemeinde|AX_Gemeindekennzeichen|kreis   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.gemeinde_land IS 'gemeinde|AX_Gemeindekennzeichen|land   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.gemeinde_regierungsbezirk IS 'gemeinde|AX_Gemeindekennzeichen|regierungsbezirk   0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.internebemerkungen IS 'interneBemerkungen   0..*';
		COMMENT ON COLUMN ax_schwerefestpunkt.katasteramt_land IS 'katasteramt|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.katasteramt_stelle IS 'katasteramt|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.land_land IS 'land|AX_Bundesland_Schluessel|land   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.namelagebeschreibung IS 'nameLagebeschreibung   0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.nutzerspezifischebemerkungen IS 'nutzerspezifischeBemerkungen   0..*';
		COMMENT ON COLUMN ax_schwerefestpunkt.punktkennung IS 'punktkennung   1';
		COMMENT ON COLUMN ax_schwerefestpunkt.punktvermarkung IS 'punktvermarkung enumeration AX_Marke 1';
		COMMENT ON COLUMN ax_schwerefestpunkt.relativehoehe IS 'relativeHoehe  Length 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.funktion IS 'funktion enumeration AX_Funktion_Schwerefestpunkt 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.ordnung IS 'ordnung enumeration AX_Ordnung_Schwerefestpunkt 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.befund IS 'qualitaetsangaben|AX_DQFestpunkt|befund   0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.gnsstauglichkeit IS 'qualitaetsangaben|AX_DQFestpunkt|gnssTauglichkeit enumeration AX_GNSSTauglichkeit 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.punktstabilitaet IS 'qualitaetsangaben|AX_DQFestpunkt|punktstabilitaet enumeration AX_Punktstabilitaet 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.ueberwachungsdatum IS 'qualitaetsangaben|AX_DQFestpunkt|ueberwachungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.unterschiedlicherbezugspunktmitrsp IS 'Assoziation zu: FeatureType AX_Referenzstationspunkt (ax_referenzstationspunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.unterschiedlicherbezugspunktmitlfp IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istidentischmitlfp IS 'Assoziation zu: FeatureType AX_Lagefestpunkt (ax_lagefestpunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istidentischmithfp IS 'Assoziation zu: FeatureType AX_Hoehenfestpunkt (ax_hoehenfestpunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.unterschiedlicherbezugspunktmithfp IS 'Assoziation zu: FeatureType AX_Hoehenfestpunkt (ax_hoehenfestpunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istzentrumzu IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..*';
		COMMENT ON COLUMN ax_schwerefestpunkt.istexzentrumzu IS 'Assoziation zu: FeatureType AX_Schwerefestpunkt (ax_schwerefestpunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istidentischmitgrenzpunkt IS 'Assoziation zu: FeatureType AX_Grenzpunkt (ax_grenzpunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istidentischmitap IS 'Assoziation zu: FeatureType AX_Aufnahmepunkt (ax_aufnahmepunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istidentischmitsvp IS 'Assoziation zu: FeatureType AX_SonstigerVermessungspunkt (ax_sonstigervermessungspunkt) 0..1';
		COMMENT ON COLUMN ax_schwerefestpunkt.istidentischmitsp IS 'Assoziation zu: FeatureType AX_Sicherungspunkt (ax_sicherungspunkt) 0..1';
		CREATE TABLE ax_kanal (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  gewaesserkennzahl character varying,
		  identnummer character varying,
		  name character varying,
		  schifffahrtskategorie integer,
		  widmung integer,
		  zweitname character varying,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_kanal_gml ON ax_kanal USING btree (gml_id,beginnt);
		CREATE INDEX ax_kanal_endet ON ax_kanal USING btree (endet);
		CREATE INDEX ax_kanal_bestehtaus ON ax_kanal USING gin (bestehtaus);
		CREATE INDEX ax_kanal_istteilvon ON ax_kanal USING gin (istteilvon);

		COMMENT ON TABLE ax_kanal IS 'FeatureType: "AX_Kanal"';
		COMMENT ON COLUMN ax_kanal.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_kanal.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_kanal.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_kanal.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_kanal.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_kanal.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_kanal.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_kanal.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_kanal.gewaesserkennzahl IS 'gewaesserkennzahl   0..1';
		COMMENT ON COLUMN ax_kanal.identnummer IS 'identnummer   0..1';
		COMMENT ON COLUMN ax_kanal.name IS 'name   0..1';
		COMMENT ON COLUMN ax_kanal.schifffahrtskategorie IS 'schifffahrtskategorie enumeration AX_Schifffahrtskategorie_Kanal 0..1';
		COMMENT ON COLUMN ax_kanal.widmung IS 'widmung enumeration AX_Widmung_Kanal 0..1';
		COMMENT ON COLUMN ax_kanal.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_wasserlauf (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  gewaesserkennzahl character varying,
		  identnummer character varying,
		  name character varying,
		  schifffahrtskategorie integer,
		  widmung integer,
		  zweitname character varying,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_wasserlauf_gml ON ax_wasserlauf USING btree (gml_id,beginnt);
		CREATE INDEX ax_wasserlauf_endet ON ax_wasserlauf USING btree (endet);
		CREATE INDEX ax_wasserlauf_bestehtaus ON ax_wasserlauf USING gin (bestehtaus);
		CREATE INDEX ax_wasserlauf_istteilvon ON ax_wasserlauf USING gin (istteilvon);

		COMMENT ON TABLE ax_wasserlauf IS 'FeatureType: "AX_Wasserlauf"';
		COMMENT ON COLUMN ax_wasserlauf.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_wasserlauf.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_wasserlauf.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_wasserlauf.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_wasserlauf.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_wasserlauf.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_wasserlauf.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_wasserlauf.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_wasserlauf.gewaesserkennzahl IS 'gewaesserkennzahl   0..1';
		COMMENT ON COLUMN ax_wasserlauf.identnummer IS 'identnummer   0..1';
		COMMENT ON COLUMN ax_wasserlauf.name IS 'name   0..1';
		COMMENT ON COLUMN ax_wasserlauf.schifffahrtskategorie IS 'schifffahrtskategorie enumeration AX_Schifffahrtskategorie 0..1';
		COMMENT ON COLUMN ax_wasserlauf.widmung IS 'widmung enumeration AX_Widmung_Wasserlauf 0..1';
		COMMENT ON COLUMN ax_wasserlauf.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_strasse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying[],
		  fahrbahntrennung integer,
		  internationalebedeutung integer,
		  name character varying,
		  strassenschluessel character varying[],
		  widmung integer NOT NULL,
		  zweitname character varying,
		  bestehtaus character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_strasse_gml ON ax_strasse USING btree (gml_id,beginnt);
		CREATE INDEX ax_strasse_endet ON ax_strasse USING btree (endet);
		CREATE INDEX ax_strasse_bestehtaus ON ax_strasse USING gin (bestehtaus);
		CREATE INDEX ax_strasse_istteilvon ON ax_strasse USING gin (istteilvon);

		COMMENT ON TABLE ax_strasse IS 'FeatureType: "AX_Strasse"';
		COMMENT ON COLUMN ax_strasse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_strasse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_strasse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_strasse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_strasse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_strasse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_strasse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_strasse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_strasse.bezeichnung IS 'bezeichnung   0..*';
		COMMENT ON COLUMN ax_strasse.fahrbahntrennung IS 'fahrbahntrennung enumeration AX_Fahrbahntrennung_Strasse 0..1';
		COMMENT ON COLUMN ax_strasse.internationalebedeutung IS 'internationaleBedeutung enumeration AX_InternationaleBedeutung_Strasse 0..1';
		COMMENT ON COLUMN ax_strasse.name IS 'name   0..1';
		COMMENT ON COLUMN ax_strasse.strassenschluessel IS 'strassenschluessel   0..*';
		COMMENT ON COLUMN ax_strasse.widmung IS 'widmung enumeration AX_Widmung_Strasse 1';
		COMMENT ON COLUMN ax_strasse.zweitname IS 'zweitname   0..1';
		CREATE TABLE ap_fpo (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art character varying,
		  darstellungsprioritaet integer,
		  signaturnummer character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  dientzurdarstellungvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ap_fpo_gml ON ap_fpo USING btree (gml_id,beginnt);
		CREATE INDEX ap_fpo_endet ON ap_fpo USING btree (endet);
		PERFORM AddGeometryColumn('ap_fpo', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ap_fpo_wkb_geometry_idx ON ap_fpo USING gist (wkb_geometry);
		CREATE INDEX ap_fpo_dientzurdarstellungvon ON ap_fpo USING gin (dientzurdarstellungvon);
		CREATE INDEX ap_fpo_istabgeleitetaus ON ap_fpo USING gin (istabgeleitetaus);
		CREATE INDEX ap_fpo_traegtbeizu ON ap_fpo USING gin (traegtbeizu);
		CREATE INDEX ap_fpo_hatdirektunten ON ap_fpo USING gin (hatdirektunten);
		CREATE INDEX ap_fpo_istteilvon ON ap_fpo USING gin (istteilvon);

		COMMENT ON TABLE ap_fpo IS 'FeatureType: "AP_FPO"';
		COMMENT ON COLUMN ap_fpo.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ap_fpo.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ap_fpo.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ap_fpo.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ap_fpo.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ap_fpo.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ap_fpo.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ap_fpo.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ap_fpo.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ap_fpo.art IS 'art  CharacterString 0..1';
		COMMENT ON COLUMN ap_fpo.darstellungsprioritaet IS 'darstellungsprioritaet  Integer 0..1';
		COMMENT ON COLUMN ap_fpo.signaturnummer IS 'signaturnummer  CharacterString 0..1';
		COMMENT ON COLUMN ap_fpo.dientzurdarstellungvon IS 'Assoziation zu: FeatureType AA_Objekt (aa_objekt) 0..*';
		CREATE TABLE ax_polder (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artdespolders integer,
		  funktion character varying,
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_polder_gml ON ax_polder USING btree (gml_id,beginnt);
		CREATE INDEX ax_polder_endet ON ax_polder USING btree (endet);
		PERFORM AddGeometryColumn('ax_polder', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_polder_wkb_geometry_idx ON ax_polder USING gist (wkb_geometry);
		CREATE INDEX ax_polder_istabgeleitetaus ON ax_polder USING gin (istabgeleitetaus);
		CREATE INDEX ax_polder_traegtbeizu ON ax_polder USING gin (traegtbeizu);
		CREATE INDEX ax_polder_hatdirektunten ON ax_polder USING gin (hatdirektunten);
		CREATE INDEX ax_polder_istteilvon ON ax_polder USING gin (istteilvon);

		COMMENT ON TABLE ax_polder IS 'FeatureType: "AX_Polder"';
		COMMENT ON COLUMN ax_polder.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_polder.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_polder.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_polder.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_polder.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_polder.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_polder.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_polder.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_polder.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_polder.artdespolders IS 'artDesPolders enumeration AX_ArtDesPolders 0..1';
		COMMENT ON COLUMN ax_polder.funktion IS 'funktion enumeration AX_Funktion_Polder 0..1';
		COMMENT ON COLUMN ax_polder.name IS 'name   0..1';
		COMMENT ON COLUMN ax_polder.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_polder.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_polder.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_polder.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_polder.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_polder.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_polder.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_polder.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_kondominium (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_kondominium_gml ON ax_kondominium USING btree (gml_id,beginnt);
		CREATE INDEX ax_kondominium_endet ON ax_kondominium USING btree (endet);
		PERFORM AddGeometryColumn('ax_kondominium', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_kondominium_wkb_geometry_idx ON ax_kondominium USING gist (wkb_geometry);
		CREATE INDEX ax_kondominium_istabgeleitetaus ON ax_kondominium USING gin (istabgeleitetaus);
		CREATE INDEX ax_kondominium_traegtbeizu ON ax_kondominium USING gin (traegtbeizu);
		CREATE INDEX ax_kondominium_hatdirektunten ON ax_kondominium USING gin (hatdirektunten);
		CREATE INDEX ax_kondominium_istteilvon ON ax_kondominium USING gin (istteilvon);

		COMMENT ON TABLE ax_kondominium IS 'FeatureType: "AX_Kondominium"';
		COMMENT ON COLUMN ax_kondominium.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_kondominium.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_kondominium.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_kondominium.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_kondominium.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_kondominium.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_kondominium.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_kondominium.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_kondominium.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_aussparungsflaeche (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artderaussparung integer NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_aussparungsflaeche_gml ON ax_aussparungsflaeche USING btree (gml_id,beginnt);
		CREATE INDEX ax_aussparungsflaeche_endet ON ax_aussparungsflaeche USING btree (endet);
		PERFORM AddGeometryColumn('ax_aussparungsflaeche', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_aussparungsflaeche_wkb_geometry_idx ON ax_aussparungsflaeche USING gist (wkb_geometry);
		CREATE INDEX ax_aussparungsflaeche_istabgeleitetaus ON ax_aussparungsflaeche USING gin (istabgeleitetaus);
		CREATE INDEX ax_aussparungsflaeche_traegtbeizu ON ax_aussparungsflaeche USING gin (traegtbeizu);
		CREATE INDEX ax_aussparungsflaeche_hatdirektunten ON ax_aussparungsflaeche USING gin (hatdirektunten);
		CREATE INDEX ax_aussparungsflaeche_istteilvon ON ax_aussparungsflaeche USING gin (istteilvon);

		COMMENT ON TABLE ax_aussparungsflaeche IS 'FeatureType: "AX_Aussparungsflaeche"';
		COMMENT ON COLUMN ax_aussparungsflaeche.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_aussparungsflaeche.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_aussparungsflaeche.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_aussparungsflaeche.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_aussparungsflaeche.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_aussparungsflaeche.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_aussparungsflaeche.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_aussparungsflaeche.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_aussparungsflaeche.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_aussparungsflaeche.artderaussparung IS 'artDerAussparung enumeration AX_ArtDerAussparung 1';
		CREATE TABLE ax_hafen (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  hafenkategorie integer,
		  name character varying,
		  nutzung integer,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_hafen_gml ON ax_hafen USING btree (gml_id,beginnt);
		CREATE INDEX ax_hafen_endet ON ax_hafen USING btree (endet);
		PERFORM AddGeometryColumn('ax_hafen', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_hafen_wkb_geometry_idx ON ax_hafen USING gist (wkb_geometry);
		CREATE INDEX ax_hafen_istabgeleitetaus ON ax_hafen USING gin (istabgeleitetaus);
		CREATE INDEX ax_hafen_traegtbeizu ON ax_hafen USING gin (traegtbeizu);
		CREATE INDEX ax_hafen_hatdirektunten ON ax_hafen USING gin (hatdirektunten);
		CREATE INDEX ax_hafen_istteilvon ON ax_hafen USING gin (istteilvon);

		COMMENT ON TABLE ax_hafen IS 'FeatureType: "AX_Hafen"';
		COMMENT ON COLUMN ax_hafen.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_hafen.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_hafen.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_hafen.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_hafen.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_hafen.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_hafen.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_hafen.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_hafen.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_hafen.hafenkategorie IS 'hafenkategorie enumeration AX_Hafenkategorie_Hafen 0..1';
		COMMENT ON COLUMN ax_hafen.name IS 'name   0..1';
		COMMENT ON COLUMN ax_hafen.nutzung IS 'nutzung enumeration AX_Nutzung_Hafen 0..1';
		COMMENT ON COLUMN ax_hafen.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_hafen.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_hafen.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_hafen.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_hafen.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_hafen.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_hafen.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_testgelaende (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_testgelaende_gml ON ax_testgelaende USING btree (gml_id,beginnt);
		CREATE INDEX ax_testgelaende_endet ON ax_testgelaende USING btree (endet);
		PERFORM AddGeometryColumn('ax_testgelaende', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_testgelaende_wkb_geometry_idx ON ax_testgelaende USING gist (wkb_geometry);
		CREATE INDEX ax_testgelaende_istabgeleitetaus ON ax_testgelaende USING gin (istabgeleitetaus);
		CREATE INDEX ax_testgelaende_traegtbeizu ON ax_testgelaende USING gin (traegtbeizu);
		CREATE INDEX ax_testgelaende_hatdirektunten ON ax_testgelaende USING gin (hatdirektunten);
		CREATE INDEX ax_testgelaende_istteilvon ON ax_testgelaende USING gin (istteilvon);

		COMMENT ON TABLE ax_testgelaende IS 'FeatureType: "AX_Testgelaende"';
		COMMENT ON COLUMN ax_testgelaende.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_testgelaende.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_testgelaende.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_testgelaende.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_testgelaende.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_testgelaende.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_testgelaende.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_testgelaende.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_testgelaende.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_testgelaende.name IS 'name   0..1';
		COMMENT ON COLUMN ax_testgelaende.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_testgelaende.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_testgelaende.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_testgelaende.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_testgelaende.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_testgelaende.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_testgelaende.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_schleuse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying,
		  konstruktionsmerkmalbauart integer,
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  zustand integer,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_schleuse_gml ON ax_schleuse USING btree (gml_id,beginnt);
		CREATE INDEX ax_schleuse_endet ON ax_schleuse USING btree (endet);
		PERFORM AddGeometryColumn('ax_schleuse', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_schleuse_wkb_geometry_idx ON ax_schleuse USING gist (wkb_geometry);
		CREATE INDEX ax_schleuse_istabgeleitetaus ON ax_schleuse USING gin (istabgeleitetaus);
		CREATE INDEX ax_schleuse_traegtbeizu ON ax_schleuse USING gin (traegtbeizu);
		CREATE INDEX ax_schleuse_hatdirektunten ON ax_schleuse USING gin (hatdirektunten);
		CREATE INDEX ax_schleuse_istteilvon ON ax_schleuse USING gin (istteilvon);

		COMMENT ON TABLE ax_schleuse IS 'FeatureType: "AX_Schleuse"';
		COMMENT ON COLUMN ax_schleuse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_schleuse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_schleuse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_schleuse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_schleuse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_schleuse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_schleuse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_schleuse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_schleuse.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_schleuse.bezeichnung IS 'bezeichnung   0..1';
		COMMENT ON COLUMN ax_schleuse.konstruktionsmerkmalbauart IS 'konstruktionsmerkmalBauart enumeration AX_KonstruktionsmerkmalBauart_Schleuse 0..1';
		COMMENT ON COLUMN ax_schleuse.name IS 'name   0..1';
		COMMENT ON COLUMN ax_schleuse.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_schleuse.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_schleuse.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_schleuse.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_schleuse.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_schleuse.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_schleuse.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_schleuse.zustand IS 'zustand enumeration AX_Zustand_Schleuse 0..1';
		CREATE TABLE ax_ortslage (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  zweitname character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_ortslage_gml ON ax_ortslage USING btree (gml_id,beginnt);
		CREATE INDEX ax_ortslage_endet ON ax_ortslage USING btree (endet);
		PERFORM AddGeometryColumn('ax_ortslage', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_ortslage_wkb_geometry_idx ON ax_ortslage USING gist (wkb_geometry);
		CREATE INDEX ax_ortslage_istabgeleitetaus ON ax_ortslage USING gin (istabgeleitetaus);
		CREATE INDEX ax_ortslage_traegtbeizu ON ax_ortslage USING gin (traegtbeizu);
		CREATE INDEX ax_ortslage_hatdirektunten ON ax_ortslage USING gin (hatdirektunten);
		CREATE INDEX ax_ortslage_istteilvon ON ax_ortslage USING gin (istteilvon);

		COMMENT ON TABLE ax_ortslage IS 'FeatureType: "AX_Ortslage"';
		COMMENT ON COLUMN ax_ortslage.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_ortslage.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_ortslage.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_ortslage.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_ortslage.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_ortslage.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_ortslage.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_ortslage.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_ortslage.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_ortslage.name IS 'name   0..1';
		COMMENT ON COLUMN ax_ortslage.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_ortslage.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_ortslage.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_ortslage.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_ortslage.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_ortslage.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_ortslage.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_ortslage.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_grenzuebergang (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_grenzuebergang_gml ON ax_grenzuebergang USING btree (gml_id,beginnt);
		CREATE INDEX ax_grenzuebergang_endet ON ax_grenzuebergang USING btree (endet);
		PERFORM AddGeometryColumn('ax_grenzuebergang', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_grenzuebergang_wkb_geometry_idx ON ax_grenzuebergang USING gist (wkb_geometry);
		CREATE INDEX ax_grenzuebergang_istabgeleitetaus ON ax_grenzuebergang USING gin (istabgeleitetaus);
		CREATE INDEX ax_grenzuebergang_traegtbeizu ON ax_grenzuebergang USING gin (traegtbeizu);
		CREATE INDEX ax_grenzuebergang_hatdirektunten ON ax_grenzuebergang USING gin (hatdirektunten);
		CREATE INDEX ax_grenzuebergang_istteilvon ON ax_grenzuebergang USING gin (istteilvon);

		COMMENT ON TABLE ax_grenzuebergang IS 'FeatureType: "AX_Grenzuebergang"';
		COMMENT ON COLUMN ax_grenzuebergang.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_grenzuebergang.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_grenzuebergang.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_grenzuebergang.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_grenzuebergang.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.name IS 'name   0..1';
		COMMENT ON COLUMN ax_grenzuebergang.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_grenzuebergang.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_grenzuebergang.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_grenzuebergang.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_grenzuebergang.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_insel (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  name character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_insel_gml ON ax_insel USING btree (gml_id,beginnt);
		CREATE INDEX ax_insel_endet ON ax_insel USING btree (endet);
		PERFORM AddGeometryColumn('ax_insel', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_insel_wkb_geometry_idx ON ax_insel USING gist (wkb_geometry);
		CREATE INDEX ax_insel_istabgeleitetaus ON ax_insel USING gin (istabgeleitetaus);
		CREATE INDEX ax_insel_traegtbeizu ON ax_insel USING gin (traegtbeizu);
		CREATE INDEX ax_insel_hatdirektunten ON ax_insel USING gin (hatdirektunten);
		CREATE INDEX ax_insel_istteilvon ON ax_insel USING gin (istteilvon);

		COMMENT ON TABLE ax_insel IS 'FeatureType: "AX_Insel"';
		COMMENT ON COLUMN ax_insel.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_insel.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_insel.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_insel.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_insel.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_insel.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_insel.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_insel.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_insel.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_insel.name IS 'name   0..1';
		CREATE TABLE ax_gewann (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  name character varying NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gewann_gml ON ax_gewann USING btree (gml_id,beginnt);
		CREATE INDEX ax_gewann_endet ON ax_gewann USING btree (endet);
		PERFORM AddGeometryColumn('ax_gewann', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gewann_wkb_geometry_idx ON ax_gewann USING gist (wkb_geometry);
		CREATE INDEX ax_gewann_istabgeleitetaus ON ax_gewann USING gin (istabgeleitetaus);
		CREATE INDEX ax_gewann_traegtbeizu ON ax_gewann USING gin (traegtbeizu);
		CREATE INDEX ax_gewann_hatdirektunten ON ax_gewann USING gin (hatdirektunten);
		CREATE INDEX ax_gewann_istteilvon ON ax_gewann USING gin (istteilvon);

		COMMENT ON TABLE ax_gewann IS 'FeatureType: "AX_Gewann"';
		COMMENT ON COLUMN ax_gewann.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gewann.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gewann.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gewann.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gewann.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gewann.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gewann.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gewann.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gewann.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gewann.name IS 'name   1';
		CREATE TABLE ax_abschnitt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying NOT NULL,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_abschnitt_gml ON ax_abschnitt USING btree (gml_id,beginnt);
		CREATE INDEX ax_abschnitt_endet ON ax_abschnitt USING btree (endet);
		PERFORM AddGeometryColumn('ax_abschnitt', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_abschnitt_wkb_geometry_idx ON ax_abschnitt USING gist (wkb_geometry);
		CREATE INDEX ax_abschnitt_istabgeleitetaus ON ax_abschnitt USING gin (istabgeleitetaus);
		CREATE INDEX ax_abschnitt_traegtbeizu ON ax_abschnitt USING gin (traegtbeizu);
		CREATE INDEX ax_abschnitt_hatdirektunten ON ax_abschnitt USING gin (hatdirektunten);
		CREATE INDEX ax_abschnitt_istteilvon ON ax_abschnitt USING gin (istteilvon);

		COMMENT ON TABLE ax_abschnitt IS 'FeatureType: "AX_Abschnitt"';
		COMMENT ON COLUMN ax_abschnitt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_abschnitt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_abschnitt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_abschnitt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_abschnitt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_abschnitt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_abschnitt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_abschnitt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_abschnitt.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_abschnitt.bezeichnung IS 'bezeichnung   1';
		COMMENT ON COLUMN ax_abschnitt.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_abschnitt.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_abschnitt.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_abschnitt.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_abschnitt.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschnitt.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_abschnitt.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_ast (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bezeichnung character varying NOT NULL,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_ast_gml ON ax_ast USING btree (gml_id,beginnt);
		CREATE INDEX ax_ast_endet ON ax_ast USING btree (endet);
		PERFORM AddGeometryColumn('ax_ast', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_ast_wkb_geometry_idx ON ax_ast USING gist (wkb_geometry);
		CREATE INDEX ax_ast_istabgeleitetaus ON ax_ast USING gin (istabgeleitetaus);
		CREATE INDEX ax_ast_traegtbeizu ON ax_ast USING gin (traegtbeizu);
		CREATE INDEX ax_ast_hatdirektunten ON ax_ast USING gin (hatdirektunten);
		CREATE INDEX ax_ast_istteilvon ON ax_ast USING gin (istteilvon);

		COMMENT ON TABLE ax_ast IS 'FeatureType: "AX_Ast"';
		COMMENT ON COLUMN ax_ast.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_ast.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_ast.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_ast.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_ast.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_ast.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_ast.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_ast.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_ast.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_ast.bezeichnung IS 'bezeichnung   1';
		COMMENT ON COLUMN ax_ast.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_ast.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_ast.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_ast.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_ast.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_ast.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_ast.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_ast.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_geripplinie (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artdergeripplinie integer,
		  erfassung_datetime character(20),
		  ax_dqerfassungsmethode integer NOT NULL,
		  identifikation integer NOT NULL,
		  hoehengenauigkeit_nameofmeasure character varying[],
		  hoehengenauigkeit_measureidentification character varying,
		  hoehengenauigkeit_measuredescription character varying,
		  hoehengenauigkeit_evaluationmethodtype character varying,
		  hoehengenauigkeit_evaluationmethoddescription character varying,
		  hoehengenauigkeit_evaluationprocedure character varying,
		  hoehengenauigkeit_datetime character(20)[],
		  hoehengenauigkeit_result character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_geripplinie_gml ON ax_geripplinie USING btree (gml_id,beginnt);
		CREATE INDEX ax_geripplinie_endet ON ax_geripplinie USING btree (endet);
		PERFORM AddGeometryColumn('ax_geripplinie', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_geripplinie_wkb_geometry_idx ON ax_geripplinie USING gist (wkb_geometry);
		CREATE INDEX ax_geripplinie_istabgeleitetaus ON ax_geripplinie USING gin (istabgeleitetaus);
		CREATE INDEX ax_geripplinie_traegtbeizu ON ax_geripplinie USING gin (traegtbeizu);
		CREATE INDEX ax_geripplinie_hatdirektunten ON ax_geripplinie USING gin (hatdirektunten);
		CREATE INDEX ax_geripplinie_istteilvon ON ax_geripplinie USING gin (istteilvon);

		COMMENT ON TABLE ax_geripplinie IS 'FeatureType: "AX_Geripplinie"';
		COMMENT ON COLUMN ax_geripplinie.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_geripplinie.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_geripplinie.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_geripplinie.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_geripplinie.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_geripplinie.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_geripplinie.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_geripplinie.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_geripplinie.wkb_geometry IS 'wkb_geometry  GM_MultiCurve 0..1';
		COMMENT ON COLUMN ax_geripplinie.artdergeripplinie IS 'artDerGeripplinie enumeration AX_ArtDerGeripplinie 0..1';
		COMMENT ON COLUMN ax_geripplinie.erfassung_datetime IS 'erfassung|AX_Erfassung_DGM|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_geripplinie.ax_dqerfassungsmethode IS 'erfassung|AX_Erfassung_DGM|AX_DQErfassungsmethode enumeration AX_DQErfassungsmethode 1';
		COMMENT ON COLUMN ax_geripplinie.identifikation IS 'erfassung|AX_Erfassung_DGM|identifikation enumeration AX_Identifikation 1';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_nameofmeasure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure  CharacterString 0..*';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_measureidentification IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_measuredescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_evaluationmethodtype IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_evaluationmethoddescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_evaluationprocedure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure  CI_Citation 0..1';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_datetime IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|dateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_geripplinie.hoehengenauigkeit_result IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|result  DQ_Result 1..*';
		CREATE TABLE ax_gewaesserbegrenzung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  besondereartdergewaesserbegrenzung integer,
		  erfassunggewaesserbegrenzung_datetime character(20),
		  ax_dqerfassungsmethodegewaesserbegrenzung integer NOT NULL,
		  identifikation integer NOT NULL,
		  hoehengenauigkeit_nameofmeasure character varying[],
		  hoehengenauigkeit_measureidentification character varying,
		  hoehengenauigkeit_measuredescription character varying,
		  hoehengenauigkeit_evaluationmethodtype character varying,
		  hoehengenauigkeit_evaluationmethoddescription character varying,
		  hoehengenauigkeit_evaluationprocedure character varying,
		  hoehengenauigkeit_datetime character(20)[],
		  hoehengenauigkeit_result character varying[],
		  ursprung integer,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gewaesserbegrenzung_gml ON ax_gewaesserbegrenzung USING btree (gml_id,beginnt);
		CREATE INDEX ax_gewaesserbegrenzung_endet ON ax_gewaesserbegrenzung USING btree (endet);
		PERFORM AddGeometryColumn('ax_gewaesserbegrenzung', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gewaesserbegrenzung_wkb_geometry_idx ON ax_gewaesserbegrenzung USING gist (wkb_geometry);
		CREATE INDEX ax_gewaesserbegrenzung_istabgeleitetaus ON ax_gewaesserbegrenzung USING gin (istabgeleitetaus);
		CREATE INDEX ax_gewaesserbegrenzung_traegtbeizu ON ax_gewaesserbegrenzung USING gin (traegtbeizu);
		CREATE INDEX ax_gewaesserbegrenzung_hatdirektunten ON ax_gewaesserbegrenzung USING gin (hatdirektunten);
		CREATE INDEX ax_gewaesserbegrenzung_istteilvon ON ax_gewaesserbegrenzung USING gin (istteilvon);

		COMMENT ON TABLE ax_gewaesserbegrenzung IS 'FeatureType: "AX_Gewaesserbegrenzung"';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.wkb_geometry IS 'wkb_geometry  GM_MultiCurve 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.besondereartdergewaesserbegrenzung IS 'besondereArtDerGewaesserbegrenzung enumeration AX_BesondereArtDerGewaesserbegrenzung 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.erfassunggewaesserbegrenzung_datetime IS 'erfassungGewaesserbegrenzung|AX_ErfassungGewaesserbegrenzung|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.ax_dqerfassungsmethodegewaesserbegrenzung IS 'erfassungGewaesserbegrenzung|AX_ErfassungGewaesserbegrenzung|AX_DQErfassungsmethodeGewaesserbegrenzung enumeration AX_DQErfassungsmethodeGewaesserbegrenzung 1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.identifikation IS 'erfassungGewaesserbegrenzung|AX_ErfassungGewaesserbegrenzung|identifikation enumeration AX_Identifikation 1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_nameofmeasure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure  CharacterString 0..*';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_measureidentification IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_measuredescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_evaluationmethodtype IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_evaluationmethoddescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_evaluationprocedure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure  CI_Citation 0..1';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_datetime IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|dateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.hoehengenauigkeit_result IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_gewaesserbegrenzung.ursprung IS 'ursprung enumeration AX_Ursprung 0..1';
		CREATE TABLE ax_strukturierterfasstegelaendepunkte (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  aktualisierungsdatum date,
		  artderstrukturierung integer NOT NULL,
		  erfassungstrukturiertegelaendepunkte_datetime character(20),
		  ax_dqerfassungsmethodestrukturiertegelaendepunkte integer NOT NULL,
		  hoehengenauigkeit_nameofmeasure character varying[],
		  hoehengenauigkeit_measureidentification character varying,
		  hoehengenauigkeit_measuredescription character varying,
		  hoehengenauigkeit_evaluationmethodtype character varying,
		  hoehengenauigkeit_evaluationmethoddescription character varying,
		  hoehengenauigkeit_evaluationprocedure character varying,
		  hoehengenauigkeit_datetime character(20)[],
		  hoehengenauigkeit_result character varying[],
		  punktabstand double precision,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_strukturierterfasstegelaendepunkte_gml ON ax_strukturierterfasstegelaendepunkte USING btree (gml_id,beginnt);
		CREATE INDEX ax_strukturierterfasstegelaendepunkte_endet ON ax_strukturierterfasstegelaendepunkte USING btree (endet);
		PERFORM AddGeometryColumn('ax_strukturierterfasstegelaendepunkte', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_strukturierterfasstegelaendepunkte_wkb_geometry_idx ON ax_strukturierterfasstegelaendepunkte USING gist (wkb_geometry);
		CREATE INDEX ax_strukturierterfasstegelaendepunkte_istabgeleitetaus ON ax_strukturierterfasstegelaendepunkte USING gin (istabgeleitetaus);
		CREATE INDEX ax_strukturierterfasstegelaendepunkte_traegtbeizu ON ax_strukturierterfasstegelaendepunkte USING gin (traegtbeizu);
		CREATE INDEX ax_strukturierterfasstegelaendepunkte_hatdirektunten ON ax_strukturierterfasstegelaendepunkte USING gin (hatdirektunten);
		CREATE INDEX ax_strukturierterfasstegelaendepunkte_istteilvon ON ax_strukturierterfasstegelaendepunkte USING gin (istteilvon);

		COMMENT ON TABLE ax_strukturierterfasstegelaendepunkte IS 'FeatureType: "AX_StrukturiertErfassteGelaendepunkte"';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.wkb_geometry IS 'wkb_geometry  GM_MultiCurve 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.aktualisierungsdatum IS 'aktualisierungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.artderstrukturierung IS 'artDerStrukturierung enumeration AX_ArtDerStrukturierung 1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.erfassungstrukturiertegelaendepunkte_datetime IS 'erfassungStrukturierteGelaendepunkte|AX_ErfassungStrukturierteGelaendepunkte|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.ax_dqerfassungsmethodestrukturiertegelaendepunkte IS 'erfassungStrukturierteGelaendepunkte|AX_ErfassungStrukturierteGelaendepunkte|AX_DQErfassungsmethodeStrukturierteGelaendepunkte enumeration AX_DQErfassungsmethodeStrukturierteGelaendepunkte 1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_nameofmeasure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure  CharacterString 0..*';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_measureidentification IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_measuredescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_evaluationmethodtype IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_evaluationmethoddescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_evaluationprocedure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure  CI_Citation 0..1';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_datetime IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|dateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.hoehengenauigkeit_result IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_strukturierterfasstegelaendepunkte.punktabstand IS 'punktabstand  Length 0..1';
		CREATE TABLE ax_einschnitt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  funktion integer,
		  tiefevoneinschnitt double precision,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_einschnitt_gml ON ax_einschnitt USING btree (gml_id,beginnt);
		CREATE INDEX ax_einschnitt_endet ON ax_einschnitt USING btree (endet);
		PERFORM AddGeometryColumn('ax_einschnitt', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_einschnitt_wkb_geometry_idx ON ax_einschnitt USING gist (wkb_geometry);
		CREATE INDEX ax_einschnitt_istabgeleitetaus ON ax_einschnitt USING gin (istabgeleitetaus);
		CREATE INDEX ax_einschnitt_traegtbeizu ON ax_einschnitt USING gin (traegtbeizu);
		CREATE INDEX ax_einschnitt_hatdirektunten ON ax_einschnitt USING gin (hatdirektunten);
		CREATE INDEX ax_einschnitt_istteilvon ON ax_einschnitt USING gin (istteilvon);

		COMMENT ON TABLE ax_einschnitt IS 'FeatureType: "AX_Einschnitt"';
		COMMENT ON COLUMN ax_einschnitt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_einschnitt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_einschnitt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_einschnitt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_einschnitt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_einschnitt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_einschnitt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_einschnitt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_einschnitt.wkb_geometry IS 'wkb_geometry  GM_MultiCurve 0..1';
		COMMENT ON COLUMN ax_einschnitt.funktion IS 'funktion enumeration AX_Funktion_Einschnitt 0..1';
		COMMENT ON COLUMN ax_einschnitt.tiefevoneinschnitt IS 'tiefeVonEinschnitt  Length 0..1';
		CREATE TABLE ax_abgeleitetehoehenlinie (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  aktualitaetsstand date NOT NULL,
		  berechnungsdatum date NOT NULL,
		  berechnungsmethodehoehenlinie integer NOT NULL,
		  hoehe double precision NOT NULL,
		  verwendeteobjekte integer[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_abgeleitetehoehenlinie_gml ON ax_abgeleitetehoehenlinie USING btree (gml_id,beginnt);
		CREATE INDEX ax_abgeleitetehoehenlinie_endet ON ax_abgeleitetehoehenlinie USING btree (endet);
		PERFORM AddGeometryColumn('ax_abgeleitetehoehenlinie', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_abgeleitetehoehenlinie_wkb_geometry_idx ON ax_abgeleitetehoehenlinie USING gist (wkb_geometry);
		CREATE INDEX ax_abgeleitetehoehenlinie_istabgeleitetaus ON ax_abgeleitetehoehenlinie USING gin (istabgeleitetaus);
		CREATE INDEX ax_abgeleitetehoehenlinie_traegtbeizu ON ax_abgeleitetehoehenlinie USING gin (traegtbeizu);
		CREATE INDEX ax_abgeleitetehoehenlinie_hatdirektunten ON ax_abgeleitetehoehenlinie USING gin (hatdirektunten);
		CREATE INDEX ax_abgeleitetehoehenlinie_istteilvon ON ax_abgeleitetehoehenlinie USING gin (istteilvon);

		COMMENT ON TABLE ax_abgeleitetehoehenlinie IS 'FeatureType: "AX_AbgeleiteteHoehenlinie"';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.wkb_geometry IS 'wkb_geometry  GM_MultiCurve 0..1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.aktualitaetsstand IS 'aktualitaetsstand  Date 1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.berechnungsdatum IS 'berechnungsdatum  Date 1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.berechnungsmethodehoehenlinie IS 'berechnungsmethodeHoehenlinie enumeration AX_BerechnungsmethodeHoehenlinie 1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.hoehe IS 'hoehe  Length 1';
		COMMENT ON COLUMN ax_abgeleitetehoehenlinie.verwendeteobjekte IS 'verwendeteObjekte enumeration AX_VerwendeteObjekte 0..*';
		CREATE TABLE ax_nullpunkt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artdesnullpunktes integer NOT NULL,
		  bezeichnung character varying NOT NULL,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_nullpunkt_gml ON ax_nullpunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_nullpunkt_endet ON ax_nullpunkt USING btree (endet);
		PERFORM AddGeometryColumn('ax_nullpunkt', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_nullpunkt_wkb_geometry_idx ON ax_nullpunkt USING gist (wkb_geometry);
		CREATE INDEX ax_nullpunkt_istabgeleitetaus ON ax_nullpunkt USING gin (istabgeleitetaus);
		CREATE INDEX ax_nullpunkt_traegtbeizu ON ax_nullpunkt USING gin (traegtbeizu);
		CREATE INDEX ax_nullpunkt_hatdirektunten ON ax_nullpunkt USING gin (hatdirektunten);
		CREATE INDEX ax_nullpunkt_istteilvon ON ax_nullpunkt USING gin (istteilvon);

		COMMENT ON TABLE ax_nullpunkt IS 'FeatureType: "AX_Nullpunkt"';
		COMMENT ON COLUMN ax_nullpunkt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_nullpunkt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_nullpunkt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_nullpunkt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_nullpunkt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_nullpunkt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_nullpunkt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_nullpunkt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_nullpunkt.wkb_geometry IS 'wkb_geometry  GM_Point 0..1';
		COMMENT ON COLUMN ax_nullpunkt.artdesnullpunktes IS 'artDesNullpunktes enumeration AX_ArtDesNullpunktes_Nullpunkt 1';
		COMMENT ON COLUMN ax_nullpunkt.bezeichnung IS 'bezeichnung   1';
		COMMENT ON COLUMN ax_nullpunkt.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_nullpunkt.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_nullpunkt.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_nullpunkt.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_nullpunkt.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_markantergelaendepunkt (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artdesmarkantenpunktes integer,
		  erfassungmarkantergelaendepunkt_datetime character(20),
		  ax_dqerfassungsmethodemarkantergelaendepunkt integer NOT NULL,
		  hoehengenauigkeit_nameofmeasure character varying[],
		  hoehengenauigkeit_measureidentification character varying,
		  hoehengenauigkeit_measuredescription character varying,
		  hoehengenauigkeit_evaluationmethodtype character varying,
		  hoehengenauigkeit_evaluationmethoddescription character varying,
		  hoehengenauigkeit_evaluationprocedure character varying,
		  hoehengenauigkeit_datetime character(20)[],
		  hoehengenauigkeit_result character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_markantergelaendepunkt_gml ON ax_markantergelaendepunkt USING btree (gml_id,beginnt);
		CREATE INDEX ax_markantergelaendepunkt_endet ON ax_markantergelaendepunkt USING btree (endet);
		PERFORM AddGeometryColumn('ax_markantergelaendepunkt', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_markantergelaendepunkt_wkb_geometry_idx ON ax_markantergelaendepunkt USING gist (wkb_geometry);
		CREATE INDEX ax_markantergelaendepunkt_istabgeleitetaus ON ax_markantergelaendepunkt USING gin (istabgeleitetaus);
		CREATE INDEX ax_markantergelaendepunkt_traegtbeizu ON ax_markantergelaendepunkt USING gin (traegtbeizu);
		CREATE INDEX ax_markantergelaendepunkt_hatdirektunten ON ax_markantergelaendepunkt USING gin (hatdirektunten);
		CREATE INDEX ax_markantergelaendepunkt_istteilvon ON ax_markantergelaendepunkt USING gin (istteilvon);

		COMMENT ON TABLE ax_markantergelaendepunkt IS 'FeatureType: "AX_MarkanterGelaendepunkt"';
		COMMENT ON COLUMN ax_markantergelaendepunkt.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_markantergelaendepunkt.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.wkb_geometry IS 'wkb_geometry  GM_Point 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.artdesmarkantenpunktes IS 'artDesMarkantenPunktes enumeration AX_ArtDesMarkantenGelaendepunktes 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.erfassungmarkantergelaendepunkt_datetime IS 'erfassungMarkanterGelaendepunkt|AX_ErfassungMarkanterGelaendepunkt|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.ax_dqerfassungsmethodemarkantergelaendepunkt IS 'erfassungMarkanterGelaendepunkt|AX_ErfassungMarkanterGelaendepunkt|AX_DQErfassungsmethodeMarkanterGelaendepunkt enumeration AX_DQErfassungsmethodeMarkanterGelaendepunkt 1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_nameofmeasure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure  CharacterString 0..*';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_measureidentification IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_measuredescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_evaluationmethodtype IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_evaluationmethoddescription IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription  CharacterString 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_evaluationprocedure IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure  CI_Citation 0..1';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_datetime IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|dateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_markantergelaendepunkt.hoehengenauigkeit_result IS 'hoehengenauigkeit|DQ_AbsoluteExternalPositionalAccuracy|result  DQ_Result 1..*';
		CREATE TABLE ax_sickerstrecke (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  gewaesserkennzahl character varying,
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  zweitname character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_sickerstrecke_gml ON ax_sickerstrecke USING btree (gml_id,beginnt);
		CREATE INDEX ax_sickerstrecke_endet ON ax_sickerstrecke USING btree (endet);
		PERFORM AddGeometryColumn('ax_sickerstrecke', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_sickerstrecke_wkb_geometry_idx ON ax_sickerstrecke USING gist (wkb_geometry);
		CREATE INDEX ax_sickerstrecke_istabgeleitetaus ON ax_sickerstrecke USING gin (istabgeleitetaus);
		CREATE INDEX ax_sickerstrecke_traegtbeizu ON ax_sickerstrecke USING gin (traegtbeizu);
		CREATE INDEX ax_sickerstrecke_hatdirektunten ON ax_sickerstrecke USING gin (hatdirektunten);
		CREATE INDEX ax_sickerstrecke_istteilvon ON ax_sickerstrecke USING gin (istteilvon);

		COMMENT ON TABLE ax_sickerstrecke IS 'FeatureType: "AX_Sickerstrecke"';
		COMMENT ON COLUMN ax_sickerstrecke.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_sickerstrecke.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_sickerstrecke.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_sickerstrecke.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_sickerstrecke.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.wkb_geometry IS 'wkb_geometry  GM_CompositeCurve 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.gewaesserkennzahl IS 'gewaesserkennzahl   0..1';
		COMMENT ON COLUMN ax_sickerstrecke.name IS 'name   0..1';
		COMMENT ON COLUMN ax_sickerstrecke.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_sickerstrecke.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_sickerstrecke.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_sickerstrecke.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_sickerstrecke.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_sickerstrecke.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_anderefestlegungnachstrassenrecht (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artderfestlegung integer NOT NULL,
		  land character varying,
		  stelle character varying,
		  nummer character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_anderefestlegungnachstrassenrecht_gml ON ax_anderefestlegungnachstrassenrecht USING btree (gml_id,beginnt);
		CREATE INDEX ax_anderefestlegungnachstrassenrecht_endet ON ax_anderefestlegungnachstrassenrecht USING btree (endet);
		PERFORM AddGeometryColumn('ax_anderefestlegungnachstrassenrecht', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_anderefestlegungnachstrassenrecht_wkb_geometry_idx ON ax_anderefestlegungnachstrassenrecht USING gist (wkb_geometry);
		CREATE INDEX ax_anderefestlegungnachstrassenrecht_istabgeleitetaus ON ax_anderefestlegungnachstrassenrecht USING gin (istabgeleitetaus);
		CREATE INDEX ax_anderefestlegungnachstrassenrecht_traegtbeizu ON ax_anderefestlegungnachstrassenrecht USING gin (traegtbeizu);
		CREATE INDEX ax_anderefestlegungnachstrassenrecht_hatdirektunten ON ax_anderefestlegungnachstrassenrecht USING gin (hatdirektunten);
		CREATE INDEX ax_anderefestlegungnachstrassenrecht_istteilvon ON ax_anderefestlegungnachstrassenrecht USING gin (istteilvon);

		COMMENT ON TABLE ax_anderefestlegungnachstrassenrecht IS 'FeatureType: "AX_AndereFestlegungNachStrassenrecht"';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.artderfestlegung IS 'artDerFestlegung enumeration AX_ArtDerFestlegung_AndereFestlegungNachStrassenrecht 1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.land IS 'ausfuehrendeStelle|AX_Dienststelle_Schluessel|land   1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.stelle IS 'ausfuehrendeStelle|AX_Dienststelle_Schluessel|stelle   1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.nummer IS 'nummer   0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_anderefestlegungnachstrassenrecht.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ax_gebiet_kreis (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  schluesselgesamt character varying NOT NULL,
		  kreis character varying NOT NULL,
		  land character varying NOT NULL,
		  regierungsbezirk character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gebiet_kreis_gml ON ax_gebiet_kreis USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebiet_kreis_endet ON ax_gebiet_kreis USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebiet_kreis', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gebiet_kreis_wkb_geometry_idx ON ax_gebiet_kreis USING gist (wkb_geometry);
		CREATE INDEX ax_gebiet_kreis_istabgeleitetaus ON ax_gebiet_kreis USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebiet_kreis_traegtbeizu ON ax_gebiet_kreis USING gin (traegtbeizu);
		CREATE INDEX ax_gebiet_kreis_hatdirektunten ON ax_gebiet_kreis USING gin (hatdirektunten);
		CREATE INDEX ax_gebiet_kreis_istteilvon ON ax_gebiet_kreis USING gin (istteilvon);

		COMMENT ON TABLE ax_gebiet_kreis IS 'FeatureType: "AX_Gebiet_Kreis"';
		COMMENT ON COLUMN ax_gebiet_kreis.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebiet_kreis.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebiet_kreis.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebiet_kreis.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebiet_kreis.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebiet_kreis.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebiet_kreis.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gebiet_kreis.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebiet_kreis.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gebiet_kreis.schluesselgesamt IS 'schluesselGesamt   1';
		COMMENT ON COLUMN ax_gebiet_kreis.kreis IS 'kreis|AX_Kreis_Schluessel|kreis   1';
		COMMENT ON COLUMN ax_gebiet_kreis.land IS 'kreis|AX_Kreis_Schluessel|land   1';
		COMMENT ON COLUMN ax_gebiet_kreis.regierungsbezirk IS 'kreis|AX_Kreis_Schluessel|regierungsbezirk   0..1';
		CREATE TABLE ax_gebiet_bundesland (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  schluesselgesamt character varying NOT NULL,
		  land character varying NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gebiet_bundesland_gml ON ax_gebiet_bundesland USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebiet_bundesland_endet ON ax_gebiet_bundesland USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebiet_bundesland', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gebiet_bundesland_wkb_geometry_idx ON ax_gebiet_bundesland USING gist (wkb_geometry);
		CREATE INDEX ax_gebiet_bundesland_istabgeleitetaus ON ax_gebiet_bundesland USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebiet_bundesland_traegtbeizu ON ax_gebiet_bundesland USING gin (traegtbeizu);
		CREATE INDEX ax_gebiet_bundesland_hatdirektunten ON ax_gebiet_bundesland USING gin (hatdirektunten);
		CREATE INDEX ax_gebiet_bundesland_istteilvon ON ax_gebiet_bundesland USING gin (istteilvon);

		COMMENT ON TABLE ax_gebiet_bundesland IS 'FeatureType: "AX_Gebiet_Bundesland"';
		COMMENT ON COLUMN ax_gebiet_bundesland.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebiet_bundesland.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebiet_bundesland.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebiet_bundesland.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebiet_bundesland.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebiet_bundesland.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebiet_bundesland.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gebiet_bundesland.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebiet_bundesland.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gebiet_bundesland.schluesselgesamt IS 'schluesselGesamt   1';
		COMMENT ON COLUMN ax_gebiet_bundesland.land IS 'land|AX_Bundesland_Schluessel|land   1';
		CREATE TABLE ax_gebiet_regierungsbezirk (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  schluesselgesamt character varying NOT NULL,
		  land character varying NOT NULL,
		  regierungsbezirk character varying NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gebiet_regierungsbezirk_gml ON ax_gebiet_regierungsbezirk USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebiet_regierungsbezirk_endet ON ax_gebiet_regierungsbezirk USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebiet_regierungsbezirk', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gebiet_regierungsbezirk_wkb_geometry_idx ON ax_gebiet_regierungsbezirk USING gist (wkb_geometry);
		CREATE INDEX ax_gebiet_regierungsbezirk_istabgeleitetaus ON ax_gebiet_regierungsbezirk USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebiet_regierungsbezirk_traegtbeizu ON ax_gebiet_regierungsbezirk USING gin (traegtbeizu);
		CREATE INDEX ax_gebiet_regierungsbezirk_hatdirektunten ON ax_gebiet_regierungsbezirk USING gin (hatdirektunten);
		CREATE INDEX ax_gebiet_regierungsbezirk_istteilvon ON ax_gebiet_regierungsbezirk USING gin (istteilvon);

		COMMENT ON TABLE ax_gebiet_regierungsbezirk IS 'FeatureType: "AX_Gebiet_Regierungsbezirk"';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.schluesselgesamt IS 'schluesselGesamt   1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.land IS 'regierungsbezirk|AX_Regierungsbezirk_Schluessel|land   1';
		COMMENT ON COLUMN ax_gebiet_regierungsbezirk.regierungsbezirk IS 'regierungsbezirk|AX_Regierungsbezirk_Schluessel|regierungsbezirk   1';
		CREATE TABLE ax_gebiet_nationalstaat (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  schluesselgesamt character varying NOT NULL,
		  nationalstaat character varying NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gebiet_nationalstaat_gml ON ax_gebiet_nationalstaat USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebiet_nationalstaat_endet ON ax_gebiet_nationalstaat USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebiet_nationalstaat', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gebiet_nationalstaat_wkb_geometry_idx ON ax_gebiet_nationalstaat USING gist (wkb_geometry);
		CREATE INDEX ax_gebiet_nationalstaat_istabgeleitetaus ON ax_gebiet_nationalstaat USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebiet_nationalstaat_traegtbeizu ON ax_gebiet_nationalstaat USING gin (traegtbeizu);
		CREATE INDEX ax_gebiet_nationalstaat_hatdirektunten ON ax_gebiet_nationalstaat USING gin (hatdirektunten);
		CREATE INDEX ax_gebiet_nationalstaat_istteilvon ON ax_gebiet_nationalstaat USING gin (istteilvon);

		COMMENT ON TABLE ax_gebiet_nationalstaat IS 'FeatureType: "AX_Gebiet_Nationalstaat"';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.schluesselgesamt IS 'schluesselGesamt   1';
		COMMENT ON COLUMN ax_gebiet_nationalstaat.nationalstaat IS 'nationalstaat   1';
		CREATE TABLE ax_gebiet_verwaltungsgemeinschaft (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  schluesselgesamt character varying NOT NULL,
		  artderverbandsgemeinde integer NOT NULL,
		  kreis character varying NOT NULL,
		  land character varying NOT NULL,
		  regierungsbezirk character varying,
		  verwaltungsgemeinschaft character varying NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gebiet_verwaltungsgemeinschaft_gml ON ax_gebiet_verwaltungsgemeinschaft USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebiet_verwaltungsgemeinschaft_endet ON ax_gebiet_verwaltungsgemeinschaft USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebiet_verwaltungsgemeinschaft', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gebiet_verwaltungsgemeinschaft_wkb_geometry_idx ON ax_gebiet_verwaltungsgemeinschaft USING gist (wkb_geometry);
		CREATE INDEX ax_gebiet_verwaltungsgemeinschaft_istabgeleitetaus ON ax_gebiet_verwaltungsgemeinschaft USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebiet_verwaltungsgemeinschaft_traegtbeizu ON ax_gebiet_verwaltungsgemeinschaft USING gin (traegtbeizu);
		CREATE INDEX ax_gebiet_verwaltungsgemeinschaft_hatdirektunten ON ax_gebiet_verwaltungsgemeinschaft USING gin (hatdirektunten);
		CREATE INDEX ax_gebiet_verwaltungsgemeinschaft_istteilvon ON ax_gebiet_verwaltungsgemeinschaft USING gin (istteilvon);

		COMMENT ON TABLE ax_gebiet_verwaltungsgemeinschaft IS 'FeatureType: "AX_Gebiet_Verwaltungsgemeinschaft"';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.schluesselgesamt IS 'schluesselGesamt   1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.artderverbandsgemeinde IS 'artDerVerbandsgemeinde enumeration AX_Art_Verbandsgemeinde 1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.kreis IS 'verwaltungsgemeinschaft|AX_Verwaltungsgemeinschaft_Schluessel|kreis   1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.land IS 'verwaltungsgemeinschaft|AX_Verwaltungsgemeinschaft_Schluessel|land   1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.regierungsbezirk IS 'verwaltungsgemeinschaft|AX_Verwaltungsgemeinschaft_Schluessel|regierungsbezirk   0..1';
		COMMENT ON COLUMN ax_gebiet_verwaltungsgemeinschaft.verwaltungsgemeinschaft IS 'verwaltungsgemeinschaft|AX_Verwaltungsgemeinschaft_Schluessel|verwaltungsgemeinschaft   1';
		CREATE TABLE ax_gewaesserstationierungsachse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artdergewaesserachse integer,
		  fliessrichtung character varying NOT NULL,
		  gewaesserkennzahl character varying,
		  identnummer character varying,
		  name character varying,
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  zweitname character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gewaesserstationierungsachse_gml ON ax_gewaesserstationierungsachse USING btree (gml_id,beginnt);
		CREATE INDEX ax_gewaesserstationierungsachse_endet ON ax_gewaesserstationierungsachse USING btree (endet);
		PERFORM AddGeometryColumn('ax_gewaesserstationierungsachse', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gewaesserstationierungsachse_wkb_geometry_idx ON ax_gewaesserstationierungsachse USING gist (wkb_geometry);
		CREATE INDEX ax_gewaesserstationierungsachse_istabgeleitetaus ON ax_gewaesserstationierungsachse USING gin (istabgeleitetaus);
		CREATE INDEX ax_gewaesserstationierungsachse_traegtbeizu ON ax_gewaesserstationierungsachse USING gin (traegtbeizu);
		CREATE INDEX ax_gewaesserstationierungsachse_hatdirektunten ON ax_gewaesserstationierungsachse USING gin (hatdirektunten);
		CREATE INDEX ax_gewaesserstationierungsachse_istteilvon ON ax_gewaesserstationierungsachse USING gin (istteilvon);

		COMMENT ON TABLE ax_gewaesserstationierungsachse IS 'FeatureType: "AX_Gewaesserstationierungsachse"';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.artdergewaesserachse IS 'artDerGewaesserachse enumeration AX_ArtDerGewaesserachse 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.fliessrichtung IS 'fliessrichtung  Boolean 1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.gewaesserkennzahl IS 'gewaesserkennzahl   0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.identnummer IS 'identnummer   0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.name IS 'name   0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_gewaesserstationierungsachse.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_gebietsgrenze (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  artdergebietsgrenze integer[] NOT NULL,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gebietsgrenze_gml ON ax_gebietsgrenze USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebietsgrenze_endet ON ax_gebietsgrenze USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebietsgrenze', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gebietsgrenze_wkb_geometry_idx ON ax_gebietsgrenze USING gist (wkb_geometry);
		CREATE INDEX ax_gebietsgrenze_istabgeleitetaus ON ax_gebietsgrenze USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebietsgrenze_traegtbeizu ON ax_gebietsgrenze USING gin (traegtbeizu);
		CREATE INDEX ax_gebietsgrenze_hatdirektunten ON ax_gebietsgrenze USING gin (hatdirektunten);
		CREATE INDEX ax_gebietsgrenze_istteilvon ON ax_gebietsgrenze USING gin (istteilvon);

		COMMENT ON TABLE ax_gebietsgrenze IS 'FeatureType: "AX_Gebietsgrenze"';
		COMMENT ON COLUMN ax_gebietsgrenze.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebietsgrenze.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebietsgrenze.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebietsgrenze.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebietsgrenze.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebietsgrenze.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebietsgrenze.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gebietsgrenze.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebietsgrenze.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_gebietsgrenze.artdergebietsgrenze IS 'artDerGebietsgrenze enumeration AX_ArtDerGebietsgrenze_Gebietsgrenze 1..*';
		CREATE TABLE ax_gewaesserachse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  breitedesgewaessers integer,
		  fliessrichtung character varying NOT NULL,
		  funktion integer,
		  hydrologischesmerkmal integer,
		  zustand integer,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_gewaesserachse_gml ON ax_gewaesserachse USING btree (gml_id,beginnt);
		CREATE INDEX ax_gewaesserachse_endet ON ax_gewaesserachse USING btree (endet);
		PERFORM AddGeometryColumn('ax_gewaesserachse', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_gewaesserachse_wkb_geometry_idx ON ax_gewaesserachse USING gist (wkb_geometry);
		CREATE INDEX ax_gewaesserachse_istabgeleitetaus ON ax_gewaesserachse USING gin (istabgeleitetaus);
		CREATE INDEX ax_gewaesserachse_traegtbeizu ON ax_gewaesserachse USING gin (traegtbeizu);
		CREATE INDEX ax_gewaesserachse_hatdirektunten ON ax_gewaesserachse USING gin (hatdirektunten);
		CREATE INDEX ax_gewaesserachse_istteilvon ON ax_gewaesserachse USING gin (istteilvon);

		COMMENT ON TABLE ax_gewaesserachse IS 'FeatureType: "AX_Gewaesserachse"';
		COMMENT ON COLUMN ax_gewaesserachse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gewaesserachse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gewaesserachse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gewaesserachse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_gewaesserachse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.breitedesgewaessers IS 'breiteDesGewaessers  Integer 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.fliessrichtung IS 'fliessrichtung  Boolean 1';
		COMMENT ON COLUMN ax_gewaesserachse.funktion IS 'funktion enumeration AX_Funktion_Gewaesserachse 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.hydrologischesmerkmal IS 'hydrologischesMerkmal enumeration AX_HydrologischesMerkmal_Gewaesserachse 0..1';
		COMMENT ON COLUMN ax_gewaesserachse.zustand IS 'zustand enumeration AX_Zustand_Kanal 0..1';
		CREATE TABLE ax_strassenachse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  anzahlderfahrstreifen integer,
		  besonderefahrstreifen integer,
		  breitederfahrbahn double precision,
		  breitedesverkehrsweges integer,
		  funktion integer,
		  oberflaechenmaterial integer,
		  verkehrsbedeutunginneroertlich integer,
		  verkehrsbedeutungueberoertlich integer,
		  zustand integer,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_strassenachse_gml ON ax_strassenachse USING btree (gml_id,beginnt);
		CREATE INDEX ax_strassenachse_endet ON ax_strassenachse USING btree (endet);
		PERFORM AddGeometryColumn('ax_strassenachse', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_strassenachse_wkb_geometry_idx ON ax_strassenachse USING gist (wkb_geometry);
		CREATE INDEX ax_strassenachse_istabgeleitetaus ON ax_strassenachse USING gin (istabgeleitetaus);
		CREATE INDEX ax_strassenachse_traegtbeizu ON ax_strassenachse USING gin (traegtbeizu);
		CREATE INDEX ax_strassenachse_hatdirektunten ON ax_strassenachse USING gin (hatdirektunten);
		CREATE INDEX ax_strassenachse_istteilvon ON ax_strassenachse USING gin (istteilvon);

		COMMENT ON TABLE ax_strassenachse IS 'FeatureType: "AX_Strassenachse"';
		COMMENT ON COLUMN ax_strassenachse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_strassenachse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_strassenachse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_strassenachse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_strassenachse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_strassenachse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_strassenachse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_strassenachse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_strassenachse.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_strassenachse.anzahlderfahrstreifen IS 'anzahlDerFahrstreifen  Integer 0..1';
		COMMENT ON COLUMN ax_strassenachse.besonderefahrstreifen IS 'besondereFahrstreifen enumeration AX_BesondereFahrstreifen 0..1';
		COMMENT ON COLUMN ax_strassenachse.breitederfahrbahn IS 'breiteDerFahrbahn  Length 0..1';
		COMMENT ON COLUMN ax_strassenachse.breitedesverkehrsweges IS 'breiteDesVerkehrsweges  Integer 0..1';
		COMMENT ON COLUMN ax_strassenachse.funktion IS 'funktion enumeration AX_Funktion_Strassenachse 0..1';
		COMMENT ON COLUMN ax_strassenachse.oberflaechenmaterial IS 'oberflaechenmaterial enumeration AX_Oberflaechenmaterial_Strasse 0..1';
		COMMENT ON COLUMN ax_strassenachse.verkehrsbedeutunginneroertlich IS 'verkehrsbedeutungInneroertlich enumeration AX_VerkehrsbedeutungInneroertlich 0..1';
		COMMENT ON COLUMN ax_strassenachse.verkehrsbedeutungueberoertlich IS 'verkehrsbedeutungUeberoertlich enumeration AX_VerkehrsbedeutungUeberoertlich 0..1';
		COMMENT ON COLUMN ax_strassenachse.zustand IS 'zustand enumeration AX_Zustand 0..1';
		CREATE TABLE ax_bahnstrecke (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  anzahlderstreckengleise integer NOT NULL,
		  bahnkategorie integer[] NOT NULL,
		  elektrifizierung integer NOT NULL,
		  name character varying,
		  nummerderbahnstrecke character varying[],
		  spurweite integer NOT NULL,
		  zustand integer,
		  zweitname character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_bahnstrecke_gml ON ax_bahnstrecke USING btree (gml_id,beginnt);
		CREATE INDEX ax_bahnstrecke_endet ON ax_bahnstrecke USING btree (endet);
		PERFORM AddGeometryColumn('ax_bahnstrecke', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_bahnstrecke_wkb_geometry_idx ON ax_bahnstrecke USING gist (wkb_geometry);
		CREATE INDEX ax_bahnstrecke_istabgeleitetaus ON ax_bahnstrecke USING gin (istabgeleitetaus);
		CREATE INDEX ax_bahnstrecke_traegtbeizu ON ax_bahnstrecke USING gin (traegtbeizu);
		CREATE INDEX ax_bahnstrecke_hatdirektunten ON ax_bahnstrecke USING gin (hatdirektunten);
		CREATE INDEX ax_bahnstrecke_istteilvon ON ax_bahnstrecke USING gin (istteilvon);

		COMMENT ON TABLE ax_bahnstrecke IS 'FeatureType: "AX_Bahnstrecke"';
		COMMENT ON COLUMN ax_bahnstrecke.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_bahnstrecke.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_bahnstrecke.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_bahnstrecke.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_bahnstrecke.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_bahnstrecke.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_bahnstrecke.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_bahnstrecke.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_bahnstrecke.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_bahnstrecke.anzahlderstreckengleise IS 'anzahlDerStreckengleise enumeration AX_AnzahlDerStreckengleise 1';
		COMMENT ON COLUMN ax_bahnstrecke.bahnkategorie IS 'bahnkategorie enumeration AX_Bahnkategorie 1..*';
		COMMENT ON COLUMN ax_bahnstrecke.elektrifizierung IS 'elektrifizierung enumeration AX_Elektrifizierung 1';
		COMMENT ON COLUMN ax_bahnstrecke.name IS 'name   0..1';
		COMMENT ON COLUMN ax_bahnstrecke.nummerderbahnstrecke IS 'nummerDerBahnstrecke   0..*';
		COMMENT ON COLUMN ax_bahnstrecke.spurweite IS 'spurweite enumeration AX_Spurweite 1';
		COMMENT ON COLUMN ax_bahnstrecke.zustand IS 'zustand enumeration AX_Zustand 0..1';
		COMMENT ON COLUMN ax_bahnstrecke.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_fahrwegachse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  befestigung integer,
		  breitedesverkehrsweges integer,
		  funktion integer NOT NULL,
		  markierung integer,
		  name character varying,
		  strassenschluessel character varying,
		  zweitname character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_fahrwegachse_gml ON ax_fahrwegachse USING btree (gml_id,beginnt);
		CREATE INDEX ax_fahrwegachse_endet ON ax_fahrwegachse USING btree (endet);
		PERFORM AddGeometryColumn('ax_fahrwegachse', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_fahrwegachse_wkb_geometry_idx ON ax_fahrwegachse USING gist (wkb_geometry);
		CREATE INDEX ax_fahrwegachse_istabgeleitetaus ON ax_fahrwegachse USING gin (istabgeleitetaus);
		CREATE INDEX ax_fahrwegachse_traegtbeizu ON ax_fahrwegachse USING gin (traegtbeizu);
		CREATE INDEX ax_fahrwegachse_hatdirektunten ON ax_fahrwegachse USING gin (hatdirektunten);
		CREATE INDEX ax_fahrwegachse_istteilvon ON ax_fahrwegachse USING gin (istteilvon);

		COMMENT ON TABLE ax_fahrwegachse IS 'FeatureType: "AX_Fahrwegachse"';
		COMMENT ON COLUMN ax_fahrwegachse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_fahrwegachse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_fahrwegachse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_fahrwegachse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_fahrwegachse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.befestigung IS 'befestigung enumeration AX_Befestigung_Fahrwegachse 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.breitedesverkehrsweges IS 'breiteDesVerkehrsweges  Integer 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.funktion IS 'funktion enumeration AX_Funktion_Wegachse 1';
		COMMENT ON COLUMN ax_fahrwegachse.markierung IS 'markierung enumeration AX_Markierung_Wegachse 0..1';
		COMMENT ON COLUMN ax_fahrwegachse.name IS 'name   0..1';
		COMMENT ON COLUMN ax_fahrwegachse.strassenschluessel IS 'strassenschluessel   0..1';
		COMMENT ON COLUMN ax_fahrwegachse.zweitname IS 'zweitname   0..1';
		CREATE TABLE ax_fahrbahnachse (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  anzahlderfahrstreifen integer,
		  besonderefahrstreifen integer,
		  breitederfahrbahn double precision,
		  funktion integer,
		  oberflaechenmaterial integer,
		  zustand integer,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_fahrbahnachse_gml ON ax_fahrbahnachse USING btree (gml_id,beginnt);
		CREATE INDEX ax_fahrbahnachse_endet ON ax_fahrbahnachse USING btree (endet);
		PERFORM AddGeometryColumn('ax_fahrbahnachse', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_fahrbahnachse_wkb_geometry_idx ON ax_fahrbahnachse USING gist (wkb_geometry);
		CREATE INDEX ax_fahrbahnachse_istabgeleitetaus ON ax_fahrbahnachse USING gin (istabgeleitetaus);
		CREATE INDEX ax_fahrbahnachse_traegtbeizu ON ax_fahrbahnachse USING gin (traegtbeizu);
		CREATE INDEX ax_fahrbahnachse_hatdirektunten ON ax_fahrbahnachse USING gin (hatdirektunten);
		CREATE INDEX ax_fahrbahnachse_istteilvon ON ax_fahrbahnachse USING gin (istteilvon);

		COMMENT ON TABLE ax_fahrbahnachse IS 'FeatureType: "AX_Fahrbahnachse"';
		COMMENT ON COLUMN ax_fahrbahnachse.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_fahrbahnachse.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_fahrbahnachse.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_fahrbahnachse.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.anzahlderfahrstreifen IS 'anzahlDerFahrstreifen  Integer 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.besonderefahrstreifen IS 'besondereFahrstreifen enumeration AX_BesondereFahrstreifen 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.breitederfahrbahn IS 'breiteDerFahrbahn  Length 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.funktion IS 'funktion enumeration AX_Funktion_Fahrbahnachse 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.oberflaechenmaterial IS 'oberflaechenmaterial enumeration AX_Oberflaechenmaterial_Strasse 0..1';
		COMMENT ON COLUMN ax_fahrbahnachse.zustand IS 'zustand enumeration AX_Zustand 0..1';
		CREATE TABLE ax_siedlungsflaeche (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  datumderletztenueberpruefung character(20),
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  artderbebauung integer,
		  name character varying,
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_siedlungsflaeche_gml ON ax_siedlungsflaeche USING btree (gml_id,beginnt);
		CREATE INDEX ax_siedlungsflaeche_endet ON ax_siedlungsflaeche USING btree (endet);
		PERFORM AddGeometryColumn('ax_siedlungsflaeche', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_siedlungsflaeche_wkb_geometry_idx ON ax_siedlungsflaeche USING gist (wkb_geometry);
		CREATE INDEX ax_siedlungsflaeche_istabgeleitetaus ON ax_siedlungsflaeche USING gin (istabgeleitetaus);
		CREATE INDEX ax_siedlungsflaeche_traegtbeizu ON ax_siedlungsflaeche USING gin (traegtbeizu);
		CREATE INDEX ax_siedlungsflaeche_hatdirektunten ON ax_siedlungsflaeche USING gin (hatdirektunten);
		CREATE INDEX ax_siedlungsflaeche_istteilvon ON ax_siedlungsflaeche USING gin (istteilvon);

		COMMENT ON TABLE ax_siedlungsflaeche IS 'FeatureType: "AX_Siedlungsflaeche"';
		COMMENT ON COLUMN ax_siedlungsflaeche.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_siedlungsflaeche.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_siedlungsflaeche.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_siedlungsflaeche.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.wkb_geometry IS 'wkb_geometry  GM_Surface 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.datumderletztenueberpruefung IS 'datumDerLetztenUeberpruefung  DateTime 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_siedlungsflaeche.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_siedlungsflaeche.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_siedlungsflaeche.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_siedlungsflaeche.artderbebauung IS 'artDerBebauung enumeration AX_ArtDerBebauung_Siedlungsflaeche 0..1';
		COMMENT ON COLUMN ax_siedlungsflaeche.name IS 'name   0..1';
		CREATE TABLE ax_flaechezurzeitunbestimmbar (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  datumderletztenueberpruefung character(20),
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  hatdirektunten character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ax_flaechezurzeitunbestimmbar_gml ON ax_flaechezurzeitunbestimmbar USING btree (gml_id,beginnt);
		CREATE INDEX ax_flaechezurzeitunbestimmbar_endet ON ax_flaechezurzeitunbestimmbar USING btree (endet);
		PERFORM AddGeometryColumn('ax_flaechezurzeitunbestimmbar', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_flaechezurzeitunbestimmbar_wkb_geometry_idx ON ax_flaechezurzeitunbestimmbar USING gist (wkb_geometry);
		CREATE INDEX ax_flaechezurzeitunbestimmbar_istabgeleitetaus ON ax_flaechezurzeitunbestimmbar USING gin (istabgeleitetaus);
		CREATE INDEX ax_flaechezurzeitunbestimmbar_traegtbeizu ON ax_flaechezurzeitunbestimmbar USING gin (traegtbeizu);
		CREATE INDEX ax_flaechezurzeitunbestimmbar_hatdirektunten ON ax_flaechezurzeitunbestimmbar USING gin (hatdirektunten);
		CREATE INDEX ax_flaechezurzeitunbestimmbar_istteilvon ON ax_flaechezurzeitunbestimmbar USING gin (istteilvon);

		COMMENT ON TABLE ax_flaechezurzeitunbestimmbar IS 'FeatureType: "AX_FlaecheZurZeitUnbestimmbar"';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.wkb_geometry IS 'wkb_geometry  GM_Surface 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.datumderletztenueberpruefung IS 'datumDerLetztenUeberpruefung  DateTime 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaechezurzeitunbestimmbar.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep  CharacterString 0..*';
		CREATE TABLE ta_compositesolidcomponent_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ta_compositesolidcomponent_3d_gml ON ta_compositesolidcomponent_3d USING btree (gml_id,beginnt);
		CREATE INDEX ta_compositesolidcomponent_3d_endet ON ta_compositesolidcomponent_3d USING btree (endet);
		PERFORM AddGeometryColumn('ta_compositesolidcomponent_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ta_compositesolidcomponent_3d_wkb_geometry_idx ON ta_compositesolidcomponent_3d USING gist (wkb_geometry);
		CREATE INDEX ta_compositesolidcomponent_3d_detailliert ON ta_compositesolidcomponent_3d USING btree (detailliert);
		CREATE INDEX ta_compositesolidcomponent_3d_generalisiert ON ta_compositesolidcomponent_3d USING btree (generalisiert);
		CREATE INDEX ta_compositesolidcomponent_3d_istteilvon ON ta_compositesolidcomponent_3d USING gin (istteilvon);

		COMMENT ON TABLE ta_compositesolidcomponent_3d IS 'FeatureType: "TA_CompositeSolidComponent_3D"';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN ta_compositesolidcomponent_3d.wkb_geometry IS 'wkb_geometry  GM_CompositeSolid 0..1';
		CREATE TABLE ta_surfacecomponent_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ta_surfacecomponent_3d_gml ON ta_surfacecomponent_3d USING btree (gml_id,beginnt);
		CREATE INDEX ta_surfacecomponent_3d_endet ON ta_surfacecomponent_3d USING btree (endet);
		PERFORM AddGeometryColumn('ta_surfacecomponent_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ta_surfacecomponent_3d_wkb_geometry_idx ON ta_surfacecomponent_3d USING gist (wkb_geometry);
		CREATE INDEX ta_surfacecomponent_3d_detailliert ON ta_surfacecomponent_3d USING btree (detailliert);
		CREATE INDEX ta_surfacecomponent_3d_generalisiert ON ta_surfacecomponent_3d USING btree (generalisiert);
		CREATE INDEX ta_surfacecomponent_3d_istteilvon ON ta_surfacecomponent_3d USING gin (istteilvon);

		COMMENT ON TABLE ta_surfacecomponent_3d IS 'FeatureType: "TA_SurfaceComponent_3D"';
		COMMENT ON COLUMN ta_surfacecomponent_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ta_surfacecomponent_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN ta_surfacecomponent_3d.wkb_geometry IS 'wkb_geometry  GM_Surface 0..1';
		CREATE TABLE ta_curvecomponent_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ta_curvecomponent_3d_gml ON ta_curvecomponent_3d USING btree (gml_id,beginnt);
		CREATE INDEX ta_curvecomponent_3d_endet ON ta_curvecomponent_3d USING btree (endet);
		PERFORM AddGeometryColumn('ta_curvecomponent_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ta_curvecomponent_3d_wkb_geometry_idx ON ta_curvecomponent_3d USING gist (wkb_geometry);
		CREATE INDEX ta_curvecomponent_3d_detailliert ON ta_curvecomponent_3d USING btree (detailliert);
		CREATE INDEX ta_curvecomponent_3d_generalisiert ON ta_curvecomponent_3d USING btree (generalisiert);
		CREATE INDEX ta_curvecomponent_3d_istteilvon ON ta_curvecomponent_3d USING gin (istteilvon);

		COMMENT ON TABLE ta_curvecomponent_3d IS 'FeatureType: "TA_CurveComponent_3D"';
		COMMENT ON COLUMN ta_curvecomponent_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ta_curvecomponent_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ta_curvecomponent_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ta_curvecomponent_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ta_curvecomponent_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ta_curvecomponent_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ta_curvecomponent_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ta_curvecomponent_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ta_curvecomponent_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN ta_curvecomponent_3d.wkb_geometry IS 'wkb_geometry  GM_Curve 0..1';
		CREATE TABLE ta_pointcomponent_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ta_pointcomponent_3d_gml ON ta_pointcomponent_3d USING btree (gml_id,beginnt);
		CREATE INDEX ta_pointcomponent_3d_endet ON ta_pointcomponent_3d USING btree (endet);
		PERFORM AddGeometryColumn('ta_pointcomponent_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ta_pointcomponent_3d_wkb_geometry_idx ON ta_pointcomponent_3d USING gist (wkb_geometry);
		CREATE INDEX ta_pointcomponent_3d_detailliert ON ta_pointcomponent_3d USING btree (detailliert);
		CREATE INDEX ta_pointcomponent_3d_generalisiert ON ta_pointcomponent_3d USING btree (generalisiert);
		CREATE INDEX ta_pointcomponent_3d_istteilvon ON ta_pointcomponent_3d USING gin (istteilvon);

		COMMENT ON TABLE ta_pointcomponent_3d IS 'FeatureType: "TA_PointComponent_3D"';
		COMMENT ON COLUMN ta_pointcomponent_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ta_pointcomponent_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ta_pointcomponent_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ta_pointcomponent_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ta_pointcomponent_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ta_pointcomponent_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ta_pointcomponent_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ta_pointcomponent_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ta_pointcomponent_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN ta_pointcomponent_3d.wkb_geometry IS 'wkb_geometry  GM_Point 0..1';
		CREATE TABLE au_trianguliertesoberflaechenobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_trianguliertesoberflaechenobjekt_3d_gml ON au_trianguliertesoberflaechenobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_trianguliertesoberflaechenobjekt_3d_endet ON au_trianguliertesoberflaechenobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_trianguliertesoberflaechenobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_trianguliertesoberflaechenobjekt_3d_wkb_geometry_idx ON au_trianguliertesoberflaechenobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_trianguliertesoberflaechenobjekt_3d_detailliert ON au_trianguliertesoberflaechenobjekt_3d USING btree (detailliert);
		CREATE INDEX au_trianguliertesoberflaechenobjekt_3d_generalisiert ON au_trianguliertesoberflaechenobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_trianguliertesoberflaechenobjekt_3d_istteilvon ON au_trianguliertesoberflaechenobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_trianguliertesoberflaechenobjekt_3d IS 'FeatureType: "AU_TrianguliertesOberflaechenObjekt_3D"';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_trianguliertesoberflaechenobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_TriangulatedSurface 0..1';
		CREATE TABLE au_mehrfachflaechenobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_mehrfachflaechenobjekt_3d_gml ON au_mehrfachflaechenobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_mehrfachflaechenobjekt_3d_endet ON au_mehrfachflaechenobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_mehrfachflaechenobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_mehrfachflaechenobjekt_3d_wkb_geometry_idx ON au_mehrfachflaechenobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_mehrfachflaechenobjekt_3d_detailliert ON au_mehrfachflaechenobjekt_3d USING btree (detailliert);
		CREATE INDEX au_mehrfachflaechenobjekt_3d_generalisiert ON au_mehrfachflaechenobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_mehrfachflaechenobjekt_3d_istteilvon ON au_mehrfachflaechenobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_mehrfachflaechenobjekt_3d IS 'FeatureType: "AU_MehrfachFlaechenObjekt_3D"';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_mehrfachflaechenobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE au_mehrfachlinienobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_mehrfachlinienobjekt_3d_gml ON au_mehrfachlinienobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_mehrfachlinienobjekt_3d_endet ON au_mehrfachlinienobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_mehrfachlinienobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_mehrfachlinienobjekt_3d_wkb_geometry_idx ON au_mehrfachlinienobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_mehrfachlinienobjekt_3d_detailliert ON au_mehrfachlinienobjekt_3d USING btree (detailliert);
		CREATE INDEX au_mehrfachlinienobjekt_3d_generalisiert ON au_mehrfachlinienobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_mehrfachlinienobjekt_3d_istteilvon ON au_mehrfachlinienobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_mehrfachlinienobjekt_3d IS 'FeatureType: "AU_MehrfachLinienObjekt_3D"';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_mehrfachlinienobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE au_umringobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_umringobjekt_3d_gml ON au_umringobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_umringobjekt_3d_endet ON au_umringobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_umringobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_umringobjekt_3d_wkb_geometry_idx ON au_umringobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_umringobjekt_3d_detailliert ON au_umringobjekt_3d USING btree (detailliert);
		CREATE INDEX au_umringobjekt_3d_generalisiert ON au_umringobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_umringobjekt_3d_istteilvon ON au_umringobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_umringobjekt_3d IS 'FeatureType: "AU_UmringObjekt_3D"';
		COMMENT ON COLUMN au_umringobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_umringobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_umringobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_umringobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_umringobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_umringobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_umringobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_umringobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_umringobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_umringobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_MultiCurve 0..1';
		CREATE TABLE ap_kpo_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  art character varying,
		  darstellungsprioritaet integer,
		  dateityp integer,
		  referenzzumfremdobjekt character varying,
		  signaturnummer character varying,
		  parameter double precision[],
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  dientzurdarstellungvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX ap_kpo_3d_gml ON ap_kpo_3d USING btree (gml_id,beginnt);
		CREATE INDEX ap_kpo_3d_endet ON ap_kpo_3d USING btree (endet);
		PERFORM AddGeometryColumn('ap_kpo_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ap_kpo_3d_wkb_geometry_idx ON ap_kpo_3d USING gist (wkb_geometry);
		CREATE INDEX ap_kpo_3d_dientzurdarstellungvon ON ap_kpo_3d USING gin (dientzurdarstellungvon);
		CREATE INDEX ap_kpo_3d_detailliert ON ap_kpo_3d USING btree (detailliert);
		CREATE INDEX ap_kpo_3d_generalisiert ON ap_kpo_3d USING btree (generalisiert);
		CREATE INDEX ap_kpo_3d_istteilvon ON ap_kpo_3d USING gin (istteilvon);

		COMMENT ON TABLE ap_kpo_3d IS 'FeatureType: "AP_KPO_3D"';
		COMMENT ON COLUMN ap_kpo_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ap_kpo_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ap_kpo_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ap_kpo_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ap_kpo_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ap_kpo_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ap_kpo_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN ap_kpo_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ap_kpo_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN ap_kpo_3d.wkb_geometry IS 'wkb_geometry  GM_Point 0..1';
		COMMENT ON COLUMN ap_kpo_3d.art IS 'art  CharacterString 0..1';
		COMMENT ON COLUMN ap_kpo_3d.darstellungsprioritaet IS 'darstellungsprioritaet  Integer 0..1';
		COMMENT ON COLUMN ap_kpo_3d.dateityp IS 'dateiTyp enumeration AP_DateiTyp_3D 0..1';
		COMMENT ON COLUMN ap_kpo_3d.referenzzumfremdobjekt IS 'referenzZumFremdobjekt  URI 0..1';
		COMMENT ON COLUMN ap_kpo_3d.signaturnummer IS 'signaturnummer  CharacterString 0..1';
		COMMENT ON COLUMN ap_kpo_3d.parameter IS 'transformationsMatrix|AP_TransformationsMatrix_3D|parameter  Real *';
		COMMENT ON COLUMN ap_kpo_3d.dientzurdarstellungvon IS 'Assoziation zu: FeatureType AA_Objekt (aa_objekt) 0..*';
		CREATE TABLE au_punkthaufenobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_punkthaufenobjekt_3d_gml ON au_punkthaufenobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_punkthaufenobjekt_3d_endet ON au_punkthaufenobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_punkthaufenobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_punkthaufenobjekt_3d_wkb_geometry_idx ON au_punkthaufenobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_punkthaufenobjekt_3d_detailliert ON au_punkthaufenobjekt_3d USING btree (detailliert);
		CREATE INDEX au_punkthaufenobjekt_3d_generalisiert ON au_punkthaufenobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_punkthaufenobjekt_3d_istteilvon ON au_punkthaufenobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_punkthaufenobjekt_3d IS 'FeatureType: "AU_PunkthaufenObjekt_3D"';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_punkthaufenobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_MultiPoint 0..1';
		CREATE TABLE au_koerperobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_koerperobjekt_3d_gml ON au_koerperobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_koerperobjekt_3d_endet ON au_koerperobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_koerperobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_koerperobjekt_3d_wkb_geometry_idx ON au_koerperobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_koerperobjekt_3d_detailliert ON au_koerperobjekt_3d USING btree (detailliert);
		CREATE INDEX au_koerperobjekt_3d_generalisiert ON au_koerperobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_koerperobjekt_3d_istteilvon ON au_koerperobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_koerperobjekt_3d IS 'FeatureType: "AU_KoerperObjekt_3D"';
		COMMENT ON COLUMN au_koerperobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_koerperobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_koerperobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_koerperobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_koerperobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_koerperobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_koerperobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_koerperobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_koerperobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_koerperobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_Solid 0..1';
		CREATE TABLE au_geometrieobjekt_3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  levelofdetail character varying NOT NULL,
		  detailliert character(16),
		  generalisiert character(16),
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);

		CREATE UNIQUE INDEX au_geometrieobjekt_3d_gml ON au_geometrieobjekt_3d USING btree (gml_id,beginnt);
		CREATE INDEX au_geometrieobjekt_3d_endet ON au_geometrieobjekt_3d USING btree (endet);
		PERFORM AddGeometryColumn('au_geometrieobjekt_3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX au_geometrieobjekt_3d_wkb_geometry_idx ON au_geometrieobjekt_3d USING gist (wkb_geometry);
		CREATE INDEX au_geometrieobjekt_3d_detailliert ON au_geometrieobjekt_3d USING btree (detailliert);
		CREATE INDEX au_geometrieobjekt_3d_generalisiert ON au_geometrieobjekt_3d USING btree (generalisiert);
		CREATE INDEX au_geometrieobjekt_3d_istteilvon ON au_geometrieobjekt_3d USING gin (istteilvon);

		COMMENT ON TABLE au_geometrieobjekt_3d IS 'FeatureType: "AU_GeometrieObjekt_3D"';
		COMMENT ON COLUMN au_geometrieobjekt_3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN au_geometrieobjekt_3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.levelofdetail IS 'levelOfDetail codelist AA_LevelOfDetail 1';
		COMMENT ON COLUMN au_geometrieobjekt_3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';

		PERFORM alkis_dropobject('alkis_wertearten');
		CREATE VIEW alkis_wertearten(k,v,d,bezeichnung,element) AS
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_benutzer' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_benutzer' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_benutzer' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ausgabemedium' AS bezeichnung,'ax_benutzer' AS element FROM ax_ausgabemedium_benutzer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'datenformat' AS bezeichnung,'ax_benutzer' AS element FROM ax_datenformat_benutzer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'letzteabgabeart' AS bezeichnung,'ax_benutzer' AS element FROM ax_letzteabgabeart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'zugriffsartfortfuehrungsanlass' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'zugriffsartproduktkennungbenutzung' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_anlassart_benutzungsauftrag UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'zugriffsartproduktkennungfuehrung' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_benutzergruppenba' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_benutzergruppenba' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_benutzergruppenba' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bereichzeitlich_art' AS bezeichnung,'ax_benutzergruppenba' AS element FROM ax_art_bereichzeitlich UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_darstellung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_darstellung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_darstellung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'aa_projektsteuerung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'aa_projektsteuerung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_projektsteuerung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlassdesprozesses' AS bezeichnung,'aa_projektsteuerung' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'aa_meilenstein' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'aa_meilenstein' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_meilenstein' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'kategorie' AS bezeichnung,'aa_meilenstein' AS element FROM aa_besonderemeilensteinkategorie UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'aa_antrag' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'aa_antrag' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_antrag' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'aa_aktivitaet' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'aa_aktivitaet' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_aktivitaet' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'aa_vorgang' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'aa_vorgang' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_vorgang' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_person' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_person' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_person' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'anrede' AS bezeichnung,'ax_person' AS element FROM ax_anrede_person UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_namensnummer' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_namensnummer' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_namensnummer' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderrechtsgemeinschaft' AS bezeichnung,'ax_namensnummer' AS element FROM ax_artderrechtsgemeinschaft_namensnummer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'eigentuemerart' AS bezeichnung,'ax_namensnummer' AS element FROM ax_eigentuemerart_namensnummer UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_anschrift' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_anschrift' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_anschrift' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_verwaltung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_verwaltung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_verwaltung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_buchungsstelle' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_buchungsstelle' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_buchungsstelle' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'buchungsart' AS bezeichnung,'ax_buchungsstelle' AS element FROM ax_buchungsart_buchungsstelle UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_personengruppe' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_personengruppe' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_personengruppe' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_buchungsblatt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_buchungsblatt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_buchungsblatt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'blattart' AS bezeichnung,'ax_buchungsblatt' AS element FROM ax_blattart_buchungsblatt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_vertretung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_vertretung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_vertretung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_skizze' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_skizze' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_skizze' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'skizzenart' AS bezeichnung,'ax_skizze' AS element FROM ax_skizzenart_skizze UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schwere' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schwere' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schwere' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'datenerhebung' AS bezeichnung,'ax_schwere' AS element FROM ax_datenerhebung_schwere UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'genauigkeitsstufe' AS bezeichnung,'ax_schwere' AS element FROM ax_genauigkeitsstufe_schwere UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'messmethode' AS bezeichnung,'ax_schwere' AS element FROM ax_messmethode_schwere UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_schwere' AS element FROM ax_vertrauenswuerdigkeit_schwere UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schwereanomalie_art' AS bezeichnung,'ax_schwere' AS element FROM ax_schwereanomalie_schwere_art UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schwerestatus' AS bezeichnung,'ax_schwere' AS element FROM ax_schwerestatus_schwere UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schweresystem' AS bezeichnung,'ax_schwere' AS element FROM ax_schweresystem_schwere UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_historischesflurstueckalb' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_historischesflurstueckalb' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_historischesflurstueckalb' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'blattart' AS bezeichnung,'ax_historischesflurstueckalb' AS element FROM ax_blattart_historischesflurstueck UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_historischesflurstueckohneraumbezug' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_historischesflurstueckohneraumbezug' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_historischesflurstueckohneraumbezug' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_lagebezeichnungohnehausnummer' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_lagebezeichnungohnehausnummer' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungohnehausnummer' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_lagebezeichnungmithausnummer' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_lagebezeichnungmithausnummer' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungmithausnummer' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_lagebezeichnungmitpseudonummer' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_lagebezeichnungmitpseudonummer' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungmitpseudonummer' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_reservierung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_reservierung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_reservierung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_reservierung' AS element FROM ax_art_reservierung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_punktkennunguntergegangen' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_punktkennunguntergegangen' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_punktkennunguntergegangen' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_punktkennunguntergegangen' AS element FROM ax_art_punktkennung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_punktkennungvergleichend' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_punktkennungvergleichend' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_punktkennungvergleichend' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_punktkennungvergleichend' AS element FROM ax_art_punktkennung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_fortfuehrungsnachweisdeckblatt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_fortfuehrungsnachweisdeckblatt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_fortfuehrungsnachweisdeckblatt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'auszugfuer_art' AS bezeichnung,'ax_fortfuehrungsnachweisdeckblatt' AS element FROM ax_art_adressat_auszug UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_fortfuehrungsfall' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_fortfuehrungsfall' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_fortfuehrungsfall' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'ueberschriftimfortfuehrungsnachweis' AS bezeichnung,'ax_fortfuehrungsfall' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gemeinde' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gemeinde' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gemeinde' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemeinde' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_buchungsblattbezirk' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_buchungsblattbezirk' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_buchungsblattbezirk' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_buchungsblattbezirk' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gemarkungsteilflur' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gemarkungsteilflur' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gemarkungsteilflur' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemarkungsteilflur' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_kreisregion' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_kreisregion' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kreisregion' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_kreisregion' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bundesland' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bundesland' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bundesland' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_bundesland' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_regierungsbezirk' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_regierungsbezirk' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_regierungsbezirk' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_regierungsbezirk' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gemeindeteil' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gemeindeteil' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gemeindeteil' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemeindeteil' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_lagebezeichnungkatalogeintrag' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_lagebezeichnungkatalogeintrag' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungkatalogeintrag' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_lagebezeichnungkatalogeintrag' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gemarkung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gemarkung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gemarkung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemarkung' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_dienststelle' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_dienststelle' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_dienststelle' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_dienststelle' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'stellenart' AS bezeichnung,'ax_dienststelle' AS element FROM ax_behoerde UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_verband' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_verband' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_verband' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_verband' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_verband' AS element FROM ax_art_verband UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_nationalstaat' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_nationalstaat' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_nationalstaat' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_nationalstaat' AS element FROM ax_administrative_funktion UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_besondererbauwerkspunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_besondererbauwerkspunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besondererbauwerkspunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_netzknoten' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_netzknoten' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_netzknoten' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktvermarkung' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM ax_funktion_referenzstationspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'gnsstauglichkeit' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM ax_gnsstauglichkeit UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktstabilitaet' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM ax_punktstabilitaet UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_lagefestpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_lagefestpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagefestpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktvermarkung' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_funktion_lagefestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hierarchiestufe3d' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_klassifikation_hierarchiestufe3d_lagefestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ordnung' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_klassifikation_ordnung_lagefestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'wertigkeit' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_klassifikation_wertigkeit_lagefestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'gnsstauglichkeit' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_gnsstauglichkeit UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktstabilitaet' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_punktstabilitaet UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktvermarkung' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ordnung' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_ordnung_hoehenfestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'gnsstauglichkeit' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_gnsstauglichkeit UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'geologischestabilitaet' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'grundwasserschwankung' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'grundwasserstand' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'guetedesbaugrundes' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'guetedesvermarkungstraegers' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hoehenstabilitaetauswiederholungsmessungen' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'topographieundumwelt' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermutetehoehenstabilitaet' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktvermarkung' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM ax_funktion_schwerefestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ordnung' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM ax_ordnung_schwerefestpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'gnsstauglichkeit' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM ax_gnsstauglichkeit UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktstabilitaet' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM ax_punktstabilitaet UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_grenzpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_grenzpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_grenzpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'abmarkung_marke' AS bezeichnung,'ax_grenzpunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bemerkungzurabmarkung' AS bezeichnung,'ax_grenzpunkt' AS element FROM ax_bemerkungzurabmarkung_grenzpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'gruendederausgesetztenabmarkung' AS bezeichnung,'ax_grenzpunkt' AS element FROM ax_gruendederausgesetztenabmarkung_grenzpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontfreiheit' AS bezeichnung,'ax_grenzpunkt' AS element FROM ax_horizontfreiheit_grenzpunkt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_aufnahmepunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_aufnahmepunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_aufnahmepunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontfreiheit' AS bezeichnung,'ax_aufnahmepunkt' AS element FROM ax_horizontfreiheit_netzpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermarkung_marke' AS bezeichnung,'ax_aufnahmepunkt' AS element FROM ax_marke UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sonstigervermessungspunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sonstigervermessungspunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sonstigervermessungspunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontfreiheit' AS bezeichnung,'ax_sonstigervermessungspunkt' AS element FROM ax_horizontfreiheit_netzpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermarkung_marke' AS bezeichnung,'ax_sonstigervermessungspunkt' AS element FROM ax_marke UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sicherungspunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sicherungspunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sicherungspunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontfreiheit' AS bezeichnung,'ax_sicherungspunkt' AS element FROM ax_horizontfreiheit_netzpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermarkung_marke' AS bezeichnung,'ax_sicherungspunkt' AS element FROM ax_marke UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_besonderergebaeudepunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_besonderergebaeudepunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besonderergebaeudepunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_besonderergebaeudepunkt' AS element FROM ax_art_gebaeudepunkt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wirtschaftlicheeinheit' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wirtschaftlicheeinheit' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wirtschaftlicheeinheit' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_verwaltungsgemeinschaft' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_verwaltungsgemeinschaft' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_verwaltungsgemeinschaft' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_verwaltungsgemeinschaft' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bezeichnungart' AS bezeichnung,'ax_verwaltungsgemeinschaft' AS element FROM ax_bezeichnung_verwaltungsgemeinschaft UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schutzgebietnachnaturumweltoderbodenschutzrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schutzgebietnachnaturumweltoderbodenschutzrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schutzgebietnachnaturumweltoderbodenschutzrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_schutzgebietnachnaturumweltoderbodenschutzrecht' AS element FROM ax_artderfestlegung_schutzgebietnachnaturumweltoderbodensc UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schutzgebietnachwasserrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schutzgebietnachwasserrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schutzgebietnachwasserrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_schutzgebietnachwasserrecht' AS element FROM ax_artderfestlegung_schutzgebietnachwasserrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_schutzgebietnachwasserrecht' AS element FROM ax_funktion_schutzgebietnachwasserrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_boeschungkliff' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_boeschungkliff' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_boeschungkliff' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_boeschungkliff' AS element FROM ax_zustand_boeschungkliff UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_besonderertopographischerpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_besonderertopographischerpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besonderertopographischerpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_kanal' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_kanal' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kanal' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schifffahrtskategorie' AS bezeichnung,'ax_kanal' AS element FROM ax_schifffahrtskategorie_kanal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_kanal' AS element FROM ax_widmung_kanal UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wasserlauf' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wasserlauf' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wasserlauf' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schifffahrtskategorie' AS bezeichnung,'ax_wasserlauf' AS element FROM ax_schifffahrtskategorie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_wasserlauf' AS element FROM ax_widmung_wasserlauf UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_strasse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_strasse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_strasse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'fahrbahntrennung' AS bezeichnung,'ax_strasse' AS element FROM ax_fahrbahntrennung_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'internationalebedeutung' AS bezeichnung,'ax_strasse' AS element FROM ax_internationalebedeutung_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_strasse' AS element FROM ax_widmung_strasse UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_fpo' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_fpo' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_fpo' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'aa_antragsgebiet' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'aa_antragsgebiet' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_antragsgebiet' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_polder' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_polder' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_polder' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdespolders' AS bezeichnung,'ax_polder' AS element FROM ax_artdespolders UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_polder' AS element FROM ax_funktion_polder UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_historischesflurstueck' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_historischesflurstueck' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_historischesflurstueck' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'blattart' AS bezeichnung,'ax_historischesflurstueck' AS element FROM ax_blattart_historischesflurstueck UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_kondominium' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_kondominium' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kondominium' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_baublock' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_baublock' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_baublock' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_baublock' AS element FROM ax_art_baublock UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_aussparungsflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_aussparungsflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_aussparungsflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderaussparung' AS bezeichnung,'ax_aussparungsflaeche' AS element FROM ax_artderaussparung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_soll' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_soll' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_soll' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_duene' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_duene' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_duene' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_transportanlage' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_transportanlage' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_transportanlage' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_transportanlage' AS element FROM ax_bauwerksfunktion_transportanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezurerdoberflaeche' AS bezeichnung,'ax_transportanlage' AS element FROM ax_lagezurerdoberflaeche_transportanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'produkt' AS bezeichnung,'ax_transportanlage' AS element FROM ax_produkt_transportanlage UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wegpfadsteig' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wegpfadsteig' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wegpfadsteig' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_wegpfadsteig' AS element FROM ax_art_wegpfadsteig UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'befestigung' AS bezeichnung,'ax_wegpfadsteig' AS element FROM ax_befestigung_wegpfadsteig UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'markierung' AS bezeichnung,'ax_wegpfadsteig' AS element FROM ax_markierung_wegpfadsteig UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gleis' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gleis' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gleis' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_gleis' AS element FROM ax_art_gleis UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bahnkategorie' AS bezeichnung,'ax_gleis' AS element FROM ax_bahnkategorie_gleis UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezuroberflaeche' AS bezeichnung,'ax_gleis' AS element FROM ax_lagezuroberflaeche_gleis UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bahnhofskategorie' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM ax_bahnhofskategorie_bahnverkehrsanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bahnkategorie' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM ax_bahnkategorie_gleis UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM ax_zustand_bahnverkehrsanlage UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_strassenverkehrsanlage' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_strassenverkehrsanlage' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_strassenverkehrsanlage' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_strassenverkehrsanlage' AS element FROM ax_art_strassenverkehrsanlage UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_einrichtungenfuerdenschiffsverkehr' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_einrichtungenfuerdenschiffsverkehr' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_einrichtungenfuerdenschiffsverkehr' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_einrichtungenfuerdenschiffsverkehr' AS element FROM ax_art_einrichtungenfuerdenschiffsverkehr UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_flugverkehrsanlage' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_flugverkehrsanlage' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flugverkehrsanlage' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_flugverkehrsanlage' AS element FROM ax_art_flugverkehrsanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'oberflaechenmaterial' AS bezeichnung,'ax_flugverkehrsanlage' AS element FROM ax_oberflaechenmaterial_flugverkehrsanlage UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_hafen' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_hafen' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_hafen' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hafenkategorie' AS bezeichnung,'ax_hafen' AS element FROM ax_hafenkategorie_hafen UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'nutzung' AS bezeichnung,'ax_hafen' AS element FROM ax_nutzung_hafen UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_testgelaende' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_testgelaende' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_testgelaende' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schleuse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schleuse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schleuse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'konstruktionsmerkmalbauart' AS bezeichnung,'ax_schleuse' AS element FROM ax_konstruktionsmerkmalbauart_schleuse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_schleuse' AS element FROM ax_zustand_schleuse UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_ortslage' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_ortslage' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_ortslage' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_grenzuebergang' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_grenzuebergang' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_grenzuebergang' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gewaessermerkmal' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gewaessermerkmal' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gewaessermerkmal' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_gewaessermerkmal' AS element FROM ax_art_gewaessermerkmal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_gewaessermerkmal' AS element FROM ax_hydrologischesmerkmal_gewaessermerkmal UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM ax_funktion_untergeordnetesgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM ax_hydrologischesmerkmal_untergeordnetesgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezurerdoberflaeche' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM ax_lagezurerdoberflaeche_untergeordnetesgewaesser UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bewuchs' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM ax_bewuchs_vegetationsmerkmal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM ax_funktion_vegetationsmerkmal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM ax_zustand_vegetationsmerkmal UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bodenart' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM ax_bodenart_musterlandesmusterundvergleichsstueck UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'entstehungsartoderklimastufewasserverhaeltnisse' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM ax_entstehungsartoderklimastufewasserverhaeltnisse_musterl UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'kulturart' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM ax_kulturart_musterlandesmusterundvergleichsstueck UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'merkmal' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM ax_merkmal_musterlandesmusterundvergleichsstueck UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'sonstigeangaben' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM ax_sonstigeangaben_musterlandesmusterundvergleichsstueck UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustandsstufeoderbodenstufe' AS bezeichnung,'ax_musterlandesmusterundvergleichsstueck' AS element FROM ax_zustandsstufeoderbodenstufe_musterlandesmusterundvergle UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_insel' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_insel' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_insel' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gewann' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gewann' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gewann' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_kleinraeumigerlandschaftsteil' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_kleinraeumigerlandschaftsteil' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kleinraeumigerlandschaftsteil' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'landschaftstyp' AS bezeichnung,'ax_kleinraeumigerlandschaftsteil' AS element FROM ax_landschaftstyp UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_landschaft' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_landschaft' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_landschaft' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'landschaftstyp' AS bezeichnung,'ax_landschaft' AS element FROM ax_landschaftstyp UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_felsenfelsblockfelsnadel' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_felsenfelsblockfelsnadel' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_felsenfelsblockfelsnadel' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_lto' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_lto' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_lto' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontaleausrichtung' AS bezeichnung,'ap_lto' AS element FROM ap_horizontaleausrichtung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertikaleausrichtung' AS bezeichnung,'ap_lto' AS element FROM ap_vertikaleausrichtung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_leitung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_leitung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_leitung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_leitung' AS element FROM ax_bauwerksfunktion_leitung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_abschnitt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_abschnitt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_abschnitt' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_ast' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_ast' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_ast' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_lpo' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_lpo' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_lpo' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_seilbahnschwebebahn' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_seilbahnschwebebahn' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_seilbahnschwebebahn' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bahnkategorie' AS bezeichnung,'ax_seilbahnschwebebahn' AS element FROM ax_bahnkategorie_seilbahnschwebebahn UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebaeudeausgestaltung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebaeudeausgestaltung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebaeudeausgestaltung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'darstellung' AS bezeichnung,'ax_gebaeudeausgestaltung' AS element FROM ax_darstellung_gebaeudeausgestaltung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_topographischelinie' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_topographischelinie' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_topographischelinie' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'liniendarstellung' AS bezeichnung,'ax_topographischelinie' AS element FROM ax_liniendarstellung_topographischelinie UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_geripplinie' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_geripplinie' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_geripplinie' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdergeripplinie' AS bezeichnung,'ax_geripplinie' AS element FROM ax_artdergeripplinie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ax_dqerfassungsmethode' AS bezeichnung,'ax_geripplinie' AS element FROM ax_dqerfassungsmethode UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'identifikation' AS bezeichnung,'ax_geripplinie' AS element FROM ax_identifikation UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'besondereartdergewaesserbegrenzung' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM ax_besondereartdergewaesserbegrenzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ax_dqerfassungsmethodegewaesserbegrenzung' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM ax_dqerfassungsmethodegewaesserbegrenzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'identifikation' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM ax_identifikation UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ursprung' AS bezeichnung,'ax_gewaesserbegrenzung' AS element FROM ax_ursprung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_strukturierterfasstegelaendepunkte' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_strukturierterfasstegelaendepunkte' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_strukturierterfasstegelaendepunkte' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderstrukturierung' AS bezeichnung,'ax_strukturierterfasstegelaendepunkte' AS element FROM ax_artderstrukturierung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ax_dqerfassungsmethodestrukturiertegelaendepunkte' AS bezeichnung,'ax_strukturierterfasstegelaendepunkte' AS element FROM ax_dqerfassungsmethodestrukturiertegelaendepunkte UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_einschnitt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_einschnitt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_einschnitt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_einschnitt' AS element FROM ax_funktion_einschnitt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_hoehenlinie' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_hoehenlinie' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_hoehenlinie' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_abgeleitetehoehenlinie' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_abgeleitetehoehenlinie' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_abgeleitetehoehenlinie' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'berechnungsmethodehoehenlinie' AS bezeichnung,'ax_abgeleitetehoehenlinie' AS element FROM ax_berechnungsmethodehoehenlinie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'verwendeteobjekte' AS bezeichnung,'ax_abgeleitetehoehenlinie' AS element FROM ax_verwendeteobjekte UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_pto' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_pto' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_pto' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontaleausrichtung' AS bezeichnung,'ap_pto' AS element FROM ap_horizontaleausrichtung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertikaleausrichtung' AS bezeichnung,'ap_pto' AS element FROM ap_vertikaleausrichtung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_heilquellegasquelle' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_heilquellegasquelle' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_heilquellegasquelle' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_heilquellegasquelle' AS element FROM ax_art_heilquellegasquelle UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_heilquellegasquelle' AS element FROM ax_hydrologischesmerkmal_heilquellegasquelle UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wasserspiegelhoehe' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wasserspiegelhoehe' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wasserspiegelhoehe' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_nullpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_nullpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_nullpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdesnullpunktes' AS bezeichnung,'ax_nullpunkt' AS element FROM ax_artdesnullpunktes_nullpunkt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_punktortau' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_punktortau' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_punktortau' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'koordinatenstatus' AS bezeichnung,'ax_punktortau' AS element FROM ax_koordinatenstatus_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'genauigkeitsstufe' AS bezeichnung,'ax_punktortau' AS element FROM ax_genauigkeitsstufe_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_punktortau' AS element FROM ax_vertrauenswuerdigkeit_punktort UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_georeferenziertegebaeudeadresse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_georeferenziertegebaeudeadresse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_georeferenziertegebaeudeadresse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'qualitaetsangaben' AS bezeichnung,'ax_georeferenziertegebaeudeadresse' AS element FROM ax_qualitaet_hauskoordinate UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_grablochderbodenschaetzung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_grablochderbodenschaetzung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_grablochderbodenschaetzung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bedeutung' AS bezeichnung,'ax_grablochderbodenschaetzung' AS element FROM ax_bedeutung_grablochderbodenschaetzung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wohnplatz' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wohnplatz' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wohnplatz' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_markantergelaendepunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_markantergelaendepunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_markantergelaendepunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdesmarkantenpunktes' AS bezeichnung,'ax_markantergelaendepunkt' AS element FROM ax_artdesmarkantengelaendepunktes UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ax_dqerfassungsmethodemarkantergelaendepunkt' AS bezeichnung,'ax_markantergelaendepunkt' AS element FROM ax_dqerfassungsmethodemarkantergelaendepunkt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_besondererhoehenpunkt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_besondererhoehenpunkt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besondererhoehenpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'besonderebedeutung' AS bezeichnung,'ax_besondererhoehenpunkt' AS element FROM ax_besonderebedeutung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ax_dqerfassungsmethodebesondererhoehenpunkt' AS bezeichnung,'ax_besondererhoehenpunkt' AS element FROM ax_dqerfassungsmethodebesondererhoehenpunkt UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_hoehleneingang' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_hoehleneingang' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_hoehleneingang' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_hoehleneingang' AS element FROM ax_zustand_hoehleneingang UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_ppo' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_ppo' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_ppo' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sickerstrecke' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sickerstrecke' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sickerstrecke' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_firstlinie' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_firstlinie' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_firstlinie' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_besonderegebaeudelinie' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_besonderegebaeudelinie' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besonderegebaeudelinie' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'beschaffenheit' AS bezeichnung,'ax_besonderegebaeudelinie' AS element FROM ax_beschaffenheit_besonderegebaeudelinie UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gelaendekante' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gelaendekante' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gelaendekante' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdergelaendekante' AS bezeichnung,'ax_gelaendekante' AS element FROM ax_artdergelaendekante UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'erfassung_ax_dqerfassungsmethode' AS bezeichnung,'ax_gelaendekante' AS element FROM ax_dqerfassungsmethode UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'erfassung_identifikation' AS bezeichnung,'ax_gelaendekante' AS element FROM ax_identifikation UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ursprung' AS bezeichnung,'ax_gelaendekante' AS element FROM ax_ursprung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM ax_funktion_bauwerk UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM ax_hydrologischesmerkmal_sonstigesbauwerkodersonstigeeinri UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bauwerkoderanlagefuersportfreizeitunderholung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bauwerkoderanlagefuersportfreizeitunderholung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauwerkoderanlagefuersportfreizeitunderholung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_bauwerkoderanlagefuersportfreizeitunderholung' AS element FROM ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'sportart' AS bezeichnung,'ax_bauwerkoderanlagefuersportfreizeitunderholung' AS element FROM ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bauwerkoderanlagefuerindustrieundgewerbe' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bauwerkoderanlagefuerindustrieundgewerbe' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauwerkoderanlagefuerindustrieundgewerbe' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_bauwerkoderanlagefuerindustrieundgewerbe' AS element FROM ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkoderanlagefuerindustrieundgewerbe' AS element FROM ax_zustand_bauwerkoderanlagefuerindustrieundgewerbe UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_einrichtunginoeffentlichenbereichen' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_einrichtunginoeffentlichenbereichen' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_einrichtunginoeffentlichenbereichen' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_einrichtunginoeffentlichenbereichen' AS element FROM ax_art_einrichtunginoeffentlichenbereichen UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_historischesbauwerkoderhistorischeeinrichtung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_historischesbauwerkoderhistorischeeinrichtung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_historischesbauwerkoderhistorischeeinrichtung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'archaeologischertyp' AS bezeichnung,'ax_historischesbauwerkoderhistorischeeinrichtung' AS element FROM ax_archaeologischertyp_historischesbauwerkoderhistorischee UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_turm' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_turm' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_turm' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_turm' AS element FROM ax_bauwerksfunktion_turm UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_turm' AS element FROM ax_zustand_turm UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM ax_bauwerksfunktion_vorratsbehaelterspeicherbauwerk UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezurerdoberflaeche' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM ax_lagezurerdoberflaeche_vorratsbehaelterspeicherbauwerk UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'speicherinhalt' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM ax_speicherinhalt_vorratsbehaelterspeicherbauwerk UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bauwerkimgewaesserbereich' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bauwerkimgewaesserbereich' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauwerkimgewaesserbereich' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_bauwerkimgewaesserbereich' AS element FROM ax_bauwerksfunktion_bauwerkimgewaesserbereich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkimgewaesserbereich' AS element FROM ax_zustand_bauwerkimgewaesserbereich UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bauwerkimverkehrsbereich' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bauwerkimverkehrsbereich' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauwerkimverkehrsbereich' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauwerksfunktion' AS bezeichnung,'ax_bauwerkimverkehrsbereich' AS element FROM ax_bauwerksfunktion_bauwerkimverkehrsbereich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkimverkehrsbereich' AS element FROM ax_zustand_bauwerkimverkehrsbereich UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schifffahrtsliniefaehrverkehr' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schifffahrtsliniefaehrverkehr' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schifffahrtsliniefaehrverkehr' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_schifffahrtsliniefaehrverkehr' AS element FROM ax_art_schifffahrtsliniefaehrverkehr UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebaeude' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebaeude' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebaeude' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauweise' AS bezeichnung,'ax_gebaeude' AS element FROM ax_bauweise_gebaeude UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'dachform' AS bezeichnung,'ax_gebaeude' AS element FROM ax_dachform UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'dachgeschossausbau' AS bezeichnung,'ax_gebaeude' AS element FROM ax_dachgeschossausbau_gebaeude UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'gebaeudefunktion' AS bezeichnung,'ax_gebaeude' AS element FROM ax_gebaeudefunktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezurerdoberflaeche' AS bezeichnung,'ax_gebaeude' AS element FROM ax_lagezurerdoberflaeche_gebaeude UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'nutzung' AS bezeichnung,'ax_gebaeude' AS element FROM ax_nutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'weiteregebaeudefunktion' AS bezeichnung,'ax_gebaeude' AS element FROM ax_weitere_gebaeudefunktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_gebaeude' AS element FROM ax_zustand_gebaeude UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_anderefestlegungnachstrassenrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_anderefestlegungnachstrassenrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_anderefestlegungnachstrassenrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_anderefestlegungnachstrassenrecht' AS element FROM ax_artderfestlegung_anderefestlegungnachstrassenrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_naturumweltoderbodenschutzrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_naturumweltoderbodenschutzrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_naturumweltoderbodenschutzrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_naturumweltoderbodenschutzrecht' AS element FROM ax_artderfestlegung_naturumweltoderbodenschutzrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_naturumweltoderbodenschutzrecht' AS element FROM ax_zustand_naturumweltoderbodenschutzrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_klassifizierungnachstrassenrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_klassifizierungnachstrassenrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_klassifizierungnachstrassenrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_klassifizierungnachstrassenrecht' AS element FROM ax_artderfestlegung_klassifizierungnachstrassenrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sonstigesrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sonstigesrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sonstigesrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_sonstigesrecht' AS element FROM ax_artderfestlegung_sonstigesrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_denkmalschutzrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_denkmalschutzrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_denkmalschutzrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_denkmalschutzrecht' AS element FROM ax_artderfestlegung_denkmalschutzrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_dammwalldeich' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_dammwalldeich' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_dammwalldeich' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_dammwalldeich' AS element FROM ax_art_dammwalldeich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_dammwalldeich' AS element FROM ax_funktion_dammwalldeich UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_punktortag' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_punktortag' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_punktortag' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'koordinatenstatus' AS bezeichnung,'ax_punktortag' AS element FROM ax_koordinatenstatus_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'genauigkeitsstufe' AS bezeichnung,'ax_punktortag' AS element FROM ax_genauigkeitsstufe_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_punktortag' AS element FROM ax_vertrauenswuerdigkeit_punktort UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bauteil' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bauteil' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauteil' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bauart' AS bezeichnung,'ax_bauteil' AS element FROM ax_bauart_bauteil UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'dachform' AS bezeichnung,'ax_bauteil' AS element FROM ax_dachform UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezurerdoberflaeche' AS bezeichnung,'ax_bauteil' AS element FROM ax_lagezurerdoberflaeche_bauteil UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_tagesabschnitt' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_tagesabschnitt' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_tagesabschnitt' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bewertung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bewertung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bewertung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'klassifizierung' AS bezeichnung,'ax_bewertung' AS element FROM ax_klassifizierung_bewertung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_anderefestlegungnachwasserrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_anderefestlegungnachwasserrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_anderefestlegungnachwasserrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_anderefestlegungnachwasserrecht' AS element FROM ax_artderfestlegung_anderefestlegungnachwasserrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_klassifizierungnachwasserrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_klassifizierungnachwasserrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_klassifizierungnachwasserrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_klassifizierungnachwasserrecht' AS element FROM ax_artderfestlegung_klassifizierungnachwasserrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_forstrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_forstrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_forstrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_forstrecht' AS element FROM ax_artderfestlegung_forstrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'besonderefunktion' AS bezeichnung,'ax_forstrecht' AS element FROM ax_besonderefunktion_forstrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bauraumoderbodenordnungsrecht' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bauraumoderbodenordnungsrecht' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauraumoderbodenordnungsrecht' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_bauraumoderbodenordnungsrecht' AS element FROM ax_artderfestlegung_bauraumoderbodenordnungsrecht UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schutzzone' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schutzzone' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schutzzone' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'rechtszustand' AS bezeichnung,'ax_schutzzone' AS element FROM ax_rechtszustand_schutzzone UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zone' AS bezeichnung,'ax_schutzzone' AS element FROM ax_zone_schutzzone UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_boeschungsflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_boeschungsflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_boeschungsflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_flurstueck' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_flurstueck' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flurstueck' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebiet_kreis' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebiet_kreis' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_kreis' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebiet_bundesland' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebiet_bundesland' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_bundesland' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebiet_regierungsbezirk' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebiet_regierungsbezirk' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_regierungsbezirk' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebiet_nationalstaat' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebiet_nationalstaat' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_nationalstaat' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_kommunalesgebiet' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_kommunalesgebiet' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kommunalesgebiet' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebiet_verwaltungsgemeinschaft' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebiet_verwaltungsgemeinschaft' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_verwaltungsgemeinschaft' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderverbandsgemeinde' AS bezeichnung,'ax_gebiet_verwaltungsgemeinschaft' AS element FROM ax_art_verbandsgemeinde UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bodenschaetzung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bodenschaetzung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bodenschaetzung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bodenart' AS bezeichnung,'ax_bodenschaetzung' AS element FROM ax_bodenart_bodenschaetzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'entstehungsartoderklimastufewasserverhaeltnisse' AS bezeichnung,'ax_bodenschaetzung' AS element FROM ax_entstehungsartoderklimastufewasserverhaeltnisse_bodensc UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'kulturart' AS bezeichnung,'ax_bodenschaetzung' AS element FROM ax_kulturart_bodenschaetzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'sonstigeangaben' AS bezeichnung,'ax_bodenschaetzung' AS element FROM ax_sonstigeangaben_bodenschaetzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustandsstufeoderbodenstufe' AS bezeichnung,'ax_bodenschaetzung' AS element FROM ax_zustandsstufeoderbodenstufe_bodenschaetzung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gewaesserstationierungsachse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gewaesserstationierungsachse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gewaesserstationierungsachse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdergewaesserachse' AS bezeichnung,'ax_gewaesserstationierungsachse' AS element FROM ax_artdergewaesserachse UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_besondereflurstuecksgrenze' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_besondereflurstuecksgrenze' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besondereflurstuecksgrenze' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderflurstuecksgrenze' AS bezeichnung,'ax_besondereflurstuecksgrenze' AS element FROM ax_artderflurstuecksgrenze_besondereflurstuecksgrenze UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gebietsgrenze' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gebietsgrenze' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebietsgrenze' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artdergebietsgrenze' AS bezeichnung,'ax_gebietsgrenze' AS element FROM ax_artdergebietsgrenze_gebietsgrenze UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gewaesserachse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gewaesserachse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gewaesserachse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_gewaesserachse' AS element FROM ax_funktion_gewaesserachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_gewaesserachse' AS element FROM ax_hydrologischesmerkmal_gewaesserachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_gewaesserachse' AS element FROM ax_zustand_kanal UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_strassenachse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_strassenachse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_strassenachse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'besonderefahrstreifen' AS bezeichnung,'ax_strassenachse' AS element FROM ax_besonderefahrstreifen UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_strassenachse' AS element FROM ax_funktion_strassenachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'oberflaechenmaterial' AS bezeichnung,'ax_strassenachse' AS element FROM ax_oberflaechenmaterial_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'verkehrsbedeutunginneroertlich' AS bezeichnung,'ax_strassenachse' AS element FROM ax_verkehrsbedeutunginneroertlich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'verkehrsbedeutungueberoertlich' AS bezeichnung,'ax_strassenachse' AS element FROM ax_verkehrsbedeutungueberoertlich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_strassenachse' AS element FROM ax_zustand UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bahnstrecke' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bahnstrecke' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bahnstrecke' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'anzahlderstreckengleise' AS bezeichnung,'ax_bahnstrecke' AS element FROM ax_anzahlderstreckengleise UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bahnkategorie' AS bezeichnung,'ax_bahnstrecke' AS element FROM ax_bahnkategorie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'elektrifizierung' AS bezeichnung,'ax_bahnstrecke' AS element FROM ax_elektrifizierung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'spurweite' AS bezeichnung,'ax_bahnstrecke' AS element FROM ax_spurweite UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bahnstrecke' AS element FROM ax_zustand UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_fahrwegachse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_fahrwegachse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_fahrwegachse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'befestigung' AS bezeichnung,'ax_fahrwegachse' AS element FROM ax_befestigung_fahrwegachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_fahrwegachse' AS element FROM ax_funktion_wegachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'markierung' AS bezeichnung,'ax_fahrwegachse' AS element FROM ax_markierung_wegachse UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_fahrbahnachse' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_fahrbahnachse' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_fahrbahnachse' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'besonderefahrstreifen' AS bezeichnung,'ax_fahrbahnachse' AS element FROM ax_besonderefahrstreifen UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_fahrbahnachse' AS element FROM ax_funktion_fahrbahnachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'oberflaechenmaterial' AS bezeichnung,'ax_fahrbahnachse' AS element FROM ax_oberflaechenmaterial_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_fahrbahnachse' AS element FROM ax_zustand UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_punktortta' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_punktortta' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_punktortta' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'koordinatenstatus' AS bezeichnung,'ax_punktortta' AS element FROM ax_koordinatenstatus_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'genauigkeitsstufe' AS bezeichnung,'ax_punktortta' AS element FROM ax_genauigkeitsstufe_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_punktortta' AS element FROM ax_vertrauenswuerdigkeit_punktort UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM ax_funktion_stehendesgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM ax_hydrologischesmerkmal_stehendesgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schifffahrtskategorie' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM ax_schifffahrtskategorie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM ax_widmung_stehendesgewaesser UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_meer' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_meer' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_meer' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_meer' AS element FROM ax_funktion_meer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'tidemerkmal' AS bezeichnung,'ax_meer' AS element FROM ax_tidemerkmal_meer UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_fliessgewaesser' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_fliessgewaesser' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_fliessgewaesser' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_fliessgewaesser' AS element FROM ax_funktion_fliessgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_fliessgewaesser' AS element FROM ax_hydrologischesmerkmal_fliessgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_fliessgewaesser' AS element FROM ax_zustand_kanal UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_hafenbecken' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_hafenbecken' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_hafenbecken' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_hafenbecken' AS element FROM ax_funktion_hafenbecken UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'nutzung' AS bezeichnung,'ax_hafenbecken' AS element FROM ax_nutzung_hafenbecken UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bergbaubetrieb' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bergbaubetrieb' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bergbaubetrieb' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'abbaugut' AS bezeichnung,'ax_bergbaubetrieb' AS element FROM ax_abbaugut_bergbaubetrieb UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bergbaubetrieb' AS element FROM ax_zustand_bergbaubetrieb UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_friedhof' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_friedhof' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_friedhof' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_friedhof' AS element FROM ax_funktion_friedhof UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_friedhof' AS element FROM ax_zustand_friedhof UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderbebauung' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM ax_artderbebauung_flaechegemischternutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM ax_funktion_flaechegemischternutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM ax_zustand_flaechegemischternutzung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wohnbauflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wohnbauflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wohnbauflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderbebauung' AS bezeichnung,'ax_wohnbauflaeche' AS element FROM ax_artderbebauung_wohnbauflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_wohnbauflaeche' AS element FROM ax_zustand_wohnbauflaeche UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderbebauung' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM ax_artderbebauung_flaechebesondererfunktionalerpraegung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM ax_funktion_flaechebesondererfunktionalerpraegung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM ax_zustand_flaechebesondererfunktionalerpraegung UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'foerdergut' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM ax_foerdergut_industrieundgewerbeflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM ax_funktion_industrieundgewerbeflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagergut' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM ax_lagergut_industrieundgewerbeflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'primaerenergie' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM ax_primaerenergie_industrieundgewerbeflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM ax_zustand_industrieundgewerbeflaeche UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_siedlungsflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_siedlungsflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_siedlungsflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderbebauung' AS bezeichnung,'ax_siedlungsflaeche' AS element FROM ax_artderbebauung_siedlungsflaeche UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_tagebaugrubesteinbruch' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_tagebaugrubesteinbruch' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_tagebaugrubesteinbruch' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'abbaugut' AS bezeichnung,'ax_tagebaugrubesteinbruch' AS element FROM ax_abbaugut_tagebaugrubesteinbruch UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_tagebaugrubesteinbruch' AS element FROM ax_zustand_tagebaugrubesteinbruch UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sportfreizeitunderholungsflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sportfreizeitunderholungsflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sportfreizeitunderholungsflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_sportfreizeitunderholungsflaeche' AS element FROM ax_funktion_sportfreizeitunderholungsflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_sportfreizeitunderholungsflaeche' AS element FROM ax_zustand_sportfreizeitunderholungsflaeche UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_halde' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_halde' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_halde' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagergut' AS bezeichnung,'ax_halde' AS element FROM ax_lagergut_halde UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_halde' AS element FROM ax_zustand_halde UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_flaechezurzeitunbestimmbar' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_flaechezurzeitunbestimmbar' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flaechezurzeitunbestimmbar' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_sumpf' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_sumpf' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_sumpf' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_unlandvegetationsloseflaeche' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_unlandvegetationsloseflaeche' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_unlandvegetationsloseflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_unlandvegetationsloseflaeche' AS element FROM ax_funktion_unlandvegetationsloseflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'oberflaechenmaterial' AS bezeichnung,'ax_unlandvegetationsloseflaeche' AS element FROM ax_oberflaechenmaterial_unlandvegetationsloseflaeche UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_gehoelz' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_gehoelz' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gehoelz' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_gehoelz' AS element FROM ax_funktion_gehoelz UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vegetationsmerkmal' AS bezeichnung,'ax_gehoelz' AS element FROM ax_vegetationsmerkmal_gehoelz UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_wald' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_wald' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wald' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vegetationsmerkmal' AS bezeichnung,'ax_wald' AS element FROM ax_vegetationsmerkmal_wald UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_heide' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_heide' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_heide' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_moor' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_moor' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_moor' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_landwirtschaft' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_landwirtschaft' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_landwirtschaft' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vegetationsmerkmal' AS bezeichnung,'ax_landwirtschaft' AS element FROM ax_vegetationsmerkmal_landwirtschaft UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_bahnverkehr' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_bahnverkehr' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bahnverkehr' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bahnkategorie' AS bezeichnung,'ax_bahnverkehr' AS element FROM ax_bahnkategorie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_bahnverkehr' AS element FROM ax_funktion_bahnverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bahnverkehr' AS element FROM ax_zustand_bahnverkehr UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_weg' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_weg' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_weg' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_weg' AS element FROM ax_funktion_weg UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_schiffsverkehr' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_schiffsverkehr' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_schiffsverkehr' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_schiffsverkehr' AS element FROM ax_funktion_schiffsverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_schiffsverkehr' AS element FROM ax_zustand_schiffsverkehr UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_flugverkehr' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_flugverkehr' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flugverkehr' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_flugverkehr' AS element FROM ax_art_flugverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_flugverkehr' AS element FROM ax_funktion_flugverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'nutzung' AS bezeichnung,'ax_flugverkehr' AS element FROM ax_nutzung_flugverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flugverkehr' AS element FROM ax_zustand_flugverkehr UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_platz' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_platz' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_platz' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_platz' AS element FROM ax_funktion_platz UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ax_strassenverkehr' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ax_strassenverkehr' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_strassenverkehr' AS element FROM aa_weiteremodellart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_strassenverkehr' AS element FROM ax_funktion_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_strassenverkehr' AS element FROM ax_zustand_strasse UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ta_compositesolidcomponent_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ta_compositesolidcomponent_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ta_compositesolidcomponent_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'ta_compositesolidcomponent_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ta_surfacecomponent_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ta_surfacecomponent_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ta_surfacecomponent_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'ta_surfacecomponent_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ta_curvecomponent_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ta_curvecomponent_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ta_curvecomponent_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'ta_curvecomponent_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ta_pointcomponent_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ta_pointcomponent_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ta_pointcomponent_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'ta_pointcomponent_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_trianguliertesoberflaechenobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_trianguliertesoberflaechenobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_trianguliertesoberflaechenobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_trianguliertesoberflaechenobjekt_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_mehrfachflaechenobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_mehrfachflaechenobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_mehrfachflaechenobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_mehrfachflaechenobjekt_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_mehrfachlinienobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_mehrfachlinienobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_mehrfachlinienobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_mehrfachlinienobjekt_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_umringobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_umringobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_umringobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_umringobjekt_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'ap_kpo_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'ap_kpo_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_kpo_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'ap_kpo_3d' AS element FROM aa_levelofdetail UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'dateityp' AS bezeichnung,'ap_kpo_3d' AS element FROM ap_dateityp_3d UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_punkthaufenobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_punkthaufenobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_punkthaufenobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_punkthaufenobjekt_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_koerperobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_koerperobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_koerperobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_koerperobjekt_3d' AS element FROM aa_levelofdetail UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlass' AS bezeichnung,'au_geometrieobjekt_3d' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'advstandardmodell' AS bezeichnung,'au_geometrieobjekt_3d' AS element FROM aa_advstandardmodell UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_geometrieobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'levelofdetail' AS bezeichnung,'au_geometrieobjekt_3d' AS element FROM aa_levelofdetail;

		PERFORM
			DropGeometryColumn(f_table_schema::varchar, f_table_name::varchar, f_geometry_column::varchar)
		FROM geometry_columns
		WHERE f_table_schema=current_schema()
		  AND f_geometry_column='dummy'
		  AND ( substr(f_table_name,1,3) IN ('ax_','ap_','ks_','aa_','au_','ta_')
		        OR f_table_name IN ('alkis_beziehungen','delete','alkis_version','nas_filter_capabilities','operation') );

		CREATE TABLE ax_fortfuehrungsauftrag (
			direkt boolean,
			ausgabeform character varying,
			crs character varying,
			anzahlDerNachkommastellen integer,
			standard boolean,
			profilkennung character varying,
			antragsnummer integer,
			auftragsnummer integer,
			impliziteloeschungderreservierung integer,
			verarbeitungsart integer,
			geometriebehandlung boolean,
			mittemporaeremarbeitsbereich boolean,
			mitobjektenimfortfuehrungsgebiet boolean,
			mitfortfuehrungsnachweis boolean,
			id serial NOT NULL,
			jahr integer NOT NULL DEFAULT date_part('year'::text, now()),
			gemkgnr integer NOT NULL,
			lfdnr integer NOT NULL,
			bemerkung text,
			auftragsdatei character varying,
			created_at timestamp without time zone NOT NULL DEFAULT now(),
			updated_at timestamp without time zone NOT NULL DEFAULT now(),
			user_name character varying NOT NULL
		);
	END IF;

	IF ver<16 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 16';

		COMMENT ON TABLE delete IS 'BASE: Lösch- und Fortführungsdatensätze';
		COMMENT ON TABLE alkis_beziehungen IS 'BASE: Objektbeziehungen';

		COMMENT ON TABLE ks_einrichtunginoeffentlichenbereichen IS 'BASE: ks_einrichtunginoeffentlichenbereichen';
		COMMENT ON TABLE ks_bauwerkanlagenfuerverundentsorgung IS 'BASE: ks_bauwerkanlagenfuerverundentsorgung';
		COMMENT ON TABLE ks_sonstigesbauwerk IS 'BASE: ks_sonstigesbauwerk';
		COMMENT ON TABLE ks_einrichtungimstrassenverkehr IS 'BASE: ks_einrichtungimstrassenverkehr';
		COMMENT ON TABLE ks_verkehrszeichen IS 'BASE: ks_verkehrszeichen';
		COMMENT ON TABLE ks_einrichtungimbahnverkehr IS 'BASE: ks_einrichtungimbahnverkehr';
		COMMENT ON TABLE ks_bauwerkimgewaesserbereich IS 'BASE: ks_bauwerkimgewaesserbereich';
		COMMENT ON TABLE ks_vegetationsmerkmal IS 'BASE: ks_vegetationsmerkmal';
		COMMENT ON TABLE ks_bauraumoderbodenordnungsrecht IS 'BASE: ks_bauraumoderbodenordnungsrecht';
		COMMENT ON TABLE ks_kommunalerbesitz IS 'BASE: ks_kommunalerbesitz';

		CREATE INDEX ap_pto_art ON ap_pto USING btree (art);
		CREATE INDEX ap_lto_art ON ap_lto USING btree (art);
		CREATE INDEX ap_darstellung_art ON ap_darstellung USING btree (art);

		CREATE INDEX ap_lpo_sn ON ap_lpo USING btree (signaturnummer);
		CREATE INDEX ap_ppo_sn ON ap_ppo USING btree (signaturnummer);
		CREATE INDEX ap_pto_sn ON ap_pto USING btree (signaturnummer);
		CREATE INDEX ap_lto_sn ON ap_lto USING btree (signaturnummer);
		CREATE INDEX ap_darstellung_sn ON ap_darstellung USING btree (signaturnummer);

		CREATE INDEX ax_dienststelle_sg ON ax_dienststelle(schluesselgesamt);

	END IF;

	IF ver<17 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 17';

		IF NOT EXISTS (SELECT * FROM information_schema.tables WHERE table_schema=current_schema() AND table_name='ks_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewerbe') THEN
			--
			-- ks_bauwerkoderanlagefuerindustrieundgewerbe
			--

			CREATE TABLE ks_bauwerkoderanlagefuerindustrieundgewerbe (
				ogc_fid serial NOT NULL,
				gml_id character(16) NOT NULL,
				anlass character varying[],
				beginnt character(20) NOT NULL,
				endet character(20),
				advstandardmodell character varying[],
				sonstigesmodell character varying[],
				zeigtaufexternes_art character varying[],
				zeigtaufexternes_name character varying[],
				zeigtaufexternes_uri character varying[],
				istabgeleitetaus character(16)[],
				traegtbeizu character(16)[],
				hatdirektunten character(16)[],
				istteilvon character(16)[],

				bauwerksfunktion integer NOT NULL,

				PRIMARY KEY (ogc_fid)
			);

			CREATE UNIQUE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_gml ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING btree (gml_id,beginnt);
			CREATE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_endet ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING btree (endet);
			PERFORM AddGeometryColumn('ks_bauwerkoderanlagefuerindustrieundgewerbe', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
			CREATE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_wkb_geometry_idx ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING gist (wkb_geometry);
			CREATE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_istabgeleitetaus ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING gin (istabgeleitetaus);
			CREATE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_traegtbeizu ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING gin (traegtbeizu);
			CREATE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_hatdirektunten ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING gin (hatdirektunten);
			CREATE INDEX ks_bauwerkoderanlagefuerindustrieundgewerbe_istteilvon ON ks_bauwerkoderanlagefuerindustrieundgewerbe USING gin (istteilvon);

			COMMENT ON TABLE ks_bauwerkoderanlagefuerindustrieundgewerbe IS 'FeatureType: "KS_BauwerkOderAnlageFuerIndustrieUndGewerbe"';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_bauwerkoderanlagefuerindustrieundgewerbe.bauwerksfunktion IS 'bauwerksfunktion  KS_Bauwerksfunktion_BauwerkOderAnlageFuerIndustrieUndGewerbe 1';

			--
			-- ks_einrichtungenundanlageninoeffentlichenbereichen
			--

			CREATE TABLE ks_einrichtungenundanlageninoeffentlichenbereichen (
				ogc_fid serial NOT NULL,
				gml_id character(16) NOT NULL,
				anlass character varying[],
				beginnt character(20) NOT NULL,
				endet character(20),
				advstandardmodell character varying[],
				sonstigesmodell character varying[],
				zeigtaufexternes_art character varying[],
				zeigtaufexternes_name character varying[],
				zeigtaufexternes_uri character varying[],
				istabgeleitetaus character(16)[],
				traegtbeizu character(16)[],
				hatdirektunten character(16)[],
				istteilvon character(16)[],

				art integer NOT NULL,

				PRIMARY KEY (ogc_fid)
			);

			CREATE UNIQUE INDEX ks_euaiob_gml ON ks_einrichtungenundanlageninoeffentlichenbereichen USING btree (gml_id,beginnt);
			CREATE INDEX ks_euaiob_endet ON ks_einrichtungenundanlageninoeffentlichenbereichen USING btree (endet);
			PERFORM AddGeometryColumn('ks_einrichtungenundanlageninoeffentlichenbereichen', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
			CREATE INDEX ks_euaiob_wkb_geometry_idx ON ks_einrichtungenundanlageninoeffentlichenbereichen USING gist (wkb_geometry);
			CREATE INDEX ks_euaiob_istabgeleitetaus ON ks_einrichtungenundanlageninoeffentlichenbereichen USING gin (istabgeleitetaus);
			CREATE INDEX ks_euaiob_traegtbeizu ON ks_einrichtungenundanlageninoeffentlichenbereichen USING gin (traegtbeizu);
			CREATE INDEX ks_euaiob_hatdirektunten ON ks_einrichtungenundanlageninoeffentlichenbereichen USING gin (hatdirektunten);
			CREATE INDEX ks_euaiob_istteilvon ON ks_einrichtungenundanlageninoeffentlichenbereichen USING gin (istteilvon);

			COMMENT ON TABLE ks_einrichtungenundanlageninoeffentlichenbereichen IS 'FeatureType: "KS_EinrichtungenUndAnlagenInOeffentlichenBereichen"';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_einrichtungenundanlageninoeffentlichenbereichen.art IS 'art  KS_Art_EinrichtungenUndAnlagenInOeffentlichenBereichen 1';

			--
			-- ks_sonstigesbauwerkodersonstigeeinrichtung
			--

			CREATE TABLE ks_sonstigesbauwerkodersonstigeeinrichtung (
				ogc_fid serial NOT NULL,
				gml_id character(16) NOT NULL,
				anlass character varying[],
				beginnt character(20) NOT NULL,
				endet character(20),
				advstandardmodell character varying[],
				sonstigesmodell character varying[],
				zeigtaufexternes_art character varying[],
				zeigtaufexternes_name character varying[],
				zeigtaufexternes_uri character varying[],
				istabgeleitetaus character(16)[],
				traegtbeizu character(16)[],
				hatdirektunten character(16)[],
				istteilvon character(16)[],

				bauwerksfunktion integer NOT NULL,

				PRIMARY KEY (ogc_fid)
			);

			CREATE UNIQUE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_gml ON ks_sonstigesbauwerkodersonstigeeinrichtung USING btree (gml_id,beginnt);
			CREATE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_endet ON ks_sonstigesbauwerkodersonstigeeinrichtung USING btree (endet);
			PERFORM AddGeometryColumn('ks_sonstigesbauwerkodersonstigeeinrichtung', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
			CREATE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_wkb_geometry_idx ON ks_sonstigesbauwerkodersonstigeeinrichtung USING gist (wkb_geometry);
			CREATE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_istabgeleitetaus ON ks_sonstigesbauwerkodersonstigeeinrichtung USING gin (istabgeleitetaus);
			CREATE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_traegtbeizu ON ks_sonstigesbauwerkodersonstigeeinrichtung USING gin (traegtbeizu);
			CREATE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_hatdirektunten ON ks_sonstigesbauwerkodersonstigeeinrichtung USING gin (hatdirektunten);
			CREATE INDEX ks_sonstigesbauwerkodersonstigeeinrichtung_istteilvon ON ks_sonstigesbauwerkodersonstigeeinrichtung USING gin (istteilvon);

			COMMENT ON TABLE ks_sonstigesbauwerkodersonstigeeinrichtung IS 'FeatureType: "KS_SonstigesBauwerkOderSonstigeEinrichtung"';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerkodersonstigeeinrichtung.bauwerksfunktion IS 'bauwerksfunktion  KS_Bauwerksfunktion_SonstigesBauwerkOderSonstigeEinrichtung 1';

			--
			-- ks_topographischeauspraegung
			--

			CREATE TABLE ks_topographischeauspraegung (
				ogc_fid serial NOT NULL,
				gml_id character(16) NOT NULL,
				anlass character varying[],
				beginnt character(20) NOT NULL,
				endet character(20),
				advstandardmodell character varying[],
				sonstigesmodell character varying[],
				zeigtaufexternes_art character varying[],
				zeigtaufexternes_name character varying[],
				zeigtaufexternes_uri character varying[],
				istabgeleitetaus character(16)[],
				traegtbeizu character(16)[],
				hatdirektunten character(16)[],
				istteilvon character(16)[],

				objektart integer NOT NULL,

				PRIMARY KEY (ogc_fid)
			);

			CREATE UNIQUE INDEX ks_topographischeauspraegung_gml ON ks_topographischeauspraegung USING btree (gml_id,beginnt);
			CREATE INDEX ks_topographischeauspraegung_endet ON ks_topographischeauspraegung USING btree (endet);
			PERFORM AddGeometryColumn('ks_topographischeauspraegung', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
			CREATE INDEX ks_topographischeauspraegung_wkb_geometry_idx ON ks_topographischeauspraegung USING gist (wkb_geometry);
			CREATE INDEX ks_topographischeauspraegung_istabgeleitetaus ON ks_topographischeauspraegung USING gin (istabgeleitetaus);
			CREATE INDEX ks_topographischeauspraegung_traegtbeizu ON ks_topographischeauspraegung USING gin (traegtbeizu);
			CREATE INDEX ks_topographischeauspraegung_hatdirektunten ON ks_topographischeauspraegung USING gin (hatdirektunten);
			CREATE INDEX ks_topographischeauspraegung_istteilvon ON ks_topographischeauspraegung USING gin (istteilvon);

			COMMENT ON TABLE ks_topographischeauspraegung IS 'FeatureType: "KS_TopographischeAuspraegung"';
			COMMENT ON COLUMN ks_topographischeauspraegung.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_topographischeauspraegung.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_topographischeauspraegung.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_topographischeauspraegung.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_topographischeauspraegung.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_topographischeauspraegung.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_topographischeauspraegung.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_topographischeauspraegung.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_topographischeauspraegung.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_topographischeauspraegung.objektart IS 'objektart  KS_Objektart_TopographischeAuspraegung 1';

			--
			-- ks_strassenverkehrsanlage
			--

			CREATE TABLE ks_strassenverkehrsanlage (
				ogc_fid serial NOT NULL,
				gml_id character(16) NOT NULL,
				anlass character varying[],
				beginnt character(20) NOT NULL,
				endet character(20),
				advstandardmodell character varying[],
				sonstigesmodell character varying[],
				zeigtaufexternes_art character varying[],
				zeigtaufexternes_name character varying[],
				zeigtaufexternes_uri character varying[],
				istabgeleitetaus character(16)[],
				traegtbeizu character(16)[],
				hatdirektunten character(16)[],
				istteilvon character(16)[],

				art integer NOT NULL,

				PRIMARY KEY (ogc_fid)
			);

			CREATE UNIQUE INDEX ks_strassenverkehrsanlage_gml ON ks_strassenverkehrsanlage USING btree (gml_id,beginnt);
			CREATE INDEX ks_strassenverkehrsanlage_endet ON ks_strassenverkehrsanlage USING btree (endet);
			PERFORM AddGeometryColumn('ks_strassenverkehrsanlage', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
			CREATE INDEX ks_strassenverkehrsanlage_wkb_geometry_idx ON ks_strassenverkehrsanlage USING gist (wkb_geometry);
			CREATE INDEX ks_strassenverkehrsanlage_istabgeleitetaus ON ks_strassenverkehrsanlage USING gin (istabgeleitetaus);
			CREATE INDEX ks_strassenverkehrsanlage_traegtbeizu ON ks_strassenverkehrsanlage USING gin (traegtbeizu);
			CREATE INDEX ks_strassenverkehrsanlage_hatdirektunten ON ks_strassenverkehrsanlage USING gin (hatdirektunten);
			CREATE INDEX ks_strassenverkehrsanlage_istteilvon ON ks_strassenverkehrsanlage USING gin (istteilvon);

			COMMENT ON TABLE ks_strassenverkehrsanlage IS 'FeatureType: "KS_Strassenverkehrsanlage"';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_strassenverkehrsanlage.art IS 'art  KS_Art_Strassenverkehrsanlage 1';

			--
			-- ks_einrichtunginoeffentlichenbereichen
			--

			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ALTER beginnt SET NOT NULL;
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen RENAME art TO art_;
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD art integer NOT NULL;
			UPDATE ks_einrichtunginoeffentlichenbereichen SET art=art_::int;
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen DROP art_;

			ALTER TABLE ks_einrichtunginoeffentlichenbereichen RENAME material TO material_;
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD material integer;
			UPDATE ks_einrichtunginoeffentlichenbereichen SET material=material_[1];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen DROP material_;

			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD traegtbeizu character(16)[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD hatdirektunten character(16)[];
			ALTER TABLE ks_einrichtunginoeffentlichenbereichen ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_einrichtunginoeffentlichenbereichen_gml ON ks_einrichtunginoeffentlichenbereichen USING btree (gml_id,beginnt);
			CREATE INDEX ks_einrichtunginoeffentlichenbereichen_endet ON ks_einrichtunginoeffentlichenbereichen USING btree (endet);
			CREATE INDEX ks_einrichtunginoeffentlichenbereichen_istabgeleitetaus ON ks_einrichtunginoeffentlichenbereichen USING gin (istabgeleitetaus);
			CREATE INDEX ks_einrichtunginoeffentlichenbereichen_traegtbeizu ON ks_einrichtunginoeffentlichenbereichen USING gin (traegtbeizu);
			CREATE INDEX ks_einrichtunginoeffentlichenbereichen_hatdirektunten ON ks_einrichtunginoeffentlichenbereichen USING gin (hatdirektunten);
			CREATE INDEX ks_einrichtunginoeffentlichenbereichen_istteilvon ON ks_einrichtunginoeffentlichenbereichen USING gin (istteilvon);

			COMMENT ON TABLE ks_einrichtunginoeffentlichenbereichen IS 'FeatureType: "KS_EinrichtungInOeffentlichenBereichen"';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.art IS 'art  KS_Art_EinrichtungInOeffentlichenBereichen 1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.oberflaechenmaterial IS 'oberflaechenmaterial  KS_Oberflaechenmaterial_KommunaleBauwerkeEinrichtungen 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.material IS 'material  KS_Material_EinrichtungInOeffentlichenBereichen 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.bezeichnung IS 'bezeichnung  CharacterString 0..1';
			COMMENT ON COLUMN ks_einrichtunginoeffentlichenbereichen.zustand IS 'zustand  KS_Zustand_KommunaleBauwerkeEinrichtungen 0..1';

			--
			-- ks_bauwerkanlagenfuerverundentsorgung
			--

			BEGIN
				ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung DROP CONSTRAINT enforce_geotype_wkb_geometry;
			EXCEPTION WHEN OTHERS THEN
				ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung RENAME wkb_geometry TO wkb_geometry_;
				PERFORM AddGeometryColumn('ks_bauwerkanlagenfuerverundentsorgung','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
				UPDATE ks_bauwerkanlagenfuerverundentsorgung SET wkb_geometry=wkb_geometry_;
				ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung DROP wkb_geometry_ CASCADE;

				CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_geom_idx ON ks_bauwerkanlagenfuerverundentsorgung USING gist(wkb_geometry);
			END;

			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ALTER beginnt SET NOT NULL;
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung RENAME art TO art_;
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD art integer NOT NULL;
			UPDATE ks_bauwerkanlagenfuerverundentsorgung SET art=art_::int;
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung DROP art_;

			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD traegtbeizu character(16)[];
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD hatdirektunten character(16)[];
			ALTER TABLE ks_bauwerkanlagenfuerverundentsorgung ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_bauwerkanlagenfuerverundentsorgung_gml ON ks_bauwerkanlagenfuerverundentsorgung USING btree (gml_id,beginnt);
			CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_endet ON ks_bauwerkanlagenfuerverundentsorgung USING btree (endet);
			CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_istabgeleitetaus ON ks_bauwerkanlagenfuerverundentsorgung USING gin (istabgeleitetaus);
			CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_traegtbeizu ON ks_bauwerkanlagenfuerverundentsorgung USING gin (traegtbeizu);
			CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_hatdirektunten ON ks_bauwerkanlagenfuerverundentsorgung USING gin (hatdirektunten);
			CREATE INDEX ks_bauwerkanlagenfuerverundentsorgung_istteilvon ON ks_bauwerkanlagenfuerverundentsorgung USING gin (istteilvon);

			COMMENT ON TABLE ks_bauwerkanlagenfuerverundentsorgung IS 'FeatureType: "KS_BauwerkAnlagenFuerVerUndEntsorgung"';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.art IS 'art  KS_Art_BauwerkAnlagenFuerVerUndEntsorgung 1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.bezeichnung IS 'bezeichnung  CharacterString 0..1';
			COMMENT ON COLUMN ks_bauwerkanlagenfuerverundentsorgung.zustand IS 'zustand  KS_Zustand_BauwerkOderAnlageFuerVerUndEntsorgung 0..1';

			--
			-- ks_sonstigesbauwerk
			--

			ALTER TABLE ks_sonstigesbauwerk ALTER beginnt SET NOT NULL;
			ALTER TABLE ks_sonstigesbauwerk ALTER bauwerksfunktion SET NOT NULL;

			ALTER TABLE ks_sonstigesbauwerk ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_sonstigesbauwerk ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_sonstigesbauwerk ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_sonstigesbauwerk ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_sonstigesbauwerk ADD traegtbeizu character(16)[];
			ALTER TABLE ks_sonstigesbauwerk ADD hatdirektunten character(16)[];
			ALTER TABLE ks_sonstigesbauwerk ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_sonstigesbauwerk_gml ON ks_sonstigesbauwerk USING btree (gml_id,beginnt);
			CREATE INDEX ks_sonstigesbauwerk_endet ON ks_sonstigesbauwerk USING btree (endet);
			CREATE INDEX ks_sonstigesbauwerk_istabgeleitetaus ON ks_sonstigesbauwerk USING gin (istabgeleitetaus);
			CREATE INDEX ks_sonstigesbauwerk_traegtbeizu ON ks_sonstigesbauwerk USING gin (traegtbeizu);
			CREATE INDEX ks_sonstigesbauwerk_hatdirektunten ON ks_sonstigesbauwerk USING gin (hatdirektunten);
			CREATE INDEX ks_sonstigesbauwerk_istteilvon ON ks_sonstigesbauwerk USING gin (istteilvon);

			COMMENT ON TABLE ks_sonstigesbauwerk IS 'FeatureType: "KS_SonstigesBauwerk"';
			COMMENT ON COLUMN ks_sonstigesbauwerk.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_sonstigesbauwerk.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.bauwerksfunktion IS 'bauwerksfunktion  KS_Bauwerksfunktion_SonstigesBauwerk 1';
			COMMENT ON COLUMN ks_sonstigesbauwerk.bezeichnung IS 'bezeichnung  CharacterString 0..1';

			--
			-- ks_einrichtungimstrassenverkehr
			--

			ALTER TABLE ks_einrichtungimstrassenverkehr ALTER beginnt SET NOT NULL;
			ALTER TABLE ks_einrichtungimstrassenverkehr ALTER art SET NOT NULL;

			ALTER TABLE ks_einrichtungimstrassenverkehr ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_einrichtungimstrassenverkehr ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_einrichtungimstrassenverkehr ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_einrichtungimstrassenverkehr ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_einrichtungimstrassenverkehr ADD traegtbeizu character(16)[];
			ALTER TABLE ks_einrichtungimstrassenverkehr ADD hatdirektunten character(16)[];
			ALTER TABLE ks_einrichtungimstrassenverkehr ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_einrichtungimstrassenverkehr_gml ON ks_einrichtungimstrassenverkehr USING btree (gml_id,beginnt);
			CREATE INDEX ks_einrichtungimstrassenverkehr_endet ON ks_einrichtungimstrassenverkehr USING btree (endet);
			CREATE INDEX ks_einrichtungimstrassenverkehr_istabgeleitetaus ON ks_einrichtungimstrassenverkehr USING gin (istabgeleitetaus);
			CREATE INDEX ks_einrichtungimstrassenverkehr_traegtbeizu ON ks_einrichtungimstrassenverkehr USING gin (traegtbeizu);
			CREATE INDEX ks_einrichtungimstrassenverkehr_hatdirektunten ON ks_einrichtungimstrassenverkehr USING gin (hatdirektunten);
			CREATE INDEX ks_einrichtungimstrassenverkehr_istteilvon ON ks_einrichtungimstrassenverkehr USING gin (istteilvon);

			COMMENT ON TABLE ks_einrichtungimstrassenverkehr IS 'FeatureType: "KS_EinrichtungImStrassenverkehr"';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.art IS 'art  KS_Art_EinrichtungImStrassenverkehr 1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.oberflaechenmaterial IS 'oberflaechenmaterial  KS_Oberflaechenmaterial_KommunaleBauwerkeEinrichtungen 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.bezeichnung IS 'bezeichnung  CharacterString 0..1';
			COMMENT ON COLUMN ks_einrichtungimstrassenverkehr.zustand IS 'zustand  KS_Zustand_KommunaleBauwerkeEinrichtungen 0..1';

			--
			-- ks_verkehrszeichen
			--

			BEGIN
				ALTER TABLE ks_verkehrszeichen DROP CONSTRAINT enforce_geotype_wkb_geometry;
			EXCEPTION WHEN OTHERS THEN
				ALTER TABLE ks_verkehrszeichen RENAME wkb_geometry TO wkb_geometry_;
				PERFORM AddGeometryColumn('ks_verkehrszeichen','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
				UPDATE ks_verkehrszeichen SET wkb_geometry=wkb_geometry_;
				ALTER TABLE ks_verkehrszeichen DROP wkb_geometry_ CASCADE;

				CREATE INDEX ks_verkehrszeichen_geom_idx ON ks_verkehrszeichen USING gist(wkb_geometry);
			END;

			ALTER TABLE ks_verkehrszeichen ALTER beginnt SET NOT NULL;

			ALTER TABLE ks_verkehrszeichen ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_verkehrszeichen ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_verkehrszeichen ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_verkehrszeichen ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_verkehrszeichen ADD traegtbeizu character(16)[];
			ALTER TABLE ks_verkehrszeichen ADD hatdirektunten character(16)[];
			ALTER TABLE ks_verkehrszeichen ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_verkehrszeichen_gml ON ks_verkehrszeichen USING btree (gml_id,beginnt);
			CREATE INDEX ks_verkehrszeichen_endet ON ks_verkehrszeichen USING btree (endet);
			CREATE INDEX ks_verkehrszeichen_istabgeleitetaus ON ks_verkehrszeichen USING gin (istabgeleitetaus);
			CREATE INDEX ks_verkehrszeichen_traegtbeizu ON ks_verkehrszeichen USING gin (traegtbeizu);
			CREATE INDEX ks_verkehrszeichen_hatdirektunten ON ks_verkehrszeichen USING gin (hatdirektunten);
			CREATE INDEX ks_verkehrszeichen_istteilvon ON ks_verkehrszeichen USING gin (istteilvon);

			COMMENT ON TABLE ks_verkehrszeichen IS 'FeatureType: "KS_Verkehrszeichen"';
			COMMENT ON COLUMN ks_verkehrszeichen.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_verkehrszeichen.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_verkehrszeichen.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_verkehrszeichen.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_verkehrszeichen.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_verkehrszeichen.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_verkehrszeichen.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_verkehrszeichen.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_verkehrszeichen.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_verkehrszeichen.gefahrzeichen IS 'gefahrzeichen  KS_Gefahrzeichen_Verkehrszeichen 0..*';
			COMMENT ON COLUMN ks_verkehrszeichen.vorschriftzeichen IS 'vorschriftzeichen  KS_Vorschriftzeichen_Verkehrszeichen 0..*';
			COMMENT ON COLUMN ks_verkehrszeichen.richtzeichen IS 'richtzeichen  KS_Richtzeichen_Verkehrszeichen 0..*';
			COMMENT ON COLUMN ks_verkehrszeichen.verkehrseinrichtung IS 'verkehrseinrichtung  KS_Verkehrseinrichtung_Verkehrszeichen 0..*';
			COMMENT ON COLUMN ks_verkehrszeichen.zusatzzeichen IS 'zusatzzeichen  KS_Zusatzzeichen_Verkehrszeichen 0..*';
			COMMENT ON COLUMN ks_verkehrszeichen.bezeichnung IS 'bezeichnung  CharacterString 0..1';

			--
			-- ks_einrichtungimbahnverkehr
			--

			ALTER TABLE ks_einrichtungimbahnverkehr ALTER beginnt SET NOT NULL;
			ALTER TABLE ks_einrichtungimbahnverkehr ALTER art SET NOT NULL;

			ALTER TABLE ks_einrichtungimbahnverkehr ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_einrichtungimbahnverkehr ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_einrichtungimbahnverkehr ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_einrichtungimbahnverkehr ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_einrichtungimbahnverkehr ADD traegtbeizu character(16)[];
			ALTER TABLE ks_einrichtungimbahnverkehr ADD hatdirektunten character(16)[];
			ALTER TABLE ks_einrichtungimbahnverkehr ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_einrichtungimbahnverkehr_gml ON ks_einrichtungimbahnverkehr USING btree (gml_id,beginnt);
			CREATE INDEX ks_einrichtungimbahnverkehr_endet ON ks_einrichtungimbahnverkehr USING btree (endet);
			CREATE INDEX ks_einrichtungimbahnverkehr_istabgeleitetaus ON ks_einrichtungimbahnverkehr USING gin (istabgeleitetaus);
			CREATE INDEX ks_einrichtungimbahnverkehr_traegtbeizu ON ks_einrichtungimbahnverkehr USING gin (traegtbeizu);
			CREATE INDEX ks_einrichtungimbahnverkehr_hatdirektunten ON ks_einrichtungimbahnverkehr USING gin (hatdirektunten);
			CREATE INDEX ks_einrichtungimbahnverkehr_istteilvon ON ks_einrichtungimbahnverkehr USING gin (istteilvon);

			COMMENT ON TABLE ks_einrichtungimbahnverkehr IS 'FeatureType: "KS_EinrichtungImBahnverkehr"';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.art IS 'art  KS_Art_EinrichtungImBahnverkehr 1';
			COMMENT ON COLUMN ks_einrichtungimbahnverkehr.bezeichnung IS 'bezeichnung  CharacterString 0..1';

			--
			-- ks_bauwerkimgewaesserbereich
			--

			BEGIN
				ALTER TABLE ks_bauwerkimgewaesserbereich DROP CONSTRAINT enforce_geotype_wkb_geometry;
			EXCEPTION WHEN OTHERS THEN
				ALTER TABLE ks_bauwerkimgewaesserbereich RENAME wkb_geometry TO wkb_geometry_;
				PERFORM AddGeometryColumn('ks_bauwerkimgewaesserbereich','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',2);
				UPDATE ks_bauwerkimgewaesserbereich SET wkb_geometry=wkb_geometry_;
				ALTER TABLE ks_bauwerkimgewaesserbereich DROP wkb_geometry_ CASCADE;

				CREATE INDEX ks_bauwerkimgewaesserbereich_geom_idx ON ks_bauwerkimgewaesserbereich USING gist(wkb_geometry);
			END;

			ALTER TABLE ks_bauwerkimgewaesserbereich ALTER beginnt SET NOT NULL;
			ALTER TABLE ks_bauwerkimgewaesserbereich ALTER bauwerksfunktion SET NOT NULL;

			ALTER TABLE ks_bauwerkimgewaesserbereich ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_bauwerkimgewaesserbereich ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_bauwerkimgewaesserbereich ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_bauwerkimgewaesserbereich ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_bauwerkimgewaesserbereich ADD traegtbeizu character(16)[];
			ALTER TABLE ks_bauwerkimgewaesserbereich ADD hatdirektunten character(16)[];
			ALTER TABLE ks_bauwerkimgewaesserbereich ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_bauwerkimgewaesserbereich_gml ON ks_bauwerkimgewaesserbereich USING btree (gml_id,beginnt);
			CREATE INDEX ks_bauwerkimgewaesserbereich_endet ON ks_bauwerkimgewaesserbereich USING btree (endet);
			CREATE INDEX ks_bauwerkimgewaesserbereich_istabgeleitetaus ON ks_bauwerkimgewaesserbereich USING gin (istabgeleitetaus);
			CREATE INDEX ks_bauwerkimgewaesserbereich_traegtbeizu ON ks_bauwerkimgewaesserbereich USING gin (traegtbeizu);
			CREATE INDEX ks_bauwerkimgewaesserbereich_hatdirektunten ON ks_bauwerkimgewaesserbereich USING gin (hatdirektunten);
			CREATE INDEX ks_bauwerkimgewaesserbereich_istteilvon ON ks_bauwerkimgewaesserbereich USING gin (istteilvon);

			COMMENT ON TABLE ks_bauwerkimgewaesserbereich IS 'FeatureType: "KS_BauwerkImGewaesserbereich"';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.bauwerksfunktion IS 'bauwerksfunktion  KS_Bauwerksfunktion_BauwerkImGewaesserbereich 1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.bezeichnung IS 'bezeichnung  CharacterString 0..1';
			COMMENT ON COLUMN ks_bauwerkimgewaesserbereich.zustand IS 'zustand  KS_Zustand_BauwerkImGewaesserbereich 0..1';

			--
			-- ks_vegetationsmerkmal
			--

			ALTER TABLE ks_vegetationsmerkmal ALTER beginnt SET NOT NULL;

			ALTER TABLE ks_vegetationsmerkmal ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_vegetationsmerkmal ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_vegetationsmerkmal ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_vegetationsmerkmal ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_vegetationsmerkmal ADD traegtbeizu character(16)[];
			ALTER TABLE ks_vegetationsmerkmal ADD hatdirektunten character(16)[];
			ALTER TABLE ks_vegetationsmerkmal ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_vegetationsmerkmal_gml ON ks_vegetationsmerkmal USING btree (gml_id,beginnt);
			CREATE INDEX ks_vegetationsmerkmal_endet ON ks_vegetationsmerkmal USING btree (endet);
			CREATE INDEX ks_vegetationsmerkmal_istabgeleitetaus ON ks_vegetationsmerkmal USING gin (istabgeleitetaus);
			CREATE INDEX ks_vegetationsmerkmal_traegtbeizu ON ks_vegetationsmerkmal USING gin (traegtbeizu);
			CREATE INDEX ks_vegetationsmerkmal_hatdirektunten ON ks_vegetationsmerkmal USING gin (hatdirektunten);
			CREATE INDEX ks_vegetationsmerkmal_istteilvon ON ks_vegetationsmerkmal USING gin (istteilvon);

			COMMENT ON TABLE ks_vegetationsmerkmal IS 'FeatureType: "KS_Vegetationsmerkmal"';
			COMMENT ON COLUMN ks_vegetationsmerkmal.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_vegetationsmerkmal.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.bewuchs IS 'bewuchs  KS_Bewuchs_Vegetationsmerkmal 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.zustand IS 'zustand  KS_Zustand_Vegetationsmerkmal 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.breitedesobjekts IS 'breiteDesObjekts  Length 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.name IS 'name  CharacterString 0..1';
			COMMENT ON COLUMN ks_vegetationsmerkmal.bezeichnung IS 'bezeichnung  CharacterString 0..1';

			--
			-- ks_bauraumoderbodenordnungsrecht
			--

			ALTER TABLE ks_bauraumoderbodenordnungsrecht ALTER beginnt SET NOT NULL;

			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD traegtbeizu character(16)[];
			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD hatdirektunten character(16)[];
			ALTER TABLE ks_bauraumoderbodenordnungsrecht ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_bauraumoderbodenordnungsrecht_gml ON ks_bauraumoderbodenordnungsrecht USING btree (gml_id,beginnt);
			CREATE INDEX ks_bauraumoderbodenordnungsrecht_endet ON ks_bauraumoderbodenordnungsrecht USING btree (endet);
			CREATE INDEX ks_bauraumoderbodenordnungsrecht_istabgeleitetaus ON ks_bauraumoderbodenordnungsrecht USING gin (istabgeleitetaus);
			CREATE INDEX ks_bauraumoderbodenordnungsrecht_traegtbeizu ON ks_bauraumoderbodenordnungsrecht USING gin (traegtbeizu);
			CREATE INDEX ks_bauraumoderbodenordnungsrecht_hatdirektunten ON ks_bauraumoderbodenordnungsrecht USING gin (hatdirektunten);
			CREATE INDEX ks_bauraumoderbodenordnungsrecht_istteilvon ON ks_bauraumoderbodenordnungsrecht USING gin (istteilvon);

			COMMENT ON TABLE ks_bauraumoderbodenordnungsrecht IS 'FeatureType: "KS_BauRaumOderBodenordnungsrecht"';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.anlass IS 'anlass codelist AA_Anlassart 0..*';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name   0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.artderfestlegung IS 'artDerFestlegung  KS_ArtDerFestlegung_BauRaumOderBauordnungsrecht 0..1';
			COMMENT ON COLUMN ks_bauraumoderbodenordnungsrecht.bezeichnung IS 'bezeichnung  CharacterString 0..1';

			--
			-- ks_kommunalerbesitz
			--

			ALTER TABLE ks_kommunalerbesitz ALTER beginnt SET NOT NULL;

			ALTER TABLE ks_kommunalerbesitz ADD zeigtaufexternes_art character varying[];
			ALTER TABLE ks_kommunalerbesitz ADD zeigtaufexternes_name character varying[];
			ALTER TABLE ks_kommunalerbesitz ADD zeigtaufexternes_uri character varying[];
			ALTER TABLE ks_kommunalerbesitz ADD istabgeleitetaus character(16)[];
			ALTER TABLE ks_kommunalerbesitz ADD traegtbeizu character(16)[];
			ALTER TABLE ks_kommunalerbesitz ADD hatdirektunten character(16)[];
			ALTER TABLE ks_kommunalerbesitz ADD istteilvon character(16)[];

			CREATE UNIQUE INDEX ks_kommunalerbesitz_gml ON ks_kommunalerbesitz USING btree (gml_id,beginnt);
			CREATE INDEX ks_kommunalerbesitz_endet ON ks_kommunalerbesitz USING btree (endet);
			CREATE INDEX ks_kommunalerbesitz_wkb_geometry_idx ON ks_kommunalerbesitz USING gist (wkb_geometry);
			CREATE INDEX ks_kommunalerbesitz_istabgeleitetaus ON ks_kommunalerbesitz USING gin (istabgeleitetaus);
			CREATE INDEX ks_kommunalerbesitz_traegtbeizu ON ks_kommunalerbesitz USING gin (traegtbeizu);
			CREATE INDEX ks_kommunalerbesitz_hatdirektunten ON ks_kommunalerbesitz USING gin (hatdirektunten);
			CREATE INDEX ks_kommunalerbesitz_istteilvon ON ks_kommunalerbesitz USING gin (istteilvon);


			--
			-- Kataloge
			--

			CREATE TABLE ks_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewerbe (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewerbe IS 'Alias: "KS_Bauwerksfunktion_BauwerkOderAnlageFuerIndustrieUndGewerbe", UML-Typ: Enumeration';
			INSERT INTO ks_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewerbe (wert,beschreibung,dokumentation) VALUES
			('1380', 'Schieberkappe', ''),
			('1390', 'Einsteigeschacht', ''),
			('1372', 'Unterflurhydrant', ''),
			('1250', 'Mast', ''),
			('1371', 'Oberflurhydrant', '');

			CREATE TABLE ks_bauwerksfunktion_bauwerkimgewaesserbereich (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_bauwerksfunktion_bauwerkimgewaesserbereich IS 'Alias: "KS_Bauwerksfunktion_BauwerkImGewaesserbereich", UML-Typ: Enumeration';
			INSERT INTO ks_bauwerksfunktion_bauwerkimgewaesserbereich (wert,beschreibung,dokumentation) VALUES
			('1200', 'Einlass/Auslass', ''),
			('1100', 'Rohrdurchlass', '');

			CREATE TABLE ks_art_strassenverkehrsanlage (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_art_strassenverkehrsanlage IS 'Alias: "KS_Art_Strassenverkehrsanlage", UML-Typ: Enumeration';
			INSERT INTO ks_art_strassenverkehrsanlage (wert,beschreibung,dokumentation) VALUES
			('1010', 'Fahrbahnbegrenzungslinie', '');

			CREATE TABLE ks_bewuchs_vegetationsmerkmal (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_bewuchs_vegetationsmerkmal IS 'Alias: "KS_Bewuchs_Vegetationsmerkmal", UML-Typ: Enumeration';
			INSERT INTO ks_bewuchs_vegetationsmerkmal (wert,beschreibung,dokumentation) VALUES
			('1013', 'Solitärstrauch', ''),
			('1102', 'Heckenkante, links', ''),
			('1012', 'Laubbaum', ''),
			('1103', 'Heckenmitte', ''),
			('2200', 'erhw. Nadelbaum', '''erhw.Nadelbaum'' beschreibt die Zugehörigkeit eines einzeln stehenden, erhaltungswürdigen Baumes zur Gruppe der Nadelhölzer.'),
			('3100', 'Beet', ''),
			('1100', 'Rasen', 'Rasen bezeichnet eine Vegetationsdecke aus Gräsern, die feste verwurzelt, durch Wurzeln und Ausläufer mit der Vegetationstrageschicht verbunden ist und nicht landwirtschaftlich genutzt wird. Rasen findet Verwendung in Gärten oder Grünanlagen (z.B. Sportplatz, Golfplatz) und wird meist kurz geschnitten.'),
			('1101', 'Heckenkante, rechts', ''),
			('2100', 'erhw. Laubbaum', '''erhw.Laubbaum'' beschreibt die Zugehörigkeit eines einzeln stehenden, erhaltungswürdigen Baumes zur Gruppe der Laubhölzer.'),
			('1011', 'Nadelbaum', '');

			CREATE TABLE ks_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtung (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtung IS 'Alias: "KS_Bauwerksfunktion_SonstigesBauwerkOderSonstigeEinrichtung", UML-Typ: Enumeration';
			INSERT INTO ks_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtung (wert,beschreibung,dokumentation) VALUES
			('1655', 'Rampe, Barrierefreiheit', ''),
			('1721', 'Stützmauer, rechts', ''),
			('1740', 'Zaun', ''),
			('1701', 'Mauerkante, rechts', ''),
			('1782', 'Springbrunnen, Zierbrunnen ', ''),
			('1630', 'Treppenunterkante', ''),
			('1780', 'Brunnen', ''),
			('1702', 'Mauerkante, links', ''),
			('1781', 'Brunnen (Trinkwasserversorgung)', ''),
			('1703', 'Mauermitte', ''),
			('1723', 'Stützmauermitte', ''),
			('1722', 'Stützmauer, links', ''),
			('1620', 'Treppe', ''),
			('1640', 'Kellereingang', ''),
			('1660', 'Kellerschacht', '');

			CREATE TABLE ks_art_bauwerkanlagenfuerverundentsorgung (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_art_bauwerkanlagenfuerverundentsorgung IS 'Alias: "KS_Art_BauwerkAnlagenFuerVerUndEntsorgung", UML-Typ: Enumeration';
			INSERT INTO ks_art_bauwerkanlagenfuerverundentsorgung (wert,beschreibung,dokumentation) VALUES
			('2200', 'Schieberkappe Wasser', ''),
			('3100', 'Stahlgittermast ohne Sockel', ''),
			('1200', 'Peilrohr', '''Peilrohr'' ist ein Rohr zum Messen des Wasserstandes'),
			('3300', 'Hochspannungsmast', ''),
			('1300', 'Wasserhahn', '''Wasserhahn'' ist eine Vorrichtung zum Öffnen und Schließen von Wasserleitungen'),
			('3200', 'Sockel für Gittermast', ''),
			('2100', 'Schieberkappe Gas', ''),
			('1100', 'städtischer Entwässerungsgraben', '''städtischer Entwässerungsgraben'' ist eine längere schmale Vertiefung im Erdboden zu dessen Entwässerung'),
			('1500', 'Kanaldeckel', ''),
			('3400', 'Stahlgittermast mit Sockel', ''),
			('1400', 'Wasserschieber', '');

			CREATE TABLE ks_art_einrichtungimstrassenverkehr (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_art_einrichtungimstrassenverkehr IS 'Alias: "KS_Art_EinrichtungImStrassenverkehr", UML-Typ: Enumeration';
			INSERT INTO ks_art_einrichtungimstrassenverkehr (wert,beschreibung,dokumentation) VALUES
			('2000', 'ruhender Verkehr', ''),
			('9999', 'Sonstiges', ''),
			('3100', 'Radweg', ''),
			('3300', 'Öffentlicher Platz', ''),
			('3200', 'Parkplatz', ''),
			('4100', 'Radarkontrolle', ''),
			('1100', 'ruhender Verkehr', ''),
			('3120', 'Fußweg', ''),
			('3600', 'Furt', ''),
			('3140', 'Rad- und Fußweg', ''),
			('3150', 'Wirtschaftsweg', ''),
			('3000', 'Fahrbahn', ''),
			('3500', 'Fahrbahnteiler, Mittelinsel', ''),
			('2200', 'Rinne', ''),
			('2100', 'Bordstein', '');

			CREATE TABLE ks_objektart_topographischeauspraegung (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_objektart_topographischeauspraegung IS 'Alias: "KS_Objektart_TopographischeAuspraegung", UML-Typ: Enumeration';
			INSERT INTO ks_objektart_topographischeauspraegung (wert,beschreibung,dokumentation) VALUES
			('9000', 'sonstige topographische Linie', '');

			CREATE TABLE ks_art_einrichtungenundanlageninoeffentlichenbereichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_art_einrichtungenundanlageninoeffentlichenbereichen IS 'Alias: "KS_Art_EinrichtungenUndAnlagenInOeffentlichenBereichen", UML-Typ: Enumeration';
			INSERT INTO ks_art_einrichtungenundanlageninoeffentlichenbereichen (wert,beschreibung,dokumentation) VALUES
			('3100', 'Bank', ''),
			('1160', 'Postdepot', ''),
			('1140', 'Feuermelder', ''),
			('1360', 'Haltestelle, Wartestand', ''),
			('1340', 'Freistehende Warntafel', ''),
			('1100', 'Kommunikationseinrichtung', ''),
			('1300', 'Verkehrszeichen', ''),
			('9001', 'sonstiges Schild', ''),
			('1510', 'Tor', ''),
			('1710', 'Leuchtsäule', ''),
			('1910', 'Fahnenmast', ''),
			('1700', 'Säule, Werbefläche', ''),
			('2600', 'Flutlichtmast', ''),
			('2101', 'Straßensinkkasten, seitlich - an Bordsteinkante', ''),
			('1500', 'Bahnübergang, Schranke', ''),
			('2100', 'Straßensinkkasten', ''),
			('1130', 'Notrufeinrichtung', ''),
			('1310', 'Verkehrsampel', ''),
			('1110', 'Fernsprechhäuschen', ''),
			('3310', 'Fahrradständer', ''),
			('1200', 'Kabelkasten, Schaltkasten', ''),
			('1120', 'Briefkasten', ''),
			('1410', 'Kilometerstein, -tafel', ''),
			('1320', 'Freistehende Hinweistafel, -zeichen', ''),
			('1620', 'Laterne, elektrisch', ''),
			('3200', 'Spielgerät', ''),
			('3120', 'Blumenkübel', ''),
			('2102', 'Straßensinkkasten, mittig', ''),
			('2210', 'Abfalleimer', ''),
			('9999', 'Sonstiges', ''),
			('2400', 'Uhr', ''),
			('2200', 'Müllbox', ''),
			('2105', 'Kastenrinne', ''),
			('1150', 'Polizeirufsäule', ''),
			('1400', 'Markierungshinweise, -steine', '');

			CREATE TABLE ks_art_einrichtunginoeffentlichenbereichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_art_einrichtunginoeffentlichenbereichen IS 'Alias: "KS_Art_EinrichtungInOeffentlichenBereichen", UML-Typ: Enumeration';
			INSERT INTO ks_art_einrichtunginoeffentlichenbereichen (wert,beschreibung,dokumentation) VALUES
			('1400', 'Abfalleimer', ''),
			('1700', 'Tisch', ''),
			('5200', 'Sport-/Spielflächen', ''),
			('5300', 'Grab', ''),
			('1500', 'Postdepot', ''),
			('5100', 'sonstige Flächen', ''),
			('5000', 'Weg (nicht in Verkehrsanlagen)', ''),
			('1600', 'Blumenkübel', ''),
			('1200', 'Spielgerät', 'Ein ''Spielgerät'' dient dem Erwerb von Wahrnehmungsleistungen, motorischen Fähigkeiten und Intelligenzleistungen des Kindes auf Spielplätzen o.ä.'),
			('1100', 'Bank', 'Bank ist eine Sitzgelegenheit aus Holz, Stein o.ä., die mehreren Personen Platz bietet'),
			('1300', 'Fahrradständer', ''),
			('5500', 'Randbefestigung, Einfassung', '');

			CREATE TABLE ks_oberflaechenmaterial_kommunalebauwerkeeinrichtungen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_oberflaechenmaterial_kommunalebauwerkeeinrichtungen IS 'Alias: "KS_Oberflaechenmaterial_KommunaleBauwerkeEinrichtungen", UML-Typ: Enumeration';
			INSERT INTO ks_oberflaechenmaterial_kommunalebauwerkeeinrichtungen (wert,beschreibung,dokumentation) VALUES
			('2010', 'Kunststoff', '''Kunststoff'' bedeutet, dass die Oberfläche aus Kunststoff besteht.'),
			('1060', 'Gehwegplatten', '''Gehwegplatten'' bedeutet, dass es sich um eine mit Gehwegplatten ausgelegte Oberfläche handelt.'),
			('1020', 'Bituminöser Belag', '''Bituminöser Belag'' bedeutet, dass die Oberfläche aus einem bituminösen Belag besteht.'),
			('1040', 'Wassergebundener Belag', '''Wassergebundener Belag'' bedeutet, dass die Oberfläche aus einem wassergebundenem Belag besteht.'),
			('3020', 'Rindenmulch', '''Rindenmulch'' bedeutet, dass die Oberfläche mit Rindenmulch bedeckt ist.'),
			('4010', 'Schotterrasen', '''Schotterrasen'' bedeutet, dass die Oberfläche aus Schotterrasen besteht.'),
			('1010', 'Asphalt', '''Asphalt'' bedeutet, dass die Oberfläche aus Asphalt besteht.'),
			('1050', 'Pflaster', '''Pflaster'' bedeutet, dass es sich um eine gepflasterte Oberfläche handelt.'),
			('3010', 'Sand', '''Sand'' bedeutet, dass die Oberfläche mit Sand bedeckt ist.'),
			('9999', 'Sonstiges', ''),
			('1030', 'Beton', '''Beton'' bedeutet, dass die Oberfläche aus Beton besteht.');

			CREATE TABLE ks_material_einrichtunginoeffentlichenbereichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_material_einrichtunginoeffentlichenbereichen IS 'Alias: "KS_Material_EinrichtungInOeffentlichenBereichen", UML-Typ: Enumeration';
			INSERT INTO ks_material_einrichtunginoeffentlichenbereichen (wert,beschreibung,dokumentation) VALUES
			('9999', 'Sonstiges', ''),
			('3000', 'Holz', '''Holz'' bedeutet, dass ''KS_EinrichtungInOeffentlichenBereichen'' aus Holz besteht.'),
			('1000', 'Stein', '''Stein'' bedeutet, dass ''KS_EinrichtungInOeffentlichenBereichen'' aus Stein besteht.'),
			('2000', 'Metall', '''Metall'' bedeutet, dass ''KS_EinrichtungInOeffentlichenBereichen'' aus Metall besteht.'),
			('4000', 'Kunststoff', '''Kunststoff'' bedeutet, dass ''KS_EinrichtungInOeffentlichenBereichen'' aus Kunststoff besteht.');

			CREATE TABLE ks_zustand_kommunalebauwerkeeinrichtungen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_zustand_kommunalebauwerkeeinrichtungen IS 'Alias: "KS_Zustand_KommunaleBauwerkeEinrichtungen", UML-Typ: Enumeration';
			INSERT INTO ks_zustand_kommunalebauwerkeeinrichtungen (wert,beschreibung,dokumentation) VALUES
			('1100', 'unbefestigt', '');

			CREATE TABLE ks_zustand_bauwerkoderanlagefuerverundentsorgung (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_zustand_bauwerkoderanlagefuerverundentsorgung IS 'Alias: "KS_Zustand_BauwerkOderAnlageFuerVerUndEntsorgung", UML-Typ: Enumeration';
			INSERT INTO ks_zustand_bauwerkoderanlagefuerverundentsorgung (wert,beschreibung,dokumentation) VALUES
			('4100', 'Offen', '''Offen'' bedeutet, dass ''Bauwerk oder Anlage für Ver- und Entsorgung'' allgemein zugänglich ist.'),
			('2100', 'Außer Betrieb, stillgelegt, verlassen', '''Außer Betrieb, stillgelegt, verlassen'' bedeutet, dass sich ''Bauwerk oder Anlage für Ver- und Entsorgung'' nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
			('4200', 'Verschlossen', '''Verschlossen'' bedeutet, dass ''Bauwerk oder Anlage für Ver- und Entsorgung'' nicht allgemein zugänglich ist.'),
			('2200', 'Verfallen, zerstört', '''Verfallen, zerstört'' bedeutet, dass sich der ursprüngliche Zustand von ''Bauwerk oder Anlage für Ver- und Entsorgung'' durch menschliche oder zeitliche Einwirkungen so verändert hat, dass eine Nutzung nicht mehr möglich ist.');

			CREATE TABLE ks_bauwerksfunktion_sonstigesbauwerk (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_bauwerksfunktion_sonstigesbauwerk IS 'Alias: "KS_Bauwerksfunktion_SonstigesBauwerk", UML-Typ: Enumeration';
			INSERT INTO ks_bauwerksfunktion_sonstigesbauwerk (wert,beschreibung,dokumentation) VALUES
			('4000', 'Schwengelpumpe', 'Wetterschutzüberdachung5000'),
			('1100', 'Balkon', ''),
			('3000', 'einzelner Zaun', '');

			CREATE TABLE ks_gefahrzeichen_verkehrszeichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_gefahrzeichen_verkehrszeichen IS 'Alias: "KS_Gefahrzeichen_Verkehrszeichen", UML-Typ: Enumeration';
			INSERT INTO ks_gefahrzeichen_verkehrszeichen (wert,beschreibung,dokumentation) VALUES
			('1100', 'Kinder', 'Zeichen 136 STVO, Kinder');

			CREATE TABLE ks_vorschriftzeichen_verkehrszeichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_vorschriftzeichen_verkehrszeichen IS 'Alias: "KS_Vorschriftzeichen_Verkehrszeichen", UML-Typ: Enumeration';
			INSERT INTO ks_vorschriftzeichen_verkehrszeichen (wert,beschreibung,dokumentation) VALUES
			('1222', 'Pfeil geradeaus/rechts', '''Pfeil rechts/geradeaus'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Sie schreiben die Fahrtrichtung vor.'),
			('1223', 'Pfeil links', '''Pfeil links'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Sie schreiben die Fahrtrichtung vor.'),
			('1210', 'Tempo 30 Zone', '''Tempo 30 Zone'' ist ein Schild oder ein auf der Fahrbahnoberfläche einer Straße angebrachtes Zeichen zur Bestimmung der Tempo 30 Zone.'),
			('1230', 'Haltelinie', '''Haltelinie'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Ergänzend zu Halt- und Wartegeboten, die durch Zeichen, durch Polizeibeamte oder Lichtzeichen gegeben werden, ordnet sie an ''Hier halten''. Dasselbe gilt vor Bahnübergängen, für den der warten muss.'),
			('1224', 'Pfeil geradeaus/links', '''Pfeil geradeaus/links'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Sie schreiben die Fahrtrichtung vor.'),
			('1225', 'Pfeil geradeaus', '''Pfeil geradeaus'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Sie schreiben die Fahrtrichtung vor.'),
			('1240', 'Sperrfläche', '''Sperrfläche'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Eine Sperrfläche darf von Fahrzeugen nicht benutzt werden.'),
			('1221', 'Pfeil rechts', '''Pfeil rechts'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Vorschriftzeichen. Sie schreiben die Fahrtrichtung vor.'),
			('1100', 'Andreaskreuz', 'Vorschriftzeichen unmittelbar vor einem Bahnübergang mit der Bedeutung ''Dem Schienenverkehr Vorrang gewähren''.'),
			('1300', 'Ver-/Gebotsschild', '');

			CREATE TABLE ks_richtzeichen_verkehrszeichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_richtzeichen_verkehrszeichen IS 'Alias: "KS_Richtzeichen_Verkehrszeichen", UML-Typ: Enumeration';
			INSERT INTO ks_richtzeichen_verkehrszeichen (wert,beschreibung,dokumentation) VALUES
			('1200', 'Leitpfosten', ''),
			('1111', 'Leitmarkierung durchgezogen', '''Leitmarkierung'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Richtzeichen.'),
			('1110', 'Leitmarkierung unterbrochen', '''Leitmarkierung'' ist ein auf der Fahrbahnoberfläche einer Straße angebrachtes Richtzeichen. Sie besteht in der Regel aus gleich langen Strichen mit regelmäßigen Abständen. Eine Leitlinie kann auch als Warnlinie ausgeführt werden; bei der Warnlinie sind die Striche länger als die Lücken.');

			CREATE TABLE ks_verkehrseinrichtung_verkehrszeichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_verkehrseinrichtung_verkehrszeichen IS 'Alias: "KS_Verkehrseinrichtung_Verkehrszeichen", UML-Typ: Enumeration';
			INSERT INTO ks_verkehrseinrichtung_verkehrszeichen (wert,beschreibung,dokumentation) VALUES
			('1400', 'Warnleuchte', ''),
			('1210', 'Parkscheinautomat', 'Ein ''Parkscheinautomat'' ist eine Einrichtung zur Überwachung der Parkzeit.'),
			('1199', 'sonstige Absperrung', ''),
			('1110', 'Barriere', ''),
			('1220', 'Parkuhr', 'Eine ''Parkuhr'' ist eine Einrichtung zur Überwachung der Parkzeit.'),
			('1100', 'Sperrpfahl, Poller', '''Sperrpfahl, Poller'' Ein Sperrpfahl ist ein starker Pfahl aus Holz, Metall oder auch Stein. Ein Poller ist kürzer und stärker als ein Sperrpfahl'),
			('1600', 'Leitplanke', '');

			CREATE TABLE ks_zusatzzeichen_verkehrszeichen (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_zusatzzeichen_verkehrszeichen IS 'Alias: "KS_Zusatzzeichen_Verkehrszeichen", UML-Typ: Enumeration';
			INSERT INTO ks_zusatzzeichen_verkehrszeichen (wert,beschreibung,dokumentation) VALUES
			('1110', 'Schwerbehinderte', '''Schwerbehinderte'' Ist ein Schild oder auf der Fahrbahnoberfläche einer Straße angebrachtes Verkehrszeichen.'),
			('1120', 'Kraftomnibus', '''Kraftomnibus frei'' Ist ein Schild oder auf der Fahrbahnoberfläche einer Straße angebrachtes Verkehrszeichen.');

			CREATE TABLE ks_art_einrichtungimbahnverkehr (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_art_einrichtungimbahnverkehr IS 'Alias: "KS_Art_EinrichtungImBahnverkehr", UML-Typ: Enumeration';
			INSERT INTO ks_art_einrichtungimbahnverkehr (wert,beschreibung,dokumentation) VALUES
			('1200', 'Bahn-Kilometerstein', ''),
			('1100', 'Gleisende, Prellbock', '''Gleisende, Prellbock'' ist der Abschluss eines Gleises einer Strecke für den Schienenverkehr. Ein Prellbock verhindert, dass ein Zug oder Waggon über das Schienenende hinausrollen kann.');

			CREATE TABLE ks_zustand_bauwerkimgewaesserbereich (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_zustand_bauwerkimgewaesserbereich IS 'Alias: "KS_Zustand_BauwerkImGewaesserbereich", UML-Typ: Enumeration';
			INSERT INTO ks_zustand_bauwerkimgewaesserbereich (wert,beschreibung,dokumentation) VALUES
			('4000', 'Im Bau', '''Im Bau'' bedeutet, dass ''Bauwerk im Gewässerbereich'' noch nicht fertiggestellt ist. ***** Objektartengruppe: Besondere kommunale Vegetationsmerkmale ***** Definition: Die Objektartengruppe mit der Bezeichnung ''Besondere kommunale Vegetationsmerkmale'' und der Kennung ''59300'' beschreibt den flächen-, linien- oder punktförmigen zusätzlichen Bewuchs einer Grundfläche. Die Objektartengruppe umfasst die Objektart Kennung Name 59301 ''Vegetationsmerkmal''. Kennung: 59300'),
			('2100', 'Außer Betrieb, stillgelegt, verlassen', '''Außer Betrieb, stillgelegt; verlassen'' bedeutet, dass sich ''Bauwerk im Gewässerbereich'' nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.');

			CREATE TABLE ks_zustand_vegetationsmerkmal (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_zustand_vegetationsmerkmal IS 'Alias: "KS_Zustand_Vegetationsmerkmal", UML-Typ: Enumeration';
			INSERT INTO ks_zustand_vegetationsmerkmal (wert,beschreibung,dokumentation) VALUES
			('1100', 'Nass', '''Nass'' bezeichnet eine Vegetationsfläche, die aufgrund besonderer Bodenbeschaffenheit ganzjährig wassergesättigt ist, zeitweise auch unter Wasser stehen kann, aus kommunaler Sicht.');

			CREATE TABLE ks_artderfestlegung_bauraumoderbauordnungsrecht (
			  wert integer,
			  beschreibung character varying,
			  dokumentation character varying,
			  PRIMARY KEY (wert)
			);

			COMMENT ON TABLE ks_artderfestlegung_bauraumoderbauordnungsrecht IS 'Alias: "KS_ArtDerFestlegung_BauRaumOderBauordnungsrecht", UML-Typ: Enumeration';
			INSERT INTO ks_artderfestlegung_bauraumoderbauordnungsrecht (wert,beschreibung,dokumentation) VALUES
			('1715', 'Bebauungsplan, einleitender Beschluss', ''),
			('1821', 'Gestaltungssatzung', '');
		END IF;

	END IF;

	IF ver<18 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 18';

		ALTER TABLE ax_punktortau RENAME processstep_description TO processstep_ax_datenerhebung_punktort;
		ALTER TABLE ax_punktortau RENAME herkunft_source_source_description TO herkunft_source_source_ax_datenerhebung_punktort;

		COMMENT ON COLUMN ax_punktortau.processstep_ax_datenerhebung_punktort IS 'qualitaetsangaben|AX_DQPunktort|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktortau.herkunft_source_source_ax_datenerhebung_punktort IS 'qualitaetsangaben|AX_DQPunktort|herkunft|LI_Lineage|source|LI_Source|description  CharacterString 0..1';

		ALTER TABLE ax_punktortag RENAME processstep_description TO processstep_ax_datenerhebung_punktort;
		ALTER TABLE ax_punktortag RENAME herkunft_source_source_description TO herkunft_source_source_ax_datenerhebung_punktort;

		COMMENT ON COLUMN ax_punktortag.processstep_ax_datenerhebung_punktort IS 'qualitaetsangaben|AX_DQPunktort|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktortag.herkunft_source_source_ax_datenerhebung_punktort IS 'qualitaetsangaben|AX_DQPunktort|herkunft|LI_Lineage|source|LI_Source|description  CharacterString 0..1';

		ALTER TABLE ax_punktortta RENAME processstep_description TO processstep_ax_datenerhebung_punktort;
		ALTER TABLE ax_punktortta RENAME herkunft_source_source_description TO herkunft_source_source_ax_datenerhebung_punktort;

		COMMENT ON COLUMN ax_punktortta.processstep_ax_datenerhebung_punktort IS 'qualitaetsangaben|AX_DQPunktort|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktortta.herkunft_source_source_ax_datenerhebung_punktort IS 'qualitaetsangaben|AX_DQPunktort|herkunft|LI_Lineage|source|LI_Source|description  CharacterString 0..1';

		UPDATE alkis_version SET version=18;
	END IF;

	IF ver<19 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 19';

		-- OpenData, NW, Märkischer Kreis/Kleve
		ALTER TABLE ax_markantergelaendepunkt ALTER ax_dqerfassungsmethodemarkantergelaendepunkt DROP NOT NULL;

		UPDATE alkis_version SET version=19;
	END IF;

	IF ver<100 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 100 (GID7)';

		DROP VIEW ax_klassifizierungsschluessel;
		DROP VIEW ax_klassifizierung;
		DROP VIEW alkis_wertearten;
		DROP VIEW v_bschaetz_entsteh_klima;
		DROP VIEW v_bschaetz_kulturart;
		DROP VIEW v_bschaetz_zustandsstufe;
		DROP VIEW v_muster_merkmal;

		ALTER TABLE aa_aktivitaet ADD quellobjektid character varying;
		ALTER TABLE aa_antrag ADD quellobjektid character varying;
		ALTER TABLE aa_antragsgebiet ADD quellobjektid character varying;
		ALTER TABLE aa_meilenstein ADD quellobjektid character varying;

		-- aa_projektsteuerung.parameterwert -> parameterwert: character varying => character varying[]

		ALTER TABLE aa_projektsteuerung ALTER parameterwert TYPE character varying[] USING CASE WHEN parameterwert IS NULL THEN NULL ELSE ARRAY[parameterwert] END;
		ALTER TABLE aa_projektsteuerung ADD quellobjektid character varying;
		ALTER TABLE aa_vorgang ADD quellobjektid character varying;
		ALTER TABLE ap_darstellung ADD quellobjektid character varying;
		ALTER TABLE ap_fpo ADD quellobjektid character varying;

		ALTER TABLE ap_kpo_3d ALTER dateityp SET NOT NULL;
		ALTER TABLE ap_kpo_3d DROP detailliert;
		ALTER TABLE ap_kpo_3d DROP generalisiert;
		ALTER TABLE ap_kpo_3d DROP levelofdetail;

		-- ap_kpo_3d.parameter -> parameter: double precision[] => character varying[]

		ALTER TABLE ap_kpo_3d RENAME parameter TO parameter_;
		ALTER TABLE ap_kpo_3d ADD parameter character varying[];
		UPDATE ap_kpo_3d SET parameter=ARRAY(SELECT unnest(parameter_)::text);
		ALTER TABLE ap_kpo_3d DROP parameter_;

		ALTER TABLE ap_kpo_3d ALTER referenzzumfremdobjekt SET NOT NULL;

		-- ap_kpo_3d.wkb_geometry -> wkb_geometry: geometry(Geometry,25832) => geometry(GeometryZ,25832)
		BEGIN
			ALTER TABLE ap_kpo_3d DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE ap_kpo_3d RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('ap_kpo_3d','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE ap_kpo_3d SET wkb_geometry=st_force3d(wkb_geometry_);
			ALTER TABLE ap_kpo_3d DROP wkb_geometry_;
			CREATE INDEX ap_kpo_3d_wkb_geometry_idx ON ap_kpo_3d USING gist(wkb_geometry);
		END;
		ALTER TABLE ap_kpo_3d ADD hatdirektunten character(16)[];
		ALTER TABLE ap_kpo_3d ADD istabgeleitetaus character(16)[];
		ALTER TABLE ap_kpo_3d ADD quellobjektid character varying;
		ALTER TABLE ap_kpo_3d ADD traegtbeizu character(16)[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ap_kpo_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ap_kpo_3d USING btree (detailliert)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ap_kpo_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ap_kpo_3d USING btree (generalisiert)';

		CREATE INDEX alkis_d6b7a61e_6156_4ba8_8156_60e222ebd41b ON ap_kpo_3d USING gin (hatdirektunten);

		CREATE INDEX alkis_342110d9_51cf_495d_8fc4_d1e9766c655f ON ap_kpo_3d USING gin (istabgeleitetaus);

		CREATE INDEX alkis_924cfe98_346b_404b_be60_abe877ba56b9 ON ap_kpo_3d USING gin (traegtbeizu);
		ALTER TABLE ap_lpo ADD quellobjektid character varying;
		ALTER TABLE ap_lto ADD quellobjektid character varying;
		ALTER TABLE ap_ppo ADD quellobjektid character varying;
		ALTER TABLE ap_pto ADD quellobjektid character varying;
		ALTER TABLE au_koerperobjekt_3d DROP detailliert;
		ALTER TABLE au_koerperobjekt_3d DROP generalisiert;
		ALTER TABLE au_koerperobjekt_3d DROP levelofdetail;

		-- au_koerperobjekt_3d.wkb_geometry -> wkb_geometry: geometry(Geometry,25832) => geometry(GeometryZ,25832)
		BEGIN
			ALTER TABLE au_koerperobjekt_3d DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE au_koerperobjekt_3d RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('au_koerperobjekt_3d','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE au_koerperobjekt_3d SET wkb_geometry=st_force3d(wkb_geometry_);
			ALTER TABLE au_koerperobjekt_3d DROP wkb_geometry_;
			CREATE INDEX au_koerperobjekt_3d_wkb_geometry_idx ON au_koerperobjekt_3d USING gist(wkb_geometry);
		END;
		ALTER TABLE au_koerperobjekt_3d ADD hatdirektunten character(16)[];
		ALTER TABLE au_koerperobjekt_3d ADD istabgeleitetaus character(16)[];
		ALTER TABLE au_koerperobjekt_3d ADD quellobjektid character varying;
		ALTER TABLE au_koerperobjekt_3d ADD traegtbeizu character(16)[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_koerperobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_koerperobjekt_3d USING btree (detailliert)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_koerperobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_koerperobjekt_3d USING btree (generalisiert)';

		CREATE INDEX alkis_b2a32041_99be_44be_8cdc_8fd8409a3d7c ON au_koerperobjekt_3d USING gin (hatdirektunten);

		CREATE INDEX alkis_78e416f4_4069_47b7_a2f4_5c8fd3265af4 ON au_koerperobjekt_3d USING gin (istabgeleitetaus);

		CREATE INDEX alkis_7790900a_79f6_4251_bfa2_761edaea12f9 ON au_koerperobjekt_3d USING gin (traegtbeizu);
		ALTER TABLE au_mehrfachlinienobjekt_3d DROP detailliert;
		ALTER TABLE au_mehrfachlinienobjekt_3d DROP generalisiert;
		ALTER TABLE au_mehrfachlinienobjekt_3d DROP levelofdetail;

		-- au_mehrfachlinienobjekt_3d.wkb_geometry -> wkb_geometry: geometry(Geometry,25832) => geometry(GeometryZ,25832)
		BEGIN
			ALTER TABLE au_mehrfachlinienobjekt_3d DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE au_mehrfachlinienobjekt_3d RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('au_mehrfachlinienobjekt_3d','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE au_mehrfachlinienobjekt_3d SET wkb_geometry=st_force3d(wkb_geometry_);
			ALTER TABLE au_mehrfachlinienobjekt_3d DROP wkb_geometry_;
			CREATE INDEX au_mehrfachlinienobjekt_3d_wkb_geometry_idx ON au_mehrfachlinienobjekt_3d USING gist(wkb_geometry);
		END;
		ALTER TABLE au_mehrfachlinienobjekt_3d ADD hatdirektunten character(16)[];
		ALTER TABLE au_mehrfachlinienobjekt_3d ADD istabgeleitetaus character(16)[];
		ALTER TABLE au_mehrfachlinienobjekt_3d ADD quellobjektid character varying;
		ALTER TABLE au_mehrfachlinienobjekt_3d ADD traegtbeizu character(16)[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_mehrfachlinienobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_mehrfachlinienobjekt_3d USING btree (detailliert)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_mehrfachlinienobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_mehrfachlinienobjekt_3d USING btree (generalisiert)';

		CREATE INDEX alkis_e652a830_9051_45ce_9898_61e60861c9d8 ON au_mehrfachlinienobjekt_3d USING gin (hatdirektunten);

		CREATE INDEX alkis_b4aab48f_af9a_486d_be45_fc6afd239658 ON au_mehrfachlinienobjekt_3d USING gin (istabgeleitetaus);

		CREATE INDEX alkis_37313be5_cf09_47ea_a903_b4dc1aa3c3cb ON au_mehrfachlinienobjekt_3d USING gin (traegtbeizu);
		ALTER TABLE au_punkthaufenobjekt_3d DROP detailliert;
		ALTER TABLE au_punkthaufenobjekt_3d DROP generalisiert;
		ALTER TABLE au_punkthaufenobjekt_3d DROP levelofdetail;

		-- au_punkthaufenobjekt_3d.wkb_geometry -> wkb_geometry: geometry(Geometry,25832) => geometry(GeometryZ,25832)
		BEGIN
			ALTER TABLE au_punkthaufenobjekt_3d DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE au_punkthaufenobjekt_3d RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('au_punkthaufenobjekt_3d','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE au_punkthaufenobjekt_3d SET wkb_geometry=st_force3d(wkb_geometry_);
			ALTER TABLE au_punkthaufenobjekt_3d DROP wkb_geometry_;
			CREATE INDEX au_punkthaufenobjekt_3d_wkb_geometry_idx ON au_punkthaufenobjekt_3d USING gist(wkb_geometry);
		END;
		ALTER TABLE au_punkthaufenobjekt_3d ADD hatdirektunten character(16)[];
		ALTER TABLE au_punkthaufenobjekt_3d ADD istabgeleitetaus character(16)[];
		ALTER TABLE au_punkthaufenobjekt_3d ADD quellobjektid character varying;
		ALTER TABLE au_punkthaufenobjekt_3d ADD traegtbeizu character(16)[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_punkthaufenobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_punkthaufenobjekt_3d USING btree (detailliert)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_punkthaufenobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_punkthaufenobjekt_3d USING btree (generalisiert)';

		CREATE INDEX alkis_36153ea9_e3e7_480a_9655_2e33df4968ac ON au_punkthaufenobjekt_3d USING gin (hatdirektunten);

		CREATE INDEX alkis_c23ebe80_c01a_4148_9d6e_56cca40019b5 ON au_punkthaufenobjekt_3d USING gin (istabgeleitetaus);

		CREATE INDEX alkis_3b941314_8677_430e_9a0e_5162a93c6d3a ON au_punkthaufenobjekt_3d USING gin (traegtbeizu);
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d DROP detailliert;
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d DROP generalisiert;
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d DROP levelofdetail;

		-- au_trianguliertesoberflaechenobjekt_3d.wkb_geometry -> wkb_geometry: geometry(Geometry,25832) => geometry(GeometryZ,25832)
		BEGIN
			ALTER TABLE au_trianguliertesoberflaechenobjekt_3d DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE au_trianguliertesoberflaechenobjekt_3d RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('au_trianguliertesoberflaechenobjekt_3d','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE au_trianguliertesoberflaechenobjekt_3d SET wkb_geometry=st_force3d(wkb_geometry_);
			ALTER TABLE au_trianguliertesoberflaechenobjekt_3d DROP wkb_geometry_;
			CREATE INDEX au_trianguliertesoberflaechenobjekt_3d_wkb_geometry_idx ON au_trianguliertesoberflaechenobjekt_3d USING gist(wkb_geometry);
		END;
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d ADD hatdirektunten character(16)[];
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d ADD istabgeleitetaus character(16)[];
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d ADD quellobjektid character varying;
		ALTER TABLE au_trianguliertesoberflaechenobjekt_3d ADD traegtbeizu character(16)[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_trianguliertesoberflaechenobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_trianguliertesoberflaechenobjekt_3d USING btree (detailliert)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_trianguliertesoberflaechenobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_trianguliertesoberflaechenobjekt_3d USING btree (generalisiert)';

		CREATE INDEX alkis_c9493b33_a294_4596_ae6e_f5773fec57fb ON au_trianguliertesoberflaechenobjekt_3d USING gin (hatdirektunten);

		CREATE INDEX alkis_382a224e_42a9_49b5_b8be_bfa0425f9668 ON au_trianguliertesoberflaechenobjekt_3d USING gin (istabgeleitetaus);

		CREATE INDEX alkis_8cb5c81f_8c54_4e3f_88f5_f6ac068879b0 ON au_trianguliertesoberflaechenobjekt_3d USING gin (traegtbeizu);
		ALTER TABLE au_umringobjekt_3d DROP detailliert;
		ALTER TABLE au_umringobjekt_3d DROP generalisiert;
		ALTER TABLE au_umringobjekt_3d DROP levelofdetail;

		-- au_umringobjekt_3d.wkb_geometry -> wkb_geometry: geometry(Geometry,25832) => geometry(GeometryZ,25832)
		BEGIN
			ALTER TABLE au_umringobjekt_3d DROP CONSTRAINT enforce_geotype_wkb_geometry;
		EXCEPTION WHEN OTHERS THEN
			ALTER TABLE au_umringobjekt_3d RENAME wkb_geometry TO wkb_geometry_;
			PERFORM AddGeometryColumn('au_umringobjekt_3d','wkb_geometry',find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'),'GEOMETRY',3);
			UPDATE au_umringobjekt_3d SET wkb_geometry=st_force3d(wkb_geometry_);
			ALTER TABLE au_umringobjekt_3d DROP wkb_geometry_;
			CREATE INDEX au_umringobjekt_3d_wkb_geometry_idx ON au_umringobjekt_3d USING gist(wkb_geometry);
		END;
		ALTER TABLE au_umringobjekt_3d ADD hatdirektunten character(16)[];
		ALTER TABLE au_umringobjekt_3d ADD istabgeleitetaus character(16)[];
		ALTER TABLE au_umringobjekt_3d ADD quellobjektid character varying;
		ALTER TABLE au_umringobjekt_3d ADD traegtbeizu character(16)[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_umringobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_umringobjekt_3d USING btree (detailliert)';
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='au_umringobjekt_3d' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON au_umringobjekt_3d USING btree (generalisiert)';

		CREATE INDEX alkis_ce2dc276_1f5e_4781_88f0_1240fa00b6fe ON au_umringobjekt_3d USING gin (hatdirektunten);

		CREATE INDEX alkis_e62b483c_ab1b_4889_bb59_a8671c9a94a1 ON au_umringobjekt_3d USING gin (istabgeleitetaus);

		CREATE INDEX alkis_66fc5c78_98f5_4f15_be2f_d86146d8c6db ON au_umringobjekt_3d USING gin (traegtbeizu);
		ALTER TABLE ax_abgeleitetehoehenlinie DROP aktualitaetsstand;
		ALTER TABLE ax_abgeleitetehoehenlinie DROP berechnungsdatum;
		ALTER TABLE ax_abgeleitetehoehenlinie DROP berechnungsmethodehoehenlinie;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD aktualisierungsdatum date;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD datetime character(20)[];
		ALTER TABLE ax_abgeleitetehoehenlinie ADD erfassungsdatum date NOT NULL;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD evaluationmethoddescription character varying;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD evaluationmethodtype character varying;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD evaluationprocedure character varying;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD massstabszahl integer NOT NULL;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD measuredescription character varying;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD measureidentification character varying;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD nameofmeasure character varying[];
		ALTER TABLE ax_abgeleitetehoehenlinie ADD quellobjektid character varying;
		ALTER TABLE ax_abgeleitetehoehenlinie ADD result character varying[];
		ALTER TABLE ax_abschnitt ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_abschnitt ADD hat3d character(16)[];
		ALTER TABLE ax_abschnitt ADD quellobjektid character varying;

		CREATE INDEX alkis_f6e012ce_85b9_4fa7_b943_543ae79e7144 ON ax_abschnitt USING gin (hat3d);
		ALTER TABLE ax_anderefestlegungnachstrassenrecht ADD quellobjektid character varying;
		ALTER TABLE ax_anderefestlegungnachwasserrecht ADD quellobjektid character varying;
		ALTER TABLE ax_anschrift ADD quellobjektid character varying;
		ALTER TABLE ax_ast ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_ast ADD hat3d character(16)[];
		ALTER TABLE ax_ast ADD quellobjektid character varying;

		CREATE INDEX alkis_5abd68a6_e0b1_425a_a253_da4e9999e1bf ON ax_ast USING gin (hat3d);
		ALTER TABLE ax_aufnahmepunkt ADD quellobjektid character varying;

		-- ax_bahnstrecke.spurweite -> spurweite: integer => integer[]

		ALTER TABLE ax_bahnstrecke ALTER spurweite TYPE integer[] USING CASE WHEN spurweite IS NULL THEN NULL ELSE ARRAY[spurweite] END;

		-- ax_bahnstrecke.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_bahnstrecke ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_bahnstrecke ADD nummerderlinie character varying[];
		ALTER TABLE ax_bahnstrecke ADD quellobjektid character varying;
		ALTER TABLE ax_bahnstrecke ADD verkehrsdienst integer;
		ALTER TABLE ax_bahnverkehr ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bahnverkehr ADD istweiterenutzung integer;
		ALTER TABLE ax_bahnverkehr ADD quellobjektid character varying;
		ALTER TABLE ax_bahnverkehrsanlage ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bahnverkehrsanlage ADD hat3d character(16)[];
		ALTER TABLE ax_bahnverkehrsanlage ADD quellobjektid character varying;
		ALTER TABLE ax_bahnverkehrsanlage ADD verkehrsdienst integer;

		CREATE INDEX alkis_2b51bd36_d39f_4d67_892f_cc7bc3c5fb2b ON ax_bahnverkehrsanlage USING gin (hat3d);
		ALTER TABLE ax_baublock ADD quellobjektid character varying;
		ALTER TABLE ax_bauraumoderbodenordnungsrecht ADD quellobjektid character varying;
		ALTER TABLE ax_bauteil ADD anzahlderunterirdischengeschosse integer;
		ALTER TABLE ax_bauteil ADD dachart character varying;
		ALTER TABLE ax_bauteil ADD hat character(16)[];
		ALTER TABLE ax_bauteil ADD herkunft_source_source_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauteil ADD herkunft_source_source_scaledenominator character varying[];
		ALTER TABLE ax_bauteil ADD herkunft_source_source_sourceextent character varying[];
		ALTER TABLE ax_bauteil ADD herkunft_source_source_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauteil ADD herkunft_source_source_sourcestep character varying[];
		ALTER TABLE ax_bauteil ADD hoehe double precision[];
		ALTER TABLE ax_bauteil ADD obererbezugspunkt integer[];
		ALTER TABLE ax_bauteil ADD processstep_address character varying[];
		ALTER TABLE ax_bauteil ADD processstep_ax_datenerhebung character varying[];
		ALTER TABLE ax_bauteil ADD processstep_ax_li_processstep_mitdatenerhebung_description character varying[];
		ALTER TABLE ax_bauteil ADD processstep_contactinstructions character varying[];
		ALTER TABLE ax_bauteil ADD processstep_datetime character(20)[];
		ALTER TABLE ax_bauteil ADD processstep_hoursofservice character varying[];
		ALTER TABLE ax_bauteil ADD processstep_individualname character varying[];
		ALTER TABLE ax_bauteil ADD processstep_onlineresource character varying[];
		ALTER TABLE ax_bauteil ADD processstep_organisationname character varying[];
		ALTER TABLE ax_bauteil ADD processstep_phone character varying[];
		ALTER TABLE ax_bauteil ADD processstep_positionname character varying[];
		ALTER TABLE ax_bauteil ADD processstep_rationale character varying[];
		ALTER TABLE ax_bauteil ADD processstep_role character varying[];
		ALTER TABLE ax_bauteil ADD processstep_scaledenominator character varying[];
		ALTER TABLE ax_bauteil ADD processstep_sourceextent character varying[];
		ALTER TABLE ax_bauteil ADD processstep_sourcereferencesystem character varying[];
		ALTER TABLE ax_bauteil ADD processstep_sourcestep character varying[];
		ALTER TABLE ax_bauteil ADD quellobjektid character varying;
		ALTER TABLE ax_bauteil ADD statement character varying;
		ALTER TABLE ax_bauteil ADD umbauterraum double precision;
		ALTER TABLE ax_bauteil ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_3c25d20d_aedf_42cf_8bdf_0170a19c42c0 ON ax_bauteil USING gin (hat);
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD hat3d character(16)[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD hoehe double precision[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD obererbezugspunkt integer[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD quellobjektid character varying;
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD regionalsprache character varying[];
		ALTER TABLE ax_bauwerkimgewaesserbereich ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_98fd6e12_1577_4113_986c_0d782f9b85ed ON ax_bauwerkimgewaesserbereich USING gin (hat3d);
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD hat3d character(16)[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD hoehe double precision[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD obererbezugspunkt integer[];
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD quellobjektid character varying;
		ALTER TABLE ax_bauwerkimverkehrsbereich ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_08e00bcf_171c_4e07_96dc_f34523e0817b ON ax_bauwerkimverkehrsbereich USING gin (hat3d);
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe DROP objekthoehe;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD hat3d character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD hoehe double precision[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD obererbezugspunkt integer[];
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD quellobjektid character varying;
		ALTER TABLE ax_bauwerkoderanlagefuerindustrieundgewerbe ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_b2274f31_b02d_4cea_b379_0b67ef9b6b95 ON ax_bauwerkoderanlagefuerindustrieundgewerbe USING gin (hat3d);

		-- ax_bauwerkoderanlagefuersportfreizeitunderholung.sportart -> sportart: integer => integer[]

		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ALTER sportart TYPE integer[] USING CASE WHEN sportart IS NULL THEN NULL ELSE ARRAY[sportart] END;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD hat3d character(16)[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD hoehe double precision[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD obererbezugspunkt integer[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD quellobjektid character varying;
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD untererbezugspunkt integer[];
		ALTER TABLE ax_bauwerkoderanlagefuersportfreizeitunderholung ADD zustand integer;

		CREATE INDEX alkis_1a3a5b27_06c5_4210_9f25_537173a1b6ea ON ax_bauwerkoderanlagefuersportfreizeitunderholung USING gin (hat3d);
		ALTER TABLE ax_benutzer ADD quellobjektid character varying;
		ALTER TABLE ax_benutzergruppemitzugriffskontrolle ADD quellobjektid character varying;
		ALTER TABLE ax_benutzergruppenba ADD abgabeversion character varying NOT NULL;
		ALTER TABLE ax_benutzergruppenba ADD quellobjektid character varying;
		ALTER TABLE ax_bergbaubetrieb ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_bergbaubetrieb ADD funktion integer;
		ALTER TABLE ax_bergbaubetrieb ADD istweiterenutzung integer;
		ALTER TABLE ax_bergbaubetrieb ADD quellobjektid character varying;
		ALTER TABLE ax_besondereflurstuecksgrenze ADD quellobjektid character varying;
		ALTER TABLE ax_besonderegebaeudelinie ADD quellobjektid character varying;
		ALTER TABLE ax_besondererbauwerkspunkt ADD art integer;
		ALTER TABLE ax_besondererbauwerkspunkt ADD hoehe double precision[];
		ALTER TABLE ax_besondererbauwerkspunkt ADD obererbezugspunkt integer[];
		ALTER TABLE ax_besondererbauwerkspunkt ADD quellobjektid character varying;
		ALTER TABLE ax_besondererbauwerkspunkt ADD untererbezugspunkt integer[];
		ALTER TABLE ax_besonderergebaeudepunkt ADD hoehe double precision[];
		ALTER TABLE ax_besonderergebaeudepunkt ADD obererbezugspunkt integer[];
		ALTER TABLE ax_besonderergebaeudepunkt ADD quellobjektid character varying;
		ALTER TABLE ax_besonderergebaeudepunkt ADD untererbezugspunkt integer[];
		ALTER TABLE ax_besonderertopographischerpunkt ADD quellobjektid character varying;
		ALTER TABLE ax_bewertung DROP herkunft_source_source_ax_datenerhebung;
		ALTER TABLE ax_bewertung DROP herkunft_source_source_scaledenominator;
		ALTER TABLE ax_bewertung DROP herkunft_source_source_sourceextent;
		ALTER TABLE ax_bewertung DROP herkunft_source_source_sourcereferencesystem;
		ALTER TABLE ax_bewertung DROP herkunft_source_source_sourcestep;
		ALTER TABLE ax_bewertung DROP processstep_address;
		ALTER TABLE ax_bewertung DROP processstep_ax_datenerhebung;
		ALTER TABLE ax_bewertung DROP processstep_ax_li_processstep_mitdatenerhebung_description;
		ALTER TABLE ax_bewertung DROP processstep_contactinstructions;
		ALTER TABLE ax_bewertung DROP processstep_datetime;
		ALTER TABLE ax_bewertung DROP processstep_hoursofservice;
		ALTER TABLE ax_bewertung DROP processstep_individualname;
		ALTER TABLE ax_bewertung DROP processstep_onlineresource;
		ALTER TABLE ax_bewertung DROP processstep_organisationname;
		ALTER TABLE ax_bewertung DROP processstep_phone;
		ALTER TABLE ax_bewertung DROP processstep_positionname;
		ALTER TABLE ax_bewertung DROP processstep_rationale;
		ALTER TABLE ax_bewertung DROP processstep_role;
		ALTER TABLE ax_bewertung DROP processstep_scaledenominator;
		ALTER TABLE ax_bewertung DROP processstep_sourceextent;
		ALTER TABLE ax_bewertung DROP processstep_sourcereferencesystem;
		ALTER TABLE ax_bewertung DROP processstep_sourcestep;
		ALTER TABLE ax_bewertung DROP statement;
		ALTER TABLE ax_bewertung ADD quellobjektid character varying;
		ALTER TABLE ax_bodenschaetzung DROP entstehungsartoderklimastufewasserverhaeltnisse;
		ALTER TABLE ax_bodenschaetzung DROP herkunft_source_source_ax_datenerhebung;
		ALTER TABLE ax_bodenschaetzung DROP herkunft_source_source_scaledenominator;
		ALTER TABLE ax_bodenschaetzung DROP herkunft_source_source_sourceextent;
		ALTER TABLE ax_bodenschaetzung DROP herkunft_source_source_sourcereferencesystem;
		ALTER TABLE ax_bodenschaetzung DROP herkunft_source_source_sourcestep;
		ALTER TABLE ax_bodenschaetzung DROP kulturart;
		ALTER TABLE ax_bodenschaetzung DROP processstep_address;
		ALTER TABLE ax_bodenschaetzung DROP processstep_ax_datenerhebung;
		ALTER TABLE ax_bodenschaetzung DROP processstep_ax_li_processstep_mitdatenerhebung_description;
		ALTER TABLE ax_bodenschaetzung DROP processstep_contactinstructions;
		ALTER TABLE ax_bodenschaetzung DROP processstep_datetime;
		ALTER TABLE ax_bodenschaetzung DROP processstep_hoursofservice;
		ALTER TABLE ax_bodenschaetzung DROP processstep_individualname;
		ALTER TABLE ax_bodenschaetzung DROP processstep_onlineresource;
		ALTER TABLE ax_bodenschaetzung DROP processstep_organisationname;
		ALTER TABLE ax_bodenschaetzung DROP processstep_phone;
		ALTER TABLE ax_bodenschaetzung DROP processstep_positionname;
		ALTER TABLE ax_bodenschaetzung DROP processstep_rationale;
		ALTER TABLE ax_bodenschaetzung DROP processstep_role;
		ALTER TABLE ax_bodenschaetzung DROP processstep_scaledenominator;
		ALTER TABLE ax_bodenschaetzung DROP processstep_sourceextent;
		ALTER TABLE ax_bodenschaetzung DROP processstep_sourcereferencesystem;
		ALTER TABLE ax_bodenschaetzung DROP processstep_sourcestep;
		ALTER TABLE ax_bodenschaetzung DROP statement;
		ALTER TABLE ax_bodenschaetzung DROP zustandsstufeoderbodenstufe;
		ALTER TABLE ax_bodenschaetzung ADD bodenstufe integer;
		ALTER TABLE ax_bodenschaetzung ADD entstehungsart integer[];
		ALTER TABLE ax_bodenschaetzung ADD klimastufe integer;
		ALTER TABLE ax_bodenschaetzung ADD nutzungsart integer NOT NULL;
		ALTER TABLE ax_bodenschaetzung ADD quellobjektid character varying;
		ALTER TABLE ax_bodenschaetzung ADD wasserverhaeltnisse integer;
		ALTER TABLE ax_bodenschaetzung ADD wirdbeschrieben character(16)[];
		ALTER TABLE ax_bodenschaetzung ADD zustandsstufe integer;

		CREATE INDEX alkis_52e4b2b3_296f_4bb7_b9a7_08b96d035ff4 ON ax_bodenschaetzung USING gin (wirdbeschrieben);
		ALTER TABLE ax_boeschungkliff ADD quellobjektid character varying;
		ALTER TABLE ax_boeschungsflaeche ADD quellobjektid character varying;
		ALTER TABLE ax_buchungsblatt ADD quellobjektid character varying;
		ALTER TABLE ax_buchungsblattbezirk ADD einwohnerzahl integer;
		ALTER TABLE ax_buchungsblattbezirk ADD historisch character varying;
		ALTER TABLE ax_buchungsblattbezirk ADD quellobjektid character varying;
		ALTER TABLE ax_buchungsblattbezirk ADD regionalsprache character varying[];

		-- ax_buchungsstelle.wirdverwaltetvon -> wirdverwaltetvon: character(16) => character(16)[]

		ALTER TABLE ax_buchungsstelle ALTER wirdverwaltetvon TYPE character(16)[] USING CASE WHEN wirdverwaltetvon IS NULL THEN NULL ELSE ARRAY[wirdverwaltetvon] END;
		ALTER TABLE ax_buchungsstelle ADD eingangdeseintragungsantrags date;
		ALTER TABLE ax_buchungsstelle ADD quellobjektid character varying;
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_buchungsstelle' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_buchungsstelle USING btree (wirdverwaltetvon)';

		CREATE INDEX alkis_8e02a148_7e37_4425_9429_123327cd3997 ON ax_buchungsstelle USING gin (wirdverwaltetvon);
		ALTER TABLE ax_bundesland ADD einwohnerzahl integer;
		ALTER TABLE ax_bundesland ADD historisch character varying;
		ALTER TABLE ax_bundesland ADD quellobjektid character varying;
		ALTER TABLE ax_bundesland ADD regionalsprache character varying[];
		ALTER TABLE ax_dammwalldeich ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_dammwalldeich ADD quellobjektid character varying;
		ALTER TABLE ax_denkmalschutzrecht ADD quellobjektid character varying;
		ALTER TABLE ax_dienststelle ADD einwohnerzahl integer;
		ALTER TABLE ax_dienststelle ADD historisch character varying;
		ALTER TABLE ax_dienststelle ADD quellobjektid character varying;
		ALTER TABLE ax_dienststelle ADD regionalsprache character varying[];
		ALTER TABLE ax_duene ADD quellobjektid character varying;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD hat3d character(16)[];
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD quellobjektid character varying;
		ALTER TABLE ax_einrichtungenfuerdenschiffsverkehr ADD zustand integer;

		CREATE INDEX alkis_0a925fab_2c89_4de8_85dc_349191bbf5ad ON ax_einrichtungenfuerdenschiffsverkehr USING gin (hat3d);
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD hat3d character(16)[];
		ALTER TABLE ax_einrichtunginoeffentlichenbereichen ADD quellobjektid character varying;

		CREATE INDEX alkis_bb0cb7d2_6d48_4654_b78c_efa5db1aa526 ON ax_einrichtunginoeffentlichenbereichen USING gin (hat3d);
		ALTER TABLE ax_einschnitt ADD quellobjektid character varying;
		ALTER TABLE ax_fahrbahnachse ADD fahrtrichtung character varying;
		ALTER TABLE ax_fahrbahnachse ADD quellobjektid character varying;

		-- ax_fahrwegachse.markierung -> markierung: integer => integer[]

		ALTER TABLE ax_fahrwegachse ALTER markierung TYPE integer[] USING CASE WHEN markierung IS NULL THEN NULL ELSE ARRAY[markierung] END;

		-- ax_fahrwegachse.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_fahrwegachse ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_fahrwegachse ADD befahrbarkeit integer;
		ALTER TABLE ax_fahrwegachse ADD fahrtrichtung character varying;
		ALTER TABLE ax_fahrwegachse ADD quellobjektid character varying;
		ALTER TABLE ax_fahrwegachse ADD regionalsprache character varying[];
		ALTER TABLE ax_felsenfelsblockfelsnadel ADD quellobjektid character varying;
		ALTER TABLE ax_firstlinie ADD quellobjektid character varying;
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD istweiterenutzung integer;
		ALTER TABLE ax_flaechebesondererfunktionalerpraegung ADD quellobjektid character varying;
		ALTER TABLE ax_flaechegemischternutzung ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_flaechegemischternutzung ADD istweiterenutzung integer;
		ALTER TABLE ax_flaechegemischternutzung ADD quellobjektid character varying;
		ALTER TABLE ax_fliessgewaesser ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_fliessgewaesser ADD istweiterenutzung integer;
		ALTER TABLE ax_fliessgewaesser ADD quellobjektid character varying;
		ALTER TABLE ax_flugverkehr ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_flugverkehr ADD istweiterenutzung integer;
		ALTER TABLE ax_flugverkehr ADD quellobjektid character varying;
		ALTER TABLE ax_flugverkehr ADD zweitname character varying[];
		ALTER TABLE ax_flugverkehrsanlage ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_flugverkehrsanlage ADD hat3d character(16)[];
		ALTER TABLE ax_flugverkehrsanlage ADD quellobjektid character varying;
		ALTER TABLE ax_flugverkehrsanlage ADD zustand integer;
		ALTER TABLE ax_flugverkehrsanlage ADD zweitname character varying[];

		CREATE INDEX alkis_cabe92ed_87d2_4c8f_91f2_30f7fd829632 ON ax_flugverkehrsanlage USING gin (hat3d);

		ALTER TABLE ax_flurstueck ALTER gemeindezugehoerigkeit_gemeinde SET NOT NULL;

		ALTER TABLE ax_flurstueck ALTER gemeindezugehoerigkeit_kreis SET NOT NULL;

		ALTER TABLE ax_flurstueck ALTER gemeindezugehoerigkeit_land SET NOT NULL;

		ALTER TABLE ax_flurstueck ALTER istgebucht SET NOT NULL;
		ALTER TABLE ax_flurstueck ADD quellobjektid character varying;
		ALTER TABLE ax_forstrecht ADD quellobjektid character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD quellobjektid character varying;
		ALTER TABLE ax_fortfuehrungsfall ADD verweistauf_zusatzartderausgabe character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD quellobjektid character varying;
		ALTER TABLE ax_fortfuehrungsnachweisdeckblatt ADD zusatzartderausgabe character varying;
		ALTER TABLE ax_friedhof ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_friedhof ADD istweiterenutzung integer;
		ALTER TABLE ax_friedhof ADD quellobjektid character varying;

		-- ax_funktion_polder.wert -> wert: character varying => integer

		ALTER TABLE ax_funktion_polder ALTER wert TYPE integer USING wert::int;

		-- ax_gebaeude.gehoertzu -> gehoertzu: character(16) => character(16)[]

		ALTER TABLE ax_gebaeude ALTER gehoertzu TYPE character(16)[] USING CASE WHEN gehoertzu IS NULL THEN NULL ELSE ARRAY[gehoertzu] END;
		ALTER TABLE ax_gebaeude DROP objekthoehe;
		ALTER TABLE ax_gebaeude ADD bestehtaus character(16)[];
		ALTER TABLE ax_gebaeude ADD hoehe double precision[];
		ALTER TABLE ax_gebaeude ADD obererbezugspunkt integer[];
		ALTER TABLE ax_gebaeude ADD quellobjektid character varying;
		ALTER TABLE ax_gebaeude ADD regionalsprache character varying[];
		ALTER TABLE ax_gebaeude ADD untererbezugspunkt integer[];
		ALTER TABLE ax_gebaeude ADD zeigtaufohne character(16);
		ALTER TABLE ax_gebaeude ADD zweitname character varying[];
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_gebaeude' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_gebaeude USING btree (gehoertzu)';

		CREATE INDEX alkis_08d9709c_c415_4861_9df3_8b2c0b71b07a ON ax_gebaeude USING btree (zeigtaufohne);

		CREATE INDEX alkis_5f3ba7ac_403b_4cb7_83db_b5fbe1b5cde6 ON ax_gebaeude USING gin (bestehtaus);

		CREATE INDEX alkis_debd37f6_1285_45b7_9cbd_5aeaeb6af309 ON ax_gebaeude USING gin (gehoertzu);
		ALTER TABLE ax_gebaeudeausgestaltung ADD quellobjektid character varying;
		ALTER TABLE ax_gebiet_bundesland ADD quellobjektid character varying;
		ALTER TABLE ax_gebiet_kreis ADD quellobjektid character varying;
		ALTER TABLE ax_gebiet_nationalstaat ADD quellobjektid character varying;
		ALTER TABLE ax_gebiet_regierungsbezirk ADD quellobjektid character varying;
		ALTER TABLE ax_gebiet_verwaltungsgemeinschaft ADD quellobjektid character varying;
		ALTER TABLE ax_gebietsgrenze ADD quellobjektid character varying;
		ALTER TABLE ax_gebietsgrenze ADD zustand integer;
		ALTER TABLE ax_gehoelz ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_gehoelz ADD istweiterenutzung integer;
		ALTER TABLE ax_gehoelz ADD quellobjektid character varying;
		ALTER TABLE ax_gemarkung ADD einwohnerzahl integer;
		ALTER TABLE ax_gemarkung ADD gemeindezugehoerigkeit_gemeinde character varying[];
		ALTER TABLE ax_gemarkung ADD gemeindezugehoerigkeit_gemeindeteil character varying[];
		ALTER TABLE ax_gemarkung ADD gemeindezugehoerigkeit_kreis character varying[];
		ALTER TABLE ax_gemarkung ADD gemeindezugehoerigkeit_land character varying[];
		ALTER TABLE ax_gemarkung ADD gemeindezugehoerigkeit_regierungsbezirk character varying[];
		ALTER TABLE ax_gemarkung ADD historisch character varying;
		ALTER TABLE ax_gemarkung ADD quellobjektid character varying;
		ALTER TABLE ax_gemarkung ADD regionalsprache character varying[];
		ALTER TABLE ax_gemarkungsteilflur ADD einwohnerzahl integer;
		ALTER TABLE ax_gemarkungsteilflur ADD historisch character varying;
		ALTER TABLE ax_gemarkungsteilflur ADD quellobjektid character varying;
		ALTER TABLE ax_gemarkungsteilflur ADD regionalsprache character varying[];
		ALTER TABLE ax_gemeinde ADD einwohnerzahl integer;
		ALTER TABLE ax_gemeinde ADD historisch character varying;
		ALTER TABLE ax_gemeinde ADD quellobjektid character varying;
		ALTER TABLE ax_gemeinde ADD regionalsprache character varying[];
		ALTER TABLE ax_gemeinde ADD rolle integer[];
		ALTER TABLE ax_gemeinde ADD schluessel_kreis character varying[];
		ALTER TABLE ax_gemeinde ADD schluessel_land character varying[];
		ALTER TABLE ax_gemeinde ADD schluessel_regierungsbezirk character varying[];
		ALTER TABLE ax_gemeinde ADD schluessel_verwaltungsgemeinschaft character varying[];
		ALTER TABLE ax_gemeindeteil ADD einwohnerzahl integer;
		ALTER TABLE ax_gemeindeteil ADD historisch character varying;
		ALTER TABLE ax_gemeindeteil ADD quellobjektid character varying;
		ALTER TABLE ax_gemeindeteil ADD regionalsprache character varying[];
		ALTER TABLE ax_georeferenziertegebaeudeadresse DROP datensatznummer;
		ALTER TABLE ax_georeferenziertegebaeudeadresse DROP hatauch;

		ALTER TABLE ax_georeferenziertegebaeudeadresse ALTER hausnummer DROP NOT NULL;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD ortsteilpost character varying;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD quellobjektid character varying;
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD verweistauf character(16);
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD weistauf character(16);
		ALTER TABLE ax_georeferenziertegebaeudeadresse ADD zeigtauf character(16);
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_georeferenziertegebaeudeadresse' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_georeferenziertegebaeudeadresse USING btree (hatauch)';

		CREATE INDEX alkis_b42e4444_55df_473e_be1e_2fa165c1eb32 ON ax_georeferenziertegebaeudeadresse USING btree (verweistauf);

		CREATE INDEX alkis_56c415c1_a1a3_426f_ba94_4efe3ef02da0 ON ax_georeferenziertegebaeudeadresse USING btree (weistauf);

		CREATE INDEX alkis_42670524_c047_480e_9112_e0a7e37607c0 ON ax_georeferenziertegebaeudeadresse USING btree (zeigtauf);

		ALTER TABLE ax_gewaesserachse ALTER breitedesgewaessers SET NOT NULL;
		ALTER TABLE ax_gewaesserachse ADD quellobjektid character varying;
		ALTER TABLE ax_gewaessermerkmal ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_gewaessermerkmal ADD hat3d character(16)[];
		ALTER TABLE ax_gewaessermerkmal ADD quellobjektid character varying;
		ALTER TABLE ax_gewaessermerkmal ADD regionalsprache character varying[];
		ALTER TABLE ax_gewaessermerkmal ADD zweitname character varying[];

		CREATE INDEX alkis_117136ba_ba5a_43ce_b418_56c3e689bbb0 ON ax_gewaessermerkmal USING gin (hat3d);
		ALTER TABLE ax_gewaesserstationierungsachse DROP artdergewaesserachse;

		-- ax_gewaesserstationierungsachse.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_gewaesserstationierungsachse ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_gewaesserstationierungsachse ADD artdergewaesserstationierungsachse integer;
		ALTER TABLE ax_gewaesserstationierungsachse ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_gewaesserstationierungsachse ADD hat3d character(16)[];
		ALTER TABLE ax_gewaesserstationierungsachse ADD quellobjektid character varying;
		ALTER TABLE ax_gewaesserstationierungsachse ADD regionalsprache character varying[];
		ALTER TABLE ax_gewaesserstationierungsachse ADD schifffahrtskategorie integer;

		CREATE INDEX alkis_1f8f3589_f15b_4630_abb4_2677a9d9e3e4 ON ax_gewaesserstationierungsachse USING gin (hat3d);
		ALTER TABLE ax_gewann ADD quellobjektid character varying;
		ALTER TABLE ax_gleis ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_gleis ADD hat3d character(16)[];
		ALTER TABLE ax_gleis ADD quellobjektid character varying;

		CREATE INDEX alkis_38f6f3d6_7eb0_4c8b_abe3_f16e84aa7070 ON ax_gleis USING gin (hat3d);
		ALTER TABLE ax_grablochderbodenschaetzung DROP bodenzahlodergruenlandgrundzahl;
		ALTER TABLE ax_grablochderbodenschaetzung DROP herkunft_source_source_ax_datenerhebung;
		ALTER TABLE ax_grablochderbodenschaetzung DROP herkunft_source_source_scaledenominator;
		ALTER TABLE ax_grablochderbodenschaetzung DROP herkunft_source_source_sourceextent;
		ALTER TABLE ax_grablochderbodenschaetzung DROP herkunft_source_source_sourcereferencesystem;
		ALTER TABLE ax_grablochderbodenschaetzung DROP herkunft_source_source_sourcestep;
		ALTER TABLE ax_grablochderbodenschaetzung DROP kennziffer_gemarkungsnummer;
		ALTER TABLE ax_grablochderbodenschaetzung DROP kennziffer_land;
		ALTER TABLE ax_grablochderbodenschaetzung DROP kennziffer_nummerierungsbezirk;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_address;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_ax_datenerhebung;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_ax_li_processstep_mitdatenerhebung_description;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_contactinstructions;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_datetime;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_hoursofservice;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_individualname;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_onlineresource;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_organisationname;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_phone;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_positionname;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_rationale;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_role;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_scaledenominator;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_sourceextent;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_sourcereferencesystem;
		ALTER TABLE ax_grablochderbodenschaetzung DROP processstep_sourcestep;
		ALTER TABLE ax_grablochderbodenschaetzung DROP statement;
		ALTER TABLE ax_grablochderbodenschaetzung ADD beschreibt character(16)[];
		ALTER TABLE ax_grablochderbodenschaetzung ADD bestimmt character(16);
		ALTER TABLE ax_grablochderbodenschaetzung ADD bodenzahlodergruenlandgrundzahlgrabloch character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD folgenummer integer;
		ALTER TABLE ax_grablochderbodenschaetzung ADD gemarkungsnummer character varying NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ADD kennungderflaeche character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD kennungdesgrablochs character varying NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ADD kennzeichen character varying NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ADD land character varying NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ADD nummerderflaeche character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD nummerderteilflaeche character varying;
		ALTER TABLE ax_grablochderbodenschaetzung ADD nummerdesordnungsmerkmals character varying NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ADD ordnungsmerkmaldesgrablochs character varying NOT NULL;
		ALTER TABLE ax_grablochderbodenschaetzung ADD quellobjektid character varying;

		CREATE INDEX alkis_eb0ce1bf_1fa6_4204_97e6_3ba0dc0b839e ON ax_grablochderbodenschaetzung USING btree (bestimmt);

		CREATE INDEX alkis_86270598_fe06_4e07_a574_3b1e5ab2edc3 ON ax_grablochderbodenschaetzung USING gin (beschreibt);
		ALTER TABLE ax_grenzpunkt ADD quellobjektid character varying;
		ALTER TABLE ax_grenzuebergang ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_grenzuebergang ADD hat3d character(16)[];
		ALTER TABLE ax_grenzuebergang ADD quellobjektid character varying;

		CREATE INDEX alkis_07f157c0_2ab8_473e_a2fa_dbbebc01e122 ON ax_grenzuebergang USING gin (hat3d);
		ALTER TABLE ax_hafen ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_hafen ADD hat3d character(16)[];
		ALTER TABLE ax_hafen ADD quellobjektid character varying;

		CREATE INDEX alkis_e62382e8_194d_4a3b_8153_ad053ba918c7 ON ax_hafen USING gin (hat3d);
		ALTER TABLE ax_hafenbecken ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_hafenbecken ADD istweiterenutzung integer;
		ALTER TABLE ax_hafenbecken ADD quellobjektid character varying;
		ALTER TABLE ax_hafenbecken ADD seekennzahl character varying;
		ALTER TABLE ax_halde ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_halde ADD istweiterenutzung integer;
		ALTER TABLE ax_halde ADD quellobjektid character varying;
		ALTER TABLE ax_heide ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_heide ADD istweiterenutzung integer;
		ALTER TABLE ax_heide ADD quellobjektid character varying;
		ALTER TABLE ax_heilquellegasquelle ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_heilquellegasquelle ADD hat3d character(16)[];
		ALTER TABLE ax_heilquellegasquelle ADD quellobjektid character varying;

		CREATE INDEX alkis_e709ba0d_74e2_49ea_8f54_abe879127637 ON ax_heilquellegasquelle USING gin (hat3d);
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD hat3d character(16)[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD hoehe double precision[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD obererbezugspunkt integer[];
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD quellobjektid character varying;
		ALTER TABLE ax_historischesbauwerkoderhistorischeeinrichtung ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_3b5d7047_7010_47b2_888d_575440af6c4f ON ax_historischesbauwerkoderhistorischeeinrichtung USING gin (hat3d);

		ALTER TABLE ax_historischesflurstueck ALTER gemeindezugehoerigkeit_gemeinde SET NOT NULL;

		ALTER TABLE ax_historischesflurstueck ALTER gemeindezugehoerigkeit_kreis SET NOT NULL;

		ALTER TABLE ax_historischesflurstueck ALTER gemeindezugehoerigkeit_land SET NOT NULL;
		ALTER TABLE ax_historischesflurstueck ADD quellobjektid character varying;
		ALTER TABLE ax_historischesflurstueckalb ADD quellobjektid character varying;

		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER gemeindezugehoerigkeit_gemeinde SET NOT NULL;

		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER gemeindezugehoerigkeit_kreis SET NOT NULL;

		ALTER TABLE ax_historischesflurstueckohneraumbezug ALTER gemeindezugehoerigkeit_land SET NOT NULL;
		ALTER TABLE ax_historischesflurstueckohneraumbezug DROP istgebucht;
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD isthistgebucht character(16);
		ALTER TABLE ax_historischesflurstueckohneraumbezug ADD quellobjektid character varying;
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_historischesflurstueckohneraumbezug' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_historischesflurstueckohneraumbezug USING btree (istgebucht)';

		CREATE INDEX alkis_b13b28e1_d8de_4e41_86e7_dbc4d4026235 ON ax_historischesflurstueckohneraumbezug USING btree (isthistgebucht);
		ALTER TABLE ax_hoehenfestpunkt DROP gemarkung_gemarkungsnummer;
		ALTER TABLE ax_hoehenfestpunkt DROP gemarkung_land;
		ALTER TABLE ax_hoehenfestpunkt RENAME gemeinde TO gemeinde_gemeinde;
		ALTER TABLE ax_hoehenfestpunkt RENAME kreis TO gemeinde_kreis;
		ALTER TABLE ax_hoehenfestpunkt DROP topographieundumwelt;
		ALTER TABLE ax_hoehenfestpunkt ADD erstvermarkung date;
		ALTER TABLE ax_hoehenfestpunkt ADD gemarkungsnummer character varying;
		ALTER TABLE ax_hoehenfestpunkt ADD land character varying;
		ALTER TABLE ax_hoehenfestpunkt ADD nutzungextern character varying NOT NULL;
		ALTER TABLE ax_hoehenfestpunkt ADD quellobjektid character varying;
		ALTER TABLE ax_hoehenfestpunkt ADD topographieundumwelteinfluesse integer;
		ALTER TABLE ax_hoehenfestpunkt ADD untergangsdatum date;
		ALTER TABLE ax_hoehenfestpunkt ADD vermarkungsdatum date;
		ALTER TABLE ax_hoehenlinie ADD quellobjektid character varying;
		ALTER TABLE ax_hoehleneingang ADD quellobjektid character varying;
		ALTER TABLE ax_hoehleneingang ADD zweitname character varying[];
		ALTER TABLE ax_industrieundgewerbeflaeche ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_industrieundgewerbeflaeche ADD istweiterenutzung integer;
		ALTER TABLE ax_industrieundgewerbeflaeche ADD quellobjektid character varying;
		ALTER TABLE ax_insel ADD quellobjektid character varying;
		ALTER TABLE ax_insel ADD regionalsprache character varying[];

		-- ax_kanal.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_kanal ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_kanal ADD quellobjektid character varying;
		ALTER TABLE ax_kanal ADD regionalsprache character varying[];
		ALTER TABLE ax_klassifizierungnachstrassenrecht ADD quellobjektid character varying;
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_klassifizierungnachwasserrecht ADD quellobjektid character varying;
		ALTER TABLE ax_kleinraeumigerlandschaftsteil ADD quellobjektid character varying;
		ALTER TABLE ax_kommunalesgebiet ADD quellobjektid character varying;
		ALTER TABLE ax_kondominium ADD quellobjektid character varying;
		ALTER TABLE ax_kreisregion ADD einwohnerzahl integer;
		ALTER TABLE ax_kreisregion ADD historisch character varying;
		ALTER TABLE ax_kreisregion ADD quellobjektid character varying;
		ALTER TABLE ax_kreisregion ADD regionalsprache character varying[];
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD einwohnerzahl integer;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD historisch character varying;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD quellobjektid character varying;
		ALTER TABLE ax_lagebezeichnungkatalogeintrag ADD regionalsprache character varying[];
		ALTER TABLE ax_lagebezeichnungmithausnummer ADD quellobjektid character varying;
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD gehoertzupseudo character(16);
		ALTER TABLE ax_lagebezeichnungmitpseudonummer ADD quellobjektid character varying;

		CREATE INDEX alkis_ca535aab_87e2_4ab3_9863_86745da822bb ON ax_lagebezeichnungmitpseudonummer USING btree (gehoertzupseudo);
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD gehoertauchzu character(16);
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD gehoertzuohne character(16);
		ALTER TABLE ax_lagebezeichnungohnehausnummer ADD quellobjektid character varying;

		CREATE INDEX alkis_709f4a78_75f7_48ea_b6c2_510a1cdee560 ON ax_lagebezeichnungohnehausnummer USING btree (gehoertauchzu);

		CREATE INDEX alkis_5c044948_5dd3_4d7c_888d_e96991cd7bfd ON ax_lagebezeichnungohnehausnummer USING btree (gehoertzuohne);
		ALTER TABLE ax_lagefestpunkt DROP gemarkung_gemarkungsnummer;
		ALTER TABLE ax_lagefestpunkt DROP gemarkung_land;
		ALTER TABLE ax_lagefestpunkt RENAME gemeinde TO gemeinde_gemeinde;
		ALTER TABLE ax_lagefestpunkt RENAME kreis TO gemeinde_kreis;
		ALTER TABLE ax_lagefestpunkt ADD erstvermarkung date;
		ALTER TABLE ax_lagefestpunkt ADD gemarkungsnummer character varying;
		ALTER TABLE ax_lagefestpunkt ADD land character varying;
		ALTER TABLE ax_lagefestpunkt ADD nutzungextern character varying NOT NULL;
		ALTER TABLE ax_lagefestpunkt ADD quellobjektid character varying;
		ALTER TABLE ax_lagefestpunkt ADD untergangsdatum date;
		ALTER TABLE ax_lagefestpunkt ADD vermarkungsdatum date;

		ALTER TABLE ax_landschaft ALTER landschaftstyp DROP NOT NULL;
		ALTER TABLE ax_landschaft ADD quellobjektid character varying;
		ALTER TABLE ax_landschaft ADD regionalsprache character varying[];
		ALTER TABLE ax_landwirtschaft ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_landwirtschaft ADD istweiterenutzung integer;
		ALTER TABLE ax_landwirtschaft ADD quellobjektid character varying;
		ALTER TABLE ax_leitung ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_leitung ADD hat3d character(16)[];
		ALTER TABLE ax_leitung ADD quellobjektid character varying;

		CREATE INDEX alkis_bd397375_f740_403f_a91d_216dae4addbe ON ax_leitung USING gin (hat3d);
		ALTER TABLE ax_meer ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_meer ADD istweiterenutzung integer;
		ALTER TABLE ax_meer ADD quellobjektid character varying;
		ALTER TABLE ax_meer ADD regionalsprache character varying[];
		ALTER TABLE ax_moor ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_moor ADD istweiterenutzung integer;
		ALTER TABLE ax_moor ADD quellobjektid character varying;

		-- ax_namensnummer.bestehtausrechtsverhaeltnissenzu -> bestehtausrechtsverhaeltnissenzu: character(16) => character(16)[]

		ALTER TABLE ax_namensnummer ALTER bestehtausrechtsverhaeltnissenzu TYPE character(16)[] USING CASE WHEN bestehtausrechtsverhaeltnissenzu IS NULL THEN NULL ELSE ARRAY[bestehtausrechtsverhaeltnissenzu] END;
		ALTER TABLE ax_namensnummer ADD quellobjektid character varying;
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_namensnummer' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_namensnummer USING btree (bestehtausrechtsverhaeltnissenzu)';

		CREATE INDEX alkis_ee3237ad_0db7_46c7_8920_29ea5da23732 ON ax_namensnummer USING gin (bestehtausrechtsverhaeltnissenzu);
		ALTER TABLE ax_nationalstaat ADD einwohnerzahl integer;
		ALTER TABLE ax_nationalstaat ADD historisch character varying;
		ALTER TABLE ax_nationalstaat ADD quellobjektid character varying;
		ALTER TABLE ax_nationalstaat ADD regionalsprache character varying[];
		ALTER TABLE ax_naturumweltoderbodenschutzrecht ADD quellobjektid character varying;
		ALTER TABLE ax_netzknoten ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_netzknoten ADD hat3d character(16)[];
		ALTER TABLE ax_netzknoten ADD quellobjektid character varying;

		CREATE INDEX alkis_a4043504_b0ca_40c6_a45e_53ef86175209 ON ax_netzknoten USING gin (hat3d);
		ALTER TABLE ax_nullpunkt ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_nullpunkt ADD hat3d character(16)[];
		ALTER TABLE ax_nullpunkt ADD quellobjektid character varying;

		CREATE INDEX alkis_b2c05fa1_e3af_4f36_84fd_351a016a7b56 ON ax_nullpunkt USING gin (hat3d);
		ALTER TABLE ax_ortslage ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_ortslage ADD hat3d character(16)[];
		ALTER TABLE ax_ortslage ADD quellobjektid character varying;
		ALTER TABLE ax_ortslage ADD regionalsprache character varying[];

		CREATE INDEX alkis_b8e917d0_d8b8_4d8a_ba3d_17f3cfa02a32 ON ax_ortslage USING gin (hat3d);
		ALTER TABLE ax_person ADD quellobjektid character varying;
		ALTER TABLE ax_person ADD rufname character varying;
		ALTER TABLE ax_person ADD sterbedatum date;
		ALTER TABLE ax_personengruppe ADD quellobjektid character varying;

		-- ax_platz.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_platz ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_platz ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_platz ADD istweiterenutzung integer;
		ALTER TABLE ax_platz ADD quellobjektid character varying;
		ALTER TABLE ax_platz ADD regionalsprache character varying[];

		-- ax_polder.funktion -> funktion: character varying => integer

		ALTER TABLE ax_polder ALTER funktion TYPE integer USING funktion::int;
		ALTER TABLE ax_polder ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_polder ADD hat3d character(16)[];
		ALTER TABLE ax_polder ADD quellobjektid character varying;

		CREATE INDEX alkis_e819a0b6_b822_4cba_896f_92fddb3e7e9e ON ax_polder USING gin (hat3d);
		ALTER TABLE ax_punktkennunguntergegangen ADD quellobjektid character varying;
		ALTER TABLE ax_punktkennungvergleichend ADD quellobjektid character varying;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_datetime;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_evaluationmethoddescription;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_evaluationmethodtype;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_evaluationprocedure;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_measuredescription;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_measureidentification;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_nameofmeasure;
		ALTER TABLE ax_punktortag DROP genauigkeitswert_result;

		-- ax_punktortag.statement -> statement: character varying => character varying[]

		ALTER TABLE ax_punktortag ALTER statement TYPE character varying[] USING CASE WHEN statement IS NULL THEN NULL ELSE ARRAY[statement] END;
		ALTER TABLE ax_punktortag ADD genauigkeitswert character varying;
		ALTER TABLE ax_punktortag ADD quellobjektid character varying;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_datetime;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_evaluationmethoddescription;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_evaluationmethodtype;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_evaluationprocedure;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_measuredescription;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_measureidentification;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_nameofmeasure;
		ALTER TABLE ax_punktortau DROP genauigkeitswert_result;

		-- ax_punktortau.statement -> statement: character varying => character varying[]

		ALTER TABLE ax_punktortau ALTER statement TYPE character varying[] USING CASE WHEN statement IS NULL THEN NULL ELSE ARRAY[statement] END;
		ALTER TABLE ax_punktortau ADD genauigkeitswert character varying;
		ALTER TABLE ax_punktortau ADD quellobjektid character varying;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_datetime;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_evaluationmethoddescription;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_evaluationmethodtype;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_evaluationprocedure;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_measuredescription;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_measureidentification;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_nameofmeasure;
		ALTER TABLE ax_punktortta DROP genauigkeitswert_result;

		-- ax_punktortta.statement -> statement: character varying => character varying[]

		ALTER TABLE ax_punktortta ALTER statement TYPE character varying[] USING CASE WHEN statement IS NULL THEN NULL ELSE ARRAY[statement] END;
		ALTER TABLE ax_punktortta ADD genauigkeitswert character varying;
		ALTER TABLE ax_punktortta ADD quellobjektid character varying;
		ALTER TABLE ax_referenzstationspunkt DROP antennenhoehe;
		ALTER TABLE ax_referenzstationspunkt DROP antennenreferenzpunkt;
		ALTER TABLE ax_referenzstationspunkt DROP aufbaudatum;
		ALTER TABLE ax_referenzstationspunkt DROP azimutaleabweichung;
		ALTER TABLE ax_referenzstationspunkt DROP beginn;
		ALTER TABLE ax_referenzstationspunkt DROP ende;
		ALTER TABLE ax_referenzstationspunkt DROP funkfrequenz;
		ALTER TABLE ax_referenzstationspunkt DROP gemarkung_gemarkungsnummer;
		ALTER TABLE ax_referenzstationspunkt DROP gemarkung_land;
		ALTER TABLE ax_referenzstationspunkt RENAME gemeinde TO gemeinde_gemeinde;
		ALTER TABLE ax_referenzstationspunkt DROP gnssantenne_abbaudatum;
		ALTER TABLE ax_referenzstationspunkt DROP gnssantenne_zusaetzlicheinformationen;
		ALTER TABLE ax_referenzstationspunkt DROP gnssantennenundradometyp;
		ALTER TABLE ax_referenzstationspunkt DROP gnssempfaenger_abbaudatum;
		ALTER TABLE ax_referenzstationspunkt DROP gnssempfaenger_aufbaudatum;
		ALTER TABLE ax_referenzstationspunkt DROP gnssempfaenger_firmwareversion;
		ALTER TABLE ax_referenzstationspunkt DROP gnssempfaenger_gnssempfaengertyp;
		ALTER TABLE ax_referenzstationspunkt DROP gnssempfaenger_seriennummer;
		ALTER TABLE ax_referenzstationspunkt DROP gnssempfaenger_zusaetzlicheinformationen;
		ALTER TABLE ax_referenzstationspunkt DROP hoehenoffsetl1;
		ALTER TABLE ax_referenzstationspunkt DROP hoehenoffsetl2;
		ALTER TABLE ax_referenzstationspunkt DROP isdnnummer;
		ALTER TABLE ax_referenzstationspunkt RENAME kreis TO gemeinde_kreis;
		ALTER TABLE ax_referenzstationspunkt DROP offsetl1_east;
		ALTER TABLE ax_referenzstationspunkt DROP offsetl1_height;
		ALTER TABLE ax_referenzstationspunkt DROP offsetl1_north;
		ALTER TABLE ax_referenzstationspunkt DROP offsetl2_east;
		ALTER TABLE ax_referenzstationspunkt DROP offsetl2_height;
		ALTER TABLE ax_referenzstationspunkt DROP offsetl2_north;
		ALTER TABLE ax_referenzstationspunkt DROP phasenzentrumsvariationl1_zeile;
		ALTER TABLE ax_referenzstationspunkt DROP phasenzentrumsvariationl2_zeile;
		ALTER TABLE ax_referenzstationspunkt DROP seriennummer;
		ALTER TABLE ax_referenzstationspunkt DROP tcpipnummer;
		ALTER TABLE ax_referenzstationspunkt DROP unterschiedlicherbezugspunktmitsfp;
		ALTER TABLE ax_referenzstationspunkt ADD erstvermarkung date;
		ALTER TABLE ax_referenzstationspunkt ADD gemarkungsnummer character varying;
		ALTER TABLE ax_referenzstationspunkt ADD land character varying;
		ALTER TABLE ax_referenzstationspunkt ADD nutzungextern character varying NOT NULL;
		ALTER TABLE ax_referenzstationspunkt ADD quellobjektid character varying;
		ALTER TABLE ax_referenzstationspunkt ADD untergangsdatum date;
		ALTER TABLE ax_referenzstationspunkt ADD vermarkungsdatum date;
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_referenzstationspunkt' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_referenzstationspunkt USING btree (unterschiedlicherbezugspunktmitsfp)';
		ALTER TABLE ax_regierungsbezirk ADD einwohnerzahl integer;
		ALTER TABLE ax_regierungsbezirk ADD historisch character varying;
		ALTER TABLE ax_regierungsbezirk ADD quellobjektid character varying;
		ALTER TABLE ax_regierungsbezirk ADD regionalsprache character varying[];
		ALTER TABLE ax_reservierung ADD quellobjektid character varying;
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD hat3d character(16)[];
		ALTER TABLE ax_schifffahrtsliniefaehrverkehr ADD quellobjektid character varying;

		CREATE INDEX alkis_8476af80_655e_4617_989d_c3e14c1b6811 ON ax_schifffahrtsliniefaehrverkehr USING gin (hat3d);
		ALTER TABLE ax_schiffsverkehr ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_schiffsverkehr ADD istweiterenutzung integer;
		ALTER TABLE ax_schiffsverkehr ADD quellobjektid character varying;
		ALTER TABLE ax_schleuse ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_schleuse ADD hat3d character(16)[];
		ALTER TABLE ax_schleuse ADD hoehe double precision[];
		ALTER TABLE ax_schleuse ADD obererbezugspunkt integer[];
		ALTER TABLE ax_schleuse ADD quellobjektid character varying;
		ALTER TABLE ax_schleuse ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_740f5837_714f_4935_be2c_943ee25db73f ON ax_schleuse USING gin (hat3d);
		ALTER TABLE ax_schutzgebietnachnaturumweltoderbodenschutzrecht ADD quellobjektid character varying;
		ALTER TABLE ax_schutzgebietnachwasserrecht ADD quellobjektid character varying;
		ALTER TABLE ax_schutzzone ADD quellobjektid character varying;

		-- ax_schwere.genauigkeitswert -> genauigkeitswert: integer => character varying

		ALTER TABLE ax_schwere ALTER genauigkeitswert TYPE character varying USING genauigkeitswert::varchar;
		ALTER TABLE ax_schwere DROP schweresystem;

		-- ax_schwere.schwerewert -> schwerewert: double precision => character varying

		ALTER TABLE ax_schwere ALTER schwerewert TYPE character varying USING schwerewert::text;

		ALTER TABLE ax_schwere ALTER schwerewert DROP NOT NULL;
		ALTER TABLE ax_schwere ADD berechnungsdatum date;
		ALTER TABLE ax_schwere ADD genauigkeitvertikalerschweregradient character varying;
		ALTER TABLE ax_schwere ADD messdatum date;
		ALTER TABLE ax_schwere ADD messhoehevertikalerschweregradient double precision[];
		ALTER TABLE ax_schwere ADD quellobjektid character varying;
		ALTER TABLE ax_schwere ADD schwerebezugssystem integer NOT NULL;
		ALTER TABLE ax_schwere ADD tauglichkeitgcg integer;
		ALTER TABLE ax_schwere ADD wertvertikalerschweregradient character varying;
		ALTER TABLE ax_schwere ADD zustaendigestelleberechnung_land character varying;
		ALTER TABLE ax_schwere ADD zustaendigestelleberechnung_stelle character varying;
		ALTER TABLE ax_schwere ADD zustaendigestellemessung_land character varying;
		ALTER TABLE ax_schwere ADD zustaendigestellemessung_stelle character varying;
		ALTER TABLE ax_schwerefestpunkt DROP gemarkung_gemarkungsnummer;
		ALTER TABLE ax_schwerefestpunkt DROP gemarkung_land;
		ALTER TABLE ax_schwerefestpunkt RENAME gemeinde TO gemeinde_gemeinde;
		ALTER TABLE ax_schwerefestpunkt RENAME kreis TO gemeinde_kreis;
		ALTER TABLE ax_schwerefestpunkt DROP unterschiedlicherbezugspunktmitrsp;
		ALTER TABLE ax_schwerefestpunkt ADD erstvermarkung date;
		ALTER TABLE ax_schwerefestpunkt ADD gemarkungsnummer character varying;
		ALTER TABLE ax_schwerefestpunkt ADD land character varying;
		ALTER TABLE ax_schwerefestpunkt ADD nutzungextern character varying NOT NULL;
		ALTER TABLE ax_schwerefestpunkt ADD quellobjektid character varying;
		ALTER TABLE ax_schwerefestpunkt ADD untergangsdatum date;
		ALTER TABLE ax_schwerefestpunkt ADD vermarkungsdatum date;
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_schwerefestpunkt' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_schwerefestpunkt USING btree (unterschiedlicherbezugspunktmitrsp)';
		ALTER TABLE ax_seilbahnschwebebahn ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_seilbahnschwebebahn ADD hat3d character(16)[];
		ALTER TABLE ax_seilbahnschwebebahn ADD quellobjektid character varying;

		CREATE INDEX alkis_f7fc9194_c365_45dc_a983_117793bcf694 ON ax_seilbahnschwebebahn USING gin (hat3d);
		ALTER TABLE ax_sicherungspunkt ADD quellobjektid character varying;
		ALTER TABLE ax_sickerstrecke ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_sickerstrecke ADD fliessrichtung character varying NOT NULL;
		ALTER TABLE ax_sickerstrecke ADD hat3d character(16)[];
		ALTER TABLE ax_sickerstrecke ADD quellobjektid character varying;

		CREATE INDEX alkis_78aea909_0eb5_4f5a_849f_8c6702f326c4 ON ax_sickerstrecke USING gin (hat3d);
		ALTER TABLE ax_siedlungsflaeche ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_siedlungsflaeche ADD funktion integer;
		ALTER TABLE ax_siedlungsflaeche ADD istweiterenutzung integer;
		ALTER TABLE ax_siedlungsflaeche ADD quellobjektid character varying;
		ALTER TABLE ax_siedlungsflaeche ADD regionalsprache character varying[];
		ALTER TABLE ax_skizze ADD quellobjektid character varying;
		ALTER TABLE ax_soll ADD quellobjektid character varying;
		ALTER TABLE ax_sonstigervermessungspunkt DROP hat;
		ALTER TABLE ax_sonstigervermessungspunkt ADD mit character(16)[];
		ALTER TABLE ax_sonstigervermessungspunkt ADD quellobjektid character varying;
		PERFORM alkis_dropobject(ix.relname) FROM pg_class cl JOIN pg_namespace ns ON ns.oid=cl.relnamespace JOIN pg_index ind ON cl.oid = ind.indrelid JOIN pg_class ix ON ix.oid = ind.indexrelid WHERE ns.nspname=current_schema() AND cl.relname='ax_sonstigervermessungspunkt' AND pg_get_indexdef(ind.indexrelid) LIKE 'CREATE INDEX % ON ax_sonstigervermessungspunkt USING gin (hat)';

		CREATE INDEX alkis_8d0d26f0_9a07_49c6_8078_9d9f536e19f9 ON ax_sonstigervermessungspunkt USING gin (mit);
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung DROP objekthoehe;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD dachform integer;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD hat3d character(16)[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD hoehe double precision[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD obererbezugspunkt integer[];
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD quellobjektid character varying;
		ALTER TABLE ax_sonstigesbauwerkodersonstigeeinrichtung ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_4d17dd53_a629_4a08_b70b_0b4d7130e225 ON ax_sonstigesbauwerkodersonstigeeinrichtung USING gin (hat3d);
		ALTER TABLE ax_sonstigesrecht ADD quellobjektid character varying;
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD istweiterenutzung integer;
		ALTER TABLE ax_sportfreizeitunderholungsflaeche ADD quellobjektid character varying;
		ALTER TABLE ax_stehendesgewaesser DROP gewaesserkennziffer;
		ALTER TABLE ax_stehendesgewaesser ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_stehendesgewaesser ADD istweiterenutzung integer;
		ALTER TABLE ax_stehendesgewaesser ADD nutzung integer[];
		ALTER TABLE ax_stehendesgewaesser ADD quellobjektid character varying;
		ALTER TABLE ax_stehendesgewaesser ADD regionalsprache character varying[];
		ALTER TABLE ax_stehendesgewaesser ADD seekennzahl character varying;
		ALTER TABLE ax_stehendesgewaesser ADD wasserspiegelhoeheinstehendemgewaesser double precision;
		ALTER TABLE ax_stehendesgewaesser ADD zustand integer;
		ALTER TABLE ax_stehendesgewaesser ADD zweitname character varying[];

		-- ax_strasse.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_strasse ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_strasse ADD quellobjektid character varying;
		ALTER TABLE ax_strasse ADD regionalsprache character varying[];
		ALTER TABLE ax_strassenachse DROP verkehrsbedeutunginneroertlich;
		ALTER TABLE ax_strassenachse DROP verkehrsbedeutungueberoertlich;
		ALTER TABLE ax_strassenachse ADD besondereverkehrsbedeutung integer;
		ALTER TABLE ax_strassenachse ADD fahrtrichtung character varying;
		ALTER TABLE ax_strassenachse ADD quellobjektid character varying;
		ALTER TABLE ax_strassenverkehr ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_strassenverkehr ADD istweiterenutzung integer;
		ALTER TABLE ax_strassenverkehr ADD quellobjektid character varying;

		-- ax_strassenverkehrsanlage.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_strassenverkehrsanlage ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_strassenverkehrsanlage ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_strassenverkehrsanlage ADD hat3d character(16)[];
		ALTER TABLE ax_strassenverkehrsanlage ADD quellobjektid character varying;

		CREATE INDEX alkis_dc1c0beb_da19_49ef_a2c6_bcfc4b9c41c7 ON ax_strassenverkehrsanlage USING gin (hat3d);
		ALTER TABLE ax_sumpf ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_sumpf ADD istweiterenutzung integer;
		ALTER TABLE ax_sumpf ADD quellobjektid character varying;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD funktion integer;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD istweiterenutzung integer;
		ALTER TABLE ax_tagebaugrubesteinbruch ADD quellobjektid character varying;
		ALTER TABLE ax_tagesabschnitt ADD quellobjektid character varying;
		ALTER TABLE ax_testgelaende ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_testgelaende ADD hat3d character(16)[];
		ALTER TABLE ax_testgelaende ADD quellobjektid character varying;

		CREATE INDEX alkis_82e1cf40_aaa0_4d83_804d_d229fe86b37a ON ax_testgelaende USING gin (hat3d);
		ALTER TABLE ax_topographischelinie ADD quellobjektid character varying;
		ALTER TABLE ax_transportanlage ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_transportanlage ADD hat3d character(16)[];
		ALTER TABLE ax_transportanlage ADD quellobjektid character varying;

		CREATE INDEX alkis_295d9747_a875_43c1_a37c_9c36462f46ef ON ax_transportanlage USING gin (hat3d);
		ALTER TABLE ax_turm DROP objekthoehe;
		ALTER TABLE ax_turm ADD dachform integer;
		ALTER TABLE ax_turm ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_turm ADD hat3d character(16)[];
		ALTER TABLE ax_turm ADD hoehe double precision[];
		ALTER TABLE ax_turm ADD obererbezugspunkt integer[];
		ALTER TABLE ax_turm ADD quellobjektid character varying;
		ALTER TABLE ax_turm ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_4768faa5_c25d_47ec_9c63_1dd687da7821 ON ax_turm USING gin (hat3d);
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD istweiterenutzung integer;
		ALTER TABLE ax_unlandvegetationsloseflaeche ADD quellobjektid character varying;
		ALTER TABLE ax_untergeordnetesgewaesser ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_untergeordnetesgewaesser ADD hat3d character(16)[];
		ALTER TABLE ax_untergeordnetesgewaesser ADD quellobjektid character varying;

		CREATE INDEX alkis_903e0c16_ce76_45d7_b6a4_cf7cb995bd69 ON ax_untergeordnetesgewaesser USING gin (hat3d);
		ALTER TABLE ax_vegetationsmerkmal ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_vegetationsmerkmal ADD hat3d character(16)[];
		ALTER TABLE ax_vegetationsmerkmal ADD quellobjektid character varying;

		CREATE INDEX alkis_fb5d2c68_d634_4291_a6eb_71408b2969e6 ON ax_vegetationsmerkmal USING gin (hat3d);
		ALTER TABLE ax_verband ADD einwohnerzahl integer;
		ALTER TABLE ax_verband ADD historisch character varying;
		ALTER TABLE ax_verband ADD quellobjektid character varying;
		ALTER TABLE ax_verband ADD regionalsprache character varying[];
		ALTER TABLE ax_vertretung ADD quellobjektid character varying;
		ALTER TABLE ax_verwaltung ADD quellobjektid character varying;
		ALTER TABLE ax_verwaltungsgemeinschaft ADD einwohnerzahl integer;
		ALTER TABLE ax_verwaltungsgemeinschaft ADD historisch character varying;
		ALTER TABLE ax_verwaltungsgemeinschaft ADD quellobjektid character varying;
		ALTER TABLE ax_verwaltungsgemeinschaft ADD regionalsprache character varying[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk DROP objekthoehe;
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD hat3d character(16)[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD hoehe double precision[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD obererbezugspunkt integer[];
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD quellobjektid character varying;
		ALTER TABLE ax_vorratsbehaelterspeicherbauwerk ADD untererbezugspunkt integer[];

		CREATE INDEX alkis_901eb86e_222f_4310_aac2_fc195f264aee ON ax_vorratsbehaelterspeicherbauwerk USING gin (hat3d);
		ALTER TABLE ax_wald ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_wald ADD istweiterenutzung integer;
		ALTER TABLE ax_wald ADD quellobjektid character varying;
		ALTER TABLE ax_wald ADD regionalsprache character varying[];
		ALTER TABLE ax_wald ADD zustand integer;

		-- ax_wasserlauf.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_wasserlauf ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_wasserlauf ADD quellobjektid character varying;
		ALTER TABLE ax_wasserlauf ADD regionalsprache character varying[];
		ALTER TABLE ax_wasserspiegelhoehe ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_wasserspiegelhoehe ADD hat3d character(16)[];
		ALTER TABLE ax_wasserspiegelhoehe ADD quellobjektid character varying;

		CREATE INDEX alkis_244959ef_2c90_4fda_821f_ca40521c86a7 ON ax_wasserspiegelhoehe USING gin (hat3d);
		ALTER TABLE ax_weg ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_weg ADD istweiterenutzung integer;
		ALTER TABLE ax_weg ADD quellobjektid character varying;

		-- ax_wegpfadsteig.markierung -> markierung: integer => integer[]

		ALTER TABLE ax_wegpfadsteig ALTER markierung TYPE integer[] USING CASE WHEN markierung IS NULL THEN NULL ELSE ARRAY[markierung] END;

		-- ax_wegpfadsteig.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_wegpfadsteig ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_wegpfadsteig ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_wegpfadsteig ADD hat3d character(16)[];
		ALTER TABLE ax_wegpfadsteig ADD quellobjektid character varying;
		ALTER TABLE ax_wegpfadsteig ADD regionalsprache character varying[];

		CREATE INDEX alkis_14761526_2400_491f_9db1_cfb7f5f7cb04 ON ax_wegpfadsteig USING gin (hat3d);
		ALTER TABLE ax_wirtschaftlicheeinheit ADD quellobjektid character varying;

		-- ax_wohnbauflaeche.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_wohnbauflaeche ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_wohnbauflaeche ADD ergebnisderueberpruefung integer;
		ALTER TABLE ax_wohnbauflaeche ADD funktion integer;
		ALTER TABLE ax_wohnbauflaeche ADD istweiterenutzung integer;
		ALTER TABLE ax_wohnbauflaeche ADD quellobjektid character varying;
		ALTER TABLE ax_wohnplatz DROP einwohnerzahl;

		-- ax_wohnplatz.zweitname -> zweitname: character varying => character varying[]

		ALTER TABLE ax_wohnplatz ALTER zweitname TYPE character varying[] USING CASE WHEN zweitname IS NULL THEN NULL ELSE ARRAY[zweitname] END;
		ALTER TABLE ax_wohnplatz ADD quellobjektid character varying;
		ALTER TABLE ax_wohnplatz ADD regionalsprache character varying[];
		CREATE TABLE ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti IS 'Alias: "AX_ErgebnisDerUeberpruefung_BauwerkeEinrichtungenUndSonstigeAngaben", UML-Typ: Enumeration';
		INSERT INTO ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fehlerkorrektur', 'Fehlerkorrektur beschreibt dass eine Anpassung durchgeführt wurde, obwohl in der Realwelt keine tatsächliche Änderung stattgefunden hat.'),
		('2000', 'Bestätigung des Ist-Zustandes', 'Bestätigung des Ist-Zustandes beschreibt, dass das Objekt zum Zeitpunkt einer Überprüfung als zutreffend ermittelt wurde.'),
		('3000', 'Erfassung eines neuen Objektes', 'Erfassung eines neuen Objektes beschreibt, dass eine tatsächliche Änderungen in der Realwelt zur Neubildung des Objektes geführt haben. Das bedeutet, dass eine fachliche Änderung auf Ebene der Objekt- und/oder Attributart stattfand.'),
		('4000', 'Geometrieveränderung eines bestehenden Objektes', 'Geometrieveränderung eines bestehenden Objektes beschreibt eine Änderung der Umringsgeometrie in der Realwelt, ohne das eine fachliche Änderung auf Ebene der Objekt- oder Attributart stattfand.');
		CREATE TABLE ax_zustand_bauwerkoderanlagefuersportfreizeitunderholung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_bauwerkoderanlagefuersportfreizeitunderholung IS 'Alias: "AX_Zustand_BauwerkOderAnlageFuerSportFreizeitUndErholung", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_bauwerkoderanlagefuersportfreizeitunderholung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich das Bauwerk oder die Anlage nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.');
		CREATE TABLE ax_art_bauwerkspunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_art_bauwerkspunkt IS 'Alias: "AX_Art_Bauwerkspunkt", UML-Typ: Enumeration';
		INSERT INTO ax_art_bauwerkspunkt (wert,beschreibung,dokumentation) VALUES
		('1100', 'First', ''),
		('1200', 'Traufe', ''),
		('2100', 'Eingang', '');
		CREATE TABLE ax_zustand_flugverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_flugverkehrsanlage IS 'Alias: "AX_Zustand_Flugverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_flugverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich Flugverkehrsanlage nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass sich überwiegende Teile von Flugverkehrsanlage im Bau befinden.');
		CREATE TABLE ax_bahnkategorie_bahnverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_bahnkategorie_bahnverkehrsanlage IS 'Alias: "AX_Bahnkategorie_Bahnverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_bahnkategorie_bahnverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('1100', 'Eisenbahn', 'Eisenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr Personen befördert und/oder Güter transportiert werden.'),
		('1101', 'Personenverkehr', 'Personenverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und / oder Fernverkehr Personen transportiert werden bzw. ist die Bezeichnung für eine Bahnverkehrsanlage mit Personenverkehr.'),
		('1102', 'Güterverkehr', 'Güterverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und / oder Fernverkehr Güter transportiert werden bzw. ist die Bezeichnung für eine Bahnverkehrsanlage mit Güterverkehr.'),
		('1103', 'Betriebsverkehr', 'Betriebsverkehr ist die Bezeichnung für eine Bahnverkehrsanlage, die aus innerbetrieblichen Gründen erforderlich ist.'),
		('1104', 'S-Bahn', 'S-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, der zur schnellen Personenbeförderung in Ballungsräumen dient und meist auf eigenen Gleisen verläuft.'),
		('1200', 'Stadtbahn', 'Stadtbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung im öffentlichen Nahverkehr fährt. Sie kann sowohl ober- als auch unterirdisch verlaufen.'),
		('1201', 'Straßenbahn', 'Straßenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung fährt. Sie verläuft i. d. R. oberirdisch.'),
		('1202', 'U-Bahn', 'U-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung in Großstädten fährt. Sie verläuft i. d. R. unterirdisch.'),
		('1300', 'Seilbahn, Bergbahn', 'Seilbahn, Bergbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn große Höhenunterschiede überwindet.'),
		('1301', 'Zahnradbahn', 'Zahnradbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn mittels Zahnradantrieb große Höhenunterschiede in stark geneigtem Gelände überwindet.'),
		('1302', 'Standseilbahn', 'Standseilbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn auf einer stark geneigten, meist kurzen und geraden Strecke verläuft. Mit Hilfe eines oder mehrerer Zugseile wird ein Schienenfahrzeug bergauf gezogen und gleichzeitig ein zweites bergab gelassen.'),
		('1400', 'Museumsbahn', 'Museumsbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem ausschließlich Touristen in alten, meist restaurierten Zügen befördert werden.'),
		('1500', 'Bahn im Freizeitpark', 'Bahn im Freizeitpark ist die Bezeichnung für einen schienengebundenen Verkehrsweg innerhalb eines Freizeitparks.'),
		('1600', 'Magnetschwebebahn', 'Magnetschwebebahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem räderlose Schienenfahrzeuge mit Hilfe von Magnetfeldern an oder auf einer Fahrschiene schwebend entlanggeführt werden.'),
		('9999', 'Sonstiges', 'Sonstiges bedeutet, dass die Bahnkategorie bekannt, aber nicht in der Attributwertliste aufgeführt ist.');
		CREATE TABLE ax_verkehrsdienst_bahnverkehrsanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_verkehrsdienst_bahnverkehrsanlage IS 'Alias: "AX_Verkehrsdienst_Bahnverkehrsanlage", UML-Typ: Enumeration';
		INSERT INTO ax_verkehrsdienst_bahnverkehrsanlage (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fernverkehrshalt', 'Fernverkehrshalt bedeutet, dass an der Bahnverkehrsanlage von einem Eisenbahnverkehrsunternehmen ein planmäßiger Halt im nationalen oder internationalen Schienenpersonenfernverkehrsdienst erbracht wird.');
		CREATE TABLE ax_zustand_einrichtungenfuerdenschiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_einrichtungenfuerdenschiffsverkehr IS 'Alias: "AX_Zustand_EinrichtungenFuerDenSchiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_einrichtungenfuerdenschiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich die Einrichtung für den Schiffsverkehr nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.');
		CREATE TABLE ax_artdergewaesserstationierungsachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_artdergewaesserstationierungsachse IS 'Alias: "AX_ArtDerGewaesserstationierungsachse", UML-Typ: Enumeration';
		INSERT INTO ax_artdergewaesserstationierungsachse (wert,beschreibung,dokumentation) VALUES
		('1000', 'Gewässerstationierungsachse der WSV', 'Gewässerstationierungsachse der WSV ist eine Gewässerachse, deren Geometrie unverändert aus den Unterlagen der Wasser- und Schifffahrtsverwaltung übernommen wurde.'),
		('2000', 'Genäherte Mittellinie in Gewässern', 'Genäherte Mittellinie in Gewässern ist eine Gewässerachse, die den Spezifikationen der Richtlinie der Gebiets- und Gewässerverschlüsselung der Länderarbeitsgemeinschaft Wasser (LAWA) entspricht.'),
		('3001', 'Fiktive Verbindung in Fließgewässern', 'Fiktive Verbindung in Fließgewässern ist eine Gewässerachse, die ein einmündendes Gewässer mit der Gewässerachse des aufnehmenden Fließgewässers verbindet.'),
		('3002', 'Fiktive Verbindung in Seen und Teichen', 'Fiktive Verbindung in Seen und Teichen ist eine hydrologisch sinnvolle Verbindungslinie in stehenden Gewässern, die für den Aufbau eines geschlossenen topologischen Gewässernetzes benötigt wird.');
		CREATE TABLE ax_schifffahrtskategorie_gewaesserstationierungsachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_schifffahrtskategorie_gewaesserstationierungsachse IS 'Alias: "AX_Schifffahrtskategorie_Gewaesserstationierungsachse", UML-Typ: Enumeration';
		INSERT INTO ax_schifffahrtskategorie_gewaesserstationierungsachse (wert,beschreibung,dokumentation) VALUES
		('1000', 'Binnenwasserstraße', 'Binnenwasserstraße ist ein oberirdisches Gewässer oder Küstengewässer, das gesetzlich für den Personen- und/oder Güterverkehr mit Schiffen bestimmt ist. Binnengewässer im Küstengebiet sind gegen das Küstengewässer gesetzlich abgegrenzt.'),
		('2000', 'Seewasserstraße', 'Seewasserstraße ist ein als Wasserstraße gesetzlich festgelegter Teil eines Küstengewässers.'),
		('3000', 'Landesgewässer mit Verkehrsordnung', 'Landesgewässer mit Verkehrsordnung ist eine Wasserstraße, die keine Binnenwasserstraße ist. Die Schiffbarkeit wird durch eine Landesverkehrsordnung geregelt.');
		CREATE TABLE ax_tauglichkeit_gcg (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_tauglichkeit_gcg IS 'Alias: "AX_Tauglichkeit_GCG", UML-Typ: Enumeration';
		INSERT INTO ax_tauglichkeit_gcg (wert,beschreibung,dokumentation) VALUES
		('1000', 'Gut geeignet', ''),
		('2000', 'Bedingt geeignet', ''),
		('5000', 'Ungeeignet', ''),
		('9998', 'Nicht untersucht', '');
		CREATE TABLE ax_schwerebezugssystem_schwere (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_schwerebezugssystem_schwere IS 'Alias: "AX_Schwerebezugssystem_Schwere", UML-Typ: Enumeration';
		INSERT INTO ax_schwerebezugssystem_schwere (wert,beschreibung,dokumentation) VALUES
		('1000', 'DHSN82', 'Schwerewert im System des DHSN82 (System der Landesvermessung)'),
		('1100', 'DSGN62', 'Schwerewert im System des DSGN62 (auch als DSN62 bezeichnet)'),
		('1200', 'SGN71', 'Schwerewert im System des SGN der DDR (auch als System 71 bezeichnet)'),
		('1300', 'DHSN96', 'Schwerewert im System des DHSN96 (System der Landesvermessung)'),
		('1400', 'DHSN2016', 'Schwerewert im System des DHSN2016 (System der Landesvermessung)'),
		('4000', 'ISGN71', 'Schwerewert im System des ISGN71 (wissenschaftliches System)'),
		('4010', 'DSGN76', 'Schwerewert im System des DSGN76 (wissenschaftliches System)'),
		('4020', 'DSGN94', 'Schwerewert im System des DSGN94 (wissenschaftliches System)'),
		('4030', 'DSGN2016', 'Schwerewert im System des DSGN2016 (wissenschaftliches System)'),
		('6000', 'PSS09', 'Potsdamer Schweresystem 1909'),
		('6100', 'SGRA43', 'Schweresystem der Geophysikalischen Reichsaufnahme 1934 - 1943');
		CREATE TABLE ax_untererbezugspunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_untererbezugspunkt IS 'Alias: "AX_UntererBezugspunkt", UML-Typ: Enumeration';
		INSERT INTO ax_untererbezugspunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Hauseingang/ Eingangstür', 'Hauseingang/Eingangstür ist ein Eingang, der in ein Haus führt.'),
		('2000', 'Mittlere Höhe Schnittpunkt mit Gelände', 'Mittlere Höhe Schnittpunkt mit Gelände ist der Mittelwert aller Schnittpunkte, die sich aus dem Schnitt der Kanten und dem Gelände ergeben.'),
		('3000', 'Höchster Punkt Schnittpunkt mit Gelände', 'Höchster Punkt Schnittpunkt mit Gelände ist der am höchsten gelegene Punkt, der sich aus dem Schnitt einer Kante und Gelände ergibt.'),
		('4000', 'Niedrigster Punkt Schnittpunkt mit Gelände', 'Niedrigster Punkt Schnittpunkt mit Gelände ist der am niedrigsten gelegene Punkt, der sich aus dem Schnitt einer Kante und Gelände ergibt.');
		CREATE TABLE ax_obererbezugspunkt (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_obererbezugspunkt IS 'Alias: "AX_ObererBezugspunkt", UML-Typ: Enumeration';
		INSERT INTO ax_obererbezugspunkt (wert,beschreibung,dokumentation) VALUES
		('1000', 'Mittlere Traufhöhe (Schnitt aufgehendes Mauerwerk mit Dachhaut)', 'Mittlere Traufhöhe ist der Mittelwert aus höchster und niedrigster Traufhöhe.'),
		('1100', 'Mittlere Giebelhöhe', 'Mittlere Giebelhöhe ist der Mittelwert aus Traufhöhe und Firsthöhe an der Giebelseite.'),
		('1200', 'Mittlere Höhe der Dachkanten', 'Mittlere Höhe der Dachkanten ist der Mittelwert der Höhen aller Dachkanten.'),
		('1300', 'Höchste Traufhöhe (Schnitt aufgehendes Mauerwerk mit Dachhaut)', 'Höchste Traufhöhe ist der absolut am höchsten gelegene Punkt aller Traufhöhen.'),
		('1400', 'Höchster Punkt der Dachaufbauten', 'Höchster Punkt der Dachaufbauten ist der höchstgelegene Punkt der Dachaufbauten.'),
		('1500', 'Höchste Dachkante', 'Höchste Dachkante ist die am höchsten gelegene Verbindung von Traufe und First.'),
		('1600', 'Niedrigste Traufhöhe (Schnitt aufgehendes Mauerwerk mit Dachhaut)', 'Niedrigste Traufhöhe ist der absolut am niedrigsten gelegene Punkt aller Traufhöhen die sich durch den Schnitt des aufgehenden Mauerwerks mit der Dachhaut ergeben.'),
		('1700', 'Niedrigste Dachkante', 'niedrigste Dachkante ist die am niedrigsten gelegene Verbindung von Traufe und First.'),
		('1800', 'First', 'First ist die oberste, waagerechte Kante einer Dachform. Bei gewölbten und runden, tonnenförmigen Dachkonstruktionen verläuft der First am Scheitelpunkt des Bogens.'),
		('1900', 'Höchster Punkt', 'Höchster Punkt ist der höchste Punkt des Objekts.'),
		('2000', 'Mittlere Höhe', 'Mittlere Höhe ist der Mittelwert der Höhen aus höchsten und niedrigsten Punkt des Objekts.'),
		('2100', 'Niedrigster Punkt', 'Niedrigster Punkt ist der niedrigste Punkt des Objekts.');
		CREATE TABLE ax_null_listenelement3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_null_listenelement3d IS 'Alias: "AX_Null_Listenelement3D", UML-Typ: Enumeration';
		INSERT INTO ax_null_listenelement3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'Keine Angabe', ''),
		('2000', 'Nicht eingetragen', '');
		CREATE TABLE ax_funktion_gebaeudeinstallation3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_funktion_gebaeudeinstallation3d IS 'Alias: "AX_Funktion_GebaeudeInstallation3D", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_gebaeudeinstallation3d (wert,beschreibung,dokumentation) VALUES
		('1010', 'Wintergarten', 'Wintergarten bezeichnet den fest umbauten Raum einer Terrasse.'),
		('1020', 'Arkade', 'Arkade bezeichnet den durch Säulen getragenen Bogengang eines Gebäudes.'),
		('1030', 'Schornstein im Gebäude', 'Schornstein im Gebäude ist ein über das Dach hinausragender Abzugskanal für die Rauchgase einer Feuerungsanlage oder für andere Abgase.'),
		('1040', 'Säule', 'Säule ist eine lotrechte, freistehende Stütze aus Holz, Stein, Ziegel oder Metall.'),
		('1050', 'Treppe', 'Treppe ist ein aus Stufen gebildeter Auf- oder Abgang.'),
		('1060', 'Gaube', 'Gaube ist ein Dachaufbau im geneigten Dach eines Gebäudes.'),
		('1070', 'Balkon', 'Balkon ist eine Plattform an einem Gebäude, die über dem Geländeniveau liegt und aus dem Baukörper hinausragt. Ein Balkon wird von einer Brüstung oder einem Geländer eingefasst.'),
		('1080', 'Fahrstuhlaufbau', 'Fahrstuhlaufbau ist ein Aufbau auf einen Dach, in welchem die Technik des Fahrstuhls untergebracht ist.'),
		('1090', 'Antenne', 'Antenne ist eine Vorrichtung zum Senden und Empfangen elektromagnetischer Wellen.'),
		('1100', 'Geländer', ''),
		('1110', 'Vordach', 'Ein Vordach ist ein zusätzliches kleines Dach, das über dem Eingangsbereich eines Hauses angebracht ist.'),
		('1120', 'Beleuchtung', 'Beleuchtung bezeichnet eine auf einem Dach installierte künstliche Lichtquelle.'),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_li_processstep_bodenhoehe_description (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_li_processstep_bodenhoehe_description IS 'Alias: "AX_LI_ProcessStep_Bodenhoehe_Description", UML-Typ: Enumeration';
		INSERT INTO ax_li_processstep_bodenhoehe_description (wert,beschreibung,dokumentation) VALUES
		('1000', 'Aus Verschneidung mit DGM', ''),
		('1100', 'Aus Verschneidung mit DGM 1', ''),
		('1200', 'Aus Verschneidung mit DGM 2', ''),
		('1300', 'Aus Verschneidung mit DGM 5', ''),
		('1400', 'Aus Verschneidung mit DGM 10', ''),
		('1500', 'Aus Verschneidung mit DGM 25', ''),
		('1600', 'Aus Verschneidung mit DGM 50', ''),
		('1700', 'Aus Verschneidung mit DGM 200', ''),
		('1800', 'Aus Verschneidung mit DGM 1000', ''),
		('2000', 'Aus Einzelmessung', ''),
		('3000', 'Aus Photogrammetrie -manuell', ''),
		('4000', 'Aus Photogrammetrie -automatisch', ''),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_li_processstep_dachhoehe_source (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_li_processstep_dachhoehe_source IS 'Alias: "AX_LI_ProcessStep_Dachhoehe_Source", UML-Typ: Enumeration';
		INSERT INTO ax_li_processstep_dachhoehe_source (wert,beschreibung,dokumentation) VALUES
		('1000', 'Aus Laserscanmessung', ''),
		('2000', 'Aus Stockwerken', ''),
		('3000', 'Aus Standardwerten', ''),
		('4000', 'Aus Photogrammetrie -manuell', ''),
		('5000', 'Aus Photogrammetrie -automatisch', ''),
		('6000', 'Manuell', ''),
		('9998', 'Nach Quellelage nicht zu spezifizieren', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_bezugspunktdach (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_bezugspunktdach IS 'Alias: "AX_BezugspunktDach", UML-Typ: Enumeration';
		INSERT INTO ax_bezugspunktdach (wert,beschreibung,dokumentation) VALUES
		('1000', 'First', 'First bezeichnet die obere Dachkante einer Dachfläche.'),
		('2000', 'Mittelwert', 'Der Mittelwert ist eine allgemeine Bezeichnung für das arithmetische Mittel.'),
		('2100', 'Arithmetrisches Mittel', 'Das arithmetische Mittel ist ein Mittelwert, der als Quotient aus der Summe aller beobachteten Werte und der Anzahl der Werte definiert ist'),
		('2200', 'Median', 'Der Median, oder Zentralwert, bezeichnet eine Grenze zwischen zwei Hälften. In der Statistik halbiert der Median eine Verteilung.'),
		('2300', 'Geometrisches Mittel', 'Das geometrische Mittel ist ein Mittelwert; es ist in der Statistik ein geeignetes Mittelmaß für Größen, von denen das Produkt anstelle der Summe interpretierbar ist.'),
		('3000', 'Traufe', 'Traufe bezeichnet den Schnittpunkt der Dachhaut mit dem aufgehenden Mauerwerk.'),
		('9998', 'Nach Quellenlage nicht zu spezifizieren', '');
		CREATE TABLE ax_material_materialeigenschaft_material3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_material_materialeigenschaft_material3d IS 'Alias: "AX_Material_Materialeigenschaft_Material3D", UML-Typ: Enumeration';
		INSERT INTO ax_material_materialeigenschaft_material3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'Holz', ''),
		('2000', 'Beton', ''),
		('3000', 'Klinker', ''),
		('4000', 'Putz', ''),
		('5000', 'Glas', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_dateitypraster_textur3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_dateitypraster_textur3d IS 'Alias: "AX_DateiTypRaster_Textur3D", UML-Typ: Enumeration';
		INSERT INTO ax_dateitypraster_textur3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'Jpg', ''),
		('2000', 'Jp2', ''),
		('3000', 'Gif', ''),
		('4000', 'Bmp', ''),
		('5000', 'Tif', ''),
		('6000', 'Png', '');
		CREATE TABLE ax_typ_textur3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_typ_textur3d IS 'Alias: "AX_Typ_Textur3D", UML-Typ: Enumeration';
		INSERT INTO ax_typ_textur3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'Typisch', 'Eine typische Textur ist eine generalisierte Darstellung der Struktur und Farbe der Oberfläche.'),
		('2000', 'Spezifisch', 'Eine spezifische Textur ist eine fotorealistische Darstellung der Oberfläche.');
		CREATE TABLE ax_zustand_gebietsgrenze (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_gebietsgrenze IS 'Alias: "AX_Zustand_Gebietsgrenze", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_gebietsgrenze (wert,beschreibung,dokumentation) VALUES
		('4100', 'Streitig/strittig', 'Streitig/strittig bedeutet, dass der Grenzverlauf umstritten ist.'),
		('4200', 'Grenzverlauf, fiktiv', 'Grenzverlauf, fiktiv’ bedeutet, dass für den Grenzverlauf des Gebietes keine explizite Grenzgeometrie festgelegt ist.');
		CREATE TABLE ax_bodenstufe (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_bodenstufe IS 'Alias: "AX_Bodenstufe", UML-Typ: Enumeration';
		INSERT INTO ax_bodenstufe (wert,beschreibung,dokumentation) VALUES
		('2100', 'Bodenstufe (I)', ''),
		('2200', 'Bodenstufe (II)', ''),
		('2300', 'Bodenstufe (III)', ''),
		('2400', 'Bodenstufe Misch- und Schichtböden sowie künstlich veränderte Böden (-)', ''),
		('3100', 'Bodenstufe (II+III)', ''),
		('3200', 'Bodenstufe ("(III)")', ''),
		('3300', 'Bodenstufe (IV)', '');
		CREATE TABLE ax_sonstigeangaben_musterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_sonstigeangaben_musterundvergleichsstueck IS 'Alias: "AX_SonstigeAngaben_MusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_sonstigeangaben_musterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1100', 'Nass, zu viel Wasser (Wa+)', ''),
		('1200', 'Trocken, zu wenig Wasser (Wa-)', ''),
		('1300', 'Besonders günstige Wasserverhältnisse (Wa gt)', ''),
		('1400', 'Rieselwasser, künstliche Bewässerung (RiWa)', ''),
		('2100', 'Unbedingtes Wiesenland (W)', ''),
		('2200', 'Streuwiese (Str)', ''),
		('2300', 'Hutung (Hu)', ''),
		('2400', 'Acker-Hackrain (Hack)', ''),
		('2500', 'Grünland-Hackrain (Hack)', ''),
		('2600', 'Garten (G)', ''),
		('3000', 'Neukultur (N)', ''),
		('4000', 'Tiefkultur (T)', ''),
		('5000', 'Geringstland (Ger)', '');
		CREATE TABLE ax_merkmal_musterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_merkmal_musterundvergleichsstueck IS 'Alias: "AX_Merkmal_MusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_merkmal_musterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1000', 'Musterstück (M)', ''),
		('3000', 'Vergleichsstück (V)', '');
		CREATE TABLE ax_wasserverhaeltnisse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_wasserverhaeltnisse IS 'Alias: "AX_Wasserverhaeltnisse", UML-Typ: Enumeration';
		INSERT INTO ax_wasserverhaeltnisse (wert,beschreibung,dokumentation) VALUES
		('7000', 'Wasserstufe nicht erkennbar (-)', ''),
		('7100', 'Wasserstufe (1)', ''),
		('7200', 'Wasserstufe (2)', ''),
		('7300', 'Wasserstufe (3)', ''),
		('7310', 'Wasserstufe (3-)', ''),
		('7400', 'Wasserstufe (4)', ''),
		('7410', 'Wasserstufe (4-)', ''),
		('7500', 'Wasserstufe (5)', ''),
		('7510', 'Wasserstufe (5-)', ''),
		('7600', 'Wasserstufe (3+4)', '');
		CREATE TABLE ax_bodenart_musterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_bodenart_musterundvergleichsstueck IS 'Alias: "AX_Bodenart_MusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_bodenart_musterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1100', 'Sand (S)', ''),
		('1200', 'Anlehmiger Sand (Sl)', ''),
		('2100', 'Lehmiger Sand (lS)', ''),
		('2200', 'Stark lehmiger Sand (SL)', ''),
		('3100', 'Lehm (L)', ''),
		('3200', 'Sandiger Lehm (sL)', ''),
		('4100', 'Ton (T)', ''),
		('4200', 'Schwerer Lehm (LT)', ''),
		('5000', 'Moor (Mo)', ''),
		('6110', 'Sand mit Moor (SMo)', ''),
		('6120', 'Lehmiger Sand mit Moor (lSMo)', ''),
		('6130', 'Lehm mit Moor (LMo)', ''),
		('6140', 'Ton mit Moor (TMo)', ''),
		('6210', 'Moor mit Sand (MoS)', ''),
		('6220', 'Moor mit lehmigem Sand (MolS)', ''),
		('6230', 'Moor mit Lehm (MoL)', ''),
		('6240', 'Moor mit Ton (MoT)', ''),
		('7100', 'Sand auf stark lehmigem Sand (S/SL)', ''),
		('7110', 'Sand auf sandigem Lehm (S/sL)', ''),
		('7120', 'Sand auf Lehm (S/L)', ''),
		('7130', 'Sand auf schwerem Lehm (S/LT)', ''),
		('7140', 'Sand auf Ton (S/T)', ''),
		('7200', 'Anlehmiger Sand auf sandigem Lehm (Sl/sL)', ''),
		('7210', 'Anlehmiger Sand auf Lehm (Sl/L)', ''),
		('7220', 'Anlehmiger Sand auf schwerem Lehm (Sl/LT)', ''),
		('7230', 'Anlehmiger Sand auf Ton (Sl/T)', ''),
		('7300', 'Lehmiger Sand auf Lehm (lS/L)', ''),
		('7310', 'Lehmiger Sand auf schwerem Lehm (lS/LT)', ''),
		('7320', 'Lehmiger Sand auf Sand (lS/S)', ''),
		('7330', 'Lehmiger Sand auf Ton (lS/T)', ''),
		('7400', 'Stark lehmiger Sand auf Ton (SL/T)', ''),
		('7410', 'Stark lehmiger Sand auf schwerem Lehm (SL/LT)', ''),
		('7420', 'Stark lehmiger Sand auf Sand (SL/S)', ''),
		('7500', 'Ton auf sandigem Lehm (T/sL)', ''),
		('7510', 'Ton auf stark lehmigem Sand (T/SL)', ''),
		('7520', 'Ton auf lehmigem Sand (T/lS)', ''),
		('7530', 'Ton auf anlehmigem Sand (T/Sl)', ''),
		('7540', 'Ton auf Sand (T/S)', ''),
		('7600', 'Schwerer Lehm auf stark lehmigem Sand (LT/SL)', ''),
		('7610', 'Schwerer Lehm auf lehmigem Sand (LT/lS)', ''),
		('7620', 'Schwerer Lehm auf anlehmigem Sand (LT/Sl)', ''),
		('7630', 'Schwerer Lehm auf Sand (LT/S)', ''),
		('7700', 'Lehm auf lehmigem Sand (L/lS)', ''),
		('7710', 'Lehm auf anlehmigem Sand (L/Sl)', ''),
		('7720', 'Lehm auf Sand (L/S)', ''),
		('7800', 'Sandiger Lehm auf Sand (sL/S)', ''),
		('7810', 'Sandiger Lehm auf anlehmigem Sand (sL/Sl)', ''),
		('7820', 'Sandiger Lehm auf Ton (sL/T)', ''),
		('8110', 'Sand auf Moor (S/Mo)', ''),
		('8120', 'Lehmiger Sand auf Moor (lS/Mo)', ''),
		('8130', 'Lehm auf Moor (L/Mo)', ''),
		('8140', 'Ton auf Moor (T/Mo)', ''),
		('8210', 'Moor auf Sand (Mo/S)', ''),
		('8220', 'Moor auf lehmigem Sand (Mo/lS)', ''),
		('8230', 'Moor auf Lehm (Mo/L)', ''),
		('8240', 'Moor auf Ton (Mo/T)', ''),
		('9120', 'Lehm und Moor, Bodenwechsel (L+Mo)', ''),
		('9130', 'Lehmiger Sand, steinig (lSg)', ''),
		('9140', 'Lehm, steinig (Lg)', ''),
		('9150', 'Lehmiger Sand und Steine/Blöcke (lS+St)', ''),
		('9160', 'Lehm und Steine/Blöcke (L+St)', ''),
		('9170', 'Steine/Blöcke und lehmiger Sand (St+lS)', ''),
		('9180', 'Steine/Blöcke und Lehm (St+L)', ''),
		('9190', 'Lehmiger Sand und Felsen (lS+Fe)', ''),
		('9200', 'Lehm und Felsen (L+Fe)', ''),
		('9210', 'Felsen und lehmiger Sand (Fe+lS)', ''),
		('9220', 'Felsen und Lehm (Fe+L)', '');
		CREATE TABLE ax_klimastufe (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_klimastufe IS 'Alias: "AX_Klimastufe", UML-Typ: Enumeration';
		INSERT INTO ax_klimastufe (wert,beschreibung,dokumentation) VALUES
		('6000', 'Klimastufe nicht erkennbar (-)', ''),
		('6100', 'Klimastufe 8° C und darüber (a)', ''),
		('6200', 'Klimastufe 7,9° - 7,0° C (b)', ''),
		('6300', 'Klimastufe 6,9° - 5,7° C (c)', ''),
		('6400', 'Klimastufe 5,6° C und darunter (d)', '');
		CREATE TABLE ax_entstehungsart (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_entstehungsart IS 'Alias: "AX_Entstehungsart", UML-Typ: Enumeration';
		INSERT INTO ax_entstehungsart (wert,beschreibung,dokumentation) VALUES
		('1000', 'Diluvium (D)', ''),
		('1100', 'Diluvium, Alluvium (DAl)', ''),
		('1110', 'Diluvium, Alluvium, grob, steinig (DAlg)', ''),
		('1200', 'Diluvium, Löß (DLö)', ''),
		('1300', 'Diluvium, Verwitterung (DV)', ''),
		('1310', 'Diluvium, Verwitterung, grob, steinig (DVg)', ''),
		('1400', 'Diluvium, grob, steinig (Dg)', ''),
		('1410', 'Diluvium, grob, steinig, Alluvium (DgAl)', ''),
		('1420', 'Diluvium, grob, steinig, Löß (DgLö)', ''),
		('1430', 'Diluvium, grob, steinig, Verwitterung (DgV)', ''),
		('2000', 'Löß (Lö)', ''),
		('2100', 'Löß, Diluvium (LöD)', ''),
		('2110', 'Löß, Diluvium, grob, steinig (LöDg)', ''),
		('2120', 'Löß, Diluvium, Verwitterung (LöDV)', ''),
		('2200', 'Löß, Alluvium (LöAl)', ''),
		('2210', 'Löß, Alluvium, grob, steinig (LöAlg)', ''),
		('2300', 'Löß, Verwitterung (LöV)', ''),
		('2310', 'Löß, Verwitterung, grob, steinig (LöVg)', ''),
		('2400', 'Löß über Verwitterung, gesteinig (LöVg)', ''),
		('3000', 'Alluvium (Al)', ''),
		('3100', 'Alluvium, Diluvium (AlD)', ''),
		('3200', 'Alluvium, Löß (AlLö)', ''),
		('3300', 'Alluvium, Verwitterung (AlV)', ''),
		('3310', 'Alluvium, Verwitterung, grob, steinig (AlVg)', ''),
		('3400', 'Alluvium, grob, steinig (Alg)', ''),
		('3410', 'Alluvium, grob, steinig, Diluvium (AlgD)', ''),
		('3420', 'Alluvium, grob, steinig, Löß (AlgLö)', ''),
		('3430', 'Alluvium, grob, steinig, Verwitterung (AlgV)', ''),
		('3500', 'Alluvium, Marsch (AlMa)', ''),
		('3610', 'Alluvium, Moor (AlMo)', ''),
		('3620', 'Moor, Alluvium (MoAI)', ''),
		('3700', 'Mergel (Me)', ''),
		('4000', 'Verwitterung (V)', ''),
		('4100', 'Verwitterung, Diluvium (VD)', ''),
		('4110', 'Verwitterung, Diluvium, grob, steinig (VDg)', ''),
		('4200', 'Verwitterung, Alluvium (VAl)', ''),
		('4210', 'Verwitterung, Alluvium, grob, steinig (VAlg)', ''),
		('4300', 'Verwitterung, Löß (VLö)', ''),
		('4400', 'Verwitterung, grob, steinig (Vg)', ''),
		('4410', 'Verwitterung, grob, steinig, Diluvium (VgD)', ''),
		('4420', 'Verwitterung, grob, steinig, Löß (VgLö)', ''),
		('4430', 'Verwitterung, grob, steinig, Alluvium (VgAl)', ''),
		('5000', 'Entstehungsart nicht erkennbar (-)', '');
		CREATE TABLE ax_zustandsstufe (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustandsstufe IS 'Alias: "AX_Zustandsstufe", UML-Typ: Enumeration';
		INSERT INTO ax_zustandsstufe (wert,beschreibung,dokumentation) VALUES
		('1100', 'Zustandsstufe (1)', ''),
		('1200', 'Zustandsstufe (2)', ''),
		('1300', 'Zustandsstufe (3)', ''),
		('1400', 'Zustandsstufe (4)', ''),
		('1500', 'Zustandsstufe (5)', ''),
		('1600', 'Zustandsstufe (6)', ''),
		('1700', 'Zustandsstufe (7)', ''),
		('1800', 'Zustandsstufe Misch- und Schichtböden sowie künstlich veränderte Böden (-)', '');
		CREATE TABLE ax_nutzungsart_bodenschaetzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_nutzungsart_bodenschaetzung IS 'Alias: "AX_Nutzungsart_Bodenschaetzung", UML-Typ: Enumeration';
		INSERT INTO ax_nutzungsart_bodenschaetzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ackerland (A)', ''),
		('2000', 'Acker-Grünland (AGr)', ''),
		('3000', 'Grünland (Gr)', ''),
		('4000', 'Grünland-Acker (GrA)', '');
		CREATE TABLE ax_nutzungsart_musterundvergleichsstueck (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_nutzungsart_musterundvergleichsstueck IS 'Alias: "AX_Nutzungsart_MusterUndVergleichsstueck", UML-Typ: Enumeration';
		INSERT INTO ax_nutzungsart_musterundvergleichsstueck (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ackerland (A)', ''),
		('2000', 'Acker-Grünland (AGr)', ''),
		('3000', 'Grünland (Gr)', ''),
		('4000', 'Grünland-Acker (GrA)', '');
		CREATE TABLE ax_ergebnisderueberpruefung_klassifizierungnachwasserrecht (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_ergebnisderueberpruefung_klassifizierungnachwasserrecht IS 'Alias: "AX_ErgebnisDerUeberpruefung_KlassifizierungNachWasserrecht", UML-Typ: Enumeration';
		INSERT INTO ax_ergebnisderueberpruefung_klassifizierungnachwasserrecht (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fehlerkorrektur', 'Fehlerkorrektur beschreibt dass eine Anpassung durchgeführt wurde, obwohl in der Realwelt keine tatsächliche Änderung stattgefunden hat.'),
		('2000', 'Bestätigung des Ist-Zustandes', 'Bestätigung des Ist-Zustandes beschreibt, dass das Objekt zum Zeitpunkt einer Überprüfung als zutreffend ermittelt wurde.'),
		('3000', 'Erfassung eines neuen Objektes', 'Erfassung eines neuen Objektes beschreibt, dass eine tatsächliche Änderungen in der Realwelt zur Neubildung des Objektes geführt haben. Das bedeutet, dass eine fachliche Änderung auf Ebene der Objekt- und/oder Attributart stattfand.'),
		('4000', 'Geometrieveränderung eines bestehenden Objektes', 'Geometrieveränderung eines bestehenden Objektes beschreibt eine Änderung der Umringsgeometrie in der Realwelt, ohne das eine fachliche Änderung auf Ebene der Objekt- oder Attributart stattfand.');
		CREATE TABLE ax_rolledergemeinde (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_rolledergemeinde IS 'Alias: "AX_RolleDerGemeinde", UML-Typ: Enumeration';
		INSERT INTO ax_rolledergemeinde (wert,beschreibung,dokumentation) VALUES
		('5000', 'Gemeinde, die sich einer erfüllenden Gemeinde bedient', 'Gemeinde, die sich einer erfüllenden Gemeinde bedient umfasst in einem Bundesland das Gebiet einer Gemeinde, die sich einer erfüllenden Gemeinde bedient.'),
		('6000', 'Erfüllende Gemeinde', 'Erfüllende Gemeinde umfasst in einem Bundesland das Gebiet einer erfüllende Gemeinde, welche in einer vereinbarten Verwaltungsgemeinschaft die Aufgaben des Gemeindeverwaltungsverbands erfüllt.');
		CREATE TABLE ax_buchungsart_anlieger (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_buchungsart_anlieger IS 'Alias: "AX_Buchungsart_Anlieger", UML-Typ: Enumeration';
		INSERT INTO ax_buchungsart_anlieger (wert,beschreibung,dokumentation) VALUES
		('5200', 'Anliegerflurstück', 'Ein Flurstück dessen Teilflächen den anliegenden Flurstücken zugerechnet wird.'),
		('5201', 'Anliegerweg', ''),
		('5202', 'Anliegergraben', ''),
		('5203', 'Anliegerwasserlauf, Anliegergewässer', '');
		CREATE TABLE ax_wirtschaftsartgrundbuch (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_wirtschaftsartgrundbuch IS 'Alias: "AX_WirtschaftsartGrundbuch", UML-Typ: Enumeration';
		INSERT INTO ax_wirtschaftsartgrundbuch (wert,beschreibung,dokumentation) VALUES
		('Wohnbaufläche', NULL, 'Wohnbaufläche wird aggregiert aus der Nutzungsart 1100.'),
		('Industrie- und Gewerbefläche', NULL, 'Industrie- und Gewerbefläche wird aggregiert aus den Nutzungsarten 1200 bis 1204, 1300 bis 1308, 1400 bis 1405 und 1500 bis 1505.'),
		('Mischnutzung', NULL, 'Mischnutzung wird aggregiert aus den Nutzungsarten 1600 bis 1671 und 1700 bis 1702.'),
		('Gebäude- und Freifläche Land- und Forstwirtschaft', NULL, 'Gebäude- und Freifläche Land- und Forstwirtschaft wird aggregiert aus der Nutzungsart 1672.'),
		('Erholungsfläche', NULL, 'Erholungsfläche wird aggregiert aus den Nutzungsarten 1800 bis 1871.'),
		('Friedhof', NULL, 'Friedhof wird aggregiert aus den Nutzungsarten 1900 bis 1971.'),
		('Verkehrsfläche', NULL, 'Verkehrsfläche wird aus den Nutzungsarten 2101 bis 2271, 2300 bis 2371 und 2400 bis 2471 aggregiert.'),
		('Landwirtschaftsfläche', NULL, 'Landwirtschaftsfläche wird aggregiert aus den Nutzungsarten 3100 bis 3109.'),
		('Waldfläche', NULL, 'Waldfläche wird aggregiert aus den Nutzungsartenkennungen 3200 bis 3203.'),
		('Sonstige Vegetationsfläche', NULL, 'Sonstige Vegetationsfläche wird aggregiert aus den Nutzungsarten 3300, 3400, 3500 und 3600.'),
		('Unland', NULL, 'Unland wird aggregiert aus den Nutzungsarten 3700 bis 3704.'),
		('Wasserfläche', NULL, 'Wasserfläche wird aggregiert aus den Nutzungsarten 4100 bis 4104, 4200 und 4201, 4300 bis 4303, 4400 und 4401.');
		CREATE TABLE ax_abgabeversion (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_abgabeversion IS 'Alias: "AX_Abgabeversion", UML-Typ: Enumeration';
		INSERT INTO ax_abgabeversion (wert,beschreibung,dokumentation) VALUES
		('7.1.0', NULL, ''),
		('6.0.1', NULL, ''),
		('6.0.0', NULL, '');
		CREATE TABLE ax_verwendeteobjekte_abgeleitetehoehenlinie (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_verwendeteobjekte_abgeleitetehoehenlinie IS 'Alias: "AX_VerwendeteObjekte_AbgeleiteteHoehenlinie", UML-Typ: Enumeration';
		INSERT INTO ax_verwendeteobjekte_abgeleitetehoehenlinie (wert,beschreibung,dokumentation) VALUES
		('5200', 'DGM', ''),
		('5210', 'DGM modifiziert', ''),
		('5410', 'Punktwolke3D', ''),
		('5420', 'Punkt3D', ''),
		('5430', 'Stukturlinie3D', ''),
		('5440', 'Fläche3D', '');
		CREATE TABLE ax_auspraegung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_auspraegung IS 'Alias: "AX_Auspraegung", UML-Typ: Enumeration';
		INSERT INTO ax_auspraegung (wert,beschreibung,dokumentation) VALUES
		('5200', 'DGM', ''),
		('5210', 'DGM modifiziert', ''),
		('5220', 'DOM', ''),
		('5230', 'DOM modifiziert', '');
		CREATE TABLE ax_verwendeteobjekte_dhmgitter (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_verwendeteobjekte_dhmgitter IS 'Alias: "AX_VerwendeteObjekte_DHMGitter", UML-Typ: Enumeration';
		INSERT INTO ax_verwendeteobjekte_dhmgitter (wert,beschreibung,dokumentation) VALUES
		('5200', 'DGM', ''),
		('5210', 'DGM modifiziert', ''),
		('5220', 'DOM', ''),
		('5230', 'DOM modifiziert', ''),
		('5410', 'Punktwolke3D', ''),
		('5420', 'Punkt3D', ''),
		('5430', 'Stukturlinie3D', ''),
		('5440', 'Fläche3D', '');
		CREATE TABLE ax_ergebnisderueberpruefung_dammwalldeich (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_ergebnisderueberpruefung_dammwalldeich IS 'Alias: "AX_ErgebnisDerUeberpruefung_DammWallDeich", UML-Typ: Enumeration';
		INSERT INTO ax_ergebnisderueberpruefung_dammwalldeich (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fehlerkorrektur', 'Fehlerkorrektur beschreibt dass eine Anpassung durchgeführt wurde, obwohl in der Realwelt keine tatsächliche Änderung stattgefunden hat.'),
		('2000', 'Bestätigung des Ist-Zustandes', 'Bestätigung des Ist-Zustandes beschreibt, dass das Objekt zum Zeitpunkt einer Überprüfung als zutreffend ermittelt wurde.'),
		('3000', 'Erfassung eines neuen Objektes', 'Erfassung eines neuen Objektes beschreibt, dass eine tatsächliche Änderungen in der Realwelt zur Neubildung des Objektes geführt haben. Das bedeutet, dass eine fachliche Änderung auf Ebene der Objekt- und/oder Attributart stattfand.'),
		('4000', 'Geometrieveränderung eines bestehenden Objektes', 'Geometrieveränderung eines bestehenden Objektes beschreibt eine Änderung der Umringsgeometrie in der Realwelt, ohne das eine fachliche Änderung auf Ebene der Objekt- oder Attributart stattfand.');
		CREATE TABLE ax_li_processstep3d_description (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_li_processstep3d_description IS 'Alias: "AX_LI_ProcessStep3D_Description", UML-Typ: Enumeration';
		INSERT INTO ax_li_processstep3d_description (wert,beschreibung,dokumentation) VALUES
		('Erhebung', NULL, 'Erhebung beschreibt im Attribut stepDateTime den Erfassungszeitpunkt (Zeitpunkt der Messung).'),
		('Berechnung', NULL, 'Berechnung beschreibt im Attribut stepDateTime den Auswertezeitpunkt.');
		CREATE TABLE ax_art_strukturlinie3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_art_strukturlinie3d IS 'Alias: "AX_Art_Strukturlinie3D", UML-Typ: Enumeration';
		INSERT INTO ax_art_strukturlinie3d (wert,beschreibung,dokumentation) VALUES
		('1100', 'Gewässerbegrenzung', 'Gewässerbegrenzung ist die Linie, welche ein Gewässer zum Ufer hin abgrenzt.'),
		('1200', 'Geländekante, allgemein', 'Geländekante, allgemein ist die einzelne Kante unterschiedlich geneigter Geländeflächen und keine Obergruppe anderer Geländekanten.'),
		('1210', 'Steilrand, Kliffkante', 'Steilrand, Kliffkante begrenzt den von der Brandung beständig abgetragenen Steilhang einer Küste.'),
		('1220', 'Oberkante', 'Oberkante ist die obere Kante eines ZUSO Böschung, Kliff oder eines Bauwerkes wie z. B. Kai- oder Stützmauer.'),
		('1230', 'Unterkante', 'Unterkante ist die untere Kante eines ZUSO Böschung, Kliff oder eines Bauwerkes wie z. B. Kai- oder Stützmauer.'),
		('1240', 'Sonstige Begrenzungskante', 'Sonstige Begrenzungskante sind alle Kanten, die nicht anderen Kanten zugeordnet werden können (z. B. Trennschraffe).'),
		('1250', 'Oberkante zugleich Unterkante', 'Oberkante zugleich Unterkante beschreibt den Wechsel der Böschungsneigung (Gefällewechsel) innerhalb von ZUSO Böschung, Kliff.'),
		('1300', 'Geripplinie', 'Geripplinie ist eine Falllinie, welche zur Erfassung von Rücken und Mulden erforderlich ist.'),
		('1310', 'Muldenlinie', 'Muldenlinie ist die tiefste Linie einer Mulde.'),
		('1311', 'Wasserführende Muldenlinie', 'Wasserführende Muldenlinie ist die tiefste Linie einer Mulde, die Wasser führt.'),
		('1320', 'Rückenlinie', 'Rückenlinie ist die höchste Linie bei lang gestreckten Bergrücken, welche die Wasserscheide bildet.'),
		('1400', 'Bauwerksbegrenzungslinie', 'Bauwerksbegrenzungslinie ist die Linie, welche ein Bauwerk zur umliegenden Umgebung hin abgrenzt.'),
		('1410', 'Brückenbegrenzungslinie', 'Brückenbegrenzungslinie ist die Linie, welche eine Brücke zur umliegenden Umgebung hin abgrenzt.'),
		('1420', 'Tunnelbegrenzungslinie', 'Tunnelbegrenzungslinie ist die Linie, welche ein Tunnelportal zur umliegenden Umgebung hin abgrenzt.');
		CREATE TABLE ax_art_punkt3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_art_punkt3d IS 'Alias: "AX_Art_Punkt3D", UML-Typ: Enumeration';
		INSERT INTO ax_art_punkt3d (wert,beschreibung,dokumentation) VALUES
		('1010', 'Markanter Geländepunkt', 'Markanter Geländepunkt ist ein charakteristischer Höhenpunkt an markanten Geländestellen.'),
		('1020', 'Kuppenpunkt', 'Kuppenpunkt ist ein charakteristischer Höhenpunkt an der höchsten Stelle einer rundlichen Einzelerhebung.'),
		('1030', 'Kesselpunkt', 'Kesselpunkt ist ein charakteristischer Höhenpunkt an der tiefsten Stelle einer rundlichen Vertiefung.'),
		('1040', 'Sattelpunkt', 'Sattelpunkt ist ein charakteristischer Höhenpunkt im Schnittpunkt einer Rücken und Muldenlinie.'),
		('1100', 'Besonderer Höhenpunkt', 'Besonderer Höhenpunkt ist ein charakteristischer Höhenpunkt.'),
		('1110', 'Höhenpunkt auf Wasserfläche', 'Höhenpunkt auf Wasserfläche ist ein charakteristischer Höhenpunkt auf einer Wasserfläche.'),
		('1120', 'Wegepunkt', 'Wegepunkt ist ein charakteristischer Höhenpunkt auf einem Weg oder einer Straße.'),
		('1210', 'Strukturiert erfasster Geländepunkt', 'Strukturiert erfasster Geländepunkt ist ein Geländepunkt, der nach einem bestimmten Kriterium erfasst wurde.'),
		('1220', 'Gemessener Höhenlinienpunkt', 'Gemessener Höhenlinienpunkt ist ein gemessener Höhenpunkt innerhalb einer Höhenlinie.'),
		('1230', 'Dynamisch gemessener Höhenprofilpunkt', 'Dynamisch gemessener Höhenlinienprofilpunkt ist ein gemessener Höhenpunkt innerhalb eines Höhenprofils.');
		CREATE TABLE ax_datenerhebung3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_datenerhebung3d IS 'Alias: "AX_Datenerhebung3D", UML-Typ: Enumeration';
		INSERT INTO ax_datenerhebung3d (wert,beschreibung,dokumentation) VALUES
		('5000', 'Terrestrische Aufnahme', ''),
		('5001', 'Terrestrisches Laserscanning', ''),
		('5010', 'Interaktive photogrammetrische Datenerfassung', ''),
		('5020', 'Airborn Laserscanning', ''),
		('5021', 'Airborne Laserscanning, first pulse', ''),
		('5022', 'Airborne Laserscanning, last pulse', ''),
		('5030', 'Digitalisierung analoger Vorlagen', ''),
		('5040', 'Bildkorrelation', ''),
		('5060', 'Amtliche Festlegung', ''),
		('9999', 'Sonstiges', '');
		CREATE TABLE ax_art_flaeche3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_art_flaeche3d IS 'Alias: "AX_Art_Flaeche3D", UML-Typ: Enumeration';
		INSERT INTO ax_art_flaeche3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'Aussparungsfläche', 'Aussparungsfläche ist eine Fläche, die bei der DHM-Bearbeitung nicht berücksichtigt wird.'),
		('1010', 'DGM-Aussparungsfläche', 'DGM-Aussparungsfläche ist eine Fläche, die bei der DGM-Bearbeitung nicht berücksichtigt wird.'),
		('1020', 'DOM-Aussparungsfläche', 'DOM-Aussparungsfläche ist eine Fläche, die bei der DOM-Bearbeitung nicht berücksichtigt wird.'),
		('1030', 'Kartographische Aussparungsfläche', 'Kartographische Aussparungsfläche ist eine Fläche, die bei der kartographischen Bearbeitung nicht berücksichtigt wird.'),
		('1040', 'Brückenbegrenzungsfläche', 'Brückenbegrenzungsfläche ist eine Fläche, die bei der Bearbeitung von Brücken-DGM berücksichtigt wird.');
		CREATE TABLE ax_art_punktwolke3d (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_art_punktwolke3d IS 'Alias: "AX_Art_Punktwolke3D", UML-Typ: Enumeration';
		INSERT INTO ax_art_punktwolke3d (wert,beschreibung,dokumentation) VALUES
		('1000', 'Unklassifizierte Punkte', 'Unklassifizierte Punkte sind nicht spezifizierte Höhenpunkte.'),
		('1100', 'Geländepunkte, allgemein', 'Geländepunkte sind nicht näher spezifizierte Höhenpunkte auf dem Gelände als auch in trockengefallenen Gewässer-/Wattflächen.'),
		('1110', 'Feinklassifizierte Geländepunkte', 'Feinklassifizierte Geländepunkte sind verifizierte Höhenpunkte auf dem Gelände als auch in trockengefallenen Gewässer-/Wattflächen.'),
		('1120', 'Geländepunkte ohne Keller', 'Geländepunkte ohne Keller sind Höhenpunkte auf dem Gelände als auch in trockengefallenen Gewässer-/Wattflächen, die nicht in einem (Keller-)Abgang oder Lichtschacht liegen.'),
		('1130', 'Gewässerpunkte', 'Gewässerpunkte sind nicht näher spezifizierte Höhenpunkte auf einem Gewässer.'),
		('1200', 'Nicht-Geländepunkte, allgemein', 'Nicht-Geländepunkte sind nicht näher spezifizierte Höhenpunkte, die nicht auf dem Gelände liegen.'),
		('1210', 'Tiefpunkte, Rauschen', 'Tiefpunkte sind nicht näher spezifizierte Höhenpunkte, die unterhalb des Geländes liegen und durch Fehlmessungen (Multipath-Effekt) entstanden sind.'),
		('1220', 'Hochpunkte, Rauschen', 'Hochpunkte sind nicht näher spezifizierte Höhenpunkte, die kein Oberflächenobjekt beschreiben und durch Fehlmessungen (z. B.: Vögel, Nebel, Wolken, etc.) entstanden sind.'),
		('1300', 'Bauwerkspunkte, allgemein', 'Bauwerkspunkte sind nicht näher spezifizierte Höhenpunkte auf einem Bauwerk.'),
		('1310', 'Gebäudepunkte', 'Gebäudepunkte sind nicht näher spezifizierte Höhenpunkte auf einem Gebäude.'),
		('1315', 'Gebäudeinstallationspunkte', 'Gebäudeinstallationspunkte sind Höhenpunkte, auf einer Gebäudeinstallation (z.B.: Antenne, Schornstein, etc.).'),
		('1318', 'Kellerpunkte', 'Kellerpunkte sind Höhenpunkte, die in einem Keller-/Abgang oder Lichtschacht liegen.'),
		('1320', 'Brückenpunkte', 'Brückenpunkte sind nicht näher spezifizierte Höhenpunkte auf einem Brückenbauwerk, die die eigentliche Brückenüberführung beschreiben.'),
		('1325', 'Brückenfundamentpunkte', 'Brückenfundamentpunkte sind Höhenpunkte, die das Brückenfundament sowie Pfeiler und Widerlager beschreiben.'),
		('1330', 'Wasserbauwerkspunkte', 'Wasserbauwerkspunkte sind Höhenpunkte, die ein Wasserbauwerk wie z. B. Buhnen, Parallelwerke, Leitdämme, nicht bewegliche Bauteile von Anlegebrücken, Sperrwerken und Schleusen, Wehre, Leuchtfeuer, etc. beschreiben.'),
		('1340', 'Straßenpunkte', 'Straßenpunkte sind nicht näher spezifizierte Höhenpunkte auf einer Straße.'),
		('1350', 'Bahnkörperpunkte', 'Bahnkörperpunkte sind nicht näher spezifizierte Höhenpunkte auf einem Bahnkörper (Schotterung).'),
		('1400', 'Vegetationspunkte, allgemein', 'Vegetationspunkte sind nicht näher spezifizierte Höhenpunkte auf der Vegetation.'),
		('1401', 'Vegetationspunkte, niedrige Vegetation', 'Vegetationspunkte, niedrige Vegetation sind nicht näher spezifizierte Höhenpunkte auf der Vegetation mit einer Höhe bis 1,5 Meter über dem Gelände.'),
		('1402', 'Vegetationspunkte, mittel hohe Vegetation', 'Vegetationspunkte, mittelhohe Vegetation sind nicht näher spezifizierte Höhenpunkte auf der Vegetation mit einer Höhe ab 1,5 Meter bis 8 Meter über dem Gelände.'),
		('1403', 'Vegetationspunkte, hohe Vegetation', 'Vegetationspunkte, hohe Vegetation sind nicht näher spezifizierte Höhenpunkte auf der Vegetation mit einer Höhe ab 8 Meter über dem Gelände.'),
		('1500', 'Energieversorgungspunkte, allgemein', 'Energieversorgungspunkte sind nicht näher spezifizierte Höhenpunkte auf einem Energieversorgungsobjekt.'),
		('1501', 'Leitungsschutzpunkte', 'Leitungsschutzpunkte sind Höhenpunkte auf einem Leitungsschutz.'),
		('1502', 'Leitungsdrahtpunkte', 'Leitungsdrahtpunkte sind Höhenpunkte auf einem Leitungsdraht.'),
		('1503', 'Fernleitungsmastpunkte', 'Fernleitungsmastpunkte sind Höhenpunkte auf einem Fernleitungsmast.'),
		('1504', 'Fernleitungsinfrastrukturpunkte', 'Fernleitungsinfrastrukturpunkte sind nicht näher spezifizierte Höhenpunkte auf einem Fernleitungsinfrastrukturobjekt wie z. B. einem Isolator, etc.');
		CREATE TABLE ax_ergebnisderueberpruefung_tatsaechlichenutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_ergebnisderueberpruefung_tatsaechlichenutzung IS 'Alias: "AX_ErgebnisDerUeberpruefung_TatsaechlicheNutzung", UML-Typ: Enumeration';
		INSERT INTO ax_ergebnisderueberpruefung_tatsaechlichenutzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fehlerkorrektur', 'Fehlerkorrektur beschreibt dass eine Anpassung durchgeführt wurde, obwohl in der Realwelt keine tatsächliche Änderung stattgefunden hat.'),
		('2000', 'Bestätigung des Ist-Zustandes', 'Bestätigung des Ist-Zustandes beschreibt, dass das Objekt zum Zeitpunkt einer Überprüfung als zutreffend ermittelt wurde.'),
		('3000', 'Erfassung eines neuen Objektes', 'Erfassung eines neuen Objektes beschreibt, dass eine tatsächliche Änderungen in der Realwelt zur Neubildung des Objektes geführt haben. Das bedeutet, dass eine fachliche Änderung auf Ebene der Objekt- und/oder Attributart stattfand.'),
		('4000', 'Geometrieveränderung eines bestehenden Objektes', 'Geometrieveränderung eines bestehenden Objektes beschreibt eine Änderung der Umringsgeometrie in der Realwelt, ohne das eine fachliche Änderung auf Ebene der Objekt- oder Attributart stattfand.');
		CREATE TABLE ax_weiterenutzung_tatsaechlichenutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_weiterenutzung_tatsaechlichenutzung IS 'Alias: "AX_WeitereNutzung_TatsaechlicheNutzung", UML-Typ: Enumeration';
		INSERT INTO ax_weiterenutzung_tatsaechlichenutzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Überlagernd', 'Überlagernd beschreibt die Überlagerung des Objektes zu weiteren Objekten der Tatsächlichen Nutzung.');
		CREATE TABLE ax_zustand_stehendesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_stehendesgewaesser IS 'Alias: "AX_Zustand_StehendesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_stehendesgewaesser (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt', 'Außer Betrieb, stillgelegt bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechender Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ax_zustand_gewaesserachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_gewaesserachse IS 'Alias: "AX_Zustand_Gewaesserachse", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_gewaesserachse (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb, stillgelegt, verlassen', 'Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich der Kanal nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass der Kanal noch nicht fertiggestellt ist.');
		CREATE TABLE ax_nutzung_stehendesgewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_nutzung_stehendesgewaesser IS 'Alias: "AX_Nutzung_StehendesGewaesser", UML-Typ: Enumeration';
		INSERT INTO ax_nutzung_stehendesgewaesser (wert,beschreibung,dokumentation) VALUES
		('1000', 'Trinkwasser', 'Trinkwasser im vorliegenden Sinne bezeichnet Wasser, das für den menschlichen Genuss geeignet ist.'),
		('2000', 'Energie', 'Energie weist die Nutzung eines Stehenden Gewässers zur Energiegewinnung aus.'),
		('3000', 'Brauchwasser', 'Brauchwasser dient spezifischen technischen, gewerblichen, industriellen, landwirtschaftlichen, hauswirtschaftlichen oder ähnlichen Zwecken, ohne dass hierfür Trinkwasserqualität verlangt wird. Hierzu zählen z B. Kesselspeisewasser, Kühlwasser, unterschiedlich aufbereitetes Rohwasser.');
		CREATE TABLE ax_funktion_siedlungsflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_funktion_siedlungsflaeche IS 'Alias: "AX_Funktion_Siedlungsflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_siedlungsflaeche (wert,beschreibung,dokumentation) VALUES
		('1200', 'Parken', 'Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		CREATE TABLE ax_funktion_tagebaugrubesteinbruch (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_funktion_tagebaugrubesteinbruch IS 'Alias: "AX_Funktion_TagebauGrubeSteinbruch", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_tagebaugrubesteinbruch (wert,beschreibung,dokumentation) VALUES
		('1200', 'Parken', 'Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		CREATE TABLE ax_funktion_bergbaubetrieb (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_funktion_bergbaubetrieb IS 'Alias: "AX_Funktion_Bergbaubetrieb", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_bergbaubetrieb (wert,beschreibung,dokumentation) VALUES
		('1200', 'Parken', 'Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		CREATE TABLE ax_funktion_wohnbauflaeche (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_funktion_wohnbauflaeche IS 'Alias: "AX_Funktion_Wohnbauflaeche", UML-Typ: Enumeration';
		INSERT INTO ax_funktion_wohnbauflaeche (wert,beschreibung,dokumentation) VALUES
		('1200', 'Parken', 'Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		CREATE TABLE ax_zustand_wald (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_zustand_wald IS 'Alias: "AX_Zustand_Wald", UML-Typ: Enumeration';
		INSERT INTO ax_zustand_wald (wert,beschreibung,dokumentation) VALUES
		('6100', 'Verjüngungs-, Neuanpflanzungsfläche', 'Verjüngungs-, Neuanpflanzungsfläche bedeutet, dass sich der Wald durch Aufforstung, Naturverjüngung oder durch Anpflanzung neu bildet.'),
		('6200', 'Waldbestattungsfläche', 'Waldbestattungsfläche ist eine Fläche im Wald, die zur Bestattung dient oder gedient hat.'),
		('6300', 'Unbewirtschaftet', 'Unbewirtschaftet bezeichnet eine Waldfläche, mit oder ohne Bäumen, welche nicht bewirtschaftet bzw. nicht wirtschaftlich genutzt wird.'),
		('7000', 'Forstwirtschaftsfläche', 'Forstwirtschaftsfläche bezeichnet eine Waldfläche, mit oder ohne Bäumen, welche forstwirtschaftlich genutzt wird. Hierzu zählen keine Kurzumtriebsplantagen.'),
		('7100', 'Dauerhaft unbestockt', 'Dauerhaft unbestockt umfasst alle als Waldflächen geltenden Flächen, auf denen dauerhaft weder Bäume noch sonstige Gehölze stehen, aber stehen könnten. Hierzu zählen z.B. Lichtungen.');
		CREATE TABLE ax_besondereverkehrsbedeutung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_besondereverkehrsbedeutung IS 'Alias: "AX_BesondereVerkehrsbedeutung", UML-Typ: Enumeration';
		INSERT INTO ax_besondereverkehrsbedeutung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Durchgangsverkehr, überörtlicher Verkehr', 'Durchgangsverkehr, überörtlicher Verkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer Straße (Durchgangsstraße), unabhängig von gesetzlichen Festlegungen (z. B. Landesstraßengesetz). Als Durchgangsstraße wird die Straße bezeichnet, auf der aufgrund des Ausbauzustandes und der örtlichen Verkehrsregelung der überörtliche Verkehr durch ein bebautes Gebiet geleitet wird. Der Durchgangsverkehr kann sowohl auf Gemeindestraßen als auch auf höherwertig klassifizierten Straßen liegen.'),
		('1003', 'Nahverkehr, zwischenörtlicher Verkehr', 'Nahverkehr, zwischenörtlicher Verkehr findet hauptsächlich auf Kreis- und Gemeindestraßen statt.'),
		('2000', 'Ortsverkehr', 'Ortsverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer Straße (Ortsstraße), unabhängig von örtlichen Festlegungen (z. B. Ortssatzungen). Ortsstraße ist in der Regel eine als Gemeindestraße gewidmete Straße, auf der kein Durchgangsverkehr verläuft.'),
		('2001', 'Sammelverkehr', 'Sammelverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer Straße (Sammelstraße), unabhängig von örtlichen Festlegungen (z. B. Ortssatzungen). Die Sammelstraße leitet hauptsächlich den innerörtlichen Verkehr von den Anliegerstrassen zur Durchgangsstraße.'),
		('2002', 'Anliegerverkehr', 'Anliegerverkehr beschreibt den tatsächlich stattfindenden Verkehr auf einer Straße (Anliegerstraße), unabhängig von örtlichen Festlegungen (z. B. Ortssatzungen). Die Anliegerstraße ist eine Straße auf die jeder Straßenanlieger von seinem Anwesen aus freie Zufahrt hat und die nicht die Funktion einer Sammelstraße übernimmt.');
		CREATE TABLE ax_verkehrsdienst_bahnstrecke (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_verkehrsdienst_bahnstrecke IS 'Alias: "AX_Verkehrsdienst_Bahnstrecke", UML-Typ: Enumeration';
		INSERT INTO ax_verkehrsdienst_bahnstrecke (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fernverkehr', 'Fernverkehr bedeutet, dass auf der Bahnstrecke von einem Eisenbahnverkehrsunternehmen ein nationaler oder internationaler Schienenpersonenfernverkehrsdienst erbracht wird.');
		CREATE TABLE ax_bahnkategorie_bahnstrecke (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_bahnkategorie_bahnstrecke IS 'Alias: "AX_Bahnkategorie_Bahnstrecke", UML-Typ: Enumeration';
		INSERT INTO ax_bahnkategorie_bahnstrecke (wert,beschreibung,dokumentation) VALUES
		('1100', 'Eisenbahn', 'Eisenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr Personen befördert und/oder Güter transportiert werden.'),
		('1101', 'Personenverkehr', 'Personenverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und / oder Fernverkehr Personen transportiert werden.'),
		('1102', 'Güterverkehr', 'Güterverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und / oder Fernverkehr Güter transportiert werden.'),
		('1104', 'S-Bahn', 'S-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, der zur schnellen Personenbeförderung in Ballungsräumen dient und meist auf eigenen Gleisen verläuft.'),
		('1200', 'Stadtbahn', 'Stadtbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung im öffentlichen Nahverkehr fährt. Sie kann sowohl ober- als auch unterirdisch verlaufen.'),
		('1201', 'Straßenbahn', 'Straßenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung fährt. Sie verläuft i. d. R. oberirdisch.'),
		('1202', 'U-Bahn', 'U-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung in Großstädten fährt. Sie verläuft i. d. R. unterirdisch.'),
		('1300', 'Seilbahn, Bergbahn', 'Seilbahn, Bergbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn große Höhenunterschiede überwindet.'),
		('1301', 'Zahnradbahn', 'Zahnradbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn mittels Zahnradantrieb große Höhenunterschiede in stark geneigtem Gelände überwindet.'),
		('1302', 'Standseilbahn', 'Standseilbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn auf einer stark geneigten, meist kurzen und geraden Strecke verläuft. Mit Hilfe eines oder mehrerer Zugseile wird ein Schienenfahrzeug bergauf gezogen und gleichzeitig ein zweites bergab gelassen.'),
		('1400', 'Museumsbahn', 'Museumsbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem ausschließlich Touristen in alten, meist restaurierten Zügen befördert werden.'),
		('1500', 'Bahn im Freizeitpark', 'Bahn im Freizeitpark ist die Bezeichnung für einen schienengebundenen Verkehrsweg innerhalb eines Freizeitparks.'),
		('1600', 'Magnetschwebebahn', 'Magnetschwebebahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem räderlose Schienenfahrzeuge mit Hilfe von Magnetfeldern an oder auf einer Fahrschiene schwebend entlanggeführt werden.');
		CREATE TABLE ax_befahrbarkeit_fahrwegachse (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_befahrbarkeit_fahrwegachse IS 'Alias: "AX_Befahrbarkeit_Fahrwegachse", UML-Typ: Enumeration';
		INSERT INTO ax_befahrbarkeit_fahrwegachse (wert,beschreibung,dokumentation) VALUES
		('1000', 'Ganzjährig befahrbar', 'Ganzjährig befahrbar bedeutet, dass Fahrwegachse zu jeder Jahreszeit befahrbar ist.'),
		('2000', 'Eingeschränkt befahrbar', 'Eingeschränkt befahrbar bedeutet, dass Fahrwegachse nicht ganzjährig befahrbar ist.');
		CREATE TABLE ax_selektionsmasstab_benutzungsauftrag (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_selektionsmasstab_benutzungsauftrag IS 'Alias: "AX_Selektionsmasstab_Benutzungsauftrag", UML-Typ: Enumeration';
		INSERT INTO ax_selektionsmasstab_benutzungsauftrag (wert,beschreibung,dokumentation) VALUES
		('0500', '1-zu-500', ''),
		('1000', '1-zu-1000', ''),
		('2000', '1-zu-2000', ''),
		('3000', '1-zu-5000', '');
		CREATE TABLE ax_verarbeitungsart_fortfuehrungsauftrag (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_verarbeitungsart_fortfuehrungsauftrag IS 'Alias: "AX_Verarbeitungsart_Fortfuehrungsauftrag", UML-Typ: Enumeration';
		INSERT INTO ax_verarbeitungsart_fortfuehrungsauftrag (wert,beschreibung,dokumentation) VALUES
		('1000', 'Fortführen mit Sperre', ''),
		('2000', 'Fortführungssimulation mit Unterbrechung der Verarbeitung', ''),
		('3000', 'Unterbrochenen Auftrag fortsetzen', ''),
		('4000', 'Fortführen ohne Sperre', ''),
		('5000', 'Entsperren und Auftrag zurücksetzen', '');
		CREATE TABLE ax_reservierungsart_reservierungsauftrag (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_reservierungsart_reservierungsauftrag IS 'Alias: "AX_Reservierungsart_Reservierungsauftrag", UML-Typ: Enumeration';
		INSERT INTO ax_reservierungsart_reservierungsauftrag (wert,beschreibung,dokumentation) VALUES
		('1100', 'Reservierung im Anschluss an die höchst vergebene Nummer', ''),
		('1200', 'Reservierung im Anschluss an die höchst vergebene Folgenummer', ''),
		('2100', 'Reservierung unter Verwendung von Nummerierungslücken bei der Nummer', ''),
		('2200', 'Reservierung unter Verwendung von Nummerierungslücken bei der Folgenummer', ''),
		('3000', 'Löschung einer Reservierung', '');
		CREATE TABLE ax_verarbeitungsart_einrichtungsauftrag (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_verarbeitungsart_einrichtungsauftrag IS 'Alias: "AX_Verarbeitungsart_Einrichtungsauftrag", UML-Typ: Enumeration';
		INSERT INTO ax_verarbeitungsart_einrichtungsauftrag (wert,beschreibung,dokumentation) VALUES
		('6000', 'Einrichten ohne Sperre', 'Ein Einrichtungsauftrag kann aus mehreren Dateien (Konvoi) bestehen (6000er, mit einem abschließenden 6100er).'),
		('6100', 'Ende Einrichten ohne Sperre', 'Verarbeitungsart der letzten Datei einer Folge von Einrichtungsaufträgen.
		
		6100 ist ein leerer Auftrag, d.h. es sind keine AAA-Fachobjekte enthalten; "LZI.beginnt" wird vom Verarbeitungsbeginn des 6100 einheitlich für ganzen Konvoi bestimmt; 
		
		6100 stößt bezogen auf seinen Konvoi und bezüglich ggf. bereits eingerichteter Bereiche Prüfungen an, z.B. Flächendeckungsprüfungen, die den korrekten Anschluss an das eingerichtete Gebiet gewährleisten.'),
		('6200', 'Abbruch', '6200 dient zum Abbruch eines Konvois und zum Rücksetzen des temporären Arbeitsbereichs.
		
		Nach Ausführung diesen Auftrages ist das aufnehmende System wieder in dem Zustand, der vor Beginn des Einrichtungskonvois dort herrschte.');
		CREATE TABLE ax_impliziteloeschungderreservierung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ax_impliziteloeschungderreservierung IS 'Alias: "AX_ImpliziteLoeschungDerReservierung", UML-Typ: Enumeration';
		INSERT INTO ax_impliziteloeschungderreservierung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Reservierte Punktkennungen und Flurstückskennzeichen löschen', ''),
		('2000', 'Reservierte Punktkennungen löschen', ''),
		('3000', 'Reservierte Flurstückskennzeichen löschen', ''),
		('4000', 'Ohne Löschung reservierter Punktkennungen und Flurstückskennzeichen', '');
		CREATE TABLE lb_wassersaettigung_lockermaterial (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_wassersaettigung_lockermaterial IS 'Alias: "LB_Wassersaettigung_Lockermaterial", UML-Typ: Enumeration';
		INSERT INTO lb_wassersaettigung_lockermaterial (wert,beschreibung,dokumentation) VALUES
		('1000', 'ganzjährig', 'ganzjährige Wassersättigung bedeutet, dass die Hohlräume des Bodens ganzjährig vollständig mit Wasser gefüllt sind. Ein solcher nasser Standort kann zeitweise auch unter Wasser stehen.'),
		('2000', 'zeitweilig', 'zeitweilige Wassersättigung bedeutet, dass die Hohlräume des Bodens in regelmäßigem Zyklus (periodisch) oder nur gelegentlich und vorübergehend (episodisch) vollständig mit Wasser gefüllt sind. Ein solcher vorübergehend nasser Standort kann zeitweise auch unter Wasser stehen.');
		CREATE TABLE lb_oberflaechenmaterial_lockermaterial (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_oberflaechenmaterial_lockermaterial IS 'Alias: "LB_Oberflaechenmaterial_Lockermaterial", UML-Typ: Enumeration';
		INSERT INTO lb_oberflaechenmaterial_lockermaterial (wert,beschreibung,dokumentation) VALUES
		('1000', 'Geröll, Schotter, Kies', 'Geröll, Schotter Kies umfasst unbewachsene Oberflächen, die mit größeren, abgerundeten oder kantigen Gesteinstrümmern bedeckt sind. Hierzu zählen auch Kohle, Erze oder Salze in zerkleinerter Form.'),
		('2000', 'Sand, Feinkies', 'Sand, Feinkies umfasst unbewachsene Oberflächen, die mit kleinen losen Gesteinskörnern bedeckt sind.'),
		('3000', 'Erdreich', 'Erdreich sind unbewachsene Oberflächen, die überwiegend mit Mutterboden (Humusanteil, feine Körngrößen) bedeckt sind.'),
		('4000', 'Ton, Schluff', 'Ton, Schluff umfasst unbewachsene Oberflächen ohne Humusanteil, die mit mineralischen Partikeln sehr feiner Korngröße bedeckt sind und im Allgemeinen auch als Lehm bezeichnet werden.'),
		('5000', 'künstlich', 'künstlich umfasst jegliche Art aus fragmentierten Materialien künstlichen Ursprungs in aufgeschütteter Form. Beispiele für künstliche Materialien sind: Abfall, Müll, Schutt, Schlacke, Schrott, Altmaterial.');
		CREATE TABLE lb_blattform_holzigevegetation (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_blattform_holzigevegetation IS 'Alias: "LB_Blattform_HolzigeVegetation", UML-Typ: Enumeration';
		INSERT INTO lb_blattform_holzigevegetation (wert,beschreibung,dokumentation) VALUES
		('1000', 'Laub', 'Laub beschreibt die Zugehörigkeit der Pflanzen zur Gruppe der Laubhölzer (Bedecktsamer).'),
		('2000', 'Nadel', 'Nadel beschreibt die Zugehörigkeit der Pflanzen zur Gruppe der Nadelhölzer (Nacktsamer).');
		CREATE TABLE lb_wassersaettigung_krautigevegetation (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_wassersaettigung_krautigevegetation IS 'Alias: "LB_Wassersaettigung_KrautigeVegetation", UML-Typ: Enumeration';
		INSERT INTO lb_wassersaettigung_krautigevegetation (wert,beschreibung,dokumentation) VALUES
		('1000', 'ganzjährig', 'ganzjährige Wassersättigung bedeutet, dass die Hohlräume des Bodens ganzjährig vollständig mit Wasser gefüllt sind. Ein solcher nasser Standort kann zeitweise auch unter Wasser stehen.'),
		('2000', 'zeitweilig', 'zeitweilige Wassersättigung bedeutet, dass die Hohlräume des Bodens in regelmäßigem Zyklus (periodisch) oder nur gelegentlich und vorübergehend (episodisch) vollständig mit Wasser gefüllt sind. Ein solcher vorübergehend nasser Standort kann zeitweise auch unter Wasser stehen.');
		CREATE TABLE lb_wassersaettigung_holzigevegetation (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_wassersaettigung_holzigevegetation IS 'Alias: "LB_Wassersaettigung_HolzigeVegetation", UML-Typ: Enumeration';
		INSERT INTO lb_wassersaettigung_holzigevegetation (wert,beschreibung,dokumentation) VALUES
		('1000', 'ganzjährig', 'ganzjährige Wassersättigung bedeutet, dass die Hohlräume des Bodens ganzjährig vollständig mit Wasser gefüllt sind. Ein solcher nasser Standort kann zeitweise auch unter Wasser stehen.'),
		('2000', 'zeitweilig', 'zeitweilige Wassersättigung bedeutet, dass die Hohlräume des Bodens in regelmäßigem Zyklus (periodisch) oder nur gelegentlich und vorübergehend (episodisch) vollständig mit Wasser gefüllt sind. Ein solcher vorübergehend nasser Standort kann zeitweise auch unter Wasser stehen.');
		CREATE TABLE lb_vegetationsmerkmal_krautigevegetation (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_vegetationsmerkmal_krautigevegetation IS 'Alias: "LB_Vegetationsmerkmal_KrautigeVegetation", UML-Typ: Enumeration';
		INSERT INTO lb_vegetationsmerkmal_krautigevegetation (wert,beschreibung,dokumentation) VALUES
		('1000', 'Gras', 'Gras beschreibt den Bewuchs einer Vegetationsfläche mit schlanken, krautigen einkeimblättrigen Blütenpflanzen.'),
		('2000', 'Röhricht, Schilf', 'Röhricht, Schilf beschreibt den Bewuchs einer Vegetations- oder Wasserfläche mit Schilfrohr- und schilfrohrähnlichen Pflanzen.'),
		('3000', 'Getreide, Staudengewächse, Farne', 'Getreide, Staudengewächse, Farne umfasst Flächen, die überwiegend mit krautigen Pflanzen (Getreide, Mais und andere Ackerfrüchte, Staudengewächse, Farne) bestanden sind. Hierzu zählt auch zeitweise vegetationsloses Erdreich (Mutterboden) von landwirtschaftlich genutzten Ackerflächen.');
		CREATE TABLE lb_vegetationsmerkmal_holzigevegetation (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_vegetationsmerkmal_holzigevegetation IS 'Alias: "LB_Vegetationsmerkmal_HolzigeVegetation", UML-Typ: Enumeration';
		INSERT INTO lb_vegetationsmerkmal_holzigevegetation (wert,beschreibung,dokumentation) VALUES
		('4000', 'Bäume', 'Bäume bedeutet, dass die Oberflächen mit verholzten Pflanzen bestanden ist, welche aus einem Wurzelwerk, einem daraus emporsteigenden, hochgewachsenen Stamm und einer verästelten Krone bestehen.'),
		('5000', 'Gehölz', 'Gehölz ist eine Mischfläche, die mit einzelnen verholzten Pflanzen unterschiedlicher Wuchshöhe und Wuchsform (sowohl Bäume als auch Büsche oder Sträucher) in gemischter Form bestockt ist.'),
		('6000', 'Büsche, Sträucher', 'Büsche, Sträucher umfasst eine Fläche, die mit holziger Vegetation unterschiedlicher Wuchsform und begrenzter Wuchshöhe bestanden ist. Büsche und Sträucher haben in der Regel mehrere Stammtriebe, deren Sprossen sich nahe der Bodenoberfläche verzweigen.'),
		('7000', 'Zwergsträucher', 'Zwergsträucher ist eine Sonderform der holzigen Vegetation. Sie umfasst eine Fläche, die mit Pflanzen sehr niederer Wuchshöhe bestanden ist. Beispiele hierfür sind: Heidekrautgewächse, Lavendel.');
		CREATE TABLE lb_fliesseigenschaft_binnengewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_fliesseigenschaft_binnengewaesser IS 'Alias: "LB_Fliesseigenschaft_Binnengewaesser", UML-Typ: Enumeration';
		INSERT INTO lb_fliesseigenschaft_binnengewaesser (wert,beschreibung,dokumentation) VALUES
		('1000', 'fließend', 'fließend bedeutet, dass das Wasser aufgrund eines Gefälles ständig in Bewegung ist.'),
		('2000', 'stehend', 'stehend bedeutet, dass das Gewässer insgesamt oder abschnittsweise eine einheitliche Höhe des Wasserspiegels besitzt; dies schließt saisonale Schwankungen dieser einheitlichen Wasserspiegelhöhe nicht aus.');
		CREATE TABLE lb_gewaesserart_binnengewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_gewaesserart_binnengewaesser IS 'Alias: "LB_Gewaesserart_Binnengewaesser", UML-Typ: Enumeration';
		INSERT INTO lb_gewaesserart_binnengewaesser (wert,beschreibung,dokumentation) VALUES
		('1010', 'Fluss', 'Fluss ist ein natürliches, fließendes Gewässer (ggf. auch mit begradigten, kanalisierten Teilstücken), das wegen seiner Größe und Bedeutung im allgemeinen Sprachgebrauch als Fluss angesprochen wird. Kriterien hierfür können eine größere Wassertiefe, ein größere Breite oder größere Gewässerquerschnitt sein.'),
		('1020', 'Bach', 'Bach ist ein natürliches, fließendes Gewässer, das wegen seiner geringen Größe und Bedeutung im allgemeinen Sprachgebrauch als Bach anzusehen ist. Kriterien hierfür können eine geringere Wassertiefe, eine geringe Breite, oder kleiner Gewässerquerschnitt sein. Bäche unterscheiden sich von Flüssen durch ihren stärker ans Gelände angepassten Verlauf, das unregelmäßige Längsprofil und den oft schießenden Abfluss.'),
		('2000', 'Altwasser, Altarm', 'Altwasser, Altarm ist ein Teil eines Fließgewässers, der bei einer Begradigung vom fließenden Gewässer an beiden oder an einem Ende abgetrennt wurde, wodurch das Gewässer einen eher stehenden Charakter bekommt.'),
		('3010', 'Kanal', 'Kanal bezeichnet einen künstlich angelegten Wasserlauf. In der Regel hat er einen regelmäßigen Gewässerquerschnitt und einen geradlinigen Verlauf.'),
		('3020', 'Graben', 'Graben ist ein ständig oder zeitweise fließendes, künstlich angelegtes Gewässer, das im allgemeinen Sprachgebrauch als Graben anzusehen ist. In der Regel hat er einen regelmäßigen Gewässerquerschnitt und einen geradlinigen Verlauf.'),
		('4000', 'Becken', 'Becken ist eine zweckgebundene, künstlich errichtete, befestigte Hohlform im Gelände, die im allgemeinen Sprachgebrauch als eine Art von "Becken" bezeichnet werden. In der Regel sind Becken von einer künstlich errichteten Umrandung oder einem Bauwerk ganz oder teilweise umschlossen. Beispiele hierfür sind: Hafenbecken, Speicherbecken, Rückhaltebecken, Klärbecken, Fischzuchtbecken.'),
		('5000', 'See, Teich', 'See, Teich ist eine natürliche oder naturnah angelegte, stehende oder nahezu stehende Wasserfläche, die im allgemeinen Sprachgebrauch als See oder Teich anzusehen ist. In der Regel haben Seen und Teiche einen natürlichen oder naturnahen Uferverlauf. Dies gilt auch für Talsperren- und Stauseen.');
		CREATE TABLE lb_wasserfuehrung_binnengewaesser (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_wasserfuehrung_binnengewaesser IS 'Alias: "LB_Wasserfuehrung_Binnengewaesser", UML-Typ: Enumeration';
		INSERT INTO lb_wasserfuehrung_binnengewaesser (wert,beschreibung,dokumentation) VALUES
		('1000', 'ganzjährig', 'ganzjährige Wasserführung bedeutet, dass Gewässer das ganze Jahr hindurch perennierend Wasser führt.'),
		('2000', 'zeitweilig', 'zeitweilige Wasserführung bedeutet, dass das Gewässer in regelmäßigem Zyklus (periodisch) Wasser führt (Beispiele: Schneeschmelze, Regenzeit etc.), oder nur gelegentlich und vorübergehend (episodisch) Wasser führt (Beispiel: saisonunabhängige Starkregenereignisse).');
		CREATE TABLE lb_meerart_meer (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_meerart_meer IS 'Alias: "LB_Meerart_Meer", UML-Typ: Enumeration';
		INSERT INTO lb_meerart_meer (wert,beschreibung,dokumentation) VALUES
		('1010', 'Watt', 'Watt ist ein aus Sand oder Schlick bestehender Boden an flachen Gezeitenküsten und Flüssen, der bei Ebbe ganz oder teilweise trocken fällt.'),
		('1020', 'Haff, Bodden', 'Haff, Bodden ist ein vom offenen Meer durch Landzungen gänzlich oder teilweise abgetrenntes Küstengewässer an der Ostsee.'),
		('1030', 'Priel', 'Priel ist eine natürliche Rinne im Watt, die auch bei Ebbe Wasser führt.');
		CREATE TABLE lb_eisart_eis (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE lb_eisart_eis IS 'Alias: "LB_Eisart_Eis", UML-Typ: Enumeration';
		INSERT INTO lb_eisart_eis (wert,beschreibung,dokumentation) VALUES
		('2010', 'Gletscher', 'Gletscher umfasst eine von Gletschereis bedeckte Fläche. Gletschereis ist aus mehrjährigem Schnee unter zunehmendem Eigendruck entstanden. Gletscher sind entsprechend der Jahreszeiten teils mit Schnee bedeckt.'),
		('2020', 'Dauerschnee, Firn', 'Dauerschnee bedeutet, dass die Erdoberfläche ganzjährig mit Schnee bedeckt ist. Firn bedeutet, dass die Erdoberfläche im Hochgebirge mit altem, grobkörnigem, mehrjährigem und stark verdichtetem Schnee bedeckt ist, der unter zunehmendem Druck zu Gletschereis wird.');
		CREATE TABLE ln_zustand_wasserwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_wasserwirtschaft IS 'Alias: "LN_Zustand_Wasserwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_wasserwirtschaft (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich das Objekt nicht mehr in regelmäßiger, der Bestimmung entsprechender Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass die Bauarbeiten am Objekt bereits begonnen haben und das Objekt noch nicht fertiggestellt ist.');
		CREATE TABLE ln_funktion_wasserwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_wasserwirtschaft IS 'Alias: "LN_Funktion_Wasserwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_wasserwirtschaft (wert,beschreibung,dokumentation) VALUES
		('7111', 'Trinkwasser', 'Trinkwasser im vorliegenden Sinne bezeichnet Wasser, das für den menschlichen Genuss geeignet ist.'),
		('7112', 'Energie', 'Energie weist die Nutzung eines Stehendes Gewässers zur Energiegewinnung aus.'),
		('7113', 'Brauchwasser', 'Brauchwasser dient spezifischen technischen, gewerblichen, industriellen, landwirtschaftlichen, hauswirtschaftlichen oder ähnlichen Zwecken, ohne dass im allgemeinen hierfür Trinkwasserqualität verlangt wird. Hierzu zählen z B. Kesselspeisewasser, Kühlwasser, unterschiedlich aufbereitetes Rohwasser.');
		CREATE TABLE ln_art_wasserwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_wasserwirtschaft IS 'Alias: "LN_Art_Wasserwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_art_wasserwirtschaft (wert,beschreibung,dokumentation) VALUES
		('7100', 'Wasserrückhalt', 'Wasserrückhalt bezeichnet Flächen zur Dämmung, Speicherung und zum Rückhalt von Wasser auf flutbaren Flächen (z. B. Polder, Talsperren).'),
		('7110', 'Stauung', 'Stauung umschreibt künstlich angelegte Flächen zur Speicherung von Wasser zur wirtschaftlichen Nutzung (z. B. Staudamm).'),
		('7120', 'Niederschlagsrückhalt', 'Niederschlagsrückhalt sind Flächen zum Rückhalt von Niederschlagwasser (z. B. Rückhaltebecken).'),
		('7130', 'Gewässerregulierung', 'Gewässerregulierung beschreibt Flächen die zur Regulierung von Gewässern beitragen (z. B. Begradigungen, Mäandrierungen, Fischtreppen, Drainagen).'),
		('7200', 'Entwässerung', 'Entwässerung beschreibt Flächen zum Abführen von Wasser (z. B. Gräben, Vorfluter, Verrohrungen).');
		CREATE TABLE ln_artderbetriebsflaeche_landwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_artderbetriebsflaeche_landwirtschaft IS 'Alias: "LN_ArtDerBetriebsflaeche_Landwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_artderbetriebsflaeche_landwirtschaft (wert,beschreibung,dokumentation) VALUES
		('1000', 'Tierhaltung', 'Tierhaltung bezeichnet eine bebaute und unbebaute Fläche, die vorwiegend dem landwirtschaftlichen Betrieb, primär der Tierhaltung dient. Diese umfasst auch die Gebäude- und Freiflächen.'),
		('2000', 'Pflanzliche Produktion', 'Pflanzliche Produktion bezeichnet eine bebaute und unbebaute Fläche, die vorwiegend dem landwirtschaftlichen Betrieb, primär der pflanzlichen Produktion dient. Diese umfasst auch die Gebäude- und Freiflächen.');
		CREATE TABLE ln_art_forstwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_forstwirtschaft IS 'Alias: "LN_Art_Forstwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_art_forstwirtschaft (wert,beschreibung,dokumentation) VALUES
		('6100', 'Forstwirtschaftsfläche', 'Forstwirtschaftsfläche bezeichnet eine Waldfläche mit oder ohne Bäumen, welche forstwirtschaftlich genutzt wird. Hierzu zählen keine Kurzumtriebsplantagen.'),
		('6200', 'Dauerhaft unbestockt', 'Dauerhaft unbestockt umfasst alle als Waldflächen geltenden Flächen, auf denen dauerhaft weder Bäume noch sonstige Gehölze stehen, aber stehen könnten. Hierzu zählen z.B. Lichtungen.'),
		('6300', 'Betriebsfläche Forstwirtschaft', 'Betriebsfläche Forstwirtschaft bezeichnet eine bebaute und unbebaute Fläche, die vorwiegend dem forstwirtschaftlich Betrieb dient.');
		CREATE TABLE ln_bewirtschaftung_landwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_bewirtschaftung_landwirtschaft IS 'Alias: "LN_Bewirtschaftung_Landwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_bewirtschaftung_landwirtschaft (wert,beschreibung,dokumentation) VALUES
		('1010', 'Ackerland', 'Ackerland ist eine Fläche für den Anbau von Feldfrüchten (z.B. Getreide, Hülsenfrüchte, Hackfrüchte) und Beerenfrüchten (z.B. Erdbeeren).'),
		('1011', 'Streuobst', 'Streuobst beschreibt den Bewuchs einer Acker-, Mahd- oder Weidelandfläche mit Obstbäumen.'),
		('1012', 'Hopfen', 'Hopfen ist eine mit speziellen Vorrichtungen ausgestattete Agrarfläche für den Anbau von Hopfen.'),
		('1013', 'Spargel', 'Spargel beschreibt den Bewuchs einer landwirtschaftlichen Fläche mit Spargel.'),
		('1014', 'Hanf', 'Hanf beschreibt den Bewuchs einer Agrarfläche mit Nutzhanf.'),
		('1020', 'Mahd- und Weideland', 'Mahd- und Weideland ist eine Grasfläche, die gemäht oder beweidet wird.'),
		('1030', 'Gartenbauland', 'Gartenbauland ist eine Fläche, die dem gewerbsmäßigen Anbau von Gartengewächsen (Gemüse, Obst und Blumen) sowie für die Aufzucht von Kulturpflanzen dient.'),
		('1040', 'Rebfläche', 'Rebfläche ist eine mit speziellen Vorrichtungen ausgestattete Agrarfläche, auf der Weinstöcke angepflanzt sind.'),
		('1050', 'Obst- und Nussplantage', 'Obst- und Nussplantage ist eine Fläche, die vorwiegend dem Intensivobstanbau dient und mit Obst- und Nussbäumen und -sträuchern bestanden ist. Im Unterschied zu Streuobst handelt es sich hierbei um gleichmäßige und dichter angelegte Monokulturen.'),
		('1060', 'Kurzumtriebsplantage', 'Kurzumtriebsplantage sind landwirtschaftliche Kulturen oder Anpflanzung schnell wachsender Bäume mit dem Ziel, innerhalb kurzer Umtriebszeiten Holz als nachwachsenden Rohstoff zu produzieren; auch mit Ziel der Energieerzeugung.'),
		('1070', 'Baumschule', 'Baumschule ist eine Fläche, auf der Holzgewächse aus Samen, Ablegern oder Stecklingen unter mehrmaligem Umpflanzen (Verschulen) gezogen werden.'),
		('1080', 'Weihnachtsbaumkultur', 'Weihnachtsbaumkultur bezeichnet eine landwirtschaftliche Fläche, die vorrangig mit Weihnachtsbäumen bepflanzt ist.'),
		('1200', 'Brachland', 'Brachland ist eine Fläche der Landwirtschaft, die seit längerem nicht mehr zu Produktionszwecken genutzt wird.'),
		('1300', 'Betriebsfläche Landwirtschaft', 'Betriebsfläche Landwirtschaft bezeichnet eine bebaute und unbebaute Fläche, die dem landwirtschaftlich Betrieb dient.');
		CREATE TABLE ln_art_aquakulturundfischereiwirtschaft (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_aquakulturundfischereiwirtschaft IS 'Alias: "LN_Art_AquakulturUndFischereiwirtschaft", UML-Typ: Enumeration';
		INSERT INTO ln_art_aquakulturundfischereiwirtschaft (wert,beschreibung,dokumentation) VALUES
		('6400', 'Fischzucht, Muschelzucht', 'Fischzucht, Muschelzucht bezeichnet Flächen/Areale, die dem (gewerblichen) Züchten bzw. der kontrollierten Aufzucht von im Wasser lebenden Organismen, insbesondere Fischen und Muscheln, zur Nahrungsgewinnung und Weiterverarbeitung dienen.'),
		('6500', 'Algenzucht', 'Algenzucht bezeichnet Flächen/Areale, die dem (gewerblichen) Züchten bzw. der kontrollierten Aufzucht von im Wasser lebenden Organismen, insbesondere Algen, zur Nahrungsgewinnung und Weiterverarbeitung dienen.');
		CREATE TABLE ln_abbaugut_abbau (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_abbaugut_abbau IS 'Alias: "LN_Abbaugut_Abbau", UML-Typ: Enumeration';
		INSERT INTO ln_abbaugut_abbau (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erden, Lockergestein', 'Erden, Lockergestein bedeutet, dass feinkörnige Gesteine abgebaut werden.'),
		('2000', 'Steine, Gestein, Festgestein', 'Steine, Gestein, Festgestein bedeutet, dass grobkörnige oder feste Gesteine abgebaut werden.'),
		('3000', 'Erze', 'Erze bedeutet, dass die in der Natur vorkommenden, metallhaltigen Mineralien und Mineralgemische abgebaut oder gespeichert werden.'),
		('4000', 'Treib- und Brennstoffe', 'Treib- und Brennstoffe bedeutet, dass die in der Natur vorkommenden brennbaren organischen und anorganischen Substanzen abgebaut oder gewonnen werden.'),
		('5000', 'Industrieminerale, Salze', 'Industrieminerale, Salze bedeutet, dass die in der Natur vorkommenden Mineralien abgebaut werden.');
		CREATE TABLE ln_oberflaeche_lagerung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_oberflaeche_lagerung IS 'Alias: "LN_Oberflaeche_Lagerung", UML-Typ: Enumeration';
		INSERT INTO ln_oberflaeche_lagerung (wert,beschreibung,dokumentation) VALUES
		('1000', 'oberirdisch', 'oberirdisch ist eine Fläche, auf der sich die Objekte auf oder über der Erdoberfläche befinden.'),
		('2000', 'unterirdisch', 'unterirdisch ist eine Fläche, auf der sich die Objekte unter der Erdoberfläche befinden.');
		CREATE TABLE ln_zustand_abbau (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_abbau IS 'Alias: "LN_Zustand_Abbau", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_abbau (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_lagergut_lagerung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_lagergut_lagerung IS 'Alias: "LN_Lagergut_Lagerung", UML-Typ: Enumeration';
		INSERT INTO ln_lagergut_lagerung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Baustoffe', 'Baustoffe sind sämtliche im Bauwesen verwendete Materialien, die als Lagergut aufbewahrt werden.'),
		('2000', 'Kohle, Erz, Salz', 'Kohle, Erz und Salz sind durch Berg- bzw. Tagebau gewonnene Abbaugüter, die für eine Weiterverwendung (vorübergehend) gelagert werden.'),
		('3000', 'Öl', 'Öl ist eine organische Flüssigkeit, die als Rohstoff gewonnen wird und in der Industrie vielseitige Verwendung findet.'),
		('4000', 'Erdreich', 'Erdreich‘ bezeichnet eine Fläche auf der „Erdreich“ gelagert wird. Erdreich im vorliegenden Sinne bezeichnet Oberflächenmaterial, das überwiegend aus Mutterboden (Humusanteil, feine Korngrößen) besteht.'),
		('5000', 'Schutt', 'Schutt ist eine nicht verfestigte Anhäufung von Trümmerstücken.'),
		('7000', 'Abraum', 'Abraum sind unbrauchbare Boden- und Gesteinsmassen.'),
		('8000', 'Schrott, Altmaterial', 'Schrott, Altmaterial sind Wertstoffe, die als Sekundärrohstoffe dienen.'),
		('9000', 'Gas', 'Gas bezeichnet den Aggregatzustand einer Materie ohne bestimmte Gestalt.');
		CREATE TABLE ln_foerdergut_abbau (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_foerdergut_abbau IS 'Alias: "LN_Foerdergut_Abbau", UML-Typ: Enumeration';
		INSERT INTO ln_foerdergut_abbau (wert,beschreibung,dokumentation) VALUES
		('1000', 'Erdöl', 'Erdöl ist ein flüssiges und brennbares Kohlenwasserstoffgemisch, das gefördert wird.'),
		('2000', 'Erdgas', 'Erdgas ist ein in der Erdkruste vorkommendes brennbares Naturgas, das gefördert wird.'),
		('3000', 'Sole, Lauge', 'Sole, Lauge ist ein kochsalzhaltiges Wasser, das gefördert wird.'),
		('4000', 'Kohlensäure', 'Kohlensäure ist eine schwache Säure, die durch Lösung von Kohlendioxid in Wasser entsteht und gefördert wird.'),
		('5000', 'Erdwärme', 'Erdwärme ist eine auf natürlichem Wege sich erneuernde Wärmeenergie, die aus einer geothermisch geringen Tiefenstufe der Erdkruste gefördert wird.');
		CREATE TABLE ln_art_abbau (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_abbau IS 'Alias: "LN_Art_Abbau", UML-Typ: Enumeration';
		INSERT INTO ln_art_abbau (wert,beschreibung,dokumentation) VALUES
		('3110', 'Tagebau', 'Tagebau ist eine Fläche, auf der oberirdisch Bodenmaterial abgebaut wird. Rekultivierte Tagebaue, Gruben, Steinbrüche werden als Objekte entsprechend der vorhandenen Nutzung erfasst.'),
		('3120', 'Untertagebau', 'Untertagebau ist eine Fläche, die für die Förderung des Abbaugutes unter Tage genutzt wird.'),
		('3200', 'Förderanlage', 'Förderanlage bezeichnet eine Fläche mit Einrichtungen zur Förderung von Rohstoffen und Energieträgern.');
		CREATE TABLE ln_sportart_sportanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_sportart_sportanlage IS 'Alias: "LN_Sportart_Sportanlage", UML-Typ: Enumeration';
		INSERT INTO ln_sportart_sportanlage (wert,beschreibung,dokumentation) VALUES
		('1010', 'Ballsport', 'Ballsport bedeutet, dass ein Spielfeld oder Stadion zur Ausübung des Ballsports genutzt wird.'),
		('1011', 'Fußball', 'Fußball bedeutet, dass ein Spielfeld oder Stadion zum Fußball spielen genutzt wird.'),
		('1012', 'Golf', 'Golf ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Golfsports genutzt wird.'),
		('1013', 'Tennis', 'Tennis ist eine Fläche mit baulichen Anlagen und mit Spielfeldern für den Tennissport. Die zusammenhängenden Spielflächen innerhalb einer Tennisanlage werden zu einem Spielfeld zusammengefasst.'),
		('1020', 'Leichtathletik', 'Leichtathletik bedeutet, dass ein Spielfeld oder Stadion zur Ausübung verschiedener Leichtathletikdisziplinen genutzt wird'),
		('1030', 'Wassersport', 'Wassersport bezeichnet ein Areal welches beispielsweise zum Rudern, Segeln oder für Wasserski genutzt wird.'),
		('1040', 'Schwimmen', 'Schwimmen bedeutet, dass ein Stadion zum Schwimmen genutzt wird.'),
		('1050', 'Ski', 'Ski bedeutet, dass ein Stadion zur Ausübung des Skisports genutzt wird.'),
		('1060', 'Motorrennsport', 'Motorrennsport bedeutet, dass eine Rennbahn zur Ausübung des Motorrennsports genutzt wird.'),
		('1070', 'Eislauf, Eishockey', 'Eislauf, Eishockey bedeutet, dass ein Stadion zur Ausübung des Eislaufsports oder des Eishockeysports genutzt wird.'),
		('1080', 'Rollschuhlaufen, Skating', 'Rollschuhlaufen, Skating bedeutet, dass eine Laufbahn zum Rollschuhfahren, Skaten genutzt wird.'),
		('1110', 'Radsport', 'Radsport bedeutet, dass ein Stadion oder eine Rennbahn zur Ausübung des Radsports genutzt wird.'),
		('1120', 'Pferdesport', 'Pferdesport ist eine Anlage für Wettkämpfe und/oder dient der Ausübung des Reitsports. Die Fläche des Reitsports kann u.a. Stallungen und kleine bauliche Anlagen enthalten.'),
		('1130', 'Hundesport', 'Hundesport ist eine Fläche, auch mit Bauwerken, die speziell mit Hunden genutzt wird. (z. B. Rennhundesport, Parcours zum Abrichten).'),
		('1140', 'Schießen', 'Schießen umfasst ein Gelände mit Gebäuden zum Üben und Prüfen von Schusswaffen und Schützen. (z.B. Schützenvereinsanlagen, Schießanlagen, Trainingsgelände für Schützen).');
		CREATE TABLE ln_primaerenergie_versorgungundentsorgung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_primaerenergie_versorgungundentsorgung IS 'Alias: "LN_Primaerenergie_VersorgungUndEntsorgung", UML-Typ: Enumeration';
		INSERT INTO ln_primaerenergie_versorgungundentsorgung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Wasser', 'Wasser bedeutet, dass das Kraftwerk potentielle und kinetische Energie des Wasserkreislaufs in elektrische Energie umwandelt.'),
		('2000', 'Kernkraft', 'Kernkraft bedeutet, dass das Kraftwerk die durch Kernspaltung gewonnene Energie in eine andere Energieform umwandelt.'),
		('3000', 'Sonne', 'Sonne bedeutet, dass das Kraftwerk bzw. Heizwerk Sonnenenergie in eine andere Energieform umwandelt.'),
		('4000', 'Wind', 'Wind bedeutet, dass das Kraftwerk die Strömungsenergie des Windes in elektrische Energie umwandelt.'),
		('5000', 'Gezeiten', 'Gezeiten bedeutet, dass das Kraftwerk die kinetische Energie der Meeresgezeiten in elektrische Energie umwandelt.'),
		('6000', 'Erdwärme', 'Erdwärme bedeutet, dass das Heizwerk die geothermische Energie der Erde nutzt.'),
		('7100', 'Kohle', 'Kohle bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Kohle frei werdende Energie in eine andere Energieform umwandelt.'),
		('7200', 'Öl', 'Öl bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Öl freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7300', 'Gas', 'Gas bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Gas freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7400', 'Müll, Abfall', 'Müll, Abfall bedeutet, dass das Kraftwerk bzw. Heizwerk die durch Verbrennung von Müll bzw. Abfall freiwerdende Energie in eine andere Energieform umwandelt.'),
		('7500', 'Biomasse', 'Biomasse sind organische Substanzen (z.B. Pflanzen, Futtermittelabfälle, Gülle), die verbrannt und/oder vergärt werden, um Energie zu gewinnen.');
		CREATE TABLE ln_art_freizeitanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_freizeitanlage IS 'Alias: "LN_Art_Freizeitanlage", UML-Typ: Enumeration';
		INSERT INTO ln_art_freizeitanlage (wert,beschreibung,dokumentation) VALUES
		('4210', 'Zoo', 'Zoo ist ein Gelände mit Tierschauhäusern und umzäunten Gehegen, auf dem Tiere gehalten und gezeigt werden.'),
		('4220', 'Safaripark, Wildpark', 'Safaripark, Wildpark ist ein Gelände mit umzäunten Gehegen, in denen Tiere im Freien gehalten und gezeigt werden.'),
		('4230', 'Freizeitpark', 'Freizeitpark ist ein Gelände mit Karussells, Verkaufs- und Schaubuden und/oder Wildgattern, das der Freizeitgestaltung dient.'),
		('4240', 'Freilichtbühne', 'Freilichtbühne ist eine Anlage mit Bühne und Zuschauerbänken für Aufführungen im Freien.'),
		('4250', 'Freilichtmuseum', 'Freilichtmuseum ist eine volkskundliche Museumsanlage, in der Wohnformen oder historische Betriebsformen in ihrer natürlichen Umgebung im Freien dargestellt sind.'),
		('4260', 'Autokino, Freilichtkino', 'Autokino, Freilichtkino ist ein Lichtspieltheater im Freien, in dem der Film im Allgemeinen vom Auto aus angesehen wird.'),
		('4270', 'Modellfluggelände', 'Modellfluggelände ist eine Fläche, die zur Ausübung des Modellflugsports dient.'),
		('4310', 'Festplatz', 'Festplatz ist eine Fläche, auf der zeitlich begrenzte Festveranstaltungen stattfinden.'),
		('4320', 'Freizeitbad', 'Freizeitbad ist eine Anlage mit Schwimmbecken oder eine Anlage an Ufern von Gewässern für den Badebetrieb und Schwimmsport.'),
		('4330', 'Campingplatz', 'Campingplatz ist eine Fläche für den Aufbau einer größeren Zahl von Zelten oder zum Abstellen und Benutzen von Wohnwagen mit ortsfesten Anlagen und Einrichtungen.'),
		('4340', 'Kletteranlage', 'Kletteranlage ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Klettersports genutzt wird.'),
		('4350', 'Gelände für Luftsportgeräte', 'Gelände für Luftsportgeräte ist eine Fläche, auf der Ultraleichtflug-, Hängegleiter-, Gleitsegel-, Sprungfallschirm-, Gleitflug- und Freiballonaktivitäten ausgeübt werden.'),
		('4360', 'Go-Kart-Bahn', 'Go-Kart-Bahn umfasst eine abgegrenzte Strecke mit Anlagen und Gebäuden, die zur Ausübung des Kartrennsports genutzt wird. Hierzu gehören Indoor- und Outdoor-Kartbahnen.');
		CREATE TABLE ln_funktion_kulturundunterhaltung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_kulturundunterhaltung IS 'Alias: "LN_Funktion_KulturUndUnterhaltung", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_kulturundunterhaltung (wert,beschreibung,dokumentation) VALUES
		('1210', 'Kultur', 'Kultur bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude für kulturelle Zwecke, z.B. Konzert- und Museumsgebäude, Bibliotheken, Theater, Schlösser und Burgen stehen.'),
		('1220', 'Medien und Kommunikation', 'Medien und Kommunikation bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude für die Erzeugung und Verbreitung von Printmedien, Hörfunk, Film und Fernsehen sowie Internet und Telefonie stehen.'),
		('1230', 'Vergnügung', 'Vergnügung‘ bezeichnet eine Fläche mit Gebäuden und Einrichtungen, in denen Möglichkeiten zur unterhaltsamen Freizeitgestaltung angeboten werden.');
		CREATE TABLE ln_zustand_industrieundverarbeitendesgewerbe (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_industrieundverarbeitendesgewerbe IS 'Alias: "LN_Zustand_IndustrieUndVerarbeitendesGewerbe", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_industrieundverarbeitendesgewerbe (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_art_versorgungundentsorgung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_versorgungundentsorgung IS 'Alias: "LN_Art_VersorgungUndEntsorgung", UML-Typ: Enumeration';
		INSERT INTO ln_art_versorgungundentsorgung (wert,beschreibung,dokumentation) VALUES
		('2520', 'Wasserwerk', 'Wasserwerk ist eine Fläche, auf der Gebäude und Einrichtungen zur Aufbereitung und Bereitstellung von Trinkwasser steht.'),
		('2530', 'Kraftwerk', 'Kraftwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von elektrischer Energie.'),
		('2540', 'Umspannstation', 'Umspannstation bezeichnet eine Fläche mit Gebäuden und sonstigen Einrichtungen, um Strom auf eine andere Spannungsebene zu transformieren.'),
		('2570', 'Heizwerk', 'Heizwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von Wärmeenergie zu Heizzwecken.'),
		('2580', 'Funk- und Fernmeldeanlage', 'Funk- und Fernmeldeanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur elektronischen Informationsübertragung stehen.'),
		('2610', 'Kläranlage, Klärwerk', 'Kläranlage, Klärwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Reinigung von Abwasser.'),
		('2620', 'Abfallbehandlungsanlage', 'Abfallbehandlungsanlage bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen, auf der Abfälle mit chemisch/physikalischen und biologischen oder thermischen Verfahren oder Kombinationen dieser Verfahren behandelt werden.');
		CREATE TABLE ln_art_industrieundverarbeitendesgewerbe (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_industrieundverarbeitendesgewerbe IS 'Alias: "LN_Art_IndustrieUndVerarbeitendesGewerbe", UML-Typ: Enumeration';
		INSERT INTO ln_art_industrieundverarbeitendesgewerbe (wert,beschreibung,dokumentation) VALUES
		('1801', 'Nahrungs-, Futter-, Genussmittel', 'Nahrungs-, Futter-, Genussmittel bezeichnet Flächen zur Fertigung von Erzeugnissen der Landwirtschaft, Forstwirtschaft sowie die Herstellung verschiedener Halbwaren, die noch keine Nahrungs-, Futter- oder Genussmittel darstellen.'),
		('1802', 'Textil-, Bekleidungs-, Lederwaren', 'Textil-, Bekleidungs-, Lederwaren bezeichnet Flächen auf denen primär Textil-, Bekleidungs- und Lederwaren wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Textilwaren umfasst Spinnstoffaufbereitung und Spinnerei, Weberei, Veredlung von Textilien und Bekleidung, sowie die Herstellung von konfektionierten Textilwaren. Bekleidungswaren umfassen alle Schneiderarbeiten aus allen Materialien für alle Bekleidungsartikel und Bekleidungszubehör. Lederwaren umfasst das Zurichten und Färben von Pelzen und die Verarbeitung von Fellen zu Leder durch Gerben und Zurichten sowie die Weiterverarbeitung des Leders zu Gebrauchsgegenständen.'),
		('1803', 'Holz-, Naturfaser-, Verpackungsprodukte', 'Holz-, Naturfaser-, Verpackungsprodukte bezeichnet Flächen auf denen primär Holz-, Naturfaser- oder Verpackungsprodukte wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Holzprodukte umfassen die Herstellung von Bauholz, Sperrholz, Furniere, Verpackungsmittel, Lagerbehälter und Ladungsträger, Bodenbeläge, Fachwerk, vorgefertigte Gebäude. Naturfaserprodukte sind Veredelungen von Holz- und Zellprodukten. Verpackungsprodukte umfasst Flächen für die Fertigung von Verpackungsmaterial aus bspw. Papier, Karton, Pappe und Holz.'),
		('1804', 'Print-, Audio-, Videoprodukte', 'Print-, Audio-, Videoprodukte bezeichnet Flächen auf denen primär die massenhafte Fertigung von Druckerzeugnissen bzw. bespielten Ton-, Bild- und Datenträgern erfolgt.'),
		('1805', 'Mineralölverarbeitung, Kokerei', 'Mineralölverarbeitung, Kokerei bezeichnet Flächen auf denen primär Rohöl und Kohle zu gebrauchsfertigen Erzeugnissen verarbeitet werden. Das vorherrschende Verfahren ist die Mineralölverarbeitung durch Trennung von Rohöl in Teilerzeugnisse anhand von Verfahren wie Spaltung und Destillation.'),
		('1806', 'Chemische-, Pharma-, Kunststoffprodukte', 'Chemische, Pharma-, Kunststoffprodukte bezeichnet Flächen auf denen primär Chemische, Pharma- und Kunststoffprodukte wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Chemische Produkte umfasst die Verarbeitung organischer und anorganischer Rohstoffe in einem chemischen Verfahren zu chemischen Erzeugnissen. 
		Pharmaprodukte umfasst die Herstellung von pharmazeutischen Grundstoffen und pharmazeutischen Spezialitäten wie auch die Herstellung von Arzneimitteln chemischen und botanischen Ursprungs.
		Kunststoffprodukte umfasst die Herstellung von Harzen, Kunststoffen und nicht vulkanisierbaren thermoplastischen Elastomeren sowie das Mischen von Harzen nach Kundenwunsch und die Herstellung von synthetischen Harzen nach eigener Spezifikation.'),
		('1807', 'Mineralische Bau- und Werkstoffe', 'Mineralische Bau- und Werkstoffe bezeichnet Flächen auf denen primär Bau- und Werkstoffe wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Baustoffe umfassen den Großhandel mit Steinen, Sand, Kies, Schotter, Zement, Mörtel, Dämmplatten sowie Fertigteilbauten aus mineralischen Stoffen, z. B. Garagen. Werkstoffe umfasst die Herstellung von Waren unter Verwendung von Stoffen mineralischen Ursprungs bezogen auf die Herstellung von Glas und Erzeugnissen daraus, keramischen Erzeugnissen, Ziegeln und Erzeugnissen aus gebranntem Ton sowie Zement und Gips, verarbeiteten Naturstein und sonstigen Mineralerzeugnissen.'),
		('1808', 'Metallerzeugung und –verarbeitung', 'Metallerzeugung und -verarbeitung umfasst die Flächen für die Tätigkeiten des Schmelzens und Legierens von Eisenmetallen und NE-Metallen aus Erz, Roheisen oder Schrott mit elektrometallurgischen und anderen metallurgischen Verfahren wie auch Flächen für die Herstellung von Metalllegierungen und Superlegierungen durch Zugabe anderer chemischer Elemente zu reinen Metallen.'),
		('1809', 'Technik, Elektrik, Elektronik', 'Technik, Elektrik, Elektronik umfasst Flächen für die Herstellung von Datenverarbeitungsgeräten, sowie elektronischen und optischen Erzeugnissen.'),
		('1810', 'Maschinenbau', 'Maschinenbau umfasst Flächen für den Bau von Maschinen, die mechanisch oder durch Wärme auf Materialien einwirken oder an Materialien Vorgänge durchführen, einschließlich ihrer mechanischen Bestandteile, die Kraft erzeugen und anwenden, sowie spezieller Teile dafür.'),
		('1811', 'Fahrzeugbau und Zulieferer', 'Fahrzeugbau und Zulieferer umfasst die Flächen für die Herstellung von Raum-, Luft-, Wasser-, Schienen- und Straßenfahrzeugen zur Personen- oder Güterbeförderung wie auch die Flächen zur Herstellung verschiedener Teile und Zubehör.'),
		('1812', 'Möbel und sonstige Konsumgüter', 'Möbel und sonstige Konsumgüter bezeichnet Flächen auf denen primär Möbel und sonstige Konsumgüter wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Möbel umfassen die Herstellung von Möbeln aller Art und verwandten Erzeugnissen aus beliebigem Material, außer Stein, Beton und Keramik, für alle Einsatzbereiche und die verschiedensten Zwecke. Sonstige Konsumgüter umfassen den Verkauf von weiteren Neu- und Gebrauchtwaren vor allem an private Haushalte für den privaten Ge- oder Verbrauch.');
		CREATE TABLE ln_zustand_wohnnutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_wohnnutzung IS 'Alias: "LN_Zustand_Wohnnutzung", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_wohnnutzung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_artderbestattungsflaeche_bestattung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_artderbestattungsflaeche_bestattung IS 'Alias: "LN_ArtDerBestattungsflaeche_Bestattung", UML-Typ: Enumeration';
		INSERT INTO ln_artderbestattungsflaeche_bestattung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Friedhof', 'Friedhof umfasst eingefriedete Flächen für Gräber.'),
		('2000', 'Waldbestattungsfläche', 'Waldbestattungsfläche umfasst eine besondere Waldfläche außerhalb eines Friedhofes zur Bestattung ohne Pflege der Grabstelle.'),
		('3000', 'historischer Friedhof', 'historischer Friedhof ist ein Friedhof, der als historisch gilt.'),
		('4000', 'Parkfriedhof', 'Parkfriedhof ist ein Friedhof, der als Park angelegt ist.');
		CREATE TABLE ln_art_freiluftundnaherholung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_freiluftundnaherholung IS 'Alias: "LN_Art_FreiluftUndNaherholung", UML-Typ: Enumeration';
		INSERT INTO ln_art_freiluftundnaherholung (wert,beschreibung,dokumentation) VALUES
		('4400', 'Grünanlage', 'Grünanlage ist in erster Linie eine Anlage mit Bäumen, Sträuchern, Rasenflächen, Blumenrabatten und Wegen, die vor allem der Erholung und Verschönerung des Stadtbildes dient.'),
		('4410', 'Siedlungsgrünfläche', 'Siedlungsgrünfläche ist eine unbebaute Wiese, Freifläche oder anderweitige Grünfläche in Städten und Siedlungen.'),
		('4420', 'Park', 'Park ist eine landschaftsgärtnerisch gestaltete Grünanlage, die der Repräsentation und der Erholung dient.'),
		('4430', 'Botanischer Garten', 'Botanischer Garten ist ein der Öffentlichkeit zugänglicher Garten zum Studium der Pflanzenwelt; systematisch geordnete Sammlung in Freiland und Gewächshäusern (Warmhäuser).'),
		('4440', 'Kleingarten', 'Kleingarten ist eine Anlage von Gartengrundstücken, die im Unterschied zu Gartenland vorwiegend der Freizeit und Erholung dient.'),
		('4450', 'Wochenendplatz', 'Wochenendplatz sind Flächen, die der Freizeitgestaltung dienen.'),
		('4470', 'Spielplatz, Bolzplatz', 'Spielplatz, Bolzplatz ist eine Freianlage, die dem nicht wettkampforientierten Sport-, Bewegungs- und Freizeitaktivitäten dient. Es können verschiedene Sportarten betrieben werden.'),
		('4480', 'Zierfläche', 'Zierfläche ist eine der Öffentlichkeit zugängliche künstlich gepflegte Fläche kleineren Ausmaßes die vornehmlich der optischen Auflockerung des Stadtbildes dient, zur Erholung mit Kunst, Zierpflanzen.');
		CREATE TABLE ln_funktion_oeffentlicheeinrichtungen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_oeffentlicheeinrichtungen IS 'Alias: "LN_Funktion_OeffentlicheEinrichtungen", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_oeffentlicheeinrichtungen (wert,beschreibung,dokumentation) VALUES
		('1110', 'Regierung und Verwaltung', 'Regierung und Verwaltung bezeichnet eine Fläche auf der vorwiegend Gebäude der öffentlichen Regierung und Verwaltung, z. B. Rathaus, Gericht, Kreisverwaltung stehen.'),
		('1120', 'Bildung und Wissenschaft', 'Bildung und Wissenschaft bezeichnet eine Fläche, auf der vorwiegend Gebäude stehen, in denen geistige, kulturelle und soziale Fähigkeiten vermittelt werden und/oder wissenschaftliche Forschung betrieben wird (z.B. Schulen, Universitäten, Institute).'),
		('1140', 'Religiöse Einrichtung', 'Religiöse Einrichtung bezeichnet eine Fläche auf der vorwiegend religiöse Gebäude stehen.'),
		('1150', 'Gesundheit, Kur', 'Gesundheit, Kur bezeichnet eine Fläche auf der vorwiegend Gebäude des Gesundheitswesens stehen, z.B. Krankenhäuser, Heil- und Pflegeanstalten.'),
		('1160', 'Soziales', 'Soziales bezeichnet eine Fläche auf der vorwiegend Gebäude des Sozialwesens stehen, z. B. Kindergärten, Jugend- und Senioreneinrichtungen, Freizeit-, Fremden- und Obdachlosenheime.'),
		('1170', 'Sicherheit und Ordnung', 'Sicherheit und Ordnung bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude der Polizei, der Bundeswehr, der Feuerwehr und der Justizvollzugsbehörden stehen.');
		CREATE TABLE ln_zustand_lagerung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_lagerung IS 'Alias: "LN_Zustand_Lagerung", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_lagerung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_zustand_kulturundunterhaltung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_kulturundunterhaltung IS 'Alias: "LN_Zustand_KulturUndUnterhaltung", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_kulturundunterhaltung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_zeitlichkeit_wohnnutzung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zeitlichkeit_wohnnutzung IS 'Alias: "LN_Zeitlichkeit_Wohnnutzung", UML-Typ: Enumeration';
		INSERT INTO ln_zeitlichkeit_wohnnutzung (wert,beschreibung,dokumentation) VALUES
		('1000', 'Dauerhaft', 'Dauerhaft bezeichnet eine beständige fortwährend anhaltende Nutzung der Flächen.'),
		('2000', 'Zeitweilig', 'Zeitweilig bezeichnet die Nutzung der Flächen nur zu bestimmten Zeiten wie z.B. Ferienhäuser und Wochenendhäuser.');
		CREATE TABLE ln_zustand_gewerblichedienstleistungen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_gewerblichedienstleistungen IS 'Alias: "LN_Zustand_GewerblicheDienstleistungen", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_gewerblichedienstleistungen (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_funktion_lagerung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_lagerung IS 'Alias: "LN_Funktion_Lagerung", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_lagerung (wert,beschreibung,dokumentation) VALUES
		('8100', 'Deponie', 'Deponie bezeichnet eine Fläche, auf der oberirdisch Abfallstoffe gelagert werden. Deponie bezeichnet ebenfalls eine oberirdische Betriebsfläche, unter der Abfallstoffe unterirdisch eingelagert werden (Untertagedeponie).'),
		('8200', 'Halde', 'Halde ist eine Fläche, auf der sich eine Aufschüttung von Material oberhalb der umgebenden Geländeoberfläche befindet, welche langfristig gelagert wird.'),
		('8300', 'Lagerfläche', 'Lagerfläche bezeichnet Flächen, auf denen inner- und außerhalb von Gebäuden wirtschaftliche Güter gelagert werden.');
		CREATE TABLE ln_zustand_oeffentlicheeinrichtungen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_oeffentlicheeinrichtungen IS 'Alias: "LN_Zustand_OeffentlicheEinrichtungen", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_oeffentlicheeinrichtungen (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_art_gewerblichedienstleistungen (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_art_gewerblichedienstleistungen IS 'Alias: "LN_Art_GewerblicheDienstleistungen", UML-Typ: Enumeration';
		INSERT INTO ln_art_gewerblichedienstleistungen (wert,beschreibung,dokumentation) VALUES
		('1310', 'Handwerk', 'Handwerk‘ bezeichnet eine Fläche, auf der vorwiegend Handwerksbetriebe vorhanden sind.'),
		('1320', 'Logistik und Transport', 'Logistik und Transport‘ umfasst Flächen mit Gebäuden und Einrichtungen, die sich mit der Planung, Steuerung und Durchführung von Güter-, Informations- und Personenströmen befassen. Hierzu gehören Speditionen, Bus- und Taxiunternehmen, Kurier-, Express- und Paketdienste.'),
		('1330', 'Tankstelle', 'Tankstelle‘ bezeichnet eine Fläche, auf der sich Gebäude und Einrichtungen befinden, an denen Kraftfahrzeuge mit den benötigten Kraftstoffen versorgt werden.'),
		('1410', 'Forschung und Entwicklung', 'Forschung und Entwicklung‘ bezeichnet eine Fläche, auf der sich vorwiegend industrielle Forschungs- und Entwicklungseinrichtungen befinden.'),
		('1510', 'freie Berufe und weitere Dienstleistungen', 'freie Berufe und weitere Dienstleistungen‘ bezeichnet eine Fläche mit Gebäuden und Einrichtungen welche zur Ausübung freier Berufe wie auch weiterer Dienstleistungen genutzt wird.'),
		('1520', 'Finanz- und Versicherungsdienstleistung', 'Finanz- und Versicherungsdienstleistungen‘ bezeichnet eine Fläche mit Gebäuden und Einrichtungen von Bank- oder Kreditunternehmen sowie von Versicherungsgesellschaften.'),
		('1530', 'Handel', 'Handel‘ bezeichnet Flächen mit Anlagen mit Einzelhandels- und Dienstleistungsbetrieben, die durch einheitliche Verwaltung, auf das Einzugsgebiet abgestimmter Anbieter und durch umfangreiche Parkmöglichkeiten geprägt sind.'),
		('1540', 'Ausstellung, Messe', 'Ausstellung, Messe‘ bezeichnet eine Fläche mit Ausstellungshallen und sonstigen Einrichtungen zur Präsentation von Warenmustern.'),
		('1550', 'Gärtnerei', 'Gärtnerei bezeichnet eine Fläche mit Gebäuden, Gewächshäusern und sonstigen Einrichtungen, die der Aufzucht von Blumen und Gemüsepflanzen dienen.'),
		('1560', 'Restauration', 'Restauration bezeichnet eine Fläche mit Gebäuden und Einrichtungen für das gewerbliche Angebot der gastronomischen Versorgung.'),
		('1570', 'Beherbergung (Hotel, Pension, Herberge)', 'Beherbergung‘ bezeichnet eine Fläche mit Gebäuden und Einrichtungen für das gewerbliche Angebot der Unterbringung von Personen wie z.B. Hotel, Pension oder Herberge.'),
		('1600', 'Verkehrsübungsplatz, Testgelände, Fahrsicherheit', 'Verkehrsübungsplatz, Testgelände, Fahrsicherheit umfasst Flächen, die Übungs- und Erprobungszwecken (auch technischer Produkte) dienen.');
		CREATE TABLE ln_zustand_versorgungundentsorgung (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_versorgungundentsorgung IS 'Alias: "LN_Zustand_VersorgungUndEntsorgung", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_versorgungundentsorgung (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich die Fläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_funktion_bahnverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_bahnverkehr IS 'Alias: "LN_Funktion_Bahnverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_bahnverkehr (wert,beschreibung,dokumentation) VALUES
		('5210', 'Bahnverkehrsfläche', 'Bahnverkehrsfläche ist eine Fläche die der Abwicklung und Sicherheit des Bahnverkehrs sowie der Unterhaltung dieser Verkehrsflächen dient. Sie beinhaltet die Flächen der Trasse sowie deren Begleitfläche.'),
		('5211', 'Trasse (Streckengleisbett)', 'Trasse ist ein befestigtes, dem allgemeinen Schienenverkehr dienendes Gleisbett einschließlich der auf Brücken oder in Tunneln verlaufenden Abschnitte.'),
		('5212', 'Begleitfläche Bahnverkehr', 'Begleitfläche Bahnverkehr bezeichnet eine unbebaute Fläche, die dem Bahnverkehr zugeordnet wird. Die Begleitfläche Bahnverkehr ist nicht Bestandteil der Gleisanlagen.'),
		('5220', 'Betriebsfläche Bahnverkehr', 'Betriebsfläche Bahnverkehr bezeichnet Flächen, auf denen vorwiegend Anlagen und Gebäude zur Versorgung, Unterhaltung und Instandhaltung des Bahnverkehrs vorhanden sind.'),
		('5230', 'Bahnhofsstation', 'Bahnhofsstation ist eine Anlage im Netz der Schienen- und Magnetschwebebahnen zur Abwicklung des Personen- und Güterverkehrs entsprechend der Angaben des Betreibers.');
		CREATE TABLE ln_funktion_strassenundwegeverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_strassenundwegeverkehr IS 'Alias: "LN_Funktion_StrassenUndWegeverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_strassenundwegeverkehr (wert,beschreibung,dokumentation) VALUES
		('5110', 'Straßen- und Wegeverkehrsfläche', 'Straßen- und Wegeverkehrsfläche ist eine Fläche die der Abwicklung und Sicherheit des Verkehrs sowie der Unterhaltung der Verkehrsfläche dient. Sie beinhaltet die Flächen der Fahrbahn sowie deren Begleitfläche.'),
		('5111', 'Fahrbahn', 'Fahrbahn bezeichnet Flächen, die den zusammenhängenden, befestigten Teil der Straße bilden, als Verkehrsraum dienen und mit Fahrzeugen befahren werden dürfen. Zur Fahrbahn gehören auch Stand- und Kriechspuren.'),
		('5112', 'Begleitfläche Straßen- und Wegeverkehr', 'Begleitfläche Straßen- und Wegeverkehr bezeichnet eine unbebaute Fläche, die einer Straße oder eines Weges zugeordnet wird. Die Begleitfläche Straßen- und Wegeverkehr ist nicht Bestandteil der Fahrbahn.'),
		('5120', 'Betriebsfläche Straßen- und Wegeverkehr', 'Betriebsfläche Straßen- und Wegeverkehr bezeichnet Flächen, auf denen vorwiegend Anlagen und Gebäude zur Versorgung und Unterhaltung der Verkehrsflächen bzw. des Straßen- und Wegeverkehrs vorhanden sind. Hierzu gehören z.B. Straßenmeistereien.'),
		('5130', 'Rastplatz', 'Rastplatz ist eine Anlage zum Rasten der Verkehrsteilnehmer mit unmittelbarem Anschluss zur Straße ohne Versorgungseinrichtung, ggf. mit Toiletten.'),
		('5140', 'Raststätte, Autohof', 'Raststätte, Autohof ist eine Anlage an Verkehrsstraßen mit Bauwerken und Einrichtungen zur Versorgung und Erholung von Reisenden. Dazu gehören Autohöfe gemäß der Verwaltungsvorschriften zur Straßenverkehrsordnung (VwV-StVO).'),
		('5150', 'Parkplatz', 'Parkplatz bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zum Abstellen von Fahrzeugen stehen.'),
		('5160', 'Marktplatz', 'Marktplatz ist eine Fläche, auf der Waren regelmäßig an einem zentralen Ort gehandelt werden.'),
		('5170', 'Busbahnhof', 'Busbahnhof umfasst einen zentralen Platz, an dem sich der Autobusverkehr einer Stadt oder Region konzentriert. Meist mit Haltestellenanlagen.');
		CREATE TABLE ln_nutzung_schiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_nutzung_schiffsverkehr IS 'Alias: "LN_Nutzung_Schiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_nutzung_schiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zivil', 'zivil bedeutet, dass Schiffsverkehr privaten oder öffentlichen Zwecken dient und nicht militärisch genutzt wird.'),
		('2000', 'Militärisch', 'Militärisch bedeutet, dass Schiffsverkehr nur von Streitkräften genutzt wird.');
		CREATE TABLE ln_zuflusssteuerung_schutzanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zuflusssteuerung_schutzanlage IS 'Alias: "LN_Zuflusssteuerung_Schutzanlage", UML-Typ: Enumeration';
		INSERT INTO ln_zuflusssteuerung_schutzanlage (wert,beschreibung,dokumentation) VALUES
		('1000', 'Gesteuert', 'Gesteuert bedeutet, dass die eingedeichte Fläche regelmäßig zu einem bestimmten festgelegten Zeitpunkt geflutet wird (z.B. bei einem ausgewählten Pegelstand).'),
		('2000', 'Ungesteuert', 'Ungesteuert bedeutet, dass die eingedeichte Fläche ereignisabhängig geflutet wird.');
		CREATE TABLE ln_fussgaengerzone_strassenundwegeverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_fussgaengerzone_strassenundwegeverkehr IS 'Alias: "LN_Fussgaengerzone_StrassenUndWegeverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_fussgaengerzone_strassenundwegeverkehr (wert,beschreibung,dokumentation) VALUES
		('5130', 'Fußgängerzone', 'Fußgängerzone ist ein dem Fußgängerverkehr vorbehaltener Bereich, in dem ausnahmsweise öffentlicher Personenverkehr, Lieferverkehr oder Fahrradverkehr zulässig sein kann.');
		CREATE TABLE ln_funktion_schiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_schiffsverkehr IS 'Alias: "LN_Funktion_Schiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_schiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('5410', 'Schiffsverkehrsfläche', 'Schiffsverkehrsfläche umfasst die wasserseitigen Flächen, auf denen der fließende oder stehende Schiffsverkehr stattfindet und die mit ihr in Zusammenhang stehenden begleitenden Freifläche wie z.B. die Uferstreifen.'),
		('5411', 'Wasserweg (Wasserkörper incl. Schleusenkammer)', 'Wasserweg ist der Transportweg auf dem Wasser, auf dem hauptsächlich durch Schifffahrt Personen und Güter befördert werden.'),
		('5412', 'Begleitfläche Schiffsverkehr', 'Begleitfläche Schiffsverkehr bezeichnet landseitige unbebaute Flächen, die dem Schiffsverkehr zugeordnet wird. Die Begleitfläche Schiffsverkehr ist nicht Bestandteil der Wasserverkehrsanlagen.'),
		('5413', 'Liegeplatz', 'Liegeplatz bezeichnet eine Stelle im Hafen oder am Ufer, an dem Wasserfahrzeuge vorübergehend oder dauerhaft verankert sind.'),
		('5420', 'Betriebsfläche Schiffsverkehr', 'Betriebsfläche bezeichnet landseitige Flächen mit zugehörigen Bauwerken, die dem Betrieb des Schiffsverkehrs zuzuordnen sind.'),
		('5421', 'Fähranlage', 'Fähranlage ist eine besondere Landfläche von der in der Regel nach festem Fahrplan über Flüsse, Seen, Kanäle, Meerengen oder Meeresarme ein Schiffsverkehr stattfindet.'),
		('5422', 'Hafenanlage (landseitig, zum Be- und Entladen)', 'Hafenanlage bezeichnet die landseitige Fläche die nicht von Wasser bedeckt ist und die ausschließlich zum Betrieb des Hafens (zum Be- und Entladen) dient.'),
		('5423', 'Anlegestelle', 'Anlegestelle umfasst den landseitigen Anleger umgebenden Bereich, der eine feste oder schwimmende Einrichtung zum Anlegen von Schiffen und Booten ist.'),
		('5424', 'Schleuse', 'Schleuse bezeichnet die Fläche Landfläche die ausschließlich zum Betrieb der Schleuse dient.');
		CREATE TABLE ln_typ_schutzanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_typ_schutzanlage IS 'Alias: "LN_Typ_Schutzanlage", UML-Typ: Enumeration';
		INSERT INTO ln_typ_schutzanlage (wert,beschreibung,dokumentation) VALUES
		('1910', 'Hochwasserdeich', 'Hochwasserdeich ist ein Deich an einem Fließgewässer oder im Küstengebiet, der dem Schutz eines Gebietes vor Hochwasser oder gegen Sturmfluten dient.'),
		('1920', 'Hauptdeich, Landesschutzdeich', 'Hauptdeich, Landesschutzdeich ist ein Deich der ersten Deichlinie zum Schutz der Küsten- und Inselgebiete gegen Sturmflut.'),
		('1930', 'Überlaufdeich', 'Überlaufdeich ist ein Deich vor dem Hauptdeich, der in erster Linie dem Schutz landwirtschaftlich genutzter Flächen gegen leichte Sturmtiden dient und der bei höheren Sturmtiden überströmt wird.'),
		('1940', 'Leitdeich', 'Leitdeich ist ein dammartiges Bauwerk im Watt, um strömendes Wasser in bestimmte Richtungen zu lenken und zum Schutz von Wasserläufen im Watt (Außentiefs) vor Versandung.'),
		('1950', 'Polderdeich', 'Polderdeich ist ein vor dem Hauptdeich liegender Deich, der landwirtschaftlich nutzbares Land (z. B. Marschland) schützt.');
		CREATE TABLE ln_artdesparkplatzes_strassenundwegeverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_artdesparkplatzes_strassenundwegeverkehr IS 'Alias: "LN_ArtDesParkplatzes_StrassenUndWegeverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_artdesparkplatzes_strassenundwegeverkehr (wert,beschreibung,dokumentation) VALUES
		('1000', 'Öffentlich', 'Öffentlich bezeichnet die Zugänglichkeit und Nutzung eines Parkplatzes für jedermann.'),
		('2000', 'Nutzungsbezogen', 'Nutzungsbezogen bezeichnet die eingeschränkte Nutzungsrecht eines Parkplatzes wie z.B. Parkplätze auf einem Firmengelände');
		CREATE TABLE ln_funktion_schutzanlage (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_schutzanlage IS 'Alias: "LN_Funktion_Schutzanlage", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_schutzanlage (wert,beschreibung,dokumentation) VALUES
		('5510', 'Hochwasserschutz (Damm, Wall, Deich, Schutzwand, Schutzmauer)', 'Hochwasserschutz ist eine Fläche die einen Hochwasserfall oder dessen Auswirkungen begrenzt. Hierzu zählen Damm, Wall, Deich, Schutzwand, Schutzmauer.'),
		('5520', 'Polder', 'Polder ist eine eingedeichte Fläche innerhalb eines Überschwemmungsgebietes, die zum Schutz vor Überflutung ereignisabhängig oder regelmäßig geflutet werden kann.'),
		('5530', 'Lärmschutz (Wall, Schutzwand)', 'Lärmschutz bedeutet, dass das Bauwerk dem Schutz vor Lärmemissionen dient. Hierzu zählen ein Lärmschutzwall oder eine Lärmschutzwand.'),
		('5540', 'Windschutz (Hecke, Knick)', 'Windschutz beschreibt bauliche Anlagen oder geeigneten Bewuchs zur Hemmung von Windschäden und Verwehungen. (z. B. Hecken, Feldgehölze, Knicks).');
		CREATE TABLE ln_zustand_strassenundwegeverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_strassenundwegeverkehr IS 'Alias: "LN_Zustand_StrassenUndWegeverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_strassenundwegeverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich das Objekt nicht mehr in regelmäßiger, der Bestimmung entsprechender Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass die Bauarbeiten am Objekt bereits begonnen haben und das Objekt noch nicht fertiggestellt ist.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_hafenkategorie_schiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_hafenkategorie_schiffsverkehr IS 'Alias: "LN_Hafenkategorie_Schiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_hafenkategorie_schiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('1010', 'Containerhafen', 'Containerhafen ist ein Hafen mit speziellen Einrichtungen (z. B. Verladebrücken) für den Umschlag von genormten Containern.'),
		('1020', 'Ölhafen', 'Ölhafen ist ein Hafen mit speziellen Einrichtungen (z. B. Tankanlagen) für den Umschlag von Rohöl und den daraus verarbeiteten Produkten'),
		('1030', 'Fischereihafen', 'Fischereihafen ist ein Hafen mit speziellen Einrichtungen (z. B. Kühlhäuser) für den Umschlag von frisch gefangenem Fisch.'),
		('1040', 'Sporthafen, Yachthafen', 'Sporthafen, Yachthafen ist ein Hafen für Sport- und Freizeitschiffe.'),
		('1050', 'Fährhafen', 'Fährhafen ist ein Hafen zum Anlegen von Fährschiffen.'),
		('1060', 'Stückguthafen', 'Stückguthafen ist ein Hafen, in dem nur Stückgüter umgeschlagen werden.'),
		('1070', 'Hafen für Massengüter', 'Hafen für Massengüter ist ein Hafen, in dem Massengüter umgeschlagen werden.');
		CREATE TABLE ln_zustand_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_flugverkehr IS 'Alias: "LN_Zustand_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich das Objekt nicht mehr in regelmäßiger, der Bestimmung entsprechender Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass die Bauarbeiten am Objekt bereits begonnen haben und das Objekt noch nicht fertiggestellt ist.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_zustand_schiffsverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_schiffsverkehr IS 'Alias: "LN_Zustand_Schiffsverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_schiffsverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich das Objekt nicht mehr in regelmäßiger, der Bestimmung entsprechender Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass die Bauarbeiten am Objekt bereits begonnen haben und das Objekt noch nicht fertiggestellt ist.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_nutzung_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_nutzung_flugverkehr IS 'Alias: "LN_Nutzung_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_nutzung_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('1000', 'Zivil', 'zivil bedeutet, dass Flugverkehr privaten oder öffentlichen Zwecken dient und nicht militärisch genutzt wird.'),
		('2000', 'Militärisch', 'Militärisch bedeutet, dass Flugverkehr nur von Streitkräften genutzt wird.');
		CREATE TABLE ln_zustand_bahnverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_zustand_bahnverkehr IS 'Alias: "LN_Zustand_Bahnverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_zustand_bahnverkehr (wert,beschreibung,dokumentation) VALUES
		('2100', 'Außer Betrieb', 'Außer Betrieb bedeutet, dass sich das Objekt nicht mehr in regelmäßiger, der Bestimmung entsprechender Nutzung befindet.'),
		('4000', 'Im Bau', 'Im Bau bedeutet, dass die Bauarbeiten am Objekt bereits begonnen haben und das Objekt noch nicht fertiggestellt ist.'),
		('8000', 'Erweiterung, Neuansiedlung', 'Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		CREATE TABLE ln_funktion_flugverkehr (
		  wert integer,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ln_funktion_flugverkehr IS 'Alias: "LN_Funktion_Flugverkehr", UML-Typ: Enumeration';
		INSERT INTO ln_funktion_flugverkehr (wert,beschreibung,dokumentation) VALUES
		('5310', 'Flugverkehrsfläche', 'Flugverkehrsfläche umfasst die baulich geprägte Fläche und die mit ihr in Zusammenhang stehende Freifläche, die ausschließlich oder vorwiegend dem Flugverkehr dient.'),
		('5311', 'Startbahn, Landebahn', 'Startbahn, Landebahn ist eine Fläche, auf der Flugzeuge starten bzw. landen.'),
		('5312', 'Begleitfläche Flugverkehr', 'Begleitfläche Flugverkehr bezeichnet eine unbebaute Fläche, die dem Flugverkehr zugeordnet wird. Die Begleitfläche Flugverkehr beinhaltet nicht die Flächen für den Flugverkehr wie Vorfeld, Start- und Landebahn oder Taxiway. Hierzu gehören z.B. Grünflächen neben den Flugverkehrsflächen.'),
		('5313', 'Zurollbahn, Taxiway', 'Zurollbahn, Taxiway ist ein Verbindungsweg zwischen den Terminals bzw. dem Vorfeld und der Start- und/oder Landebahn.'),
		('5314', 'Vorfeld', 'Vorfeld ist ein Bereich, in dem Flugzeuge abgefertigt und abgestellt werden.'),
		('5320', 'Betriebsfläche Flugverkehr', 'Betriebsfläche Flugverkehr bezeichnet Flächen, auf denen vorwiegend Anlagen und Gebäude zur Versorgung und Unterhaltung des Flugverkehrs vorhanden sind. Hierzu gehören z.B. Hangars.');
		CREATE TABLE ci_rolecode (
		  wert character varying,
		  beschreibung character varying,
		  dokumentation character varying,
		  PRIMARY KEY (wert)
		);
		
		COMMENT ON TABLE ci_rolecode IS 'Alias: "CI_RoleCode", UML-Typ: Enumeration';
		INSERT INTO ci_rolecode (wert,beschreibung,dokumentation) VALUES
		('distributor', NULL, ''),
		('author', NULL, ''),
		('processor', NULL, ''),
		('originator', NULL, ''),
		('custodian', NULL, ''),
		('user', NULL, ''),
		('owner', NULL, ''),
		('principalInvestigator', NULL, ''),
		('publisher', NULL, ''),
		('resourceProvider', NULL, ''),
		('pointOfContact', NULL, '');
		CREATE TABLE aa_gefuehrteobjektart (
		  codespace text,
		  id character varying,
		  value text,
		  PRIMARY KEY (id)
		);
		
		COMMENT ON TABLE aa_gefuehrteobjektart IS 'Alias: "AA_GefuehrteObjektart", UML-Typ: Code Liste';
		CREATE TABLE ax_punkt3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art integer,
		  aktualisierungsdatum3d date,
		  herkunft3d_description character varying,
		  herkunft3d_rationale character varying,
		  herkunft3d_datetime character(20),
		  herkunft3d_individualname character varying[],
		  herkunft3d_organisationname character varying[],
		  herkunft3d_positionname character varying[],
		  herkunft3d_phone character varying[],
		  herkunft3d_address character varying[],
		  herkunft3d_onlineresource character varying[],
		  herkunft3d_hoursofservice character varying[],
		  herkunft3d_contactinstructions character varying[],
		  herkunft3d_role character varying[],
		  source_description character varying[],
		  herkunft3d_scaledenominator character varying[],
		  herkunft3d_sourcereferencesystem character varying[],
		  herkunft3d_sourceextent character varying[],
		  herkunft3d_sourcestep character varying[],
		  hoehengenauigkeit3d_nameofmeasure character varying[],
		  hoehengenauigkeit3d_measureidentification character varying,
		  hoehengenauigkeit3d_measuredescription character varying,
		  hoehengenauigkeit3d_evaluationmethodtype character varying,
		  hoehengenauigkeit3d_evaluationmethoddescription character varying,
		  hoehengenauigkeit3d_evaluationprocedure character varying,
		  hoehengenauigkeit3d_datetime character(20)[],
		  hoehengenauigkeit3d_result character varying[],
		  lagegenauigkeit3d_nameofmeasure character varying[],
		  lagegenauigkeit3d_measureidentification character varying,
		  lagegenauigkeit3d_measuredescription character varying,
		  lagegenauigkeit3d_evaluationmethodtype character varying,
		  lagegenauigkeit3d_evaluationmethoddescription character varying,
		  lagegenauigkeit3d_evaluationprocedure character varying,
		  lagegenauigkeit3d_datetime character(20)[],
		  lagegenauigkeit3d_result character varying[],
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_punkt3d_gml ON ax_punkt3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_punkt3d_endet ON ax_punkt3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_punkt3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_punkt3d_wkb_geometry_idx ON ax_punkt3d USING gist (wkb_geometry);
		CREATE INDEX ax_punkt3d_hatdirektunten ON ax_punkt3d USING gin (hatdirektunten);
		CREATE INDEX ax_punkt3d_istabgeleitetaus ON ax_punkt3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_punkt3d_traegtbeizu ON ax_punkt3d USING gin (traegtbeizu);
		CREATE INDEX ax_punkt3d_istteilvon ON ax_punkt3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_punkt3d IS 'FeatureType: "AX_Punkt3D"';
		COMMENT ON COLUMN ax_punkt3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_punkt3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_punkt3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_punkt3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_punkt3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_punkt3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_punkt3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_punkt3d.wkb_geometry IS 'wkb_geometry  GM_Point 0..1';
		COMMENT ON COLUMN ax_punkt3d.art IS 'art enumeration AX_Art_Punkt3D 0..1';
		COMMENT ON COLUMN ax_punkt3d.aktualisierungsdatum3d IS 'qualitaetsangaben|AX_DQErhebung3D|aktualisierungsdatum3D  Date 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_rationale IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_individualname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_organisationname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_positionname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_phone IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_address IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_onlineresource IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_hoursofservice IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_contactinstructions IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_role IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_punkt3d.source_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_scaledenominator IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_sourcereferencesystem IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_sourceextent IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punkt3d.herkunft3d_sourcestep IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_punkt3d.hoehengenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_punkt3d.lagegenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		CREATE TABLE ax_musterundvergleichsstueck (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  ackerzahlodergruenlandzahl character varying,
		  bodenart integer,
		  bodenstufe integer,
		  bodenzahlodergruenlandgrundzahl character varying,
		  entstehungsart integer,
		  jahreszahl integer,
		  klimastufe integer,
		  merkmal integer NOT NULL,
		  nummer character varying,
		  nutzungsart integer,
		  sonstigeangaben integer[],
		  wasserverhaeltnisse integer,
		  zustandsstufe integer,
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  wirdbestimmt character(16),
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_musterundvergleichsstueck_gml ON ax_musterundvergleichsstueck USING btree (gml_id,beginnt);
		CREATE INDEX ax_musterundvergleichsstueck_endet ON ax_musterundvergleichsstueck USING btree (endet);
		PERFORM AddGeometryColumn('ax_musterundvergleichsstueck', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_musterundvergleichsstueck_wkb_geometry_idx ON ax_musterundvergleichsstueck USING gist (wkb_geometry);
		CREATE INDEX ax_musterundvergleichsstueck_wirdbestimmt ON ax_musterundvergleichsstueck USING btree (wirdbestimmt);
		CREATE INDEX ax_musterundvergleichsstueck_hatdirektunten ON ax_musterundvergleichsstueck USING gin (hatdirektunten);
		CREATE INDEX ax_musterundvergleichsstueck_istabgeleitetaus ON ax_musterundvergleichsstueck USING gin (istabgeleitetaus);
		CREATE INDEX ax_musterundvergleichsstueck_traegtbeizu ON ax_musterundvergleichsstueck USING gin (traegtbeizu);
		CREATE INDEX ax_musterundvergleichsstueck_istteilvon ON ax_musterundvergleichsstueck USING gin (istteilvon);
		
		COMMENT ON TABLE ax_musterundvergleichsstueck IS 'FeatureType: "AX_MusterUndVergleichsstueck"';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.ackerzahlodergruenlandzahl IS 'ackerzahlOderGruenlandzahl  CharacterString 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.bodenart IS 'bodenart enumeration AX_Bodenart_MusterUndVergleichsstueck 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.bodenstufe IS 'bodenstufe enumeration AX_Bodenstufe 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.bodenzahlodergruenlandgrundzahl IS 'bodenzahlOderGruenlandgrundzahl  CharacterString 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.entstehungsart IS 'entstehungsart enumeration AX_Entstehungsart 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.jahreszahl IS 'jahreszahl  Integer 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.klimastufe IS 'klimastufe enumeration AX_Klimastufe 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.merkmal IS 'merkmal enumeration AX_Merkmal_MusterUndVergleichsstueck 1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.nummer IS 'nummer  CharacterString 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.nutzungsart IS 'nutzungsart enumeration AX_Nutzungsart_MusterUndVergleichsstueck 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.sonstigeangaben IS 'sonstigeAngaben enumeration AX_SonstigeAngaben_MusterUndVergleichsstueck 0..*';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.wasserverhaeltnisse IS 'wasserverhaeltnisse enumeration AX_Wasserverhaeltnisse 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.zustandsstufe IS 'zustandsstufe enumeration AX_Zustandsstufe 0..1';
		COMMENT ON COLUMN ax_musterundvergleichsstueck.wirdbestimmt IS 'Assoziation zu: FeatureType AX_GrablochDerBodenschaetzung (ax_grablochderbodenschaetzung) 0..1';
		CREATE TABLE ax_kommunalesteilgebiet (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  administrativefunktion integer[],
		  bezeichnung character varying NOT NULL,
		  einwohnerzahl integer,
		  hierarchiename character varying NOT NULL,
		  hierarchiestufe integer NOT NULL,
		  historisch character varying,
		  gemeinde character varying NOT NULL,
		  gemeindeteil character varying,
		  kreis character varying NOT NULL,
		  land character varying NOT NULL,
		  regierungsbezirk character varying,
		  regionalsprache character varying[],
		  schluesselgesamt character varying NOT NULL,
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_kommunalesteilgebiet_gml ON ax_kommunalesteilgebiet USING btree (gml_id,beginnt);
		CREATE INDEX ax_kommunalesteilgebiet_endet ON ax_kommunalesteilgebiet USING btree (endet);
		PERFORM AddGeometryColumn('ax_kommunalesteilgebiet', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 2);
		CREATE INDEX ax_kommunalesteilgebiet_wkb_geometry_idx ON ax_kommunalesteilgebiet USING gist (wkb_geometry);
		CREATE INDEX ax_kommunalesteilgebiet_hatdirektunten ON ax_kommunalesteilgebiet USING gin (hatdirektunten);
		CREATE INDEX ax_kommunalesteilgebiet_istabgeleitetaus ON ax_kommunalesteilgebiet USING gin (istabgeleitetaus);
		CREATE INDEX ax_kommunalesteilgebiet_traegtbeizu ON ax_kommunalesteilgebiet USING gin (traegtbeizu);
		CREATE INDEX ax_kommunalesteilgebiet_istteilvon ON ax_kommunalesteilgebiet USING gin (istteilvon);
		
		COMMENT ON TABLE ax_kommunalesteilgebiet IS 'FeatureType: "AX_KommunalesTeilgebiet"';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.administrativefunktion IS 'administrativeFunktion enumeration AX_Administrative_Funktion 0..*';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.bezeichnung IS 'bezeichnung  CharacterString 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.einwohnerzahl IS 'einwohnerzahl  Integer 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.hierarchiename IS 'hierarchiename  CharacterString 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.hierarchiestufe IS 'hierarchiestufe  Integer 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.historisch IS 'historisch  Boolean 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.gemeinde IS 'kennzeichen|AX_Gemeindekennzeichen|gemeinde  CharacterString 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.gemeindeteil IS 'kennzeichen|AX_Gemeindekennzeichen|gemeindeteil  CharacterString 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.kreis IS 'kennzeichen|AX_Gemeindekennzeichen|kreis  CharacterString 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.land IS 'kennzeichen|AX_Gemeindekennzeichen|land  CharacterString 1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.regierungsbezirk IS 'kennzeichen|AX_Gemeindekennzeichen|regierungsbezirk  CharacterString 0..1';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.regionalsprache IS 'regionalsprache  CharacterString 0..*';
		COMMENT ON COLUMN ax_kommunalesteilgebiet.schluesselgesamt IS 'schluesselGesamt  CharacterString 1';
		CREATE TABLE ax_strukturlinie3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art integer,
		  aktualisierungsdatum3d date,
		  herkunft3d_description character varying,
		  herkunft3d_rationale character varying,
		  herkunft3d_datetime character(20),
		  herkunft3d_individualname character varying[],
		  herkunft3d_organisationname character varying[],
		  herkunft3d_positionname character varying[],
		  herkunft3d_phone character varying[],
		  herkunft3d_address character varying[],
		  herkunft3d_onlineresource character varying[],
		  herkunft3d_hoursofservice character varying[],
		  herkunft3d_contactinstructions character varying[],
		  herkunft3d_role character varying[],
		  source_description character varying[],
		  herkunft3d_scaledenominator character varying[],
		  herkunft3d_sourcereferencesystem character varying[],
		  herkunft3d_sourceextent character varying[],
		  herkunft3d_sourcestep character varying[],
		  hoehengenauigkeit3d_nameofmeasure character varying[],
		  hoehengenauigkeit3d_measureidentification character varying,
		  hoehengenauigkeit3d_measuredescription character varying,
		  hoehengenauigkeit3d_evaluationmethodtype character varying,
		  hoehengenauigkeit3d_evaluationmethoddescription character varying,
		  hoehengenauigkeit3d_evaluationprocedure character varying,
		  hoehengenauigkeit3d_datetime character(20)[],
		  hoehengenauigkeit3d_result character varying[],
		  lagegenauigkeit3d_nameofmeasure character varying[],
		  lagegenauigkeit3d_measureidentification character varying,
		  lagegenauigkeit3d_measuredescription character varying,
		  lagegenauigkeit3d_evaluationmethodtype character varying,
		  lagegenauigkeit3d_evaluationmethoddescription character varying,
		  lagegenauigkeit3d_evaluationprocedure character varying,
		  lagegenauigkeit3d_datetime character(20)[],
		  lagegenauigkeit3d_result character varying[],
		  ursprung integer,
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  an character(16),
		  istgelaendeschnittlinievon character(16),
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_strukturlinie3d_gml ON ax_strukturlinie3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_strukturlinie3d_endet ON ax_strukturlinie3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_strukturlinie3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_strukturlinie3d_wkb_geometry_idx ON ax_strukturlinie3d USING gist (wkb_geometry);
		CREATE INDEX ax_strukturlinie3d_an ON ax_strukturlinie3d USING btree (an);
		CREATE INDEX ax_strukturlinie3d_istgelaendeschnittlinievon ON ax_strukturlinie3d USING btree (istgelaendeschnittlinievon);
		CREATE INDEX ax_strukturlinie3d_hatdirektunten ON ax_strukturlinie3d USING gin (hatdirektunten);
		CREATE INDEX ax_strukturlinie3d_istabgeleitetaus ON ax_strukturlinie3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_strukturlinie3d_traegtbeizu ON ax_strukturlinie3d USING gin (traegtbeizu);
		CREATE INDEX ax_strukturlinie3d_istteilvon ON ax_strukturlinie3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_strukturlinie3d IS 'FeatureType: "AX_Strukturlinie3D"';
		COMMENT ON COLUMN ax_strukturlinie3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_strukturlinie3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_strukturlinie3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.wkb_geometry IS 'wkb_geometry  GM_CompositeCurve 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.art IS 'art enumeration AX_Art_Strukturlinie3D 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.aktualisierungsdatum3d IS 'qualitaetsangaben|AX_DQErhebung3D|aktualisierungsdatum3D  Date 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_rationale IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_individualname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_organisationname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_positionname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_phone IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_address IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_onlineresource IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_hoursofservice IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_contactinstructions IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_role IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_strukturlinie3d.source_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_scaledenominator IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_sourcereferencesystem IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_sourceextent IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.herkunft3d_sourcestep IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.hoehengenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_strukturlinie3d.lagegenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_strukturlinie3d.ursprung IS 'ursprung enumeration AX_Ursprung 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.an IS 'Assoziation zu: FeatureType AX_Bauteil3D (ax_bauteil3d) 0..1';
		COMMENT ON COLUMN ax_strukturlinie3d.istgelaendeschnittlinievon IS 'Assoziation zu: FeatureType AX_Bauwerk3D (ax_bauwerk3d) 0..1';
		CREATE TABLE ax_bauteil3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  anzahlderoberirdischengeschosse integer,
		  anzahlderunterirdischengeschosse integer,
		  baujahr integer[],
		  dachart character varying,
		  dachform integer,
		  durchfahrtshoehe double precision,
		  geschosshoeheuebergrund_null integer,
		  geschosshoeheuebergrund_wert double precision,
		  geschosshoeheuntergrund_null integer,
		  geschosshoeheuntergrund_wert double precision,
		  lagezurerdoberflaeche integer,
		  hoehe double precision[],
		  obererbezugspunkt integer[],
		  untererbezugspunkt integer[],
		  qbodenhoehe_statement character varying,
		  qbodenhoehe_ps_description character varying[],
		  qbodenhoehe_ps_rationale character varying[],
		  qbodenhoehe_ps_datetime character(20)[],
		  qbodenhoehe_ps_individualname character varying[],
		  qbodenhoehe_ps_organisationname character varying[],
		  qbodenhoehe_ps_positionname character varying[],
		  qbodenhoehe_ps_phone character varying[],
		  qbodenhoehe_ps_address character varying[],
		  qbodenhoehe_ps_onlineresource character varying[],
		  qbodenhoehe_ps_hoursofservice character varying[],
		  qbodenhoehe_ps_contactinstructions character varying[],
		  qbodenhoehe_ps_role character varying[],
		  qbodenhoehe_ps_src_description character varying[],
		  qbodenhoehe_ps_src_scaledenominator character varying[],
		  qbodenhoehe_ps_src_sourcereferencesystem character varying[],
		  qbodenhoehe_ps_src_sourceextent character varying[],
		  qbodenhoehe_ps_src_sourcestep character varying[],
		  qbodenhoehe_src_description character varying[],
		  qbodenhoehe_src_scaledenominator character varying[],
		  qbodenhoehe_src_sourcereferencesystem character varying[],
		  qbodenhoehe_src_sourceextent character varying[],
		  qbodenhoehe_src_sourcestep character varying[],
		  qdachhoehe_statement character varying,
		  qdachhoehe_ps_description character varying[],
		  qdachhoehe_ps_rationale character varying[],
		  qdachhoehe_ps_datetime character(20)[],
		  qdachhoehe_ps_individualname character varying[],
		  qdachhoehe_ps_organisationname character varying[],
		  qdachhoehe_ps_positionname character varying[],
		  qdachhoehe_ps_phone character varying[],
		  qdachhoehe_ps_address character varying[],
		  qdachhoehe_ps_onlineresource character varying[],
		  qdachhoehe_ps_hoursofservice character varying[],
		  qdachhoehe_ps_contactinstructions character varying[],
		  qdachhoehe_ps_role character varying[],
		  qdachhoehe_ps_src_description character varying[],
		  qdachhoehe_ps_src_scaledenominator character varying[],
		  qdachhoehe_ps_src_sourcereferencesystem character varying[],
		  qdachhoehe_ps_src_sourceextent character varying[],
		  qdachhoehe_ps_src_sourcestep character varying[],
		  qdachhoehe_src_description character varying[],
		  qdachhoehe_src_scaledenominator character varying[],
		  qdachhoehe_src_sourcereferencesystem character varying[],
		  qdachhoehe_src_sourceextent character varying[],
		  qdachhoehe_src_sourcestep character varying[],
		  statement character varying,
		  processstep_ax_li_processstep_mitdatenerhebung_description character varying[],
		  processstep_rationale character varying[],
		  processstep_datetime character(20)[],
		  processstep_individualname character varying[],
		  processstep_organisationname character varying[],
		  processstep_positionname character varying[],
		  processstep_phone character varying[],
		  processstep_address character varying[],
		  processstep_onlineresource character varying[],
		  processstep_hoursofservice character varying[],
		  processstep_contactinstructions character varying[],
		  processstep_role character varying[],
		  processstep_ax_datenerhebung character varying[],
		  processstep_scaledenominator character varying[],
		  processstep_sourcereferencesystem character varying[],
		  processstep_sourceextent character varying[],
		  processstep_sourcestep character varying[],
		  herkunft_source_source_ax_datenerhebung character varying[],
		  herkunft_source_source_scaledenominator character varying[],
		  herkunft_source_source_sourcereferencesystem character varying[],
		  herkunft_source_source_sourceextent character varying[],
		  herkunft_source_source_sourcestep character varying[],
		  umbauterraum double precision,
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  gehoertzu character(16)[],
		  beziehtsichauf character(16),
		  wirdbegrenztdurch character(16)[],
		  hat character(16)[],
		  hatgelaendeschnittlinie character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_bauteil3d_gml ON ax_bauteil3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_bauteil3d_endet ON ax_bauteil3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_bauteil3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_bauteil3d_wkb_geometry_idx ON ax_bauteil3d USING gist (wkb_geometry);
		CREATE INDEX ax_bauteil3d_gehoertzu ON ax_bauteil3d USING gin (gehoertzu);
		CREATE INDEX ax_bauteil3d_beziehtsichauf ON ax_bauteil3d USING btree (beziehtsichauf);
		CREATE INDEX ax_bauteil3d_wirdbegrenztdurch ON ax_bauteil3d USING gin (wirdbegrenztdurch);
		CREATE INDEX ax_bauteil3d_hat ON ax_bauteil3d USING gin (hat);
		CREATE INDEX ax_bauteil3d_hatgelaendeschnittlinie ON ax_bauteil3d USING gin (hatgelaendeschnittlinie);
		CREATE INDEX ax_bauteil3d_hatdirektunten ON ax_bauteil3d USING gin (hatdirektunten);
		CREATE INDEX ax_bauteil3d_istabgeleitetaus ON ax_bauteil3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_bauteil3d_traegtbeizu ON ax_bauteil3d USING gin (traegtbeizu);
		CREATE INDEX ax_bauteil3d_istteilvon ON ax_bauteil3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_bauteil3d IS 'FeatureType: "AX_Bauteil3D"';
		COMMENT ON COLUMN ax_bauteil3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_bauteil3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_bauteil3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_bauteil3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_bauteil3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_bauteil3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_bauteil3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_bauteil3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_bauteil3d.anzahlderoberirdischengeschosse IS 'anzahlDerOberirdischenGeschosse  Integer 0..1';
		COMMENT ON COLUMN ax_bauteil3d.anzahlderunterirdischengeschosse IS 'anzahlDerUnterirdischenGeschosse  Integer 0..1';
		COMMENT ON COLUMN ax_bauteil3d.baujahr IS 'baujahr  Integer 0..*';
		COMMENT ON COLUMN ax_bauteil3d.dachart IS 'dachart  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.dachform IS 'dachform enumeration AX_Dachform 0..1';
		COMMENT ON COLUMN ax_bauteil3d.durchfahrtshoehe IS 'durchfahrtshoehe  Length 0..1';
		COMMENT ON COLUMN ax_bauteil3d.geschosshoeheuebergrund_null IS 'geschosshoeheUeberGrund|AX_Listenelement3D|null enumeration AX_Null_Listenelement3D 0..1';
		COMMENT ON COLUMN ax_bauteil3d.geschosshoeheuebergrund_wert IS 'geschosshoeheUeberGrund|AX_Listenelement3D|wert  Length 0..1';
		COMMENT ON COLUMN ax_bauteil3d.geschosshoeheuntergrund_null IS 'geschosshoeheUnterGrund|AX_Listenelement3D|null enumeration AX_Null_Listenelement3D 0..1';
		COMMENT ON COLUMN ax_bauteil3d.geschosshoeheuntergrund_wert IS 'geschosshoeheUnterGrund|AX_Listenelement3D|wert  Length 0..1';
		COMMENT ON COLUMN ax_bauteil3d.lagezurerdoberflaeche IS 'lageZurErdoberflaeche enumeration AX_LageZurErdoberflaeche_Gebaeude 0..1';
		COMMENT ON COLUMN ax_bauteil3d.hoehe IS 'objekthoehe|AX_RelativeHoehe|hoehe  Length 1';
		COMMENT ON COLUMN ax_bauteil3d.obererbezugspunkt IS 'objekthoehe|AX_RelativeHoehe|obererBezugspunkt enumeration AX_ObererBezugspunkt 0..1';
		COMMENT ON COLUMN ax_bauteil3d.untererbezugspunkt IS 'objekthoehe|AX_RelativeHoehe|untererBezugspunkt enumeration AX_UntererBezugspunkt 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_statement IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|statement|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_description IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_rationale IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_datetime IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_individualname IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_organisationname IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_positionname IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_phone IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_address IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_onlineresource IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_hoursofservice IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_contactinstructions IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_role IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_src_description IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_src_scaledenominator IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_src_sourcereferencesystem IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_src_sourceextent IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_ps_src_sourcestep IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_src_description IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_src_scaledenominator IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_src_sourcereferencesystem IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_src_sourceextent IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qbodenhoehe_src_sourcestep IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_statement IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|statement|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_description IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_rationale IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_datetime IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_individualname IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_organisationname IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_positionname IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_phone IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_address IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_onlineresource IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_hoursofservice IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_contactinstructions IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_role IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_src_description IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_src_scaledenominator IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_src_sourcereferencesystem IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_src_sourceextent IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_ps_src_sourcestep IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_src_description IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_src_scaledenominator IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_src_sourcereferencesystem IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_src_sourceextent IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.qdachhoehe_src_sourcestep IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.statement IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|statement|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_ax_li_processstep_mitdatenerhebung_description IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|description|AX_LI_ProcessStep_MitDatenerhebung_Description enumeration  1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_rationale IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_datetime IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_individualname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_organisationname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_positionname IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_phone IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_address IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_onlineresource IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_hoursofservice IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_contactinstructions IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_role IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.processstep_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.processstep_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.herkunft_source_source_ax_datenerhebung IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|description|AX_Datenerhebung  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.herkunft_source_source_scaledenominator IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.herkunft_source_source_sourcereferencesystem IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauteil3d.herkunft_source_source_sourceextent IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.herkunft_source_source_sourcestep IS 'qualitaetsangaben|AX_DQMitDatenerhebung|herkunft|LI_Lineage|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauteil3d.umbauterraum IS 'umbauterRaum  Volume 0..1';
		COMMENT ON COLUMN ax_bauteil3d.gehoertzu IS 'Assoziation zu: FeatureType AX_Gebaeude (ax_gebaeude) 0..*';
		COMMENT ON COLUMN ax_bauteil3d.beziehtsichauf IS 'Assoziation zu: FeatureType AX_Bauteil (ax_bauteil) 0..1';
		COMMENT ON COLUMN ax_bauteil3d.wirdbegrenztdurch IS 'Assoziation zu: FeatureType AX_Begrenzungsflaeche3D (ax_begrenzungsflaeche3d) 0..*';
		COMMENT ON COLUMN ax_bauteil3d.hat IS 'Assoziation zu: FeatureType AX_GebaeudeInstallation3D (ax_gebaeudeinstallation3d) 0..*';
		COMMENT ON COLUMN ax_bauteil3d.hatgelaendeschnittlinie IS 'Assoziation zu: FeatureType AX_Strukturlinie3D (ax_strukturlinie3d) 0..*';
		CREATE TABLE ax_gebaeudeinstallation3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  funktion integer NOT NULL,
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  istteil character(16)[],
		  gehoertzu character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_gebaeudeinstallation3d_gml ON ax_gebaeudeinstallation3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_gebaeudeinstallation3d_endet ON ax_gebaeudeinstallation3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_gebaeudeinstallation3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_gebaeudeinstallation3d_wkb_geometry_idx ON ax_gebaeudeinstallation3d USING gist (wkb_geometry);
		CREATE INDEX ax_gebaeudeinstallation3d_istteil ON ax_gebaeudeinstallation3d USING gin (istteil);
		CREATE INDEX ax_gebaeudeinstallation3d_gehoertzu ON ax_gebaeudeinstallation3d USING gin (gehoertzu);
		CREATE INDEX ax_gebaeudeinstallation3d_hatdirektunten ON ax_gebaeudeinstallation3d USING gin (hatdirektunten);
		CREATE INDEX ax_gebaeudeinstallation3d_istabgeleitetaus ON ax_gebaeudeinstallation3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_gebaeudeinstallation3d_traegtbeizu ON ax_gebaeudeinstallation3d USING gin (traegtbeizu);
		CREATE INDEX ax_gebaeudeinstallation3d_istteilvon ON ax_gebaeudeinstallation3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_gebaeudeinstallation3d IS 'FeatureType: "AX_GebaeudeInstallation3D"';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.funktion IS 'funktion enumeration AX_Funktion_GebaeudeInstallation3D 1';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.istteil IS 'Assoziation zu: FeatureType AX_Bauteil3D (ax_bauteil3d) 0..*';
		COMMENT ON COLUMN ax_gebaeudeinstallation3d.gehoertzu IS 'Assoziation zu: FeatureType AX_Bauwerk3D (ax_bauwerk3d) 0..*';
		CREATE TABLE ax_bauwerk3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  qbodenhoehe_statement character varying,
		  qbodenhoehe_ps_description character varying[],
		  qbodenhoehe_ps_rationale character varying[],
		  qbodenhoehe_ps_datetime character(20)[],
		  qbodenhoehe_ps_individualname character varying[],
		  qbodenhoehe_ps_organisationname character varying[],
		  qbodenhoehe_ps_positionname character varying[],
		  qbodenhoehe_ps_phone character varying[],
		  qbodenhoehe_ps_address character varying[],
		  qbodenhoehe_ps_onlineresource character varying[],
		  qbodenhoehe_ps_hoursofservice character varying[],
		  qbodenhoehe_ps_contactinstructions character varying[],
		  qbodenhoehe_ps_role character varying[],
		  qbodenhoehe_ps_src_description character varying[],
		  qbodenhoehe_ps_src_scaledenominator character varying[],
		  qbodenhoehe_ps_src_sourcereferencesystem character varying[],
		  qbodenhoehe_ps_src_sourceextent character varying[],
		  qbodenhoehe_ps_src_sourcestep character varying[],
		  qbodenhoehe_src_description character varying[],
		  qbodenhoehe_src_scaledenominator character varying[],
		  qbodenhoehe_src_sourcereferencesystem character varying[],
		  qbodenhoehe_src_sourceextent character varying[],
		  qbodenhoehe_src_sourcestep character varying[],
		  qdachhoehe_statement character varying,
		  qdachhoehe_ps_description character varying[],
		  qdachhoehe_ps_rationale character varying[],
		  qdachhoehe_ps_datetime character(20)[],
		  qdachhoehe_ps_individualname character varying[],
		  qdachhoehe_ps_organisationname character varying[],
		  qdachhoehe_ps_positionname character varying[],
		  qdachhoehe_ps_phone character varying[],
		  qdachhoehe_ps_address character varying[],
		  qdachhoehe_ps_onlineresource character varying[],
		  qdachhoehe_ps_hoursofservice character varying[],
		  qdachhoehe_ps_contactinstructions character varying[],
		  qdachhoehe_ps_role character varying[],
		  qdachhoehe_ps_src_description character varying[],
		  qdachhoehe_ps_src_scaledenominator character varying[],
		  qdachhoehe_ps_src_sourcereferencesystem character varying[],
		  qdachhoehe_ps_src_sourceextent character varying[],
		  qdachhoehe_ps_src_sourcestep character varying[],
		  qdachhoehe_src_description character varying[],
		  qdachhoehe_src_scaledenominator character varying[],
		  qdachhoehe_src_sourcereferencesystem character varying[],
		  qdachhoehe_src_sourceextent character varying[],
		  qdachhoehe_src_sourcestep character varying[],
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  beziehtsichauf_ax_transportanlage character(16),
		  beziehtsichauf_ax_heilquellegasquelle character(16),
		  beziehtsichauf_ax_vorratsbehaelterspeicherbauwerk character(16),
		  beziehtsichauf_ax_historischesbauwerkoderhistorischeeinric character(16),
		  beziehtsichauf_ax_bauwerkoderanlagefuersportfreizeitunderh character(16),
		  beziehtsichauf_ax_bauwerkoderanlagefuerindustrieundgewerbe character(16),
		  beziehtsichauf_ax_einrichtunginoeffentlichenbereichen character(16),
		  beziehtsichauf_ax_sonstigesbauwerkodersonstigeeinrichtung character(16),
		  beziehtsichauf_ax_leitung character(16),
		  beziehtsichauf_ax_turm character(16),
		  beziehtsichauf_ax_seilbahnschwebebahn character(16),
		  beziehtsichauf_ax_wegpfadsteig character(16),
		  beziehtsichauf_ax_bahnverkehrsanlage character(16),
		  beziehtsichauf_ax_gleis character(16),
		  beziehtsichauf_ax_strassenverkehrsanlage character(16),
		  beziehtsichauf_ax_bauwerkimverkehrsbereich character(16),
		  beziehtsichauf_ax_flugverkehrsanlage character(16),
		  beziehtsichauf_ax_einrichtungenfuerdenschiffsverkehr character(16),
		  beziehtsichauf_ax_bauwerkimgewaesserbereich character(16),
		  beziehtsichauf_ax_schifffahrtsliniefaehrverkehr character(16),
		  beziehtsichauf_ax_sickerstrecke character(16),
		  beziehtsichauf_ax_gewaesserstationierungsachse character(16),
		  beziehtsichauf_ax_wasserspiegelhoehe character(16),
		  beziehtsichauf_ax_nullpunkt character(16),
		  beziehtsichauf_ax_abschnitt character(16),
		  beziehtsichauf_ax_netzknoten character(16),
		  beziehtsichauf_ax_ast character(16),
		  beziehtsichauf_ax_grenzuebergang character(16),
		  beziehtsichauf_ax_testgelaende character(16),
		  beziehtsichauf_ax_schleuse character(16),
		  beziehtsichauf_ax_ortslage character(16),
		  beziehtsichauf_ax_hafen character(16),
		  beziehtsichauf_ax_untergeordnetesgewaesser character(16),
		  beziehtsichauf_ax_gewaessermerkmal character(16),
		  beziehtsichauf_ax_polder character(16),
		  beziehtsichauf_ax_vegetationsmerkmal character(16),
		  bauwerkwirdbegrenztdurch character(16)[],
		  hat character(16)[],
		  gehoertzubauwerk_3d character(16)[],
		  hatbauwerk_3d character(16)[],
		  hatgelaendeschnittlinie character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_bauwerk3d_gml ON ax_bauwerk3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_bauwerk3d_endet ON ax_bauwerk3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_bauwerk3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_bauwerk3d_wkb_geometry_idx ON ax_bauwerk3d USING gist (wkb_geometry);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_transportanlage ON ax_bauwerk3d USING btree (beziehtsichauf_ax_transportanlage);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_heilquellegasquelle ON ax_bauwerk3d USING btree (beziehtsichauf_ax_heilquellegasquelle);
		CREATE INDEX ax_b3d_beziehtsichauf_ax_vorratsbehaelterspeicherbauwerk ON ax_bauwerk3d USING btree (beziehtsichauf_ax_vorratsbehaelterspeicherbauwerk);
		CREATE INDEX ax_b3d_bsa_ax_hbohe ON ax_bauwerk3d USING btree (beziehtsichauf_ax_historischesbauwerkoderhistorischeeinric);
		CREATE INDEX ax_b3d_bsa_ax_boafsfue ON ax_bauwerk3d USING btree (beziehtsichauf_ax_bauwerkoderanlagefuersportfreizeitunderh);
		CREATE INDEX ax_b3d_bsa_ax_boafiug ON ax_bauwerk3d USING btree (beziehtsichauf_ax_bauwerkoderanlagefuerindustrieundgewerbe);
		CREATE INDEX ax_b3d_bsa_ax_eiob ON ax_bauwerk3d USING btree (beziehtsichauf_ax_einrichtunginoeffentlichenbereichen);
		CREATE INDEX ax_b3d_bsa_ax_sbose ON ax_bauwerk3d USING btree (beziehtsichauf_ax_sonstigesbauwerkodersonstigeeinrichtung);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_leitung ON ax_bauwerk3d USING btree (beziehtsichauf_ax_leitung);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_turm ON ax_bauwerk3d USING btree (beziehtsichauf_ax_turm);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_seilbahnschwebebahn ON ax_bauwerk3d USING btree (beziehtsichauf_ax_seilbahnschwebebahn);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_wegpfadsteig ON ax_bauwerk3d USING btree (beziehtsichauf_ax_wegpfadsteig);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_bahnverkehrsanlage ON ax_bauwerk3d USING btree (beziehtsichauf_ax_bahnverkehrsanlage);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_gleis ON ax_bauwerk3d USING btree (beziehtsichauf_ax_gleis);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_strassenverkehrsanlage ON ax_bauwerk3d USING btree (beziehtsichauf_ax_strassenverkehrsanlage);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_bauwerkimverkehrsbereich ON ax_bauwerk3d USING btree (beziehtsichauf_ax_bauwerkimverkehrsbereich);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_flugverkehrsanlage ON ax_bauwerk3d USING btree (beziehtsichauf_ax_flugverkehrsanlage);
		CREATE INDEX ax_b3d_bsa_ax_efds ON ax_bauwerk3d USING btree (beziehtsichauf_ax_einrichtungenfuerdenschiffsverkehr);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_bauwerkimgewaesserbereich ON ax_bauwerk3d USING btree (beziehtsichauf_ax_bauwerkimgewaesserbereich);
		CREATE INDEX ax_b3d_beziehtsichauf_ax_schifffahrtsliniefaehrverkehr ON ax_bauwerk3d USING btree (beziehtsichauf_ax_schifffahrtsliniefaehrverkehr);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_sickerstrecke ON ax_bauwerk3d USING btree (beziehtsichauf_ax_sickerstrecke);
		CREATE INDEX ax_b3d_beziehtsichauf_ax_gewaesserstationierungsachse ON ax_bauwerk3d USING btree (beziehtsichauf_ax_gewaesserstationierungsachse);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_wasserspiegelhoehe ON ax_bauwerk3d USING btree (beziehtsichauf_ax_wasserspiegelhoehe);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_nullpunkt ON ax_bauwerk3d USING btree (beziehtsichauf_ax_nullpunkt);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_abschnitt ON ax_bauwerk3d USING btree (beziehtsichauf_ax_abschnitt);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_netzknoten ON ax_bauwerk3d USING btree (beziehtsichauf_ax_netzknoten);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_ast ON ax_bauwerk3d USING btree (beziehtsichauf_ax_ast);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_grenzuebergang ON ax_bauwerk3d USING btree (beziehtsichauf_ax_grenzuebergang);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_testgelaende ON ax_bauwerk3d USING btree (beziehtsichauf_ax_testgelaende);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_schleuse ON ax_bauwerk3d USING btree (beziehtsichauf_ax_schleuse);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_ortslage ON ax_bauwerk3d USING btree (beziehtsichauf_ax_ortslage);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_hafen ON ax_bauwerk3d USING btree (beziehtsichauf_ax_hafen);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_untergeordnetesgewaesser ON ax_bauwerk3d USING btree (beziehtsichauf_ax_untergeordnetesgewaesser);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_gewaessermerkmal ON ax_bauwerk3d USING btree (beziehtsichauf_ax_gewaessermerkmal);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_polder ON ax_bauwerk3d USING btree (beziehtsichauf_ax_polder);
		CREATE INDEX ax_bauwerk3d_beziehtsichauf_ax_vegetationsmerkmal ON ax_bauwerk3d USING btree (beziehtsichauf_ax_vegetationsmerkmal);
		CREATE INDEX ax_bauwerk3d_bauwerkwirdbegrenztdurch ON ax_bauwerk3d USING gin (bauwerkwirdbegrenztdurch);
		CREATE INDEX ax_bauwerk3d_hat ON ax_bauwerk3d USING gin (hat);
		CREATE INDEX ax_bauwerk3d_gehoertzubauwerk_3d ON ax_bauwerk3d USING gin (gehoertzubauwerk_3d);
		CREATE INDEX ax_bauwerk3d_hatbauwerk_3d ON ax_bauwerk3d USING gin (hatbauwerk_3d);
		CREATE INDEX ax_bauwerk3d_hatgelaendeschnittlinie ON ax_bauwerk3d USING gin (hatgelaendeschnittlinie);
		CREATE INDEX ax_bauwerk3d_hatdirektunten ON ax_bauwerk3d USING gin (hatdirektunten);
		CREATE INDEX ax_bauwerk3d_istabgeleitetaus ON ax_bauwerk3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_bauwerk3d_traegtbeizu ON ax_bauwerk3d USING gin (traegtbeizu);
		CREATE INDEX ax_bauwerk3d_istteilvon ON ax_bauwerk3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_bauwerk3d IS 'FeatureType: "AX_Bauwerk3D"';
		COMMENT ON COLUMN ax_bauwerk3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_bauwerk3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_bauwerk3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_statement IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|statement|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_description IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_rationale IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_datetime IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_individualname IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_organisationname IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_positionname IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_phone IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_address IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_onlineresource IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_hoursofservice IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_contactinstructions IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_role IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_src_description IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_src_scaledenominator IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_src_sourcereferencesystem IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_src_sourceextent IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_ps_src_sourcestep IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_src_description IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_src_scaledenominator IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_src_sourcereferencesystem IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_src_sourceextent IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qbodenhoehe_src_sourcestep IS 'qualitaetBodenhoehe|AX_DQBodenhoehe|herkunft|LI_Lineage|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_statement IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|statement|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_description IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_rationale IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_datetime IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_individualname IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_organisationname IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_positionname IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_phone IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_address IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_onlineresource IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_hoursofservice IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_contactinstructions IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_role IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_src_description IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_src_scaledenominator IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_src_sourcereferencesystem IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_src_sourceextent IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_ps_src_sourcestep IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|processStep|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_src_description IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_src_scaledenominator IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_src_sourcereferencesystem IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_src_sourceextent IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.qdachhoehe_src_sourcestep IS 'qualitaetDachhoehe|AX_DQDachhoehe|herkunft|LI_Lineage|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_transportanlage IS 'Assoziation zu: FeatureType AX_Transportanlage (ax_transportanlage) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_heilquellegasquelle IS 'Assoziation zu: FeatureType AX_HeilquelleGasquelle (ax_heilquellegasquelle) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_vorratsbehaelterspeicherbauwerk IS 'Assoziation zu: FeatureType AX_VorratsbehaelterSpeicherbauwerk (ax_vorratsbehaelterspeicherbauwerk) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_historischesbauwerkoderhistorischeeinric IS 'Assoziation zu: FeatureType AX_HistorischesBauwerkOderHistorischeEinrichtung (ax_historischesbauwerkoderhistorischeeinrichtung) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_bauwerkoderanlagefuersportfreizeitunderh IS 'Assoziation zu: FeatureType AX_BauwerkOderAnlageFuerSportFreizeitUndErholung (ax_bauwerkoderanlagefuersportfreizeitunderholung) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_bauwerkoderanlagefuerindustrieundgewerbe IS 'Assoziation zu: FeatureType AX_BauwerkOderAnlageFuerIndustrieUndGewerbe (ax_bauwerkoderanlagefuerindustrieundgewerbe) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_einrichtunginoeffentlichenbereichen IS 'Assoziation zu: FeatureType AX_EinrichtungInOeffentlichenBereichen (ax_einrichtunginoeffentlichenbereichen) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_sonstigesbauwerkodersonstigeeinrichtung IS 'Assoziation zu: FeatureType AX_SonstigesBauwerkOderSonstigeEinrichtung (ax_sonstigesbauwerkodersonstigeeinrichtung) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_leitung IS 'Assoziation zu: FeatureType AX_Leitung (ax_leitung) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_turm IS 'Assoziation zu: FeatureType AX_Turm (ax_turm) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_seilbahnschwebebahn IS 'Assoziation zu: FeatureType AX_SeilbahnSchwebebahn (ax_seilbahnschwebebahn) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_wegpfadsteig IS 'Assoziation zu: FeatureType AX_WegPfadSteig (ax_wegpfadsteig) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_bahnverkehrsanlage IS 'Assoziation zu: FeatureType AX_Bahnverkehrsanlage (ax_bahnverkehrsanlage) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_gleis IS 'Assoziation zu: FeatureType AX_Gleis (ax_gleis) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_strassenverkehrsanlage IS 'Assoziation zu: FeatureType AX_Strassenverkehrsanlage (ax_strassenverkehrsanlage) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_bauwerkimverkehrsbereich IS 'Assoziation zu: FeatureType AX_BauwerkImVerkehrsbereich (ax_bauwerkimverkehrsbereich) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_flugverkehrsanlage IS 'Assoziation zu: FeatureType AX_Flugverkehrsanlage (ax_flugverkehrsanlage) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_einrichtungenfuerdenschiffsverkehr IS 'Assoziation zu: FeatureType AX_EinrichtungenFuerDenSchiffsverkehr (ax_einrichtungenfuerdenschiffsverkehr) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_bauwerkimgewaesserbereich IS 'Assoziation zu: FeatureType AX_BauwerkImGewaesserbereich (ax_bauwerkimgewaesserbereich) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_schifffahrtsliniefaehrverkehr IS 'Assoziation zu: FeatureType AX_SchifffahrtslinieFaehrverkehr (ax_schifffahrtsliniefaehrverkehr) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_sickerstrecke IS 'Assoziation zu: FeatureType AX_Sickerstrecke (ax_sickerstrecke) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_gewaesserstationierungsachse IS 'Assoziation zu: FeatureType AX_Gewaesserstationierungsachse (ax_gewaesserstationierungsachse) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_wasserspiegelhoehe IS 'Assoziation zu: FeatureType AX_Wasserspiegelhoehe (ax_wasserspiegelhoehe) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_nullpunkt IS 'Assoziation zu: FeatureType AX_Nullpunkt (ax_nullpunkt) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_abschnitt IS 'Assoziation zu: FeatureType AX_Abschnitt (ax_abschnitt) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_netzknoten IS 'Assoziation zu: FeatureType AX_Netzknoten (ax_netzknoten) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_ast IS 'Assoziation zu: FeatureType AX_Ast (ax_ast) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_grenzuebergang IS 'Assoziation zu: FeatureType AX_Grenzuebergang (ax_grenzuebergang) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_testgelaende IS 'Assoziation zu: FeatureType AX_Testgelaende (ax_testgelaende) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_schleuse IS 'Assoziation zu: FeatureType AX_Schleuse (ax_schleuse) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_ortslage IS 'Assoziation zu: FeatureType AX_Ortslage (ax_ortslage) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_hafen IS 'Assoziation zu: FeatureType AX_Hafen (ax_hafen) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_untergeordnetesgewaesser IS 'Assoziation zu: FeatureType AX_UntergeordnetesGewaesser (ax_untergeordnetesgewaesser) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_gewaessermerkmal IS 'Assoziation zu: FeatureType AX_Gewaessermerkmal (ax_gewaessermerkmal) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_polder IS 'Assoziation zu: FeatureType AX_Polder (ax_polder) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.beziehtsichauf_ax_vegetationsmerkmal IS 'Assoziation zu: FeatureType AX_Vegetationsmerkmal (ax_vegetationsmerkmal) 0..1';
		COMMENT ON COLUMN ax_bauwerk3d.bauwerkwirdbegrenztdurch IS 'Assoziation zu: FeatureType AX_Begrenzungsflaeche3D (ax_begrenzungsflaeche3d) 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.hat IS 'Assoziation zu: FeatureType AX_GebaeudeInstallation3D (ax_gebaeudeinstallation3d) 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.gehoertzubauwerk_3d IS 'Assoziation zu: FeatureType AX_Bauwerk3D (ax_bauwerk3d) 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.hatbauwerk_3d IS 'Assoziation zu: FeatureType AX_Bauwerk3D (ax_bauwerk3d) 0..*';
		COMMENT ON COLUMN ax_bauwerk3d.hatgelaendeschnittlinie IS 'Assoziation zu: FeatureType AX_Strukturlinie3D (ax_strukturlinie3d) 0..*';
		CREATE TABLE ax_tuer3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  istenthaltenin character(16),
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_tuer3d_gml ON ax_tuer3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_tuer3d_endet ON ax_tuer3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_tuer3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_tuer3d_wkb_geometry_idx ON ax_tuer3d USING gist (wkb_geometry);
		CREATE INDEX ax_tuer3d_istenthaltenin ON ax_tuer3d USING btree (istenthaltenin);
		CREATE INDEX ax_tuer3d_hatdirektunten ON ax_tuer3d USING gin (hatdirektunten);
		CREATE INDEX ax_tuer3d_istabgeleitetaus ON ax_tuer3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_tuer3d_traegtbeizu ON ax_tuer3d USING gin (traegtbeizu);
		CREATE INDEX ax_tuer3d_istteilvon ON ax_tuer3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_tuer3d IS 'FeatureType: "AX_Tuer3D"';
		COMMENT ON COLUMN ax_tuer3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_tuer3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_tuer3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_tuer3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_tuer3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_tuer3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_tuer3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_tuer3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_tuer3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_tuer3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_fenster3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  istenthaltenin character(16),
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_fenster3d_gml ON ax_fenster3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_fenster3d_endet ON ax_fenster3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_fenster3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_fenster3d_wkb_geometry_idx ON ax_fenster3d USING gist (wkb_geometry);
		CREATE INDEX ax_fenster3d_istenthaltenin ON ax_fenster3d USING btree (istenthaltenin);
		CREATE INDEX ax_fenster3d_hatdirektunten ON ax_fenster3d USING gin (hatdirektunten);
		CREATE INDEX ax_fenster3d_istabgeleitetaus ON ax_fenster3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_fenster3d_traegtbeizu ON ax_fenster3d USING gin (traegtbeizu);
		CREATE INDEX ax_fenster3d_istteilvon ON ax_fenster3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_fenster3d IS 'FeatureType: "AX_Fenster3D"';
		COMMENT ON COLUMN ax_fenster3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_fenster3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_fenster3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_fenster3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_fenster3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_fenster3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_fenster3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_fenster3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_fenster3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_fenster3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_dachflaeche3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  hat character(16)[],
		  begrenzt character(16),
		  begrenztbauwerk character(16),
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_dachflaeche3d_gml ON ax_dachflaeche3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_dachflaeche3d_endet ON ax_dachflaeche3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_dachflaeche3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_dachflaeche3d_wkb_geometry_idx ON ax_dachflaeche3d USING gist (wkb_geometry);
		CREATE INDEX ax_dachflaeche3d_hat ON ax_dachflaeche3d USING gin (hat);
		CREATE INDEX ax_dachflaeche3d_begrenzt ON ax_dachflaeche3d USING btree (begrenzt);
		CREATE INDEX ax_dachflaeche3d_begrenztbauwerk ON ax_dachflaeche3d USING btree (begrenztbauwerk);
		CREATE INDEX ax_dachflaeche3d_hatdirektunten ON ax_dachflaeche3d USING gin (hatdirektunten);
		CREATE INDEX ax_dachflaeche3d_istabgeleitetaus ON ax_dachflaeche3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_dachflaeche3d_traegtbeizu ON ax_dachflaeche3d USING gin (traegtbeizu);
		CREATE INDEX ax_dachflaeche3d_istteilvon ON ax_dachflaeche3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_dachflaeche3d IS 'FeatureType: "AX_Dachflaeche3D"';
		COMMENT ON COLUMN ax_dachflaeche3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_dachflaeche3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_dachflaeche3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_dachflaeche3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_dachflaeche3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_dachflaeche3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_dachflaeche3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_dachflaeche3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_dachflaeche3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_dachflaeche3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_abschlussflaeche3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  hat character(16)[],
		  begrenzt character(16),
		  begrenztbauwerk character(16),
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_abschlussflaeche3d_gml ON ax_abschlussflaeche3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_abschlussflaeche3d_endet ON ax_abschlussflaeche3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_abschlussflaeche3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_abschlussflaeche3d_wkb_geometry_idx ON ax_abschlussflaeche3d USING gist (wkb_geometry);
		CREATE INDEX ax_abschlussflaeche3d_hat ON ax_abschlussflaeche3d USING gin (hat);
		CREATE INDEX ax_abschlussflaeche3d_begrenzt ON ax_abschlussflaeche3d USING btree (begrenzt);
		CREATE INDEX ax_abschlussflaeche3d_begrenztbauwerk ON ax_abschlussflaeche3d USING btree (begrenztbauwerk);
		CREATE INDEX ax_abschlussflaeche3d_hatdirektunten ON ax_abschlussflaeche3d USING gin (hatdirektunten);
		CREATE INDEX ax_abschlussflaeche3d_istabgeleitetaus ON ax_abschlussflaeche3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_abschlussflaeche3d_traegtbeizu ON ax_abschlussflaeche3d USING gin (traegtbeizu);
		CREATE INDEX ax_abschlussflaeche3d_istteilvon ON ax_abschlussflaeche3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_abschlussflaeche3d IS 'FeatureType: "AX_Abschlussflaeche3D"';
		COMMENT ON COLUMN ax_abschlussflaeche3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_abschlussflaeche3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_abschlussflaeche3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_bodenflaeche3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  hat character(16)[],
		  begrenzt character(16),
		  begrenztbauwerk character(16),
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_bodenflaeche3d_gml ON ax_bodenflaeche3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_bodenflaeche3d_endet ON ax_bodenflaeche3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_bodenflaeche3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_bodenflaeche3d_wkb_geometry_idx ON ax_bodenflaeche3d USING gist (wkb_geometry);
		CREATE INDEX ax_bodenflaeche3d_hat ON ax_bodenflaeche3d USING gin (hat);
		CREATE INDEX ax_bodenflaeche3d_begrenzt ON ax_bodenflaeche3d USING btree (begrenzt);
		CREATE INDEX ax_bodenflaeche3d_begrenztbauwerk ON ax_bodenflaeche3d USING btree (begrenztbauwerk);
		CREATE INDEX ax_bodenflaeche3d_hatdirektunten ON ax_bodenflaeche3d USING gin (hatdirektunten);
		CREATE INDEX ax_bodenflaeche3d_istabgeleitetaus ON ax_bodenflaeche3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_bodenflaeche3d_traegtbeizu ON ax_bodenflaeche3d USING gin (traegtbeizu);
		CREATE INDEX ax_bodenflaeche3d_istteilvon ON ax_bodenflaeche3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_bodenflaeche3d IS 'FeatureType: "AX_Bodenflaeche3D"';
		COMMENT ON COLUMN ax_bodenflaeche3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_bodenflaeche3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_bodenflaeche3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_bodenflaeche3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_bodenflaeche3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_bodenflaeche3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_bodenflaeche3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_bodenflaeche3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_bodenflaeche3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_bodenflaeche3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_wandflaeche3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  hat character(16)[],
		  begrenzt character(16),
		  begrenztbauwerk character(16),
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_wandflaeche3d_gml ON ax_wandflaeche3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_wandflaeche3d_endet ON ax_wandflaeche3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_wandflaeche3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_wandflaeche3d_wkb_geometry_idx ON ax_wandflaeche3d USING gist (wkb_geometry);
		CREATE INDEX ax_wandflaeche3d_hat ON ax_wandflaeche3d USING gin (hat);
		CREATE INDEX ax_wandflaeche3d_begrenzt ON ax_wandflaeche3d USING btree (begrenzt);
		CREATE INDEX ax_wandflaeche3d_begrenztbauwerk ON ax_wandflaeche3d USING btree (begrenztbauwerk);
		CREATE INDEX ax_wandflaeche3d_hatdirektunten ON ax_wandflaeche3d USING gin (hatdirektunten);
		CREATE INDEX ax_wandflaeche3d_istabgeleitetaus ON ax_wandflaeche3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_wandflaeche3d_traegtbeizu ON ax_wandflaeche3d USING gin (traegtbeizu);
		CREATE INDEX ax_wandflaeche3d_istteilvon ON ax_wandflaeche3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_wandflaeche3d IS 'FeatureType: "AX_Wandflaeche3D"';
		COMMENT ON COLUMN ax_wandflaeche3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_wandflaeche3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_wandflaeche3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_wandflaeche3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_wandflaeche3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_wandflaeche3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_wandflaeche3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_wandflaeche3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_wandflaeche3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_wandflaeche3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		CREATE TABLE ax_flaeche3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art integer NOT NULL,
		  aktualisierungsdatum3d date,
		  herkunft3d_description character varying,
		  herkunft3d_rationale character varying,
		  herkunft3d_datetime character(20),
		  herkunft3d_individualname character varying[],
		  herkunft3d_organisationname character varying[],
		  herkunft3d_positionname character varying[],
		  herkunft3d_phone character varying[],
		  herkunft3d_address character varying[],
		  herkunft3d_onlineresource character varying[],
		  herkunft3d_hoursofservice character varying[],
		  herkunft3d_contactinstructions character varying[],
		  herkunft3d_role character varying[],
		  source_description character varying[],
		  herkunft3d_scaledenominator character varying[],
		  herkunft3d_sourcereferencesystem character varying[],
		  herkunft3d_sourceextent character varying[],
		  herkunft3d_sourcestep character varying[],
		  hoehengenauigkeit3d_nameofmeasure character varying[],
		  hoehengenauigkeit3d_measureidentification character varying,
		  hoehengenauigkeit3d_measuredescription character varying,
		  hoehengenauigkeit3d_evaluationmethodtype character varying,
		  hoehengenauigkeit3d_evaluationmethoddescription character varying,
		  hoehengenauigkeit3d_evaluationprocedure character varying,
		  hoehengenauigkeit3d_datetime character(20)[],
		  hoehengenauigkeit3d_result character varying[],
		  lagegenauigkeit3d_nameofmeasure character varying[],
		  lagegenauigkeit3d_measureidentification character varying,
		  lagegenauigkeit3d_measuredescription character varying,
		  lagegenauigkeit3d_evaluationmethodtype character varying,
		  lagegenauigkeit3d_evaluationmethoddescription character varying,
		  lagegenauigkeit3d_evaluationprocedure character varying,
		  lagegenauigkeit3d_datetime character(20)[],
		  lagegenauigkeit3d_result character varying[],
		  ursprung integer,
		  hatdirektunten character(16)[],
		  istabgeleitetaus character(16)[],
		  traegtbeizu character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_flaeche3d_gml ON ax_flaeche3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_flaeche3d_endet ON ax_flaeche3d USING btree (endet);
		PERFORM AddGeometryColumn('ax_flaeche3d', 'wkb_geometry', find_srid(current_schema()::text,'ax_flurstueck','wkb_geometry'), 'GEOMETRY', 3);
		CREATE INDEX ax_flaeche3d_wkb_geometry_idx ON ax_flaeche3d USING gist (wkb_geometry);
		CREATE INDEX ax_flaeche3d_hatdirektunten ON ax_flaeche3d USING gin (hatdirektunten);
		CREATE INDEX ax_flaeche3d_istabgeleitetaus ON ax_flaeche3d USING gin (istabgeleitetaus);
		CREATE INDEX ax_flaeche3d_traegtbeizu ON ax_flaeche3d USING gin (traegtbeizu);
		CREATE INDEX ax_flaeche3d_istteilvon ON ax_flaeche3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_flaeche3d IS 'FeatureType: "AX_Flaeche3D"';
		COMMENT ON COLUMN ax_flaeche3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_flaeche3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_flaeche3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_flaeche3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_flaeche3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_flaeche3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_flaeche3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_flaeche3d.wkb_geometry IS 'wkb_geometry  GM_Object 0..1';
		COMMENT ON COLUMN ax_flaeche3d.art IS 'art enumeration AX_Art_Flaeche3D 1';
		COMMENT ON COLUMN ax_flaeche3d.aktualisierungsdatum3d IS 'qualitaetsangaben|AX_DQErhebung3D|aktualisierungsdatum3D  Date 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_rationale IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_individualname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_organisationname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_positionname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_phone IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_address IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_onlineresource IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_hoursofservice IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_contactinstructions IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_role IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_flaeche3d.source_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_scaledenominator IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_sourcereferencesystem IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_sourceextent IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaeche3d.herkunft3d_sourcestep IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_flaeche3d.hoehengenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_flaeche3d.lagegenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_flaeche3d.ursprung IS 'ursprung enumeration AX_Ursprung 0..1';
		CREATE TABLE ax_textur3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art character varying,
		  darstellungsprioritaet integer,
		  signaturnummer character varying,
		  thema character varying,
		  vorderseite character varying,
		  aktualitaet character(20),
		  dateitypraster integer,
		  link character varying NOT NULL,
		  texturkoordinaten double precision[] NOT NULL,
		  horizontal integer,
		  vertikal integer,
		  typ integer,
		  dientzurdarstellungvon character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_textur3d_gml ON ax_textur3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_textur3d_endet ON ax_textur3d USING btree (endet);
		CREATE INDEX ax_textur3d_dientzurdarstellungvon ON ax_textur3d USING gin (dientzurdarstellungvon);
		CREATE INDEX ax_textur3d_istteilvon ON ax_textur3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_textur3d IS 'FeatureType: "AX_Textur3D"';
		COMMENT ON COLUMN ax_textur3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_textur3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_textur3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_textur3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_textur3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_textur3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_textur3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_textur3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_textur3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_textur3d.art IS 'art  CharacterString 0..1';
		COMMENT ON COLUMN ax_textur3d.darstellungsprioritaet IS 'darstellungsprioritaet  Integer 0..1';
		COMMENT ON COLUMN ax_textur3d.signaturnummer IS 'signaturnummer  CharacterString 0..1';
		COMMENT ON COLUMN ax_textur3d.thema IS 'thema  CharacterString 0..1';
		COMMENT ON COLUMN ax_textur3d.vorderseite IS 'vorderseite  Boolean 0..1';
		COMMENT ON COLUMN ax_textur3d.aktualitaet IS 'aktualitaet  DateTime 0..1';
		COMMENT ON COLUMN ax_textur3d.dateitypraster IS 'dateiTypRaster enumeration AX_DateiTypRaster_Textur3D 0..1';
		COMMENT ON COLUMN ax_textur3d.link IS 'link  URI 1';
		COMMENT ON COLUMN ax_textur3d.texturkoordinaten IS 'texturKoordinaten  Real 1..*';
		COMMENT ON COLUMN ax_textur3d.horizontal IS 'texturVerarbeitung|AX_TexturVerarbeitung_Textur3D|horizontal  Integer 1';
		COMMENT ON COLUMN ax_textur3d.vertikal IS 'texturVerarbeitung|AX_TexturVerarbeitung_Textur3D|vertikal  Integer 1';
		COMMENT ON COLUMN ax_textur3d.typ IS 'typ enumeration AX_Typ_Textur3D 0..1';
		CREATE TABLE ax_material3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art character varying,
		  darstellungsprioritaet integer,
		  signaturnummer character varying,
		  thema character varying,
		  vorderseite character varying,
		  aktualitaet character(20),
		  blau integer,
		  gruen integer,
		  rot integer,
		  material integer,
		  dientzurdarstellungvon character(16)[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_material3d_gml ON ax_material3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_material3d_endet ON ax_material3d USING btree (endet);
		CREATE INDEX ax_material3d_dientzurdarstellungvon ON ax_material3d USING gin (dientzurdarstellungvon);
		CREATE INDEX ax_material3d_istteilvon ON ax_material3d USING gin (istteilvon);
		
		COMMENT ON TABLE ax_material3d IS 'FeatureType: "AX_Material3D"';
		COMMENT ON COLUMN ax_material3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_material3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_material3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_material3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_material3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_material3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_material3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_material3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_material3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_material3d.art IS 'art  CharacterString 0..1';
		COMMENT ON COLUMN ax_material3d.darstellungsprioritaet IS 'darstellungsprioritaet  Integer 0..1';
		COMMENT ON COLUMN ax_material3d.signaturnummer IS 'signaturnummer  CharacterString 0..1';
		COMMENT ON COLUMN ax_material3d.thema IS 'thema  CharacterString 0..1';
		COMMENT ON COLUMN ax_material3d.vorderseite IS 'vorderseite  Boolean 0..1';
		COMMENT ON COLUMN ax_material3d.aktualitaet IS 'aktualitaet  DateTime 0..1';
		COMMENT ON COLUMN ax_material3d.blau IS 'materialeigenschaft|AX_Materialeigenschaft_Material3D|farbeRGB|AX_FarbeRGB_Materialeigenschaft_Material3D|blau  Integer 1';
		COMMENT ON COLUMN ax_material3d.gruen IS 'materialeigenschaft|AX_Materialeigenschaft_Material3D|farbeRGB|AX_FarbeRGB_Materialeigenschaft_Material3D|gruen  Integer 1';
		COMMENT ON COLUMN ax_material3d.rot IS 'materialeigenschaft|AX_Materialeigenschaft_Material3D|farbeRGB|AX_FarbeRGB_Materialeigenschaft_Material3D|rot  Integer 1';
		COMMENT ON COLUMN ax_material3d.material IS 'materialeigenschaft|AX_Materialeigenschaft_Material3D|material enumeration AX_Material_Materialeigenschaft_Material3D 0..1';
		CREATE TABLE ax_flurstueckgrundbuch (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  amtlicheflaeche character varying NOT NULL,
		  anlassflurstueck character varying,
		  anliegervermerk_buchungsart integer[],
		  anliegervermerk_flurnummer character varying[],
		  anliegervermerk_nenner character varying[],
		  anliegervermerk_zaehler character varying[],
		  anliegervermerk_gemarkungsnummer character varying[],
		  anliegervermerk_land character varying[],
		  flurnummer character varying,
		  flurstuecksfolge character varying,
		  flurstueckskennzeichen character varying NOT NULL,
		  nenner character varying,
		  zaehler character varying NOT NULL,
		  gemarkungsnummer character varying NOT NULL,
		  land character varying NOT NULL,
		  gemeindezugehoerigkeit_gemeinde character varying NOT NULL,
		  gemeindezugehoerigkeit_gemeindeteil character varying,
		  gemeindezugehoerigkeit_kreis character varying NOT NULL,
		  gemeindezugehoerigkeit_land character varying NOT NULL,
		  gemeindezugehoerigkeit_regierungsbezirk character varying,
		  lagebezeichnung character varying[] NOT NULL,
		  lebenszeitintervallflurstueck_beginnt character(20) NOT NULL,
		  lebenszeitintervallflurstueck_endet character(20),
		  rechtsbehelfsverfahren character varying,
		  strittigegrenze character varying,
		  wirtschaftsart character varying[] NOT NULL,
		  zustaendigestelle_land character varying NOT NULL,
		  zustaendigestelle_stelle character varying NOT NULL,
		  istteilvon character(16)[],
		  istgebucht character(16) NOT NULL,
		  isteinverweisaufflurstueck character(16) NOT NULL,
		  einbezogenin character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_flurstueckgrundbuch_gml ON ax_flurstueckgrundbuch USING btree (gml_id,beginnt);
		CREATE INDEX ax_flurstueckgrundbuch_endet ON ax_flurstueckgrundbuch USING btree (endet);
		CREATE INDEX ax_flurstueckgrundbuch_istgebucht ON ax_flurstueckgrundbuch USING btree (istgebucht);
		CREATE INDEX ax_flurstueckgrundbuch_isteinverweisaufflurstueck ON ax_flurstueckgrundbuch USING btree (isteinverweisaufflurstueck);
		CREATE INDEX ax_flurstueckgrundbuch_einbezogenin ON ax_flurstueckgrundbuch USING gin (einbezogenin);
		CREATE INDEX ax_flurstueckgrundbuch_istteilvon ON ax_flurstueckgrundbuch USING gin (istteilvon);
		
		COMMENT ON TABLE ax_flurstueckgrundbuch IS 'FeatureType: "AX_FlurstueckGrundbuch"';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.amtlicheflaeche IS 'amtlicheFlaeche  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anlassflurstueck IS 'anlassFlurstueck codelist AA_Anlassart 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anliegervermerk_buchungsart IS 'anliegervermerk|AX_Anliegervermerk|buchungsart enumeration AX_Buchungsart_Anlieger 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anliegervermerk_flurnummer IS 'anliegervermerk|AX_Anliegervermerk|flurnummer  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anliegervermerk_nenner IS 'anliegervermerk|AX_Anliegervermerk|flurstuecksnummer|AX_Flurstuecksnummer|nenner  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anliegervermerk_zaehler IS 'anliegervermerk|AX_Anliegervermerk|flurstuecksnummer|AX_Flurstuecksnummer|zaehler  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anliegervermerk_gemarkungsnummer IS 'anliegervermerk|AX_Anliegervermerk|gemarkung|AX_Gemarkung_Schluessel|gemarkungsnummer  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.anliegervermerk_land IS 'anliegervermerk|AX_Anliegervermerk|gemarkung|AX_Gemarkung_Schluessel|land  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.flurnummer IS 'flurnummer  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.flurstuecksfolge IS 'flurstuecksfolge  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.flurstueckskennzeichen IS 'flurstueckskennzeichen  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.nenner IS 'flurstuecksnummer|AX_Flurstuecksnummer|nenner  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.zaehler IS 'flurstuecksnummer|AX_Flurstuecksnummer|zaehler  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.gemarkungsnummer IS 'gemarkung|AX_Gemarkung_Schluessel|gemarkungsnummer  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.land IS 'gemarkung|AX_Gemarkung_Schluessel|land  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.gemeindezugehoerigkeit_gemeinde IS 'gemeindezugehoerigkeit|AX_Gemeindekennzeichen|gemeinde  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.gemeindezugehoerigkeit_gemeindeteil IS 'gemeindezugehoerigkeit|AX_Gemeindekennzeichen|gemeindeteil  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.gemeindezugehoerigkeit_kreis IS 'gemeindezugehoerigkeit|AX_Gemeindekennzeichen|kreis  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.gemeindezugehoerigkeit_land IS 'gemeindezugehoerigkeit|AX_Gemeindekennzeichen|land  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.gemeindezugehoerigkeit_regierungsbezirk IS 'gemeindezugehoerigkeit|AX_Gemeindekennzeichen|regierungsbezirk  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.lagebezeichnung IS 'lagebezeichnung  CharacterString 1..*';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.lebenszeitintervallflurstueck_beginnt IS 'lebenszeitintervallFlurstueck|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.lebenszeitintervallflurstueck_endet IS 'lebenszeitintervallFlurstueck|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.rechtsbehelfsverfahren IS 'rechtsbehelfsverfahren  Boolean 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.strittigegrenze IS 'strittigeGrenze  CharacterString 0..1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.wirtschaftsart IS 'wirtschaftsart enumeration AX_WirtschaftsartGrundbuch 1..*';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.zustaendigestelle_land IS 'zustaendigeStelle|AX_Dienststelle_Schluessel|land  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.zustaendigestelle_stelle IS 'zustaendigeStelle|AX_Dienststelle_Schluessel|stelle  CharacterString 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.istgebucht IS 'Assoziation zu: FeatureType AX_Buchungsstelle (ax_buchungsstelle) 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.isteinverweisaufflurstueck IS 'Assoziation zu: FeatureType AX_Flurstueck (ax_flurstueck) 1';
		COMMENT ON COLUMN ax_flurstueckgrundbuch.einbezogenin IS 'Assoziation zu: FeatureType AX_BauRaumOderBodenordnungsrechtGrundbuch (ax_bauraumoderbodenordnungsrechtgrundbuch) 0..*';
		CREATE TABLE ax_bauraumoderbodenordnungsrechtgrundbuch (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  anlassbauraumoderbodenordnungsrecht character varying,
		  artderfestlegung integer NOT NULL,
		  land character varying,
		  stelle character varying,
		  ausfuehrendestellebezeichnung character varying,
		  bezeichnung character varying,
		  datumabgabe date,
		  datumanordnung date,
		  datumbesitzeinweisung date,
		  datumrechtskraeftig date,
		  lebenszeitintervallbauraumoderbodenordnungsrecht_beginnt character(20) NOT NULL,
		  lebenszeitintervallbauraumoderbodenordnungsrecht_endet character(20),
		  name character varying,
		  istteilvon character(16)[],
		  isteinverweisaufbauraumoderbodenordnungsrecht character(16) NOT NULL,
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_bauraumoderbodenordnungsrechtgrundbuch_gml ON ax_bauraumoderbodenordnungsrechtgrundbuch USING btree (gml_id,beginnt);
		CREATE INDEX ax_bauraumoderbodenordnungsrechtgrundbuch_endet ON ax_bauraumoderbodenordnungsrechtgrundbuch USING btree (endet);
		CREATE INDEX ax_brobg_isteinverweisaufbauraumoderbodenordnungsrecht ON ax_bauraumoderbodenordnungsrechtgrundbuch USING btree (isteinverweisaufbauraumoderbodenordnungsrecht);
		CREATE INDEX ax_bauraumoderbodenordnungsrechtgrundbuch_istteilvon ON ax_bauraumoderbodenordnungsrechtgrundbuch USING gin (istteilvon);
		
		COMMENT ON TABLE ax_bauraumoderbodenordnungsrechtgrundbuch IS 'FeatureType: "AX_BauRaumOderBodenordnungsrechtGrundbuch"';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.anlassbauraumoderbodenordnungsrecht IS 'anlassBauRaumOderBodenordnungsrecht codelist AA_Anlassart 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.artderfestlegung IS 'artDerFestlegung enumeration AX_ArtDerFestlegung_BauRaumOderBodenordnungsrecht 1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.land IS 'ausfuehrendeStelle|AX_Dienststelle_Schluessel|land  CharacterString 1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.stelle IS 'ausfuehrendeStelle|AX_Dienststelle_Schluessel|stelle  CharacterString 1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.ausfuehrendestellebezeichnung IS 'ausfuehrendeStelleBezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.datumabgabe IS 'datumAbgabe  Date 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.datumanordnung IS 'datumAnordnung  Date 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.datumbesitzeinweisung IS 'datumBesitzeinweisung  Date 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.datumrechtskraeftig IS 'datumRechtskraeftig  Date 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.lebenszeitintervallbauraumoderbodenordnungsrecht_beginnt IS 'lebenszeitintervallBauRaumOderBodenordnungsrecht|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.lebenszeitintervallbauraumoderbodenordnungsrecht_endet IS 'lebenszeitintervallBauRaumOderBodenordnungsrecht|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ax_bauraumoderbodenordnungsrechtgrundbuch.isteinverweisaufbauraumoderbodenordnungsrecht IS 'Assoziation zu: FeatureType AX_BauRaumOderBodenordnungsrecht (ax_bauraumoderbodenordnungsrecht) 1';
		CREATE TABLE ax_fortfuehrungsfallgrundbuch (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  bemerkung character varying,
		  bezeichnungbauraumoderbodenordnungsrecht character varying,
		  fortfuehrungsfallnummer integer NOT NULL,
		  gemarkungsnummer character varying,
		  land character varying,
		  laufendenummer character varying,
		  ordnungsnummer character varying[],
		  ueberschriftimfortfuehrungsnachweis character varying[] NOT NULL,
		  zeigtaufaltesflurstueckgrundbuch character varying[],
		  zeigtaufneuesflurstueckgrundbuch character varying[],
		  istteilvon character(16)[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_fortfuehrungsfallgrundbuch_gml ON ax_fortfuehrungsfallgrundbuch USING btree (gml_id,beginnt);
		CREATE INDEX ax_fortfuehrungsfallgrundbuch_endet ON ax_fortfuehrungsfallgrundbuch USING btree (endet);
		CREATE INDEX ax_fortfuehrungsfallgrundbuch_istteilvon ON ax_fortfuehrungsfallgrundbuch USING gin (istteilvon);
		
		COMMENT ON TABLE ax_fortfuehrungsfallgrundbuch IS 'FeatureType: "AX_FortfuehrungsfallGrundbuch"';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.bemerkung IS 'bemerkung  CharacterString 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.bezeichnungbauraumoderbodenordnungsrecht IS 'bezeichnungBauRaumOderBodenordnungsrecht  CharacterString 0..1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.fortfuehrungsfallnummer IS 'fortfuehrungsfallnummer  Integer 1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.gemarkungsnummer IS 'laufendeNummer|AX_Fortfuehrungsnummer|gemarkungsnummer  CharacterString 1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.land IS 'laufendeNummer|AX_Fortfuehrungsnummer|land  CharacterString 1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.laufendenummer IS 'laufendeNummer|AX_Fortfuehrungsnummer|laufendeNummer  CharacterString 1';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.ordnungsnummer IS 'ordnungsnummer  CharacterString 0..*';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.ueberschriftimfortfuehrungsnachweis IS 'ueberschriftImFortfuehrungsnachweis codelist AA_Anlassart 1..*';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.zeigtaufaltesflurstueckgrundbuch IS 'zeigtAufAltesFlurstueckGrundbuch  CharacterString 0..*';
		COMMENT ON COLUMN ax_fortfuehrungsfallgrundbuch.zeigtaufneuesflurstueckgrundbuch IS 'zeigtAufNeuesFlurstueckGrundbuch  CharacterString 0..*';
		CREATE TABLE ax_punktwolke3d (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beschreibung character varying,
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  name character varying,
		  quellobjektid character varying,
		  zeigtaufexternes_art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  art integer,
		  aktualisierungsdatum3d date,
		  herkunft3d_description character varying,
		  herkunft3d_rationale character varying,
		  herkunft3d_datetime character(20),
		  herkunft3d_individualname character varying[],
		  herkunft3d_organisationname character varying[],
		  herkunft3d_positionname character varying[],
		  herkunft3d_phone character varying[],
		  herkunft3d_address character varying[],
		  herkunft3d_onlineresource character varying[],
		  herkunft3d_hoursofservice character varying[],
		  herkunft3d_contactinstructions character varying[],
		  herkunft3d_role character varying[],
		  source_description character varying[],
		  herkunft3d_scaledenominator character varying[],
		  herkunft3d_sourcereferencesystem character varying[],
		  herkunft3d_sourceextent character varying[],
		  herkunft3d_sourcestep character varying[],
		  hoehengenauigkeit3d_nameofmeasure character varying[],
		  hoehengenauigkeit3d_measureidentification character varying,
		  hoehengenauigkeit3d_measuredescription character varying,
		  hoehengenauigkeit3d_evaluationmethodtype character varying,
		  hoehengenauigkeit3d_evaluationmethoddescription character varying,
		  hoehengenauigkeit3d_evaluationprocedure character varying,
		  hoehengenauigkeit3d_datetime character(20)[],
		  hoehengenauigkeit3d_result character varying[],
		  lagegenauigkeit3d_nameofmeasure character varying[],
		  lagegenauigkeit3d_measureidentification character varying,
		  lagegenauigkeit3d_measuredescription character varying,
		  lagegenauigkeit3d_evaluationmethodtype character varying,
		  lagegenauigkeit3d_evaluationmethoddescription character varying,
		  lagegenauigkeit3d_evaluationprocedure character varying,
		  lagegenauigkeit3d_datetime character(20)[],
		  lagegenauigkeit3d_result character varying[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_punktwolke3d_gml ON ax_punktwolke3d USING btree (gml_id,beginnt);
		CREATE INDEX ax_punktwolke3d_endet ON ax_punktwolke3d USING btree (endet);
		
		COMMENT ON TABLE ax_punktwolke3d IS 'FeatureType: "AX_Punktwolke3D"';
		COMMENT ON COLUMN ax_punktwolke3d.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.beschreibung IS 'beschreibung  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_punktwolke3d.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.zeigtaufexternes_art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_punktwolke3d.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.art IS 'art enumeration AX_Art_Punktwolke3D 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.aktualisierungsdatum3d IS 'qualitaetsangaben|AX_DQErhebung3D|aktualisierungsdatum3D  Date 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|description|CharacterString enumeration  1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_rationale IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|rationale|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|dateTime|DateTime  DateTime 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_individualname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|individualName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_organisationname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|organisationName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_positionname IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|positionName|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_phone IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|phone|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_address IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|address|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_onlineresource IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|onlineResource|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_hoursofservice IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|hoursOfService|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_contactinstructions IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|contactInfo|CI_Contact|contactInstructions|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_role IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|processor|CI_ResponsibleParty|role|CI_RoleCode enumeration CI_RoleCode 1';
		COMMENT ON COLUMN ax_punktwolke3d.source_description IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|description|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_scaledenominator IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|scaleDenominator|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_sourcereferencesystem IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceReferenceSystem|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_sourceextent IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceExtent|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.herkunft3d_sourcestep IS 'qualitaetsangaben|AX_DQErhebung3D|herkunft3D|LI_ProcessStep|source|LI_Source|sourceStep|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.hoehengenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|hoehengenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_nameofmeasure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_measureidentification IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_measuredescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_evaluationmethodtype IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_evaluationmethoddescription IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_evaluationprocedure IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_datetime IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_punktwolke3d.lagegenauigkeit3d_result IS 'qualitaetsangaben|AX_DQErhebung3D|lagegenauigkeit3D|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		CREATE TABLE ax_dhmgitter (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  anlass character varying[],
		  beschreibung character varying,
		  beginnt character(20) NOT NULL,
		  endet character(20),
		  advstandardmodell character varying[],
		  sonstigesmodell character varying[],
		  name character varying,
		  quellobjektid character varying,
		  art character varying[],
		  zeigtaufexternes_name character varying[],
		  zeigtaufexternes_uri character varying[],
		  aktualisierungsdatum date,
		  auspraegung integer NOT NULL,
		  berechnungsmethode integer[],
		  erfassungsdatum date NOT NULL,
		  nameofmeasure character varying[],
		  measureidentification character varying,
		  measuredescription character varying,
		  evaluationmethodtype character varying,
		  evaluationmethoddescription character varying,
		  evaluationprocedure character varying,
		  datetime character(20)[],
		  result character varying[],
		  gitterweite double precision NOT NULL,
		  verwendeteobjekte integer[],
		  PRIMARY KEY (ogc_fid)
		);
		
		CREATE UNIQUE INDEX ax_dhmgitter_gml ON ax_dhmgitter USING btree (gml_id,beginnt);
		CREATE INDEX ax_dhmgitter_endet ON ax_dhmgitter USING btree (endet);
		
		COMMENT ON TABLE ax_dhmgitter IS 'FeatureType: "AX_DHMGitter"';
		COMMENT ON COLUMN ax_dhmgitter.anlass IS 'anlass codelist AA_Anlassart 0..*';
		COMMENT ON COLUMN ax_dhmgitter.beschreibung IS 'beschreibung  CharacterString 0..1';
		COMMENT ON COLUMN ax_dhmgitter.beginnt IS 'lebenszeitintervall|AA_Lebenszeitintervall|beginnt  DateTime 1';
		COMMENT ON COLUMN ax_dhmgitter.endet IS 'lebenszeitintervall|AA_Lebenszeitintervall|endet  DateTime 0..1';
		COMMENT ON COLUMN ax_dhmgitter.advstandardmodell IS 'modellart|AA_Modellart|advStandardModell enumeration AA_AdVStandardModell 0..1';
		COMMENT ON COLUMN ax_dhmgitter.sonstigesmodell IS 'modellart|AA_Modellart|sonstigesModell codelist AA_WeitereModellart 0..1';
		COMMENT ON COLUMN ax_dhmgitter.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ax_dhmgitter.quellobjektid IS 'quellobjektID  CharacterString 0..1';
		COMMENT ON COLUMN ax_dhmgitter.art IS 'zeigtAufExternes|AA_Fachdatenverbindung|art  URI 1';
		COMMENT ON COLUMN ax_dhmgitter.zeigtaufexternes_name IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|name  CharacterString 0..1';
		COMMENT ON COLUMN ax_dhmgitter.zeigtaufexternes_uri IS 'zeigtAufExternes|AA_Fachdatenverbindung|fachdatenobjekt|AA_Fachdatenobjekt|uri  URI 0..1';
		COMMENT ON COLUMN ax_dhmgitter.aktualisierungsdatum IS 'aktualisierungsdatum  Date 0..1';
		COMMENT ON COLUMN ax_dhmgitter.auspraegung IS 'auspraegung enumeration AX_Auspraegung 1';
		COMMENT ON COLUMN ax_dhmgitter.berechnungsmethode IS 'berechnungsmethode enumeration AX_Berechnungsmethode 0..*';
		COMMENT ON COLUMN ax_dhmgitter.erfassungsdatum IS 'erfassungsdatum  Date 1';
		COMMENT ON COLUMN ax_dhmgitter.nameofmeasure IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|nameOfMeasure|CharacterString  CharacterString 0..*';
		COMMENT ON COLUMN ax_dhmgitter.measureidentification IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureIdentification|MD_Identifier  MD_Identifier 0..1';
		COMMENT ON COLUMN ax_dhmgitter.measuredescription IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|measureDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_dhmgitter.evaluationmethodtype IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodType|DQ_EvaluationMethodTypeCode  DQ_EvaluationMethodTypeCode 0..1';
		COMMENT ON COLUMN ax_dhmgitter.evaluationmethoddescription IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationMethodDescription|CharacterString  CharacterString 0..1';
		COMMENT ON COLUMN ax_dhmgitter.evaluationprocedure IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|evaluationProcedure|CI_Citation  CI_Citation 0..1';
		COMMENT ON COLUMN ax_dhmgitter.datetime IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|dateTime|DateTime  DateTime 0..*';
		COMMENT ON COLUMN ax_dhmgitter.result IS 'genauigkeit|DQ_AbsoluteExternalPositionalAccuracy|result|DQ_Result  DQ_Result 1..*';
		COMMENT ON COLUMN ax_dhmgitter.gitterweite IS 'gitterweite  Length 1';
		COMMENT ON COLUMN ax_dhmgitter.verwendeteobjekte IS 'verwendeteObjekte enumeration AX_VerwendeteObjekte_DHMGitter 0..*';
		CREATE TABLE lb_lockermaterial (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  oberflaechenmaterial integer,
		  wassersaettigung integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_lockermaterial IS 'FeatureType: "LB_Lockermaterial"';
		COMMENT ON COLUMN lb_lockermaterial.oberflaechenmaterial IS 'oberflaechenmaterial enumeration LB_Oberflaechenmaterial_Lockermaterial 0..1';
		COMMENT ON COLUMN lb_lockermaterial.wassersaettigung IS 'wassersaettigung enumeration LB_Wassersaettigung_Lockermaterial 0..1';
		CREATE TABLE lb_festgestein (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_festgestein IS 'FeatureType: "LB_Festgestein"';
		CREATE TABLE lb_hochbauundbaulichenebenflaeche (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_hochbauundbaulichenebenflaeche IS 'FeatureType: "LB_HochbauUndBaulicheNebenflaeche"';
		CREATE TABLE lb_tiefbau (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_tiefbau IS 'FeatureType: "LB_Tiefbau"';
		CREATE TABLE lb_krautigevegetation (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  salzigerstandort character varying,
		  vegetationsmerkmal integer,
		  wassersaettigung integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_krautigevegetation IS 'FeatureType: "LB_KrautigeVegetation"';
		COMMENT ON COLUMN lb_krautigevegetation.salzigerstandort IS 'salzigerStandort   0..1';
		COMMENT ON COLUMN lb_krautigevegetation.vegetationsmerkmal IS 'vegetationsmerkmal enumeration LB_Vegetationsmerkmal_KrautigeVegetation 0..1';
		COMMENT ON COLUMN lb_krautigevegetation.wassersaettigung IS 'wassersaettigung enumeration LB_Wassersaettigung_KrautigeVegetation 0..1';
		CREATE TABLE lb_holzigevegetation (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  blattform integer[],
		  vegetationsmerkmal integer,
		  verjuengungsflaeche character varying,
		  wassersaettigung integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_holzigevegetation IS 'FeatureType: "LB_HolzigeVegetation"';
		COMMENT ON COLUMN lb_holzigevegetation.blattform IS 'blattform enumeration LB_Blattform_HolzigeVegetation 0..*';
		COMMENT ON COLUMN lb_holzigevegetation.vegetationsmerkmal IS 'vegetationsmerkmal enumeration LB_Vegetationsmerkmal_HolzigeVegetation 0..1';
		COMMENT ON COLUMN lb_holzigevegetation.verjuengungsflaeche IS 'verjuengungsflaeche   0..1';
		COMMENT ON COLUMN lb_holzigevegetation.wassersaettigung IS 'wassersaettigung enumeration LB_Wassersaettigung_HolzigeVegetation 0..1';
		CREATE TABLE lb_binnengewaesser (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  fliesseigenschaft integer,
		  gewaesserart integer,
		  wasserfuehrung integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_binnengewaesser IS 'FeatureType: "LB_Binnengewaesser"';
		COMMENT ON COLUMN lb_binnengewaesser.fliesseigenschaft IS 'fliesseigenschaft enumeration LB_Fliesseigenschaft_Binnengewaesser 0..1';
		COMMENT ON COLUMN lb_binnengewaesser.gewaesserart IS 'gewaesserart enumeration LB_Gewaesserart_Binnengewaesser 0..1';
		COMMENT ON COLUMN lb_binnengewaesser.wasserfuehrung IS 'wasserfuehrung enumeration LB_Wasserfuehrung_Binnengewaesser 0..1';
		CREATE TABLE lb_eis (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  eisart integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_eis IS 'FeatureType: "LB_Eis"';
		COMMENT ON COLUMN lb_eis.eisart IS 'eisart enumeration LB_Eisart_Eis 0..1';
		CREATE TABLE lb_meer (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  meerart integer,
		  tideeinfluss character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE lb_meer IS 'FeatureType: "LB_Meer"';
		COMMENT ON COLUMN lb_meer.meerart IS 'meerart enumeration LB_Meerart_Meer 0..1';
		COMMENT ON COLUMN lb_meer.tideeinfluss IS 'tideeinfluss   0..1';
		CREATE TABLE ln_wasserwirtschaft (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  funktion integer[],
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_wasserwirtschaft IS 'FeatureType: "LN_Wasserwirtschaft"';
		COMMENT ON COLUMN ln_wasserwirtschaft.art IS 'art enumeration LN_Art_Wasserwirtschaft 0..1';
		COMMENT ON COLUMN ln_wasserwirtschaft.funktion IS 'funktion enumeration LN_Funktion_Wasserwirtschaft 0..*';
		COMMENT ON COLUMN ln_wasserwirtschaft.zustand IS 'zustand enumeration LN_Zustand_Wasserwirtschaft 0..1';
		CREATE TABLE ln_ohnenutzung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  bezeichnung character varying,
		  name character varying,
		  zweitname character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_ohnenutzung IS 'FeatureType: "LN_OhneNutzung"';
		COMMENT ON COLUMN ln_ohnenutzung.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_ohnenutzung.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_ohnenutzung.zweitname IS 'zweitname  CharacterString 0..1';
		CREATE TABLE ln_forstwirtschaft (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_forstwirtschaft IS 'FeatureType: "LN_Forstwirtschaft"';
		COMMENT ON COLUMN ln_forstwirtschaft.art IS 'art enumeration LN_Art_Forstwirtschaft 0..1';
		CREATE TABLE ln_aquakulturundfischereiwirtschaft (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer[],
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_aquakulturundfischereiwirtschaft IS 'FeatureType: "LN_AquakulturUndFischereiwirtschaft"';
		COMMENT ON COLUMN ln_aquakulturundfischereiwirtschaft.art IS 'art enumeration LN_Art_AquakulturUndFischereiwirtschaft 0..*';
		CREATE TABLE ln_landwirtschaft (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  artderbetriebsflaeche integer[],
		  bewirtschaftung integer,
		  name integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_landwirtschaft IS 'FeatureType: "LN_Landwirtschaft"';
		COMMENT ON COLUMN ln_landwirtschaft.artderbetriebsflaeche IS 'artDerBetriebsflaeche enumeration LN_ArtDerBetriebsflaeche_Landwirtschaft 0..*';
		COMMENT ON COLUMN ln_landwirtschaft.bewirtschaftung IS 'bewirtschaftung enumeration LN_Bewirtschaftung_Landwirtschaft 0..1';
		COMMENT ON COLUMN ln_landwirtschaft.name IS 'name enumeration LN_ArtDerBetriebsflaeche_Landwirtschaft 0..1';
		CREATE TABLE ln_freiluftundnaherholung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  bezeichnung character varying,
		  name character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_freiluftundnaherholung IS 'FeatureType: "LN_FreiluftUndNaherholung"';
		COMMENT ON COLUMN ln_freiluftundnaherholung.art IS 'art enumeration LN_Art_FreiluftUndNaherholung 0..1';
		COMMENT ON COLUMN ln_freiluftundnaherholung.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_freiluftundnaherholung.name IS 'name  CharacterString 0..1';
		CREATE TABLE ln_oeffentlicheeinrichtungen (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  funktion integer,
		  name character varying,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_oeffentlicheeinrichtungen IS 'FeatureType: "LN_OeffentlicheEinrichtungen"';
		COMMENT ON COLUMN ln_oeffentlicheeinrichtungen.funktion IS 'funktion enumeration LN_Funktion_OeffentlicheEinrichtungen 0..1';
		COMMENT ON COLUMN ln_oeffentlicheeinrichtungen.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_oeffentlicheeinrichtungen.zustand IS 'zustand enumeration LN_Zustand_OeffentlicheEinrichtungen 0..1';
		CREATE TABLE ln_gewerblichedienstleistungen (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  bezeichnung character varying,
		  name character varying,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_gewerblichedienstleistungen IS 'FeatureType: "LN_GewerblicheDienstleistungen"';
		COMMENT ON COLUMN ln_gewerblichedienstleistungen.art IS 'art enumeration LN_Art_GewerblicheDienstleistungen 0..1';
		COMMENT ON COLUMN ln_gewerblichedienstleistungen.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_gewerblichedienstleistungen.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_gewerblichedienstleistungen.zustand IS 'zustand enumeration LN_Zustand_GewerblicheDienstleistungen 0..1';
		CREATE TABLE ln_sportanlage (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  bezeichnung character varying,
		  name character varying,
		  sportart integer[],
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_sportanlage IS 'FeatureType: "LN_Sportanlage"';
		COMMENT ON COLUMN ln_sportanlage.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_sportanlage.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_sportanlage.sportart IS 'sportart enumeration LN_Sportart_Sportanlage 0..*';
		CREATE TABLE ln_lagerung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  funktion integer,
		  lagergut integer,
		  name character varying,
		  oberflaeche integer,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_lagerung IS 'FeatureType: "LN_Lagerung"';
		COMMENT ON COLUMN ln_lagerung.funktion IS 'funktion enumeration LN_Funktion_Lagerung 0..1';
		COMMENT ON COLUMN ln_lagerung.lagergut IS 'lagergut enumeration LN_Lagergut_Lagerung 0..1';
		COMMENT ON COLUMN ln_lagerung.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_lagerung.oberflaeche IS 'oberflaeche enumeration LN_Oberflaeche_Lagerung 0..1';
		COMMENT ON COLUMN ln_lagerung.zustand IS 'zustand enumeration LN_Zustand_Lagerung 0..1';
		CREATE TABLE ln_versorgungundentsorgung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  bezeichnung character varying,
		  name character varying,
		  primaerenergie integer,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_versorgungundentsorgung IS 'FeatureType: "LN_VersorgungUndEntsorgung"';
		COMMENT ON COLUMN ln_versorgungundentsorgung.art IS 'art enumeration LN_Art_VersorgungUndEntsorgung 0..1';
		COMMENT ON COLUMN ln_versorgungundentsorgung.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_versorgungundentsorgung.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_versorgungundentsorgung.primaerenergie IS 'primaerenergie enumeration LN_Primaerenergie_VersorgungUndEntsorgung 0..1';
		COMMENT ON COLUMN ln_versorgungundentsorgung.zustand IS 'zustand enumeration LN_Zustand_VersorgungUndEntsorgung 0..1';
		CREATE TABLE ln_freizeitanlage (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  bezeichnung character varying,
		  name character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_freizeitanlage IS 'FeatureType: "LN_Freizeitanlage"';
		COMMENT ON COLUMN ln_freizeitanlage.art IS 'art enumeration LN_Art_Freizeitanlage 0..1';
		COMMENT ON COLUMN ln_freizeitanlage.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_freizeitanlage.name IS 'name  CharacterString 0..1';
		CREATE TABLE ln_industrieundverarbeitendesgewerbe (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  art integer,
		  bezeichnung character varying,
		  name character varying,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_industrieundverarbeitendesgewerbe IS 'FeatureType: "LN_IndustrieUndVerarbeitendesGewerbe"';
		COMMENT ON COLUMN ln_industrieundverarbeitendesgewerbe.art IS 'art enumeration LN_Art_IndustrieUndVerarbeitendesGewerbe 0..1';
		COMMENT ON COLUMN ln_industrieundverarbeitendesgewerbe.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_industrieundverarbeitendesgewerbe.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_industrieundverarbeitendesgewerbe.zustand IS 'zustand enumeration LN_Zustand_IndustrieUndVerarbeitendesGewerbe 0..1';
		CREATE TABLE ln_abbau (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  abbaugut integer[],
		  art integer,
		  bezeichnung character varying,
		  foerdergut integer,
		  name character varying,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_abbau IS 'FeatureType: "LN_Abbau"';
		COMMENT ON COLUMN ln_abbau.abbaugut IS 'abbaugut enumeration LN_Abbaugut_Abbau 0..*';
		COMMENT ON COLUMN ln_abbau.art IS 'art enumeration LN_Art_Abbau 0..1';
		COMMENT ON COLUMN ln_abbau.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_abbau.foerdergut IS 'foerdergut enumeration LN_Foerdergut_Abbau 0..1';
		COMMENT ON COLUMN ln_abbau.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_abbau.zustand IS 'zustand enumeration LN_Zustand_Abbau 0..1';
		CREATE TABLE ln_bestattung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  artderbestattungsflaeche integer,
		  name character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_bestattung IS 'FeatureType: "LN_Bestattung"';
		COMMENT ON COLUMN ln_bestattung.artderbestattungsflaeche IS 'artDerBestattungsflaeche enumeration LN_ArtDerBestattungsflaeche_Bestattung 0..1';
		COMMENT ON COLUMN ln_bestattung.name IS 'name  CharacterString 0..1';
		CREATE TABLE ln_kulturundunterhaltung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  funktion integer,
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_kulturundunterhaltung IS 'FeatureType: "LN_KulturUndUnterhaltung"';
		COMMENT ON COLUMN ln_kulturundunterhaltung.funktion IS 'funktion enumeration LN_Funktion_KulturUndUnterhaltung 0..1';
		COMMENT ON COLUMN ln_kulturundunterhaltung.zustand IS 'zustand enumeration LN_Zustand_KulturUndUnterhaltung 0..1';
		CREATE TABLE ln_wohnnutzung (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  bezeichnung character varying,
		  name character varying,
		  zeitlichkeit integer,
		  zustand integer,
		  zweitname character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_wohnnutzung IS 'FeatureType: "LN_Wohnnutzung"';
		COMMENT ON COLUMN ln_wohnnutzung.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_wohnnutzung.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_wohnnutzung.zeitlichkeit IS 'zeitlichkeit enumeration LN_Zeitlichkeit_Wohnnutzung 0..1';
		COMMENT ON COLUMN ln_wohnnutzung.zustand IS 'zustand enumeration LN_Zustand_Wohnnutzung 0..1';
		COMMENT ON COLUMN ln_wohnnutzung.zweitname IS 'zweitname  CharacterString 0..1';
		CREATE TABLE ln_flugverkehr (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  funktion integer,
		  nutzung integer[],
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_flugverkehr IS 'FeatureType: "LN_Flugverkehr"';
		COMMENT ON COLUMN ln_flugverkehr.funktion IS 'funktion enumeration LN_Funktion_Flugverkehr 0..1';
		COMMENT ON COLUMN ln_flugverkehr.nutzung IS 'nutzung enumeration LN_Nutzung_Flugverkehr 0..*';
		COMMENT ON COLUMN ln_flugverkehr.zustand IS 'zustand enumeration LN_Zustand_Flugverkehr 0..1';
		CREATE TABLE ln_schutzanlage (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  funktion integer,
		  typ integer,
		  zuflusssteuerung integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_schutzanlage IS 'FeatureType: "LN_Schutzanlage"';
		COMMENT ON COLUMN ln_schutzanlage.funktion IS 'funktion enumeration LN_Funktion_Schutzanlage 0..1';
		COMMENT ON COLUMN ln_schutzanlage.typ IS 'typ enumeration LN_Typ_Schutzanlage 0..1';
		COMMENT ON COLUMN ln_schutzanlage.zuflusssteuerung IS 'zuflusssteuerung enumeration LN_Zuflusssteuerung_Schutzanlage 0..1';
		CREATE TABLE ln_schiffsverkehr (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  funktion integer,
		  hafenkategorie integer,
		  name character varying,
		  nutzung integer[],
		  zustand integer,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_schiffsverkehr IS 'FeatureType: "LN_Schiffsverkehr"';
		COMMENT ON COLUMN ln_schiffsverkehr.funktion IS 'funktion enumeration LN_Funktion_Schiffsverkehr 0..1';
		COMMENT ON COLUMN ln_schiffsverkehr.hafenkategorie IS 'hafenkategorie enumeration LN_Hafenkategorie_Schiffsverkehr 0..1';
		COMMENT ON COLUMN ln_schiffsverkehr.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_schiffsverkehr.nutzung IS 'nutzung enumeration LN_Nutzung_Schiffsverkehr 0..*';
		COMMENT ON COLUMN ln_schiffsverkehr.zustand IS 'zustand enumeration LN_Zustand_Schiffsverkehr 0..1';
		CREATE TABLE ln_strassenundwegeverkehr (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  artdesparkplatzes integer,
		  bezeichnung character varying,
		  funktion integer,
		  fussgaengerzone integer,
		  name character varying,
		  zustand integer,
		  zweitname character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_strassenundwegeverkehr IS 'FeatureType: "LN_StrassenUndWegeverkehr"';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.artdesparkplatzes IS 'artDesParkplatzes enumeration LN_ArtDesParkplatzes_StrassenUndWegeverkehr 0..1';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.funktion IS 'funktion enumeration LN_Funktion_StrassenUndWegeverkehr 0..1';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.fussgaengerzone IS 'fussgaengerzone enumeration LN_Fussgaengerzone_StrassenUndWegeverkehr 0..1';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.name IS 'name  CharacterString 0..1';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.zustand IS 'zustand enumeration LN_Zustand_StrassenUndWegeverkehr 0..1';
		COMMENT ON COLUMN ln_strassenundwegeverkehr.zweitname IS 'zweitname  CharacterString 0..1';
		CREATE TABLE ln_bahnverkehr (
		  ogc_fid serial NOT NULL,
		  gml_id character(16) NOT NULL,
		  bezeichnung character varying,
		  funktion integer,
		  zustand integer,
		  zweitname character varying,
		  PRIMARY KEY (ogc_fid)
		);
		
		
		COMMENT ON TABLE ln_bahnverkehr IS 'FeatureType: "LN_Bahnverkehr"';
		COMMENT ON COLUMN ln_bahnverkehr.bezeichnung IS 'bezeichnung  CharacterString 0..1';
		COMMENT ON COLUMN ln_bahnverkehr.funktion IS 'funktion enumeration LN_Funktion_Bahnverkehr 0..1';
		COMMENT ON COLUMN ln_bahnverkehr.zustand IS 'zustand enumeration LN_Zustand_Bahnverkehr 0..1';
		COMMENT ON COLUMN ln_bahnverkehr.zweitname IS 'zweitname  CharacterString 0..1';
		CREATE OR REPLACE VIEW alkis_wertearten(k,v,d,bezeichnung,element) AS
		  SELECT id::text AS k, value::text AS v,'' AS d,'anlassdesprozesses' AS bezeichnung,'aa_projektsteuerung' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'kategorie' AS bezeichnung,'aa_meilenstein' AS element FROM aa_besonderemeilensteinkategorie UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_aktivitaet' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_antrag' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_antragsgebiet' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'aa_vorgang' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_darstellung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_fpo' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_lpo' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ap_ppo' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_koerperobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_mehrfachlinienobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_punkthaufenobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_trianguliertesoberflaechenobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'au_umringobjekt_3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_abschlussflaeche3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_anschrift' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bauwerk3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_besonderertopographischerpunkt' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_bodenflaeche3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_boeschungsflaeche' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_dachflaeche3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_duene' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_felsenfelsblockfelsnadel' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_fenster3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_firstlinie' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_flurstueck' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_bundesland' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_kreis' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_nationalstaat' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gebiet_regierungsbezirk' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_gewann' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_historischesflurstueckohneraumbezug' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_hoehenlinie' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_insel' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kommunalesgebiet' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_kondominium' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungmithausnummer' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungmitpseudonummer' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_lagebezeichnungohnehausnummer' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_personengruppe' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_soll' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_tagesabschnitt' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_tuer3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_vertretung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_verwaltung' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wandflaeche3d' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wirtschaftlicheeinheit' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'sonstigesmodell' AS bezeichnung,'ax_wohnplatz' AS element FROM aa_weiteremodellart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'ueberschriftimfortfuehrungsnachweis' AS bezeichnung,'ax_fortfuehrungsfall' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'ueberschriftimfortfuehrungsnachweis' AS bezeichnung,'ax_fortfuehrungsfallgrundbuch' AS element FROM aa_anlassart UNION
		  SELECT id::text AS k, value::text AS v,'' AS d,'zugriffsartproduktkennungfuehrung' AS bezeichnung,'ax_benutzergruppemitzugriffskontrolle' AS element FROM aa_anlassart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_buchungsblattbezirk' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_bundesland' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemarkung' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemarkungsteilflur' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_gemeindeteil' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_kommunalesteilgebiet' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_kreisregion' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_lagebezeichnungkatalogeintrag' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_nationalstaat' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'administrativefunktion' AS bezeichnung,'ax_regierungsbezirk' AS element FROM ax_administrative_funktion UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'anrede' AS bezeichnung,'ax_person' AS element FROM ax_anrede_person UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_baublock' AS element FROM ax_art_baublock UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_punkt3d' AS element FROM ax_art_punkt3d UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_punktkennunguntergegangen' AS element FROM ax_art_punktkennung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_punktkennungvergleichend' AS element FROM ax_art_punktkennung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_punktwolke3d' AS element FROM ax_art_punktwolke3d UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_reservierung' AS element FROM ax_art_reservierung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ax_verband' AS element FROM ax_art_verband UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ln_aquakulturundfischereiwirtschaft' AS element FROM ln_art_aquakulturundfischereiwirtschaft UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ln_forstwirtschaft' AS element FROM ln_art_forstwirtschaft UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ln_freiluftundnaherholung' AS element FROM ln_art_freiluftundnaherholung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'art' AS bezeichnung,'ln_freizeitanlage' AS element FROM ln_art_freizeitanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderbestattungsflaeche' AS bezeichnung,'ln_bestattung' AS element FROM ln_artderbestattungsflaeche_bestattung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_anderefestlegungnachstrassenrecht' AS element FROM ax_artderfestlegung_anderefestlegungnachstrassenrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_anderefestlegungnachwasserrecht' AS element FROM ax_artderfestlegung_anderefestlegungnachwasserrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_bauraumoderbodenordnungsrecht' AS element FROM ax_artderfestlegung_bauraumoderbodenordnungsrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_bauraumoderbodenordnungsrechtgrundbuch' AS element FROM ax_artderfestlegung_bauraumoderbodenordnungsrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_denkmalschutzrecht' AS element FROM ax_artderfestlegung_denkmalschutzrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_klassifizierungnachstrassenrecht' AS element FROM ax_artderfestlegung_klassifizierungnachstrassenrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_schutzgebietnachnaturumweltoderbodenschutzrecht' AS element FROM ax_artderfestlegung_schutzgebietnachnaturumweltoderbodensc UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderfestlegung' AS bezeichnung,'ax_sonstigesrecht' AS element FROM ax_artderfestlegung_sonstigesrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderflurstuecksgrenze' AS bezeichnung,'ax_besondereflurstuecksgrenze' AS element FROM ax_artderflurstuecksgrenze_besondereflurstuecksgrenze UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'artderverbandsgemeinde' AS bezeichnung,'ax_gebiet_verwaltungsgemeinschaft' AS element FROM ax_art_verbandsgemeinde UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'auszugfuer_art' AS bezeichnung,'ax_fortfuehrungsnachweisdeckblatt' AS element FROM ax_art_adressat_auszug UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bedeutung' AS bezeichnung,'ax_grablochderbodenschaetzung' AS element FROM ax_bedeutung_grablochderbodenschaetzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bereichzeitlich_art' AS bezeichnung,'ax_benutzergruppenba' AS element FROM ax_art_bereichzeitlich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'beschaffenheit' AS bezeichnung,'ax_besonderegebaeudelinie' AS element FROM ax_beschaffenheit_besonderegebaeudelinie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'besonderefunktion' AS bezeichnung,'ax_forstrecht' AS element FROM ax_besonderefunktion_forstrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'bezeichnungart' AS bezeichnung,'ax_verwaltungsgemeinschaft' AS element FROM ax_bezeichnung_verwaltungsgemeinschaft UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'blattart' AS bezeichnung,'ax_buchungsblatt' AS element FROM ax_blattart_buchungsblatt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'blattart' AS bezeichnung,'ax_historischesflurstueck' AS element FROM ax_blattart_historischesflurstueck UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'blattart' AS bezeichnung,'ax_historischesflurstueckalb' AS element FROM ax_blattart_historischesflurstueck UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'buchungsart' AS bezeichnung,'ax_buchungsstelle' AS element FROM ax_buchungsart_buchungsstelle UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'darstellung' AS bezeichnung,'ax_gebaeudeausgestaltung' AS element FROM ax_darstellung_gebaeudeausgestaltung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'dateityp' AS bezeichnung,'ap_kpo_3d' AS element FROM ap_dateityp_3d UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'eigentuemerart' AS bezeichnung,'ax_namensnummer' AS element FROM ax_eigentuemerart_namensnummer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'eisart' AS bezeichnung,'lb_eis' AS element FROM lb_eisart_eis UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_abschnitt' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_ast' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_einrichtunginoeffentlichenbereichen' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_grenzuebergang' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_klassifizierungnachwasserrecht' AS element FROM ax_ergebnisderueberpruefung_klassifizierungnachwasserrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_leitung' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_netzknoten' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_nullpunkt' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_ortslage' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_schifffahrtsliniefaehrverkehr' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_seilbahnschwebebahn' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_sickerstrecke' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_strassenverkehrsanlage' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_testgelaende' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ergebnisderueberpruefung' AS bezeichnung,'ax_wasserspiegelhoehe' AS element FROM ax_ergebnisderueberpruefung_bauwerkeeinrichtungenundsonsti UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_dammwalldeich' AS element FROM ax_funktion_dammwalldeich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_einschnitt' AS element FROM ax_funktion_einschnitt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_gebaeudeinstallation3d' AS element FROM ax_funktion_gebaeudeinstallation3d UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_platz' AS element FROM ax_funktion_platz UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_polder' AS element FROM ax_funktion_polder UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_schutzgebietnachwasserrecht' AS element FROM ax_funktion_schutzgebietnachwasserrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_siedlungsflaeche' AS element FROM ax_funktion_siedlungsflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'funktion' AS bezeichnung,'ax_weg' AS element FROM ax_funktion_weg UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'horizontfreiheit' AS bezeichnung,'ax_grenzpunkt' AS element FROM ax_horizontfreiheit_grenzpunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_gewaessermerkmal' AS element FROM ax_hydrologischesmerkmal_gewaessermerkmal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'hydrologischesmerkmal' AS bezeichnung,'ax_heilquellegasquelle' AS element FROM ax_hydrologischesmerkmal_heilquellegasquelle UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'istweiterenutzung' AS bezeichnung,'ax_heide' AS element FROM ax_weiterenutzung_tatsaechlichenutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'istweiterenutzung' AS bezeichnung,'ax_moor' AS element FROM ax_weiterenutzung_tatsaechlichenutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'istweiterenutzung' AS bezeichnung,'ax_sumpf' AS element FROM ax_weiterenutzung_tatsaechlichenutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'klassifizierung' AS bezeichnung,'ax_bewertung' AS element FROM ax_klassifizierung_bewertung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezurerdoberflaeche' AS bezeichnung,'ax_untergeordnetesgewaesser' AS element FROM ax_lagezurerdoberflaeche_untergeordnetesgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'lagezuroberflaeche' AS bezeichnung,'ax_gleis' AS element FROM ax_lagezuroberflaeche_gleis UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'landschaftstyp' AS bezeichnung,'ax_kleinraeumigerlandschaftsteil' AS element FROM ax_landschaftstyp UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'landschaftstyp' AS bezeichnung,'ax_landschaft' AS element FROM ax_landschaftstyp UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'letzteabgabeart' AS bezeichnung,'ax_benutzer' AS element FROM ax_letzteabgabeart UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'liniendarstellung' AS bezeichnung,'ax_topographischelinie' AS element FROM ax_liniendarstellung_topographischelinie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'markierung' AS bezeichnung,'ax_fahrwegachse' AS element FROM ax_markierung_wegachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'markierung' AS bezeichnung,'ax_wegpfadsteig' AS element FROM ax_markierung_wegpfadsteig UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'material' AS bezeichnung,'ax_material3d' AS element FROM ax_material_materialeigenschaft_material3d UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'meerart' AS bezeichnung,'lb_meer' AS element FROM lb_meerart_meer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'name' AS bezeichnung,'ln_landwirtschaft' AS element FROM ln_artderbetriebsflaeche_landwirtschaft UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'nutzung' AS bezeichnung,'ax_hafen' AS element FROM ax_nutzung_hafen UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'nutzung' AS bezeichnung,'ax_hafenbecken' AS element FROM ax_nutzung_hafenbecken UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'oberflaechenmaterial' AS bezeichnung,'ax_unlandvegetationsloseflaeche' AS element FROM ax_oberflaechenmaterial_unlandvegetationsloseflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'produkt' AS bezeichnung,'ax_transportanlage' AS element FROM ax_produkt_transportanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktstabilitaet' AS bezeichnung,'ax_lagefestpunkt' AS element FROM ax_punktstabilitaet UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktstabilitaet' AS bezeichnung,'ax_referenzstationspunkt' AS element FROM ax_punktstabilitaet UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'punktstabilitaet' AS bezeichnung,'ax_schwerefestpunkt' AS element FROM ax_punktstabilitaet UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'qualitaetsangaben' AS bezeichnung,'ax_georeferenziertegebaeudeadresse' AS element FROM ax_qualitaet_hauskoordinate UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'rolle' AS bezeichnung,'ax_gemeinde' AS element FROM ax_rolledergemeinde UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schifffahrtskategorie' AS bezeichnung,'ax_gewaesserstationierungsachse' AS element FROM ax_schifffahrtskategorie_gewaesserstationierungsachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'schwerestatus' AS bezeichnung,'ax_schwere' AS element FROM ax_schwerestatus_schwere UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'skizzenart' AS bezeichnung,'ax_skizze' AS element FROM ax_skizzenart_skizze UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'speicherinhalt' AS bezeichnung,'ax_vorratsbehaelterspeicherbauwerk' AS element FROM ax_speicherinhalt_vorratsbehaelterspeicherbauwerk UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'sportart' AS bezeichnung,'ln_sportanlage' AS element FROM ln_sportart_sportanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'stellenart' AS bezeichnung,'ax_dienststelle' AS element FROM ax_behoerde UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'tidemerkmal' AS bezeichnung,'ax_meer' AS element FROM ax_tidemerkmal_meer UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'typ' AS bezeichnung,'ax_textur3d' AS element FROM ax_typ_textur3d UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'untererbezugspunkt' AS bezeichnung,'ax_bauteil' AS element FROM ax_untererbezugspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'untererbezugspunkt' AS bezeichnung,'ax_bauteil3d' AS element FROM ax_untererbezugspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'untererbezugspunkt' AS bezeichnung,'ax_besondererbauwerkspunkt' AS element FROM ax_untererbezugspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'untererbezugspunkt' AS bezeichnung,'ax_besonderergebaeudepunkt' AS element FROM ax_untererbezugspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'untererbezugspunkt' AS bezeichnung,'ax_historischesbauwerkoderhistorischeeinrichtung' AS element FROM ax_untererbezugspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'untererbezugspunkt' AS bezeichnung,'ax_sonstigesbauwerkodersonstigeeinrichtung' AS element FROM ax_untererbezugspunkt UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ursprung' AS bezeichnung,'ax_flaeche3d' AS element FROM ax_ursprung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'ursprung' AS bezeichnung,'ax_strukturlinie3d' AS element FROM ax_ursprung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vegetationsmerkmal' AS bezeichnung,'ax_gehoelz' AS element FROM ax_vegetationsmerkmal_gehoelz UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vegetationsmerkmal' AS bezeichnung,'ax_landwirtschaft' AS element FROM ax_vegetationsmerkmal_landwirtschaft UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermarkung_marke' AS bezeichnung,'ax_aufnahmepunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermarkung_marke' AS bezeichnung,'ax_sicherungspunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermarkung_marke' AS bezeichnung,'ax_sonstigervermessungspunkt' AS element FROM ax_marke UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vermutetehoehenstabilitaet' AS bezeichnung,'ax_hoehenfestpunkt' AS element FROM ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertikaleausrichtung' AS bezeichnung,'ap_lto' AS element FROM ap_vertikaleausrichtung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertikaleausrichtung' AS bezeichnung,'ap_pto' AS element FROM ap_vertikaleausrichtung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_punktortag' AS element FROM ax_vertrauenswuerdigkeit_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_punktortau' AS element FROM ax_vertrauenswuerdigkeit_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'vertrauenswuerdigkeit' AS bezeichnung,'ax_punktortta' AS element FROM ax_vertrauenswuerdigkeit_punktort UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'verwendeteobjekte' AS bezeichnung,'ax_abgeleitetehoehenlinie' AS element FROM ax_verwendeteobjekte_abgeleitetehoehenlinie UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'verwendeteobjekte' AS bezeichnung,'ax_dhmgitter' AS element FROM ax_verwendeteobjekte_dhmgitter UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'wasserfuehrung' AS bezeichnung,'lb_binnengewaesser' AS element FROM lb_wasserfuehrung_binnengewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'wassersaettigung' AS bezeichnung,'lb_holzigevegetation' AS element FROM lb_wassersaettigung_holzigevegetation UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'wassersaettigung' AS bezeichnung,'lb_krautigevegetation' AS element FROM lb_wassersaettigung_krautigevegetation UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'wassersaettigung' AS bezeichnung,'lb_lockermaterial' AS element FROM lb_wassersaettigung_lockermaterial UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_kanal' AS element FROM ax_widmung_kanal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_strasse' AS element FROM ax_widmung_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'widmung' AS bezeichnung,'ax_wasserlauf' AS element FROM ax_widmung_wasserlauf UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'wirtschaftsart' AS bezeichnung,'ax_flurstueckgrundbuch' AS element FROM ax_wirtschaftsartgrundbuch UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zone' AS bezeichnung,'ax_schutzzone' AS element FROM ax_zone_schutzzone UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zuflusssteuerung' AS bezeichnung,'ln_schutzanlage' AS element FROM ln_zuflusssteuerung_schutzanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bahnstrecke' AS element FROM ax_zustand UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bahnverkehr' AS element FROM ax_zustand_bahnverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bahnverkehrsanlage' AS element FROM ax_zustand_bahnverkehrsanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkimgewaesserbereich' AS element FROM ax_zustand_bauwerkimgewaesserbereich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkimverkehrsbereich' AS element FROM ax_zustand_bauwerkimverkehrsbereich UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkoderanlagefuerindustrieundgewerbe' AS element FROM ax_zustand_bauwerkoderanlagefuerindustrieundgewerbe UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bauwerkoderanlagefuersportfreizeitunderholung' AS element FROM ax_zustand_bauwerkoderanlagefuersportfreizeitunderholung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_bergbaubetrieb' AS element FROM ax_zustand_bergbaubetrieb UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_boeschungkliff' AS element FROM ax_zustand_boeschungkliff UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_einrichtungenfuerdenschiffsverkehr' AS element FROM ax_zustand_einrichtungenfuerdenschiffsverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_fahrbahnachse' AS element FROM ax_zustand UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flaechebesondererfunktionalerpraegung' AS element FROM ax_zustand_flaechebesondererfunktionalerpraegung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flaechegemischternutzung' AS element FROM ax_zustand_flaechegemischternutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_fliessgewaesser' AS element FROM ax_zustand_kanal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flugverkehr' AS element FROM ax_zustand_flugverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_flugverkehrsanlage' AS element FROM ax_zustand_flugverkehrsanlage UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_friedhof' AS element FROM ax_zustand_friedhof UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_gebaeude' AS element FROM ax_zustand_gebaeude UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_gebietsgrenze' AS element FROM ax_zustand_gebietsgrenze UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_gewaesserachse' AS element FROM ax_zustand_gewaesserachse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_halde' AS element FROM ax_zustand_halde UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_hoehleneingang' AS element FROM ax_zustand_hoehleneingang UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_industrieundgewerbeflaeche' AS element FROM ax_zustand_industrieundgewerbeflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_naturumweltoderbodenschutzrecht' AS element FROM ax_zustand_naturumweltoderbodenschutzrecht UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_schiffsverkehr' AS element FROM ax_zustand_schiffsverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_schleuse' AS element FROM ax_zustand_schleuse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_sportfreizeitunderholungsflaeche' AS element FROM ax_zustand_sportfreizeitunderholungsflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_stehendesgewaesser' AS element FROM ax_zustand_stehendesgewaesser UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_strassenachse' AS element FROM ax_zustand UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_strassenverkehr' AS element FROM ax_zustand_strasse UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_tagebaugrubesteinbruch' AS element FROM ax_zustand_tagebaugrubesteinbruch UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_turm' AS element FROM ax_zustand_turm UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_vegetationsmerkmal' AS element FROM ax_zustand_vegetationsmerkmal UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_wald' AS element FROM ax_zustand_wald UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ax_wohnbauflaeche' AS element FROM ax_zustand_wohnbauflaeche UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_abbau' AS element FROM ln_zustand_abbau UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_bahnverkehr' AS element FROM ln_zustand_bahnverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_flugverkehr' AS element FROM ln_zustand_flugverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_gewerblichedienstleistungen' AS element FROM ln_zustand_gewerblichedienstleistungen UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_industrieundverarbeitendesgewerbe' AS element FROM ln_zustand_industrieundverarbeitendesgewerbe UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_kulturundunterhaltung' AS element FROM ln_zustand_kulturundunterhaltung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_lagerung' AS element FROM ln_zustand_lagerung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_oeffentlicheeinrichtungen' AS element FROM ln_zustand_oeffentlicheeinrichtungen UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_schiffsverkehr' AS element FROM ln_zustand_schiffsverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_strassenundwegeverkehr' AS element FROM ln_zustand_strassenundwegeverkehr UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_versorgungundentsorgung' AS element FROM ln_zustand_versorgungundentsorgung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_wasserwirtschaft' AS element FROM ln_zustand_wasserwirtschaft UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustand' AS bezeichnung,'ln_wohnnutzung' AS element FROM ln_zustand_wohnnutzung UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustandsstufe' AS bezeichnung,'ax_bodenschaetzung' AS element FROM ax_zustandsstufe UNION
		  SELECT wert::text AS k, beschreibung::text AS v,'' AS d,'zustandsstufe' AS bezeichnung,'ax_musterundvergleichsstueck' AS element FROM ax_zustandsstufe;
		
		DROP TABLE aa_instanzenthemen;
		DROP TABLE aa_levelofdetail;
		DROP TABLE au_geometrieobjekt_3d;
		DROP TABLE au_mehrfachflaechenobjekt_3d;
		DROP TABLE ax_artderaussparung;
		DROP TABLE ax_artdergelaendekante;
		DROP TABLE ax_artdergeripplinie;
		DROP TABLE ax_artdergewaesserachse;
		DROP TABLE ax_artdernichtgelaendepunkte;
		DROP TABLE ax_artderstrukturierung;
		DROP TABLE ax_artdesmarkantengelaendepunktes;
		DROP TABLE ax_aussparungsflaeche;
		DROP TABLE ax_berechnungsmethodehoehenlinie;
		DROP TABLE ax_besondereartdergewaesserbegrenzung;
		DROP TABLE ax_besonderebedeutung;
		DROP TABLE ax_besondererhoehenpunkt;
		DROP TABLE ax_bodenart_musterlandesmusterundvergleichsstueck;
		DROP TABLE ax_dqerfassungsmethode;
		DROP TABLE ax_dqerfassungsmethodebesondererhoehenpunkt;
		DROP TABLE ax_dqerfassungsmethodegewaesserbegrenzung;
		DROP TABLE ax_dqerfassungsmethodemarkantergelaendepunkt;
		DROP TABLE ax_dqerfassungsmethodesekundaeresdgm;
		DROP TABLE ax_dqerfassungsmethodestrukturiertegelaendepunkte;
		DROP TABLE ax_entstehungsartoderklimastufewasserverhaeltnisse_bodensc;
		DROP TABLE ax_entstehungsartoderklimastufewasserverhaeltnisse_musterl;
		DROP TABLE ax_flaechezurzeitunbestimmbar;
		DROP TABLE ax_funktionhgr_k_tnhgr;
		DROP TABLE ax_funktionoa_k_tnfl;
		DROP TABLE ax_funktionoa_k_tngr_all;
		DROP TABLE ax_funktionoa_k_tngrerweitert_all;
		DROP TABLE ax_gelaendekante;
		DROP TABLE ax_geripplinie;
		DROP TABLE ax_gewaesserbegrenzung;
		DROP TABLE ax_identifikation;
		DROP TABLE ax_kulturart_bodenschaetzung;
		DROP TABLE ax_kulturart_musterlandesmusterundvergleichsstueck;
		DROP TABLE ax_lagezurerdoberflaeche_bauteil;
		DROP TABLE ax_markantergelaendepunkt;
		DROP TABLE ax_merkmal_musterlandesmusterundvergleichsstueck;
		DROP TABLE ax_musterlandesmusterundvergleichsstueck;
		DROP TABLE ax_schweresystem_schwere;
		DROP TABLE ax_sonstigeangaben_musterlandesmusterundvergleichsstueck;
		DROP TABLE ax_strukturierterfasstegelaendepunkte;
		DROP TABLE ax_verkehrsbedeutunginneroertlich;
		DROP TABLE ax_verkehrsbedeutungueberoertlich;
		DROP TABLE ax_verwendeteobjekte;
		DROP TABLE ax_zustandsstufeoderbodenstufe_bodenschaetzung;
		DROP TABLE ax_zustandsstufeoderbodenstufe_musterlandesmusterundvergle;
		DROP TABLE ta_compositesolidcomponent_3d;
		DROP TABLE ta_curvecomponent_3d;
		DROP TABLE ta_pointcomponent_3d;
		DROP TABLE ta_surfacecomponent_3d;

		DELETE FROM aa_advstandardmodell WHERE wert IN ('DGM2','DGM25','DGM5','DGM50');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('BORIS','Bodenrichtwertobjektmodell','BORIS beinhaltet die Wertermittlungsinformationen der Gutachterausschüsse für Grundstückswerte der Bundesrepublik Deutschland.');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('DHM','DigitalesHoehenmodell','');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('GVM','GeometrischesVerbesserungsModell','');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('GeoBasis-DE','LandbedeckungLandnutzung','GeoBasis-DE beinhaltet die Geobasisdaten der Landbedeckung (LB) und der Landnutzung (LN) der Bundesrepublik Deutschland.');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('LoD1','LevelOfDetail1','');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('LoD2','LevelOfDetail2','');
		INSERT INTO aa_advstandardmodell(wert,beschreibung,dokumentation) VALUES ('LoD3','LevelOfDetail3','');
		DELETE FROM aa_art_themendefinition WHERE wert IN ('2000');
		DELETE FROM ap_dateityp_3d WHERE wert IN ('6000');
		UPDATE ap_dateityp_3d SET beschreibung='CityGML' WHERE wert='1000';
		UPDATE ap_dateityp_3d SET beschreibung='VRML' WHERE wert='2000';
		UPDATE ap_dateityp_3d SET beschreibung='kml' WHERE wert='3000';
		UPDATE ap_dateityp_3d SET beschreibung='X3D' WHERE wert='4000';
		UPDATE ap_dateityp_3d SET beschreibung='COLLADA' WHERE wert='5000';
		UPDATE ap_dateityp_3d SET dokumentation='OGC-Standard' WHERE wert='1000';
		UPDATE ap_dateityp_3d SET dokumentation='ISO-Standard' WHERE wert='2000';
		UPDATE ap_dateityp_3d SET dokumentation='OGC-Standard' WHERE wert='3000';
		UPDATE ap_dateityp_3d SET dokumentation='ISO-Standard' WHERE wert='4000';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET beschreibung='Ski' WHERE wert='1060';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET beschreibung='Eissport, Rollschuhlaufen' WHERE wert='1070';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET beschreibung='Eislauf, Eishockey' WHERE wert='1071';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET dokumentation='Reiten bedeutet, dass ein Stadion, ein Spielfeld oder eine Rennbahn zur Ausübung des Reitsports genutzt wird.' WHERE wert='1040';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET dokumentation='Ski bedeutet, dass ein Stadion zur Ausübung des Skisports genutzt wird.' WHERE wert='1060';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET dokumentation='Eissport, Rollschuhlaufen bedeutet, dass ein Bauwerk oder eine Anlage zur Ausübung des Eis- oder des Rollschuhsports genutzt wird.' WHERE wert='1070';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET dokumentation='Eislauf, Eishockey bedeutet, dass ein Bauwerk oder eine Anlage zur Ausübung des Eissports genutzt wird.' WHERE wert='1071';
		UPDATE ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung SET dokumentation='Rollschuhlaufen bedeutet, dass ein Bauwerk oder eine Anlage zur Ausübung des Rollschuhsports genutzt wird.' WHERE wert='1072';
		INSERT INTO ax_sportart_bauwerkoderanlagefuersportfreizeitunderholung(wert,beschreibung,dokumentation) VALUES ('1120','Hundesport','Hundesport sind Sportanlagen für Hunde, die dem Training, Ausbildung, aber auch dem Wettkampf (keine Hunderennen!) dienen.');
		UPDATE ax_produkt_transportanlage SET dokumentation='Brauchwasser ist ein für technische u. a. Zwecke verwendetes Wasser, das transportiert wird.' WHERE wert='1132';
		UPDATE ax_produkt_transportanlage SET dokumentation='Fernwärme bezeichnet eine Wärmelieferung zur Heizung von Gebäuden mit Warmwasser.' WHERE wert='1140';
		UPDATE ax_bauwerksfunktion_turm SET dokumentation='Leuchtturm ist ein als Schifffahrtszeichen errichteter hoher Turm.' WHERE wert='1006';
		UPDATE ax_bauwerksfunktion_turm SET dokumentation='Sende-, Funkturm, Fernmeldeturm’ ist ein Bauwerk, ausgerüstet mit Sende - und Empfangsantennen zum Übertragen und Empfangen von Nachrichten aller Arten von Telekommunikation.' WHERE wert='1008';
		UPDATE ax_speicherinhalt_vorratsbehaelterspeicherbauwerk SET dokumentation='Gas ist eine gasförmige oder flüssige Substanz, die gespeichert wird.' WHERE wert='1120';
		UPDATE ax_speicherinhalt_vorratsbehaelterspeicherbauwerk SET dokumentation='Gülle ist ein Stoffgemisch, hauptsächlich aus Urin und Kot landwirtschaftlicher Nutztiere, das gelagert wird.' WHERE wert='1140';
		UPDATE ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer SET beschreibung='Schornstein' WHERE wert='1290';
		UPDATE ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer SET dokumentation='Biogasanlage ist eine Anlage, in der aus Biomasse Gas erzeugt wird.' WHERE wert='1215';
		UPDATE ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer SET dokumentation='Schornstein ist ein freistehend senkrecht hochgeführter Abzugskanal für die Rauchgase einer Feuerungsanlage oder für andere Abgase.' WHERE wert='1290';
		UPDATE ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer SET dokumentation='Bergbaubetrieb ist eine Fläche, die für die Förderung des Abbaugutes unter Tage genutzt wird' WHERE wert='1700';
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer(wert,beschreibung,dokumentation) VALUES ('1275','Funknavigationsanlage','Funknavigationsanlage ist eine Vorrichtung zur Verkehrssicherung.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuerindustrieundgewer(wert,beschreibung,dokumentation) VALUES ('2530','Kraftwerk','Kraftwerk bezeichnet eine Fläche mit Bauwerken und sonstigen Einrichtungen zur Erzeugung von elektrischer Energie.');
		UPDATE ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde SET dokumentation='Stadion ist ein Bauwerk mit Tribünen und entsprechenden Einrichtungen, das vorwiegend zur Ausübung von bestimmten Sportarten dient.' WHERE wert='1440';
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1441','Stadion, überdacht','Stadion, überdacht ist ein Bauwerk mit Tribünen und entsprechenden Einrichtungen, das vorwiegend zur Ausübung von bestimmten Sportarten dient und ganz oder nahezu ganz überdacht ist.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1442','Stadion, nicht überdacht','Stadion, nicht überdacht ist ein Bauwerk mit Tribünen und entsprechenden Einrichtungen, das vorwiegend zur Ausübung von bestimmten Sportarten dient, aber ohne Dachflächen ist.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1610','Zoo','Zoo ist ein Gelände mit Tierschauhäusern und umzäunten Gehegen, auf dem Tiere gehalten und gezeigt werden.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1620','Safaripark, Wildpark','Safaripark, Wildpark, ist ein Gelände mit umzäunten Gehegen, in denen Tiere im Freien gehalten und gezeigt werden.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1630','Freizeitpark','Freizeitpark ist ein Gelände mit Karussells, Verkaufs- und Schaubuden und/oder Wildgattern, das der Freizeitgestaltung dient.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1640','Freilichtbühne','Freilichtbühne ist ein Anlage mit Bühnen und Zuschauerbänken für Aufführungen im Freien.');
		INSERT INTO ax_bauwerksfunktion_bauwerkoderanlagefuersportfreizeitunde(wert,beschreibung,dokumentation) VALUES ('1650','Wassersportanlage','Wassersportanlage bezeichnet ein Areal welches beispielsweise zum Rudern, Segeln oder für Wasserski genutzt wird.');
		INSERT INTO ax_zustand_bauwerkoderanlagefuerindustrieundgewerbe(wert,beschreibung,dokumentation) VALUES ('4000','Im Bau','Im Bau bedeutet, dass sich überwiegende Teile der Bauwerke oder Anlagen für Industrie und Gewerbe (Großbaustelle) im Bau befinden.');
		UPDATE ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun SET dokumentation='Überdachungen sind i. d. R. an allen Seiten offen. Eine geschlossene Seite kann über eine besondere Gebäudelinie mit der Werteart Geschlossene Seite einer Überdachung nachgewiesen werden.' WHERE wert='1610';
		UPDATE ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun SET dokumentation='Carports sind i. d. R. an allen Seiten offen. Eine geschlossene Seite kann über eine besondere Gebäudelinie mit der Werteart Geschlossene Seite einer Überdachung nachgewiesen werden.' WHERE wert='1611';
		UPDATE ax_bauwerksfunktion_sonstigesbauwerkodersonstigeeinrichtun SET dokumentation='Meilenstein, historischer Grenzstein sind Steine von kulturgeschichtlicher Bedeutung, die am Rande von Verkehrswegen aufgestellt sind und Entfernungen in unterschiedlichen Maßeinheiten (z. B. Meilen, Kilometer oder Stunden) angeben oder als Grenzsteine vergangene Eigentumsverhältnisse dokumentieren.' WHERE wert='1770';
		UPDATE ax_bauwerksfunktion_vorratsbehaelterspeicherbauwerk SET dokumentation='Gasometer ist ein volumenveränderbarer Niederdruckbehälter für Gas.' WHERE wert='1206';
		UPDATE ax_bahnkategorie_gleis SET beschreibung='Seilbahn, Bergbahn' WHERE wert='1300';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Eisenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr Personen befördert und/oder Güter transportiert werden.' WHERE wert='1100';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Güterverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr Güter transportiert werden.' WHERE wert='1102';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='S-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, der zur schnellen Personenbeförderung in Ballungsräumen dient und meist auf eigenen Gleisen verläuft.' WHERE wert='1104';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Stadtbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung im öffentlichen Nahverkehr fährt. Sie kann sowohl ober- als auch unterirdisch verlaufen.' WHERE wert='1200';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Straßenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung fährt. Sie verläuft i. d. R. oberirdisch.' WHERE wert='1201';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='U-Bahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung in Großstädten fährt. Sie verläuft i. d. R. unterirdisch.' WHERE wert='1202';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Seilbahn, Bergbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn große Höhenunterschiede überwindet.' WHERE wert='1300';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Zahnradbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn mittels Zahnradantrieb große Höhenunterschiede in stark geneigtem Gelände überwindet.' WHERE wert='1301';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Standseilbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine Schienenbahn auf einer stark geneigten, meist kurzen und geraden Strecke verläuft. Mit Hilfe eines oder mehrerer Zugseile wird ein Schienenfahrzeug bergauf gezogen und gleichzeitig ein zweites bergab gelassen.' WHERE wert='1302';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Museumsbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem ausschließlich Touristen in alten, meist restaurierten Zügen befördert werden.' WHERE wert='1400';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Bahn im Freizeitpark ist die Bezeichnung für einen schienengebundenen Verkehrsweg innerhalb eines Freizeitparks.' WHERE wert='1500';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Magnetschwebebahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem räderlose Schienenfahrzeuge mit Hilfe von Magnetfeldern an oder auf einer Fahrschiene schwebend entlanggeführt werden.' WHERE wert='1600';
		UPDATE ax_bahnkategorie_gleis SET dokumentation='Sonstiges bedeutet, dass die Bahnkategorie bekannt, aber nicht in der Attributwertliste aufgeführt ist.' WHERE wert='9999';
		INSERT INTO ax_bahnkategorie_gleis(wert,beschreibung,dokumentation) VALUES ('1101','Personenverkehr','Personenverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und Fernverkehr Personen transportiert werden.');
		INSERT INTO ax_bahnkategorie_gleis(wert,beschreibung,dokumentation) VALUES ('1103','Betriebsverkehr','Betriebsverkehr ist die Bezeichnung für ein Gleis, das aus innerbetrieblichen Gründen erforderlich ist.');
		UPDATE ax_art_strassenverkehrsanlage SET beschreibung='Anschlussstelle, Anschluss' WHERE wert='3003';
		UPDATE ax_art_strassenverkehrsanlage SET beschreibung='Raststätte, Autohof' WHERE wert='5330';
		UPDATE ax_art_strassenverkehrsanlage SET dokumentation='Anschlussstelle, Anschluss ist die verkehrliche Verknüpfung der Autobahn mit dem nachgeordneten Straßennetz.' WHERE wert='3003';
		UPDATE ax_art_strassenverkehrsanlage SET dokumentation='Raststätte, Autohof ist eine Anlage an Verkehrsstraßen mit Bauwerken und Einrichtungen zur Versorgung und Erholung von Reisenden. Dazu gehören auch Autohöfe gemäß der Verwaltungsvorschriften zur Straßenverkehrsordnung (VwV-StVO).' WHERE wert='5330';
		INSERT INTO ax_art_strassenverkehrsanlage(wert,beschreibung,dokumentation) VALUES ('6000','Busbahnhof','Busbahnhof ist eine Verkehrsanlage, die als zentraler Verknüpfungspunkt verschiedener Buslinien dient.');
		UPDATE ax_zustand_bahnverkehrsanlage SET dokumentation='Im Bau bedeutet, dass sich überwiegende Teile der Bahnverkehrsanlage im Bau befinden.' WHERE wert='4000';
		DELETE FROM ax_art_flugverkehrsanlage WHERE wert IN ('5520','5531','5540');
		UPDATE ax_art_flugverkehrsanlage SET dokumentation='Segelfluggelände ist ein Flugplatz, der in der Luftfahrtkarte 1:500000 (ICAO) für den Segelflugsport ausgewiesen ist.' WHERE wert='5550';
		INSERT INTO ax_art_flugverkehrsanlage(wert,beschreibung,dokumentation) VALUES ('5521','Verkehrslandeplatz','Verkehrslandeplatz ist ein Flugplatz, der im Luftfahrthandbuch als Flugplatz, Landeplatz oder Verkehrslandeplatz ausgewiesen ist.');
		INSERT INTO ax_art_flugverkehrsanlage(wert,beschreibung,dokumentation) VALUES ('5522','Sonderlandeplatz','Sonderlandeplatz ist ein Flugplatz, der im Luftfahrthandbuch oder in den Bescheiden der zuständigen Luftfahrtbehörden als Sonderlandeplatz ausgewiesen ist.');
		INSERT INTO ax_art_flugverkehrsanlage(wert,beschreibung,dokumentation) VALUES ('5530','Hubschrauberlandeplatz','Hubschrauberlandeplatz ist ein Flugplatz, der im Luftfahrthandbuch, in der Luftfahrtkarte 1:500000 (ICAO) oder aufgrund von Ländervorschriften als solcher ausgewiesen ist.');
		INSERT INTO ax_art_flugverkehrsanlage(wert,beschreibung,dokumentation) VALUES ('5560','Wasserlandeplatz','Wasserlandeplatz ist ein Flugplatz, der im Luftfahrthandbuch als Sonderlandeplatz mit einem Start- und Landebahnoberflächentyp "Wasser" ausgewiesen ist.');
		INSERT INTO ax_art_flugverkehrsanlage(wert,beschreibung,dokumentation) VALUES ('9998','Nach Quellenlage nicht zu spezifizieren','Nach Quellenlage nicht zu spezifizieren bedeutet, dass keine Aussage über die Werteart gemacht werden kann.');
		UPDATE ax_bauwerksfunktion_bauwerkimverkehrsbereich SET dokumentation='Brücke ist ein Bauwerk , das einen Verkehrsweg, ein Gewässer oder einen Tierpfad (Grünbrücke) über ein natürliches oder künstliches Hindernis führt.' WHERE wert='1800';
		UPDATE ax_bauwerksfunktion_bauwerkimverkehrsbereich SET dokumentation='Steg ist eine kleine Brücke einfacher Bauart.' WHERE wert='1820';
		UPDATE ax_bauwerksfunktion_bauwerkimverkehrsbereich SET dokumentation='Schutzgalerie, Einhausung ist eine bauliche Einrichtung an Verkehrswegen zum Schutz gegen Lawinen, Schneeverwehungen, Steinschlägen sowie zum Schutz gegen Emission. 
Schutzgalerien sind einseitige Überbauungen an Verkehrswegen, Einhausungen umschließen die Verkehrswege meist vollständig.' WHERE wert='1880';
		UPDATE ax_bauwerksfunktion_bauwerkimgewaesserbereich SET dokumentation='Rückhaltebecken ist ein natürliches oder künstlich angelegtes Becken, ggf. mit Bauwerken und Einrichtungen, zur vorübergehenden Speicherung großer Wassermengen.' WHERE wert='2020';
		UPDATE ax_bauwerksfunktion_bauwerkimgewaesserbereich SET dokumentation='Wehr ist ein festes oder mit beweglichen Teilen ausgestattetes Bauwerk im Gewässerbereich zur Regulierung des Wasserabflusses.' WHERE wert='2050';
		UPDATE ax_bauwerksfunktion_bauwerkimgewaesserbereich SET dokumentation='Schöpfwerk ist eine Anlage, in der Pumpen Wasser einem höher gelegenen Vorfluter zuführen, u. a. zur künstlichen Entwässerung von landwirtschaftlich genutzten Flächen.' WHERE wert='2090';
		UPDATE ax_bauwerksfunktion_bauwerkimgewaesserbereich SET dokumentation='Fischtreppeist eine Vorrichtung mit Stufen oder Wasserbecken für Fische, um Höhenunterschiede im Gewässer zu überwinden.' WHERE wert='2110';
		UPDATE ax_bauwerksfunktion_bauwerkimgewaesserbereich SET dokumentation='Lahnung ist ein Bauwerk zum Küstenschutz und zur Landgewinnung zumeist im Wattenmeer. Es besteht aus doppelten Holzpflockreihen, mit dazwischen geschnürten Sträuchern, den sog. Faschinen. Bei ablaufendem Wasser sammeln sich hinter der Lahnung Sedimente und Schlick.' WHERE wert='2132';
		INSERT INTO ax_bauwerksfunktion_bauwerkimgewaesserbereich(wert,beschreibung,dokumentation) VALUES ('2013','Wassertunnel, Wasserstollen, Druckstollen','Wassertunnel, Wasserstollen, Druckstollen ist ein in einen Berg oder Hügel getriebener unterirdischer Tunnel (Stollen), durch den Wasser hindurchgeführt wird. Dabei fließt das Wasser in einem Wassertunnel bzw. Wasserstollen in Richtung des gebauten Gefälles. In einem Druckstollen, der als Wasserleitung genutzt wird, baut sich durch die vollständige Füllung des Stollens ein hydrostatischer Wasserdruck auf, so dass das Wasser auch ansteigende Abschnitte überwinden kann.');
		INSERT INTO ax_bauwerksfunktion_bauwerkimgewaesserbereich(wert,beschreibung,dokumentation) VALUES ('2085','Verschlussbauwerk','Verschlussbauwerk ist ein Bauwerk mit einem Verschlussmechanismus zur Regulierung des Wasserablaufs bzw. zum Schutz vor Hochwasser.');
		INSERT INTO ax_art_einrichtungenfuerdenschiffsverkehr(wert,beschreibung,dokumentation) VALUES ('1470','Liegeplatz','Liegeplatz bezeichnet eine Stelle im Hafen oder am Ufer, an dem Wasserfahrzeuge vorübergehend oder dauerhaft verankert sind.');
		INSERT INTO ax_zustand_bauwerkimverkehrsbereich(wert,beschreibung,dokumentation) VALUES ('4000','Im Bau','Im Bau bedeutet, dass sich überwiegende Teile von Bauwerk im Verkehrsbereich im Bau befinden.');
		UPDATE ax_art_gewaessermerkmal SET dokumentation='Watt ist ein aus Sand oder Schlick bestehender Boden an flachen Gezeitenküsten und Flüssen, der bei Ebbe ganz oder teilweise trocken fällt.' WHERE wert='1650';
		INSERT INTO ax_art_gewaessermerkmal(wert,beschreibung,dokumentation) VALUES ('1700','Bodden, Haff','Bodden, Haff ist ein vom offenen Meer durch Landzungen abgetrenntes Küstengewässer an der Ostsee.');
		DELETE FROM ax_funktion_polder WHERE wert IN (' 7410',' 7420');
		INSERT INTO ax_funktion_polder(wert,beschreibung,dokumentation) VALUES ('7410','Gesteuert','Gesteuert bedeutet, dass Polder regelmäßig zu einem bestimmten festgelegten Zeitpunkt geflutet wird (z.B. bei einem ausgewählten Pegelstand).');
		INSERT INTO ax_funktion_polder(wert,beschreibung,dokumentation) VALUES ('7420','Ungesteuert','Ungesteuert bedeutet, dass die eingedeichte Fläche ereignisabhängig geflutet wird.');
		INSERT INTO ax_zustand_vegetationsmerkmal(wert,beschreibung,dokumentation) VALUES ('6100','Waldverjüngungs-, Neuanpflanzungsfläche','Waldverjüngungs-, Neuanpflanzungsfläche bedeutet, dass sich der Wald durch Aufforstung, Naturverjüngung oder durch Anpflanzung neu bildet.');
		INSERT INTO ax_bewuchs_vegetationsmerkmal(wert,beschreibung,dokumentation) VALUES ('1020','Baumbestand','Baumbestand beschreibt den Bewuchs einer Vegetationsfläche mit Bäumen.');
		INSERT INTO ax_eigentuemerart_namensnummer(wert,beschreibung,dokumentation) VALUES ('5108','Bundesanstalt für Immobilienaufgaben','');
		INSERT INTO ax_eigentuemerart_namensnummer(wert,beschreibung,dokumentation) VALUES ('5940','Eigenes Bundesland, Naturschutzverwaltung','');
		UPDATE ax_blattart_buchungsblatt SET dokumentation='Ein Pseudoblatt ist ein Buchungsblatt, das die Buchung, die bereits vor Eintrag im Grundbuch Rechtskraft erlangt hat, enthält.' WHERE wert='3000';
		UPDATE ax_anrede_person SET dokumentation='Frau ist eine natürliche, menschliche Person weiblichen Geschlechts.' WHERE wert='1000';
		UPDATE ax_anrede_person SET dokumentation='Herr ist eine natürliche, menschliche Person männlichen Geschlechts.' WHERE wert='2000';
		UPDATE ax_anrede_person SET dokumentation='Firma ist ein gewerbliches Unternehmen.' WHERE wert='3000';
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4010','Gesamtberechtigte gemäß § 428 BGB','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4020','Gesamtberechtigte gemäß § 432 BGB','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4030','Mitglieder eines nicht eingetragenen Vereins','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4040','Fortgesetzte Gütergemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4050','Beendete, nicht auseinandergesetzte Gütergemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4060','Errungenschaftsgemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4070','Fortgesetzte Errungenschaftsgemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4080','Beendete, nicht auseinandergesetzte Errungenschaftsgemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4090','Fahrnisgemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4100','Fortgesetzte Fahrnisgemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4110','Beendete, nicht auseinandergesetzte Fahrnisgemeinschaft','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4120','Eigentums- und Vermögensgemeinschaft nach FGB','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4130','Beendete, nicht auseinandergesetzte Eigentums- und Vermögensgemeinschaft nach FGB','');
		INSERT INTO ax_artderrechtsgemeinschaft_namensnummer(wert,beschreibung,dokumentation) VALUES ('4140','Altrechtliche Gemeinschaft','');
		UPDATE ax_buchungsart_buchungsstelle SET dokumentation='Das Wohnungseigentum kann nach Par. 3 Wohnungseigentumsgesetz (WEG) durch Vertrag der Miteigentümer oder nach Par. 8 WEG durch Erklärung des Eigentümers 
begründet werden.
Das entstehende Wohnungseigentum (Teileigentum) ist echtes Eigentum bürgerlichen Rechts in Form einer rechtlichen Verbindung von Miteigentum an Grundstück und Gebäude mit Sondereigentum an einer Wohnung bzw. Teileigentum an nicht zu Wohnzwecken dienenden Räumen.' WHERE wert='1301';
		UPDATE ax_buchungsart_buchungsstelle SET dokumentation='Hierbei handelt es sich um die frei veräußerliche und vererbliche Befugnis zum Betrieb eines bestimmten Gewerbes, die mit dem Besitz einer Liegenschaft verbunden sein kann aber nicht zwingend an ein bestimmtes Grundstücks gebunden sein muss. Die nähere Bezeichnung des Nutzungsrechts ergibt sich aus dem Attribut Buchungstext.' WHERE wert='2107';
		UPDATE ax_buchungsart_buchungsstelle SET dokumentation='Gemeinderecht ist das Recht zur Nutzung eines gemeinschaftlichen Grundstücks. Die näheren Angaben zu diesem Recht sind in privatrechtlichen Verträgen enthalten.' WHERE wert='2108';
		INSERT INTO ax_buchungsart_buchungsstelle(wert,beschreibung,dokumentation) VALUES ('2206','Aufgeteiltes Recht Par. 3 Abs. 4 GBO (Untererbbaurecht)','Historisches Untererbbaurecht, welches gemäß § 3 Abs. 4 GBO aufgeteilt worden ist. Es handelt sich hier um eine Buchungsart für das Fiktive Blatt.');
		INSERT INTO ax_buchungsart_buchungsstelle(wert,beschreibung,dokumentation) VALUES ('2306','Untererbbaurechtsanteil Par. 3 Abs. 4 GBO','Untererbbaurecht, welches gemäß § 3 Abs. 4 GBO aufgeteilt worden ist.');
		UPDATE ax_klassifikation_hierarchiestufe3d_lagefestpunkt SET beschreibung='A' WHERE wert='1000';
		UPDATE ax_klassifikation_hierarchiestufe3d_lagefestpunkt SET beschreibung='B' WHERE wert='2000';
		UPDATE ax_klassifikation_hierarchiestufe3d_lagefestpunkt SET beschreibung='C' WHERE wert='3000';
		UPDATE ax_klassifikation_hierarchiestufe3d_lagefestpunkt SET beschreibung='D' WHERE wert='4000';
		UPDATE ax_klassifikation_hierarchiestufe3d_lagefestpunkt SET beschreibung='E' WHERE wert='5000';
		DELETE FROM ax_punktstabilitaet WHERE wert IN ('8000');
		UPDATE ax_punktstabilitaet SET beschreibung='Sehr gut' WHERE wert='1000';
		UPDATE ax_punktstabilitaet SET beschreibung='Gut' WHERE wert='2000';
		UPDATE ax_punktstabilitaet SET beschreibung='Befriedigend' WHERE wert='3000';
		UPDATE ax_punktstabilitaet SET beschreibung='Ausreichend' WHERE wert='4000';
		UPDATE ax_punktstabilitaet SET beschreibung='Mangelhaft' WHERE wert='5000';
		UPDATE ax_punktstabilitaet SET beschreibung='Mangelhaft (Bergsenkungsgebiet)' WHERE wert='5100';
		UPDATE ax_punktstabilitaet SET beschreibung='Mangelhaft (in rutschgefährdeter Hanglage)' WHERE wert='5200';
		UPDATE ax_punktstabilitaet SET beschreibung='Mangelhaft (sehr nahe an Gewässer)' WHERE wert='5300';
		UPDATE ax_punktstabilitaet SET beschreibung='Mangelhaft (instabiler Untergrund)' WHERE wert='5400';
		UPDATE ax_punktstabilitaet SET beschreibung='Aus Wiederholungsmessungen nachgewiesen' WHERE wert='6000';
		UPDATE ax_punktstabilitaet SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet SET beschreibung='Sehr gut' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet SET beschreibung='Gut' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet SET beschreibung='Befriedigend' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet SET beschreibung='Ausreichend' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet SET beschreibung='Mangelhaft' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_geologischestabilitaet SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_klassifikation_ordnung_lagefestpunkt SET beschreibung='1. Ordnung' WHERE wert='1000';
		UPDATE ax_klassifikation_ordnung_lagefestpunkt SET beschreibung='2. Ordnung' WHERE wert='2000';
		UPDATE ax_klassifikation_ordnung_lagefestpunkt SET beschreibung='3. Ordnung' WHERE wert='3000';
		UPDATE ax_klassifikation_ordnung_lagefestpunkt SET beschreibung='4. Ordnung' WHERE wert='4000';
		UPDATE ax_klassifikation_ordnung_lagefestpunkt SET beschreibung='5. Ordnung' WHERE wert='5000';
		UPDATE ax_klassifikation_ordnung_lagefestpunkt SET beschreibung='Nach Quellenlage nicht zu spezifizieren' WHERE wert='9998';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra SET beschreibung='Sehr gut' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra SET beschreibung='Gut' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra SET beschreibung='Befriedigend' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra SET beschreibung='Ausreichend' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra SET beschreibung='Mangelhaft' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesvermarkungstra SET beschreibung='Nicht bekannt' WHERE wert='9998';
		UPDATE ax_ordnung_schwerefestpunkt SET beschreibung='1. Ordnung' WHERE wert='1000';
		UPDATE ax_ordnung_schwerefestpunkt SET beschreibung='2. Ordnung' WHERE wert='2000';
		UPDATE ax_ordnung_schwerefestpunkt SET beschreibung='3. Ordnung' WHERE wert='3000';
		UPDATE ax_ordnung_schwerefestpunkt SET beschreibung='4. Ordnung' WHERE wert='4000';
		UPDATE ax_ordnung_schwerefestpunkt SET beschreibung='Schweregrundnetzpunkt' WHERE wert='500';
		UPDATE ax_ordnung_schwerefestpunkt SET beschreibung='Nach Quellenlage nicht zu spezifizieren' WHERE wert='9998';
		UPDATE ax_funktion_lagefestpunkt SET beschreibung='Exzentrum' WHERE wert='2000';
		UPDATE ax_skizzenart_skizze SET beschreibung='Einmessungsskizze' WHERE wert='1000';
		UPDATE ax_skizzenart_skizze SET beschreibung='Sonstige Lageskizze' WHERE wert='2000';
		UPDATE ax_skizzenart_skizze SET beschreibung='Sonstige Einmessungsskizze' WHERE wert='2100';
		UPDATE ax_skizzenart_skizze SET beschreibung='Sonstige Ansichtszeichnung oder Foto' WHERE wert='2200';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi SET beschreibung='Sehr gut' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi SET beschreibung='Gut' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi SET beschreibung='Befriedigend' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi SET beschreibung='Bedenklich' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi SET beschreibung='Mangelhaft' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_hoehenstabilitaetauswi SET beschreibung='Nicht bekannt' WHERE wert='9998';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes SET beschreibung='Sehr gut' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes SET beschreibung='Gut' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes SET beschreibung='Befriedigend' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes SET beschreibung='Ausreichend' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes SET beschreibung='Mangelhaft' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_guetedesbaugrundes SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung SET beschreibung='Sehr gering (kleiner gleich 0,5 m)' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung SET beschreibung='Gering (größer 0,5 m und kleiner gleich 2 m)' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung SET beschreibung='Mäßig (größer 2 m und kleiner gleich 5 m)' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung SET beschreibung='Stark (größer 5 m und kleiner gleich 10 m)' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung SET beschreibung='Sehr stark (größer 10 m)' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserschwankung SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt SET beschreibung='Keine' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt SET beschreibung='Geringe' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt SET beschreibung='Mäßige' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt SET beschreibung='Starke' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt SET beschreibung='Sehr starke' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_topographieundumwelt SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_klassifikation_wertigkeit_lagefestpunkt SET beschreibung='Fundamentalpunkt' WHERE wert='1000';
		UPDATE ax_klassifikation_wertigkeit_lagefestpunkt SET dokumentation='Punkt auf dem die Position (3D), die schwerebezogene Höhe und die Schwere hoch genau bestimmt worden sind.' WHERE wert='1000';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Vermutlich sehr gut' WHERE wert='1000';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Sehr gut' WHERE wert='1001';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Vermutlich gut' WHERE wert='3000';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Gut' WHERE wert='3001';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Vermutlich befriedigend' WHERE wert='3100';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Befriedigend' WHERE wert='3101';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Ungenügend' WHERE wert='5000';
		UPDATE ax_gnsstauglichkeit SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Weitgehende Horizontfreiheit, Mehrwegeffekte nicht wahrscheinlich.' WHERE wert='1000';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Sehr gute Satelliten-Empfangseigenschaften in Messungen nachgewiesen.' WHERE wert='1001';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Eingeschränkte Horizontfreiheit.' WHERE wert='3000';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Eingeschränkte Horizontfreiheit, Tauglichkeit nachgewiesen.' WHERE wert='3001';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Mehrwegeffekte möglich.' WHERE wert='3100';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Mehrwegeffekte nachgewiesen.' WHERE wert='3101';
		UPDATE ax_gnsstauglichkeit SET dokumentation='Festpunkt nicht geeignet für Satellitenmessverfahren.' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Sehr tief (größer 10 m)' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Tief (größer 5 m und kleiner gleich 10 m)' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Normal (größer 2 m und kleiner gleich 5 m)' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Hoch (größer 0,5 m und kleiner gleich 2 m)' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Sehr hoch (kleiner gleich 0,5 m)' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Abgesenkt' WHERE wert='9000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_grundwasserstand SET beschreibung='Nicht untersucht' WHERE wert='9998';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili SET beschreibung='Sehr gut' WHERE wert='1000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili SET beschreibung='Gut' WHERE wert='2000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili SET beschreibung='Befriedigend' WHERE wert='3000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili SET beschreibung='Ausreichend' WHERE wert='4000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili SET beschreibung='Mangelhaft' WHERE wert='5000';
		UPDATE ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili SET beschreibung='Nicht untersucht' WHERE wert='9998';
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili(wert,beschreibung,dokumentation) VALUES ('5100','Mangelhaft (Bergsenkungsgebiet)','');
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili(wert,beschreibung,dokumentation) VALUES ('5200','Mangelhaft (in rutschgefährdeter Hanglage)','');
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili(wert,beschreibung,dokumentation) VALUES ('5300','Mangelhaft (sehr nahe an Gewässer)','');
		INSERT INTO ax_punktstabilitaet_hoehenfestpunkt_vermutetehoehenstabili(wert,beschreibung,dokumentation) VALUES ('5400','Mangelhaft (instabiler Untergrund)','');
		UPDATE ax_ordnung_hoehenfestpunkt SET beschreibung='1. Ordnung' WHERE wert='1000';
		UPDATE ax_ordnung_hoehenfestpunkt SET beschreibung='1. Ordnung - Netzverdichtung GPS (Niedersachsen)' WHERE wert='1001';
		UPDATE ax_ordnung_hoehenfestpunkt SET beschreibung='2. Ordnung' WHERE wert='2000';
		UPDATE ax_ordnung_hoehenfestpunkt SET beschreibung='3. Ordnung' WHERE wert='3000';
		UPDATE ax_ordnung_hoehenfestpunkt SET beschreibung='3. Ordnung - nivellitisch bestimmter Bodenpunkt für Referenzstation' WHERE wert='3001';
		UPDATE ax_ordnung_hoehenfestpunkt SET beschreibung='4. Ordnung' WHERE wert='4000';
		UPDATE ax_artderflurstuecksgrenze_besondereflurstuecksgrenze SET beschreibung='Topographische Gewässerbegrenzung' WHERE wert='2100';
		DELETE FROM ax_marke WHERE wert IN ('3010','3170','3180','3190');
		UPDATE ax_marke SET beschreibung='Festlegung STN 1. Ordnung, Pfeilerkopf 30x30 cm, Bezugspunkt Platte 60x60 cm, Steinwürfel, Tonkegel' WHERE wert='2102';
		UPDATE ax_marke SET beschreibung='Festlegung 2. bis 5. Ordnung, Bezugspunkt Kopf 16x16 oder 12x12 cm, Platte 30x30 cm' WHERE wert='2111';
		UPDATE ax_marke SET beschreibung='3D-Bolzen in Kopffläche, einbetonierter Granitpfeiler 40x40x90 cm' WHERE wert='2266';
		UPDATE ax_marke SET beschreibung='Gebohrter Granitstein (Bezugspunkt) über Tonrohr' WHERE wert='2601';
		UPDATE ax_marke SET beschreibung='Gebohrter Granitstein über Tonrohr (Bezugspunkt)' WHERE wert='2602';
		UPDATE ax_marke SET beschreibung='Gebohrter Granitstein (Bezugspunkt) über Platte' WHERE wert='2603';
		UPDATE ax_marke SET beschreibung='Gebohrter Granitstein über Platte (Bezugspunkt)' WHERE wert='2604';
		UPDATE ax_marke SET beschreibung='Gebohrter Granitstein (Bezugspunkt) über Eisenrohr' WHERE wert='2605';
		UPDATE ax_marke SET beschreibung='Gebohrter Granitstein über Eisenrohr (Bezugspunkt)' WHERE wert='2606';
		UPDATE ax_marke SET beschreibung='Festlegung Orientierungspunkt, Bezugspunkt Platte' WHERE wert='2710';
		UPDATE ax_marke SET beschreibung='Platte, unterirdisch, mit Kopfbolzen' WHERE wert='2951';
		UPDATE ax_marke SET beschreibung='Unterirdische Festlegung' WHERE wert='3000';
		UPDATE ax_marke SET beschreibung='Mauerbolzen, horizontal eingebracht' WHERE wert='3210';
		UPDATE ax_marke SET beschreibung='Mauerbolzen, vertikal eingebracht' WHERE wert='3220';
		UPDATE ax_marke SET beschreibung='Höhenmarke' WHERE wert='3230';
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('2167','3D-Messingbolzen (Durchmesser 5 cm) mit Inschrift RFP HESSEN','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('2267','3D-Bolzen in Kopffläche, einbetonierter Granitpfeiler 25x25x100 cm','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('2268','3D-Bolzen in Kopffläche, einbetonierter Granitpfeiler 30x30x100 cm','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('2269','3D-Bolzen in Kopffläche, einbetonierter Granitpfeiler 50x50x100 cm','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3011','Unterirdische Festlegung mit Achatkugel','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3012','Unterirdische Festlegung mit Halbkugel','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3013','Unterirdische Festlegung mit Diabaseinsatz','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3014','Unterirdische Festlegung im Schacht','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3015','Kleine unterirdische Festlegung','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3231','Höhenmarke (Königlich Preußische Landesaufnahme)','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3232','Höhenmarke (Königlich Sächsische Landesaufnahme)','');
		INSERT INTO ax_marke(wert,beschreibung,dokumentation) VALUES ('3233','Höhenmarke (Reichsamt für Landesaufnahme)','');
		UPDATE ax_genauigkeitsstufe_punktort SET beschreibung='Standardabweichung S größer 500 cm' WHERE wert='5000';
		INSERT INTO ax_genauigkeitsstufe_punktort(wert,beschreibung,dokumentation) VALUES ('2400','Standardabweichung S kleiner gleich 20 cm','');
		UPDATE ax_messmethode_schwere SET beschreibung='Absolutgravimetermessung' WHERE wert='1000';
		UPDATE ax_messmethode_schwere SET beschreibung='Relativgravimetermessung' WHERE wert='2000';
		UPDATE ax_koordinatenstatus_punktort SET dokumentation='Gültiger Wert in dem amtlichen Bezugssystem.' WHERE wert='1000';
		UPDATE ax_koordinatenstatus_punktort SET dokumentation='Weiterer gültiger Wert in einem nicht-amtlichen Bezugssystem.' WHERE wert='2000';
		UPDATE ax_koordinatenstatus_punktort SET dokumentation='Vorläufige Koordinaten bzw. vorläufige Höhe.' WHERE wert='3000';
		UPDATE ax_koordinatenstatus_punktort SET dokumentation='Zu keiner Zeit gültig gewesene Koordinaten bzw. Höhe.' WHERE wert='4000';
		UPDATE ax_koordinatenstatus_punktort SET dokumentation='Ein historischer, nicht mehr amtlicher oder gültiger Wert.' WHERE wert='5000';
		UPDATE ax_koordinatenstatus_punktort SET dokumentation='Koordinaten bzw. Höhe, die sich als fehlerhaft herausgestellt haben.' WHERE wert='5100';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Mittels Freiluftreduktion über geringe Entfernung abgeleitet' WHERE wert='1000';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Mittels Freiluftreduktion über größere Entfernung abgeleitet' WHERE wert='2000';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Mittels Interpolation unter Verwendung einfacher Bougueranomalien ermittelt' WHERE wert='3000';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Durch Abschlag (-19*10^-8m*s^-2) aus Schwerewert im DHSN82 ermittelt' WHERE wert='3100';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Durch Transformation aus ISGN71 ermittelt' WHERE wert='3200';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Durch andere Methode ermittelt' WHERE wert='4000';
		UPDATE ax_datenerhebung_schwere SET beschreibung='Methode unbekannt' WHERE wert='9998';
		UPDATE ax_datenerhebung_schwere SET dokumentation='Höhenunterschied bis 1 m, Horizontalabstand bis 5 m' WHERE wert='1000';
		UPDATE ax_datenerhebung_schwere SET dokumentation='Topografische Reduktion erfolgt nur als Plattenreduktion' WHERE wert='3000';
		INSERT INTO ax_datenerhebung_schwere(wert,beschreibung,dokumentation) VALUES ('800','Mittels zentrisch gemessenem vertikalen Schweregradienten auf die Vermarkung abgeleitet','');
		INSERT INTO ax_datenerhebung_schwere(wert,beschreibung,dokumentation) VALUES ('900','Mittels exzentrisch gemessenem vertikalen Schweregradienten abgeleitet','');
		INSERT INTO ax_datenerhebung_schwere(wert,beschreibung,dokumentation) VALUES ('3050','Mittels Interpolation unter Verwendung verfeinerter Bougueranomalien ermittelt','Topografische Reduktion erfolgt als Platten- und Geländereduktion');
		UPDATE ax_vertrauenswuerdigkeit_schwere SET beschreibung='Ausgleichung' WHERE wert='1100';
		UPDATE ax_vertrauenswuerdigkeit_schwere SET beschreibung='Ohne Ausgleichung kontrolliert' WHERE wert='1300';
		UPDATE ax_vertrauenswuerdigkeit_schwere SET beschreibung='Unkontrolliert' WHERE wert='1400';
		UPDATE ax_vertrauenswuerdigkeit_schwere SET dokumentation='Die Identität der Anschlusspunkte ist überprüft. Die Zuverlässigkeitskriterien sind durch Ausgleichung und durch mathematisch-statistische Testverfahren festgestellt.' WHERE wert='1100';
		UPDATE ax_vertrauenswuerdigkeit_schwere SET dokumentation='Die Zuverlässigkeitskriterien sind auf andere Weise (z. B. durch Vergleich von Schwereanomalien) festgestellt.' WHERE wert='1300';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Geländereduktion' WHERE wert='1000';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Freiluftanomalie' WHERE wert='2000';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Faye-Anomalie' WHERE wert='3000';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Schwereanomalie nach Molodenski' WHERE wert='3100';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Verfeinerte Bougueranomalie' WHERE wert='4000';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Einfache Bougueranomalie' WHERE wert='5000';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Bougueranomalie im DHSN96 mit Freiluft- und Plattenreduktion' WHERE wert='6000';
		UPDATE ax_schwereanomalie_schwere_art SET beschreibung='Unbekannt' WHERE wert='9998';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Teil der topografischen Reduktion, der die Abweichung der Erdoberfläche von einer horizontalen Platte oder sphärischen Figur berücksichtigt.' WHERE wert='1000';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Differenz zwischen dem mittels Freiluftreduktion auf das Geoid reduzierten Schwerewert und dem entsprechenden Wert der Normalschwere auf dem Niveauellipsoid.' WHERE wert='2000';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Freiluftanomalie mit zusätzlich angebrachter Geländereduktion' WHERE wert='3000';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Schwere im Oberflächenpunkt minus Normalschwere im zugeordneten Telluroidpunkt' WHERE wert='3100';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Topografische Reduktion erfolgt als Plattenreduktion und Geländereduktion' WHERE wert='4000';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Topografische Reduktion erfolgt nur als Plattenreduktion' WHERE wert='5000';
		UPDATE ax_schwereanomalie_schwere_art SET dokumentation='Normalschwere im GRS80' WHERE wert='6000';
		UPDATE ax_vertrauenswuerdigkeit_punktort SET dokumentation='Vertrauenswürdigkeitsstufe Ausgleichung: Die Vertrauenswürdigkeit ist durch Ausgleichung und durch mathematisch-statistische Testverfahren festgestellt. Bei den örtlichen Vermessungen sind die Anschlusspunkte auf Identität überprüft.' WHERE wert='1100';
		UPDATE ax_vertrauenswuerdigkeit_punktort SET dokumentation='Vertrauenswürdigkeitsstufe Berechnung: Die Vertrauenswürdigkeit ist durch Berechnung überprüft. Bei den örtlichen Vermessungen sind die Anschlusspunkte auf Identität überprüft. Die Zuverlässigkeit ist durch Programm festgestellt bzw. ergibt sich durch die rechnerisch wirksam kontrollierte Ermittlung der Position (Doppelbestimmung).' WHERE wert='1200';
		UPDATE ax_vertrauenswuerdigkeit_punktort SET dokumentation='Vertrauenswürdigkeitsstufe Bestimmungsverfahren: Die Vertrauenswürdigkeit ist durch die Art der Bestimmung der Position überprüft. Bei den örtlichen Vermessungen sind die Anschlusspunkte auf Identität überprüft. Die Position ist durch wirksame Kontrollen überprüft.' WHERE wert='1300';
		UPDATE ax_schwerestatus_schwere SET beschreibung='Amtliche Schwere' WHERE wert='1000';
		UPDATE ax_schwerestatus_schwere SET beschreibung='Weitere gültige Schwere' WHERE wert='2000';
		UPDATE ax_schwerestatus_schwere SET beschreibung='Vorläufige Schwere' WHERE wert='3000';
		UPDATE ax_schwerestatus_schwere SET beschreibung='Zu keiner Zeit gültig gewesene Schwere' WHERE wert='4000';
		UPDATE ax_schwerestatus_schwere SET beschreibung='Historische Schwere' WHERE wert='5000';
		UPDATE ax_schwerestatus_schwere SET beschreibung='Schwere, die sich als fehlerhaft herausgestellt hat' WHERE wert='5100';
		UPDATE ax_schwerestatus_schwere SET dokumentation='Gültiger Wert in dem amtlichen Schwerebezugssystem.' WHERE wert='1000';
		UPDATE ax_schwerestatus_schwere SET dokumentation='Weiterer gültiger Wert in einem nicht-amtlichen Schwerebezugssystem.' WHERE wert='2000';
		UPDATE ax_schwerestatus_schwere SET dokumentation='Vorläufige Schwere.' WHERE wert='3000';
		UPDATE ax_schwerestatus_schwere SET dokumentation='Zu keiner Zeit gültig gewesene Schwere.' WHERE wert='4000';
		UPDATE ax_schwerestatus_schwere SET dokumentation='Ein historischer, nicht mehr amtlicher oder gültiger Wert.' WHERE wert='5000';
		UPDATE ax_schwerestatus_schwere SET dokumentation='Schwere, die sich als fehlerhaft herausgestellt hat.' WHERE wert='5100';
		UPDATE ax_li_processstep_punktort_description SET dokumentation='Erhebung beschreibt im Attribut stepDateTime den Erfassungszeitpunkt (Zeitpunkt der Messung), z. B. für Position, Lage oder Höhe.' WHERE wert='Erhebung';
		UPDATE ax_li_processstep_punktort_description SET dokumentation='Berechnung beschreibt im Attribut stepDateTime den Auswertezeitpunkt, z. B. von Position, Lage oder Höhe.' WHERE wert='Berechnung';
		UPDATE ax_genauigkeitsstufe_schwere SET beschreibung='Standardabweichung S kleiner 20*10^-8m*s^-2' WHERE wert='1000';
		UPDATE ax_genauigkeitsstufe_schwere SET beschreibung='Standardabweichung S kleiner gleich 100*10^-8m*s^-2' WHERE wert='2000';
		UPDATE ax_genauigkeitsstufe_schwere SET beschreibung='Standardabweichung S größer 100*10^-8m*s^-2' WHERE wert='3000';
		INSERT INTO ax_genauigkeitsstufe_schwere(wert,beschreibung,dokumentation) VALUES ('900','Standardabweichung S kleiner gleich 12 * 10^-8m*s^-2','');
		INSERT INTO ax_genauigkeitsstufe_schwere(wert,beschreibung,dokumentation) VALUES ('1500','Standardabweichung S kleiner gleich 50 * 10^-8m*s^-2','');
		DELETE FROM ax_datenerhebung_punktort WHERE wert IN ('5150','5160','5170');
		UPDATE ax_datenerhebung_punktort SET beschreibung='Aus sonstigen Unterlagen digitalisiert, Mit sonstigen geometrischen Bedingungen und/oder Homogenisierung (M größer gleich 1 zu 1000)' WHERE wert='4360';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Präzisionsnivellement' WHERE wert='5100';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Präzisionsnivellement, Messgenauigkeit 1.Ordnung' WHERE wert='5110';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Präzisionsnivellement, Messgenauigkeit 2.Ordnung' WHERE wert='5120';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Präzisionsnivellement, Messgenauigkeit 3.Ordnung' WHERE wert='5130';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Präzisionsnivellement, Messgenauigkeit 4.Ordnung' WHERE wert='5140';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Präzisionsnivellement (nur eine Messungsrichtung)' WHERE wert='5200';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Aus satellitengeodätischer Messung und Addition einer Höhenanomalie' WHERE wert='6000';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Mittels Höhenanomalie abgeleitet von gemessener ellipsoidischer Höhe' WHERE wert='6100';
		UPDATE ax_datenerhebung_punktort SET beschreibung='Mittels Höhenanomalie abgeleitet von gemessener Normalhöhe' WHERE wert='6200';
		UPDATE ax_qualitaet_hauskoordinate SET beschreibung='AmtlichMit (A)' WHERE wert='1000';
		UPDATE ax_qualitaet_hauskoordinate SET beschreibung='Amtlich (B)' WHERE wert='2000';
		UPDATE ax_qualitaet_hauskoordinate SET beschreibung='Katasterintern (C)' WHERE wert='3000';
		UPDATE ax_qualitaet_hauskoordinate SET dokumentation='Amtliche Hausnummer, Koordinate liegt sicher innerhalb der erfassten Gebäudegeometrie.' WHERE wert='1000';
		UPDATE ax_qualitaet_hauskoordinate SET dokumentation='Amtliche Hausnummer, Koordinate liegt sicher innerhalb der Flurstücksfläche, das Gebäude ist nicht sicher in der Örtlichkeit vorhanden.' WHERE wert='2000';
		UPDATE ax_qualitaet_hauskoordinate SET dokumentation='Katasterinterne Hausnummer, die Koordinate liegt sicher innerhalb der erfassten Gebäudegeometrie.' WHERE wert='3000';
		UPDATE ax_art_reservierung SET dokumentation='Eine Reservierung von Folgenummern zu einer Nummer darf sich nur auf aktuelle Flurstücke 11001 beziehen und nicht auf dauerhaft reservierte ausfallende Nummern, die keine aktuellen Flurstücke haben.' WHERE wert='3000';
		INSERT INTO ax_lagezurerdoberflaeche_gebaeude(wert,beschreibung,dokumentation) VALUES ('1500','Beweglich, drehbar','Beweglich, drehbar bedeutet, dass ein Gebäude beweglich oder drehbar ist.');
		UPDATE ax_zustand_gebaeude SET dokumentation='In behelfsmäßigem Zustand bedeutet, dass das Gebäude nur eingeschränkt bewohnt oder genutzt werden kann.' WHERE wert='1000';
		UPDATE ax_zustand_gebaeude SET dokumentation='In ungenutztem Zustand bedeutet, dass das Gebäude nicht genutzt wird.' WHERE wert='2000';
		UPDATE ax_zustand_gebaeude SET dokumentation='Teilweise zerstört bedeutet, dass sich der ursprüngliche Zustand des Gebäudes durch menschliche oder zeitliche Einwirkungen so verändert hat, dass eine Nutzung nur noch teilweise möglich ist.' WHERE wert='2300';
		UPDATE ax_zustand_gebaeude SET dokumentation='Geplant und beantragt bedeutet, dass ein Gebäude geplant und dessen Errichtung beantragt ist.' WHERE wert='3000';
		UPDATE ax_zustand_gebaeude SET dokumentation='Im Bau bedeutet, dass sich ein Gebäude im Bau befindet.' WHERE wert='4000';
		UPDATE ax_dachgeschossausbau_gebaeude SET dokumentation='Nicht ausbaufähig bedeutet, dass sich das Dachgeschoss des Gebäudes nicht zum Ausbau zu Wohnzwecken eignet.' WHERE wert='1000';
		UPDATE ax_dachgeschossausbau_gebaeude SET dokumentation='Ausbaufähig bedeutet, dass sich das Dachgeschoss des Gebäudes zum Ausbau zu Wohnzwecken eignet.' WHERE wert='2000';
		UPDATE ax_dachgeschossausbau_gebaeude SET dokumentation='Ausgebaut bedeutet, dass das Dachgeschoss des Gebäudes zu Wohnzwecken ausgebaut ist.' WHERE wert='3000';
		UPDATE ax_dachgeschossausbau_gebaeude SET dokumentation='Ausbaufähigkeit unklar bedeutet, dass für das Gebäude keine Aussage zur Ausbaufähigkeit des Dachgeschosses getroffen werden kann.' WHERE wert='4000';
		UPDATE ax_dachform SET dokumentation='Flachdächer sind Dächer, die keine oder nureine geringe Dachneigung bis zu 10° (17,6%) aufweisen.' WHERE wert='1000';
		UPDATE ax_dachform SET dokumentation='Ein Pultdach ist ein Dach mit nur einer geneigten Dachfläche. Die untere Kante bildet die Dachtraufe, die obere den Dachfirst. Die Neigung des Pultdaches beträgt mindestens 10°.' WHERE wert='2100';
		UPDATE ax_dachform SET dokumentation='Ein versetztes Pultdach besteht aus zwei Pultdächern, deren Firste in der Höhe versetzt sind. Zwischen den Dachflächen entsteht immer eine Wandfläche.' WHERE wert='2200';
		UPDATE ax_dachform SET dokumentation='Das Satteldach besteht aus zwei entgegengesetzt geneigten Dachflächen, die am Dachfirst aufeinander treffen.' WHERE wert='3100';
		UPDATE ax_dachform SET dokumentation='Ein Walmdach hat nicht nur auf der Traufseite, sondern auch auf der Giebelseite geneigte Dachflächen, die als Walm bezeichnet werden. Ein vollständiger Walm ersetzt den Giebel und hat eine einheitliche Traufhöhe, das Dach hat also an allen vier Seiten Schrägen. In Abgrenzung zum Zeltdach besitzt ein Walmdach immer einen Dachfirst.' WHERE wert='3200';
		UPDATE ax_dachform SET dokumentation='Ein Walm, dessen Traufe oberhalb der Traufe des Hauptdaches liegt, bildet ein Krüppelwalmdach. Es bleibt ein trapezförmiger Restgiebel erhalten.' WHERE wert='3300';
		UPDATE ax_dachform SET dokumentation='Bei der Dachform Mansardendach sind die Dachflächen im unteren Bereich abgeknickt, so dass die untere Dachfläche über eine wesentlich steilere Neigung verfügt als die obere.' WHERE wert='3400';
		UPDATE ax_dachform SET dokumentation='Ein Zeltdach zeichnet sich durch mindestens drei gegeneinander geneigte Dachflächen aus, die in einer Spitze zusammenlaufen. Abgrenzung zum Turmdach: Neigung des Zeltdachs < 45°.' WHERE wert='3500';
		UPDATE ax_dachform SET dokumentation='Ein Kegeldach ist eine Dachform, die einem Kreiskegel entspricht.' WHERE wert='3600';
		UPDATE ax_dachform SET dokumentation='Ein Kuppeldach beschreibt eine halbkugel- oder glockenförmige Dachform.' WHERE wert='3700';
		UPDATE ax_dachform SET dokumentation='Ein Sheddach ist eine Dachform, bei der mehrere gleichartige pult- oder satteldachartige Dachaufbauten hintereinander angereiht werden.' WHERE wert='3800';
		UPDATE ax_dachform SET dokumentation='Ein Bogendach besitzt eine Wölbung die kreis- oder elliptische Formen annehmen kann.' WHERE wert='3900';
		UPDATE ax_dachform SET dokumentation='Ein Turmdach ist ein Zeltdach mit einer Neigung von mehr als 45°.' WHERE wert='4000';
		UPDATE ax_dachform SET dokumentation='Die Dachform Mischform setzt sich aus mehreren Standarddachformen zusammen, wobei keine Dachform überwiegt.' WHERE wert='5000';
		UPDATE ax_dachform SET dokumentation='Sonstiges Dach ist eine Dachform, die auch durch eine Zerlegung in Standarddachformen nicht modelliert werden kann.' WHERE wert='9999';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Freistehendes Einzelgebäude ist ein freistehendes Wohngebäude mit in der Regel bis zu 2½ Geschossen (auch Villa, Landhaus, Bungalow).' WHERE wert='1100';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Freistehender Gebäudeblock ist ein freistehendes Wohngebäude (Mehrfamilienhaus), in der Regel
3 - 8-geschossig.' WHERE wert='1200';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Einzelgarage ist eine einzeln stehende oder angebaute einzelne Garage als Abstellmöglichkeit für ein Fahrzeug, meist einen Pkw (auch eine einzelne Garage in Garagenhöfen).' WHERE wert='1300';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Doppelgarage ist eine einzeln stehende oder angebaute Garage als Abstellmöglichkeit für zwei Fahrzeuge, meist zwei Pkw.' WHERE wert='1400';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Sammelgarage ist eine Garage mit Abstellmöglichkeit für mehr als zwei Fahrzeuge, meist Pkw.' WHERE wert='1500';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Doppelhaushälfte ist ein dreiseitig freistehendes Wohnhaus mit in der Regel bis zu 2½ Geschossen, an dem ein im allgemeinen gleichartiges Wohnhaus angebaut ist (etwa gleicher Baustil und ungefähr gleiche Baumaße).' WHERE wert='2100';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Reihenhaus ist eines von mehr als 2 gleichartig aneinandergebauten Wohnhäusern mit in der Regel bis zu 2½ Geschossen in einer geschlossenen Häuserzeile (etwa gleicher Baustil und ungefähr gleiche Baumaße).' WHERE wert='2200';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Haus in Reihe ist eines von mehr als zwei ungleichartigen, aneinandergebauten Wohnhäusern, in der Regel mit bis zu 2 ½ Geschossen (z. B. in geschlossener Bauweise errichtete Wohngebäude in alten Ortskernen).' WHERE wert='2300';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Gruppenhaus ist eines von mehr als 2 gleichartigen, aneinandergebauten Wohnhäusern mit in der Regel bis zu 2½ Geschossen, die so gegeneinander verschoben sind, dass keine gemeinsame Achse gegeben ist.' WHERE wert='2400';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Gebäudeblock in geschlossener Bauweise ist eines von mehreren aneinandergebauten Wohngebäuden (Mehrfamilienhäuser), in der Regel 3-8 geschossig; z. B. in Stadtkernen.' WHERE wert='2500';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Unter einer Offenen Halle ist eine Halle zu verstehen, bei der alle vier Seiten offen sind.
Hallen, bei denen eine, zwei oder drei Seiten geschlossen sind, werden nur mit der entsprechenden Gebäudefunktion ohne Belegung der Bauweise erfasst. Die offenen Gebäudeseiten sind mit Besondere Gebäudelinie, Beschaffenheit Offene Gebäudelinie zu belegen.' WHERE wert='4000';
		UPDATE ax_bauweise_gebaeude SET dokumentation='Sonstiges bedeutet, dass das Gebäude eine Bauweise aufweist, die bekannt, aber nicht in der Liste der Wertearten aufgeführt ist.' WHERE wert='9999';
		UPDATE ax_gebaeudefunktion SET beschreibung='Wartungshalle' WHERE wert='2412';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohnheim ist ein Gebäude, das nach seiner baulichen Anlage und Ausstattung zur Unterbringung von Studenten, Arbeitern u. a. bestimmt ist.' WHERE wert='1020';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kinderheim ist ein Gebäude, welches zur Unterbringung und Betreuung von Kindern, die vorübergehend oder dauerhaft getrennt von ihren leiblichen Eltern oder sonstigen Erziehungsberechtigten leben, dient.' WHERE wert='1021';
		UPDATE ax_gebaeudefunktion SET dokumentation='Seniorenheim ist ein Gebäude, welches zur Unterbringung, Betreuung und Pflege von Menschen dient.' WHERE wert='1022';
		UPDATE ax_gebaeudefunktion SET dokumentation='Schwesternwohnheim ist ein Gebäude, in dem Angehörige eines Ordens oder Pflegepersonal wohnen.' WHERE wert='1023';
		UPDATE ax_gebaeudefunktion SET dokumentation='Studenten-, Schülerwohnheim ist ein Gebäude, in welchem Studenten bzw. Schüler wohnen.' WHERE wert='1024';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gemischt genutztes Gebäude mit Wohnen ist ein Gebäude, in dem sowohl gewohnt wird, als auch Teile des Gebäudes zum Anbieten von Dienstleistungen, zur Durchführung von öffentlichen oder privaten Verwaltungsarbeiten, zur gewerblichen oder industriellen Tätigkeit genutzt werden.' WHERE wert='1100';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohngebäude mit Gemeinbedarf ist ein Gebäude, das vorrangig dem Wohnen als auch der Allgemeinheit, z. B. zur Versammlung, dient.' WHERE wert='1110';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohngebäude mit Handel und Dienstleistungen ist ein Gebäude, das vorrangig dem Wohnen als auch dem Anbieten von Arbeitsleistungen, die nicht im Zusammenhang mit der Produktion von materiellen Gütern stehen, dient.' WHERE wert='1120';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohn- und Verwaltungsgebäude ist ein Gebäude, in dem gewohnt wird und in dem sich Räume einer öffentlichen oder privaten Verwaltung befinden.' WHERE wert='1121';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohn- und Bürogebäude ist ein Gebäude, in dem gewohnt wird und in dem sich Büros mehrerer Unternehmen befinden.' WHERE wert='1122';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohngebäude mit Gewerbe und Industrie ist ein Gebäude, das vorrangig dem Wohnen und dem Anbieten von gewerblichen oder industriellen Tätigkeiten dient.' WHERE wert='1130';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohn- und Betriebsgebäude ist ein Gebäude, das sowohl zum Wohnen als auch zur Produktion von Gütern dient.' WHERE wert='1131';
		UPDATE ax_gebaeudefunktion SET dokumentation='Land- und forstwirtschaftliches Wohngebäude ist ein Gebäude, in dem Beschäftigte der Land- und Forstwirtschaft wohnen.' WHERE wert='1210';
		UPDATE ax_gebaeudefunktion SET dokumentation='Land- und forstwirtschaftliches Wohn- und Betriebsgebäude ist ein Gebäude, das zum Wohnen und zur Produktion von land- und forstwirtschaftlichen Gütern dient.' WHERE wert='1220';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wohn- und Wirtschaftsgebäude ist ein Gebäude, in dem gewohnt wird und das zum Betrieb eines wirtschaftlichen Anwesens notwendig ist.' WHERE wert='1222';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Freizeitgestaltung ist ein Gebäude, das der Ausübung von freizeitlichen Aktivitäten dient.' WHERE wert='1310';
		UPDATE ax_gebaeudefunktion SET dokumentation='Ferienhaus ist ein Gebäude, das zum vorübergehenden Aufenthalt von Gästen dient.' WHERE wert='1311';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wochenendhaus ist ein Gebäude, in dem dauerhaftes Wohnen möglich, aber nicht gestattet ist. Es dient nur zum zeitlich begrenzten Aufenthalt in der Freizeit, beispielsweise am Wochenende oder im Urlaub und steht i. d. R. in einem besonders dafür ausgewiesenen Gebiet (Wochenendhausgebiet).' WHERE wert='1312';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gartenhaus ist ein eingeschossiges Gebäude in einfacher Ausführung und dient hauptsächlich der Unterbringung von Gartengeräten.' WHERE wert='1313';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Handel und Dienstleistungen ist ein Gebäude, in dem Arbeitsleistungen, die nicht der Produktion von materiellen Gütern dienen, angeboten werden. Dazu gehört u. a. der Handel (Ankauf, Transport, Verkauf) mit Gütern, Kapital oder Wissen.' WHERE wert='2010';
		UPDATE ax_gebaeudefunktion SET dokumentation='Markthalle ist ein Gebäude, in dem Marktstände fest oder vorübergehend aufgebaut sind.' WHERE wert='2053';
		UPDATE ax_gebaeudefunktion SET dokumentation='Laden ist ein Geschäft, in dem Waren des Einzelhandels angeboten und verkauft werden.' WHERE wert='2054';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Beherbergung ist ein Gebäude, das der Unterbringung von Gästen dient.' WHERE wert='2070';
		UPDATE ax_gebaeudefunktion SET dokumentation='Campingplatzgebäude ist ein Gebäude auf einem angelegten Platz, z. B. mit Strom- und Wasseranschlüssen sowie sanitären Einrichtungen.' WHERE wert='2074';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Bewirtung ist ein Gebäude, in dem die Möglichkeit besteht Mahlzeiten und Getränke einzunehmen.' WHERE wert='2080';
		UPDATE ax_gebaeudefunktion SET dokumentation='Hütte (ohne Übernachtungsmöglichkeit) ist ein Gebäude außerhalb von Ortschaften, meist in den Bergen, in dem Menschen Schutz suchen können und in dem die Möglichkeit besteht, Mahlzeiten und Getränke einzunehmen.' WHERE wert='2082';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kantine ist ein Gebäude, das einem Unternehmen, einer Behörde oder einer öffentlichen Einrichtung zur Ausgabe von Mahlzeiten und Getränken dient.' WHERE wert='2083';
		UPDATE ax_gebaeudefunktion SET dokumentation='Festsaal ist ein Gebäude, in dem Feierlichkeiten ausgerichtet werden.' WHERE wert='2091';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kino ist ein Gebäude, in dem Filme für ein Publikum abgespielt werden.' WHERE wert='2092';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kegel-, Bowlinghalle ist ein Gebäude, in dem die Sportarten Kegeln oder Bowling ausgeübt werden.' WHERE wert='2093';
		UPDATE ax_gebaeudefunktion SET dokumentation='Spielkasino ist eine Einrichtung, in der öffentlich zugänglich staatlich konzessioniertes Glücksspiel betrieben wird.' WHERE wert='2094';
		UPDATE ax_gebaeudefunktion SET dokumentation='Brauerei ist ein Gebäude, in dem Getränke durch Gärung hergestellt werden.' WHERE wert='2113';
		UPDATE ax_gebaeudefunktion SET dokumentation='Brennerei ist ein Gebäude, in dem alkoholische Getränke durch Destillation hergestellt werden.' WHERE wert='2114';
		UPDATE ax_gebaeudefunktion SET dokumentation='Werkstatt ist ein Gebäude, in dem mit Werkzeugen und Maschinen Güter hergestellt oder repariert werden.' WHERE wert='2120';
		UPDATE ax_gebaeudefunktion SET dokumentation='Sägewerk ist ein Gebäude, in dem Holz zugeschnitten wird.' WHERE wert='2121';
		UPDATE ax_gebaeudefunktion SET dokumentation='Waschstraße, Waschanlage, Waschhalle ist ein Gebäude, in dem Fahrzeuge gereinigt werden.' WHERE wert='2131';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Vorratshaltung ist ein Gebäude, in dem Güter vorübergehend gelagert werden.' WHERE wert='2140';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kühlhaus ist ein Gebäude, das zur Lagerung von Gütern mit niedriger Temperatur dient.' WHERE wert='2141';
		UPDATE ax_gebaeudefunktion SET dokumentation='Speichergebäude ist ein Gebäude zur Vorratshaltung.' WHERE wert='2142';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Grundstoffgewinnung ist ein Gebäude zur Gewinnung von Grundstoffen (z.B. Erz oder Kohle).' WHERE wert='2170';
		UPDATE ax_gebaeudefunktion SET dokumentation='Bergwerk ist ein Gebäude zur Gewinnung von Rohstoffen aus der Erde.' WHERE wert='2171';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für betriebliche Sozialeinrichtung ist ein Gebäude, in dem Arbeitnehmern betriebliche Zusatzangebote gewährt werden (z. B. Kinderbetreuung, Betriebssport oder Beratung).' WHERE wert='2180';
		UPDATE ax_gebaeudefunktion SET dokumentation='Sonstiges Gebäude für Gewerbe und Industrie ist ein Gebäude, das zum Anbieten von gewerblichen oder industriellen Tätigkeiten genutzt wird.' WHERE wert='2200';
		UPDATE ax_gebaeudefunktion SET dokumentation='Mühle ist ein Gebäude, das zum Mahlen, zum Sägen, zum Pumpen oder zur Erzeugung von Strom dient.' WHERE wert='2210';
		UPDATE ax_gebaeudefunktion SET dokumentation='Windmühle ist ein Gebäude, dessen wesentlicher Bestandteil die an einer Achse befestigten Flächen (Flügel, Schaufeln) sind, die von der Windkraft in Drehung versetzt werden.' WHERE wert='2211';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Handel und Dienstleistungen mit Wohnen ist ein Gebäude, in dem Arbeitsleistungen, die nicht der Produktion von materiellen Gütern dienen, angeboten werden und in dem zusätzlich gewohnt wird.' WHERE wert='2310';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Gewerbe und Industrie mit Wohnen ist ein Gebäude, das zum Anbieten von gewerblichen oder industriellen Tätigkeiten genutzt und in dem zusätzlich gewohnt wird.' WHERE wert='2320';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude zu Verkehrsanlagen (allgemein) ist ein Gebäude zur Aufrechterhaltung, Instandhaltung oder Überwachung von Verkehrsanlagen.' WHERE wert='2400';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude für Straßenverkehr ist ein Gebäude zur Aufrechterhaltung oder Instandhaltung des Straßenverkehrs.' WHERE wert='2410';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wartungshalle ist ein Gebäude zur Wartung oder Instandsetzung.' WHERE wert='2412';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude für Schienenverkehr ist ein Gebäude zur Aufrechterhaltung oder Instandhaltung des Schienenverkehrs.' WHERE wert='2420';
		UPDATE ax_gebaeudefunktion SET dokumentation='Bahnwärterhaus ist ein Gebäude, das als Dienstwohnung für Bahnwärter dient.' WHERE wert='2421';
		UPDATE ax_gebaeudefunktion SET dokumentation='Lokschuppen, Wagenhalle ist ein Gebäude, das als Unterstellplatz für Schienenfahrzeuge dient.' WHERE wert='2422';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude des Güterbahnhofs ist ein Gebäude zur Aufrechterhaltung oder Überwachung des Güterzugverkehrs.' WHERE wert='2424';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude für Flugverkehr ist ein Gebäude zur Aufrechterhaltung oder Überwachung des Flugverkehrs.' WHERE wert='2430';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude für Schiffsverkehr ist ein Gebäude zur Aufrechterhaltung oder Überwachung des Schiffsverkehrs.' WHERE wert='2440';
		UPDATE ax_gebaeudefunktion SET dokumentation='Werft (Halle) ist ein Gebäude, in dem Schiffe gebaut und repariert werden.' WHERE wert='2441';
		UPDATE ax_gebaeudefunktion SET dokumentation='Dock (Halle) ist ein Gebäude, in dem Schiffe trockengelegt werden.' WHERE wert='2442';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude zur Schleuse ist ein Gebäude, in dem der Schleusenbetrieb gesteuert und überwacht wird.' WHERE wert='2443';
		UPDATE ax_gebaeudefunktion SET dokumentation='Bootshaus ist ein Gebäude, das als Unterstellplatz für kleinere Wasserfahrzeuge dient.' WHERE wert='2444';
		UPDATE ax_gebaeudefunktion SET dokumentation='Betriebsgebäude zur Seilbahn ist ein Gebäude, in dem der Seilbahnbetrieb gesteuert und überwacht wird.' WHERE wert='2450';
		UPDATE ax_gebaeudefunktion SET dokumentation='Spannwerk zur Drahtseilbahn ist ein Gebäude, in dem das Seil der Seilbahn gespannt und umgelenkt wird.' WHERE wert='2451';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zum Parken ist ein Gebäude zum Abstellen von Fahrzeugen.' WHERE wert='2460';
		UPDATE ax_gebaeudefunktion SET dokumentation='Parkdeck ist ein Gebäude, in dem Fahrzeuge auf einer Etage abgestellt werden.' WHERE wert='2462';
		UPDATE ax_gebaeudefunktion SET dokumentation='Tiefgarage ist ein Bauwerk unter der Erdoberfläche, in dem Fahrzeuge abgestellt werden.' WHERE wert='2465';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Versorgung ist ein Gebäude, das die Grundversorgung mit Wasser oder Energie sicherstellt.' WHERE wert='2500';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Energieversorgung ist ein Gebäude, das die Grundversorgung mit Energie sicherstellt.' WHERE wert='2501';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Wasserversorgung ist ein Gebäude, das die Grundversorgung mit Wasser sicherstellt.' WHERE wert='2510';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wasserwerk ist ein Gebäude zur Aufbereitung und Bereitstellung von Trinkwasser.' WHERE wert='2511';
		UPDATE ax_gebaeudefunktion SET dokumentation='Pumpstation ist ein Gebäude an einem Rohrleitungssystem, in dem eine oder mehrere Pumpen zur Wasserversorgung eingebaut sind.' WHERE wert='2512';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Elektrizitätsversorgung ist ein Gebäude, in dem Elektrizität erzeugt oder übertragen wird.' WHERE wert='2520';
		UPDATE ax_gebaeudefunktion SET dokumentation='Elektrizitätswerk ist ein Gebäude, in dem Elektrizität erzeugt wird.' WHERE wert='2521';
		UPDATE ax_gebaeudefunktion SET dokumentation='Umspannwerk ist ein Gebäude, in dem verschiedene Spannungsebenen des elektrischen Versorgungsnetzes miteinander verbunden werden.' WHERE wert='2522';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kesselhaus ist ein Gebäude, in dem ein Dampfkessel mitsamt seiner Feuerung aufgestellt ist.' WHERE wert='2529';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Fernmeldewesen ist ein Gebäude, in dem sich Einrichtungen zur Telekommunikation befinden.' WHERE wert='2540';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude an unterirdischen Leitungen ist ein Gebäude, das zur Kontrolle von Versorgungsleitungen unter der Erde dient.' WHERE wert='2560';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Gasversorgung ist ein Gebäude, in dem sich Gasanlagen befinden.' WHERE wert='2570';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gaswerk ist ein Gebäude, in dem technische Gase hergestellt, gespeichert und bereitgestellt werden.' WHERE wert='2571';
		UPDATE ax_gebaeudefunktion SET dokumentation='Heizwerk ist ein Gebäude zur zentralen Erzeugung von Wärme (z.B. für Warmwasserversorgung).' WHERE wert='2580';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Versorgungsanlage ist ein Gebäude, in dem sich Anlagen zur Unterstützung von Versorgungseinrichtungen befinden.' WHERE wert='2590';
		UPDATE ax_gebaeudefunktion SET dokumentation='Pumpwerk (nicht für Wasserversorgung) ist ein Gebäude, in dem Wasser aus einem niedriger gelegenen Gewässer in ein höher gelegenes gepumpt wird.' WHERE wert='2591';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Entsorgung ist ein Gebäude zur Beseitigung von Abwässern oder Abfällen.' WHERE wert='2600';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Abwasserbeseitigung ist ein Gebäude zur Reinigung von verschmutztem Wasser oder zur Entsorgung von Fäkalien.' WHERE wert='2610';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude der Kläranlage ist ein Gebäude innerhalb einer Kläranlage.' WHERE wert='2611';
		UPDATE ax_gebaeudefunktion SET dokumentation='Toilette ist eine Einrichtung mit sanitären Vorrichtungen zur Aufnahme von Körperausscheidungen.' WHERE wert='2612';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zur Abfallbehandlung ist ein Gebäude zur Behandlung von Abfällen.' WHERE wert='2620';
		UPDATE ax_gebaeudefunktion SET dokumentation='Müllbunker ist ein Gebäude, in dem Müll gelagert wird.' WHERE wert='2621';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude der Abfalldeponie ist ein Gebäude auf einer Fläche, die zur endgültigen Lagerung von Abfällen genutzt wird.' WHERE wert='2623';
		UPDATE ax_gebaeudefunktion SET dokumentation='Land- und forstwirtschaftliches Betriebsgebäude ist ein Gebäude zur Produktion von land- und forstwirtschaftlichen Gütern.' WHERE wert='2720';
		UPDATE ax_gebaeudefunktion SET dokumentation='Schuppen ist ein Gebäude in einfacher Ausführung, das als Abstellplatz oder als Lagerraum zur Unterbringung von Fahrzeugen, Geräten und Materialien der Land- und Forstwirtschaft verwendet wird.' WHERE wert='2723';
		UPDATE ax_gebaeudefunktion SET dokumentation='Scheune und Stall ist ein Gebäude, in dem landwirtschaftliche Güter gelagert werden (z.B. Stroh, Heu oder Getreide) und in dem auch Tiere untergebracht sein können.' WHERE wert='2726';
		UPDATE ax_gebaeudefunktion SET dokumentation='Stall für Tiergroßhaltung ist ein Gebäude zur Unterbringung einer großen Anzahl von Tieren.' WHERE wert='2727';
		UPDATE ax_gebaeudefunktion SET dokumentation='Reithalle ist ein Gebäude zum Ausüben des Reitsports.' WHERE wert='2728';
		UPDATE ax_gebaeudefunktion SET dokumentation='Wirtschaftsgebäude ist ein Gebäude, das zu wirtschaftlichen Zwecken dient (z.B. Lager- oder Produktionshallen).' WHERE wert='2729';
		UPDATE ax_gebaeudefunktion SET dokumentation='Jagdhaus, Jagdhütte ist ein Gebäude, das als Unterkunft bei der Jagd dient.' WHERE wert='2735';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gewächshaus, verschiebbar ist ein Gebäude mit lichtdurchlässigem Dach und Wänden, das durch künstliche Klimagestaltung der Aufzucht oder Produktion von Pflanzen dient und dabei z. B. auf Schienen hin- und her bewegt werden kann.' WHERE wert='2742';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kreisverwaltung ist ein Gebäude, in dem sich die Verwaltung eines Landkreises befindet.' WHERE wert='3017';
		UPDATE ax_gebaeudefunktion SET dokumentation='Bezirksregierung ist ein Gebäude, in dem sich die Regierung eines Bezirks befindet.' WHERE wert='3018';
		UPDATE ax_gebaeudefunktion SET dokumentation='Finanzamt ist ein Gebäude, in dem sich eine örtliche Behörde der Finanzverwaltung befindet.' WHERE wert='3019';
		UPDATE ax_gebaeudefunktion SET dokumentation='Berufsbildende Schule ist ein Gebäude, in dem berufsbezogenes und fachgebundenes Wissen vermittelt wird.' WHERE wert='3022';
		UPDATE ax_gebaeudefunktion SET dokumentation='Veranstaltungsgebäude ist ein Gebäude, das hauptsächlich für kulturelle Zwecke wie z. B. Aufführungen, Ausstellungen, Konzerte genutzt wird.' WHERE wert='3036';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für religiöse Zwecke ist ein Gebäude, das bei Gottesdiensten oder sonstigen religiösen Veranstaltungen als Versammlungsort dient.' WHERE wert='3040';
		UPDATE ax_gebaeudefunktion SET dokumentation='Synagoge ist ein Gebäude, in dem sich Personen jüdischen Glaubens zu Gottesdiensten, zum Schriftstudium und zur Unterweisung versammeln.' WHERE wert='3042';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gemeindehaus ist ein Gebäude, das Personen einer bestimmten Glaubensgemeinschaft zu verschiedenen Zwecken dient.' WHERE wert='3044';
		UPDATE ax_gebaeudefunktion SET dokumentation='Moschee ist ein Gebäude, in dem sich Personen muslimischen Glaubens zum Gebet versammeln und das als sozialer Treffpunkt dient.' WHERE wert='3046';
		UPDATE ax_gebaeudefunktion SET dokumentation='Tempel ist ein Gebäude, das Personen in der Ausübung ihrer Religion (z. B. Buddhisten, Hinduisten) als Versammlungsort dient.' WHERE wert='3047';
		UPDATE ax_gebaeudefunktion SET dokumentation='Kloster ist ein Gebäude, in dem Angehörige eines Ordens in einer auf die Ausübung ihrer Religion konzentrierten Lebensweise zusammenleben.' WHERE wert='3048';
		UPDATE ax_gebaeudefunktion SET dokumentation='Heilanstalt, Pflegeanstalt, Pflegestation ist ein Gebäude, das einer länger andauernden Behandlung von Patienten dient.' WHERE wert='3052';
		UPDATE ax_gebaeudefunktion SET dokumentation='Jugendfreizeitheim ist ein Gebäude der offenen Kinder- und Jugendarbeit.' WHERE wert='3061';
		UPDATE ax_gebaeudefunktion SET dokumentation='Freizeit-, Vereinsheim, Dorfgemeinschafts-, Bürgerhaus ist ein Gebäude zur gemeinschaftlichen Nutzung unterschiedlicher sozialer Gruppen.' WHERE wert='3062';
		UPDATE ax_gebaeudefunktion SET dokumentation='Seniorenfreizeitstätte ist ein Gebäude zur Ausübung seniorengerechter Freizeitaktivitäten.' WHERE wert='3063';
		UPDATE ax_gebaeudefunktion SET dokumentation='Obdachlosenheim ist ein Gebäude, in dem Obdachlose untergebracht sind und betreut werden.' WHERE wert='3064';
		UPDATE ax_gebaeudefunktion SET dokumentation='Asylbewerberheim ist ein Gebäude, in dem Asylbewerber ohne Aufenthaltsgenehmigung für Deutschland eine gewisse Zeit untergebracht sind.' WHERE wert='3066';
		UPDATE ax_gebaeudefunktion SET dokumentation='Friedhofsgebäude ist ein Gebäude, das zur Aufrechterhaltung des Friedhofbetriebes dient (z. B. Verwaltung, Leichenhalle, Krematorium).' WHERE wert='3080';
		UPDATE ax_gebaeudefunktion SET dokumentation='Trauerhalle ist ein Gebäude, welches für Bestattungszeremonien bestimmt ist und zur kurzzeitigen Aufbewahrung von Toten dienen kann.' WHERE wert='3081';
		UPDATE ax_gebaeudefunktion SET dokumentation='Krematorium ist ein Gebäude, in dem Feuerbestattungen durchgeführt werden.' WHERE wert='3082';
		UPDATE ax_gebaeudefunktion SET dokumentation='Bahnhofsgebäude ist ein Gebäude u. a. mit Wartebereich und Fahrkartenausgabe zur Abwicklung des Bahnverkehrs.' WHERE wert='3091';
		UPDATE ax_gebaeudefunktion SET dokumentation='Flughafengebäude ist ein Gebäude u. a. mit Wartebereich, Flugticket- und Gepäckschalter zur Abwicklung des Flugverkehrs.' WHERE wert='3092';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zum U-Bahnhof ist ein Gebäude u. a. mit Wartebereich und Fahrkartenausgabe zur Abwicklung des U-Bahn-Verkehrs.' WHERE wert='3094';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zum S-Bahnhof ist ein Gebäude u. a. mit Wartebereich und Fahrkartenausgabe zur Abwicklung des S-Bahn-Verkehrs.' WHERE wert='3095';
		UPDATE ax_gebaeudefunktion SET dokumentation='Empfangsgebäude Schifffahrt ist ein Gebäude u. a. mit Wartebereich, Fahrticket- und Gepäckschalter zur Abwicklung des Schiffsverkehrs.' WHERE wert='3098';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für öffentliche Zwecke mit Wohnen ist ein Gebäude, das der Allgemeinheit dient und auch zum Wohnen genutzt wird.' WHERE wert='3100';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude zum Sportplatz ist ein Gebäude auf einer Fläche, die zur sportlichen Betätigung genutzt wird.' WHERE wert='3212';
		UPDATE ax_gebaeudefunktion SET dokumentation='Badegebäude ist ein Gebäude, in dem sich Anlagen zur Erholung und sportlichen Betätigung im Wasser befinden.' WHERE wert='3220';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude im Freibad ist ein Gebäude, das sich in einer Außenanlage mit Schwimmbecken und zugehörigen Einrichtungen (z. B. Umkleidekabinen) befindet.' WHERE wert='3222';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude im Stadion ist ein Gebäude, das sich in einer großen Anlage für sportliche Aktivitäten und Wettkämpfe befindet.' WHERE wert='3230';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für Kurbetrieb ist ein Gebäude, in dem Maßnahmen zur Erholung oder Rehabilitation durchgeführt werden.' WHERE wert='3240';
		UPDATE ax_gebaeudefunktion SET dokumentation='Badegebäude für medizinische Zwecke ist ein Gebäude, in dem Bäder zur therapeutischen Anwendung durchgeführt werden.' WHERE wert='3241';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude im Zoo ist ein Gebäude, das sich in einer parkartigen Anlage zur Haltung und öffentlichen Zurschaustellung verschiedener Tierarten befindet.' WHERE wert='3260';
		UPDATE ax_gebaeudefunktion SET dokumentation='Empfangsgebäude des Zoos ist ein Gebäude, das sich im Eingangsbereich des Zoos befindet u. a. mit Wartebereich und Einlasskontrolle.' WHERE wert='3261';
		UPDATE ax_gebaeudefunktion SET dokumentation='Tierschauhaus ist ein Gebäude, in dem Tiere untergebracht sind und Besuchern gezeigt werden.' WHERE wert='3263';
		UPDATE ax_gebaeudefunktion SET dokumentation='Stall im Zoo ist ein Gebäude, das meist zur separaten Unterbringung der Zootiere dient.' WHERE wert='3264';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude im botanischen Garten ist ein Gebäude, das sich in einer parkartigen Anlage mit thematisch geordneter Anpflanzung befindet.' WHERE wert='3270';
		UPDATE ax_gebaeudefunktion SET dokumentation='Empfangsgebäude des botanischen Gartens ist ein Gebäude, das sich im Eingangsbereich des botanischen Gartens befindet u. a. mit Wartebereich und Einlasskontrolle.' WHERE wert='3271';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gewächshaus (Botanik) ist ein Gebäude, welches das geschützte und kontrollierte Kultivieren von Pflanzen ermöglicht.' WHERE wert='3272';
		UPDATE ax_gebaeudefunktion SET dokumentation='Pflanzenschauhaus ist ein Gebäude, in dem Pflanzen unterschiedlicher Klima- oder Vegetationszonen ausgestellt sind und Besuchern gezeigt werden.' WHERE wert='3273';
		UPDATE ax_gebaeudefunktion SET dokumentation='Gebäude für andere Erholungseinrichtung ist ein Gebäude, das einer anderen Art der Erholung dient.' WHERE wert='3280';
		INSERT INTO ax_gebaeudefunktion(wert,beschreibung,dokumentation) VALUES ('2095','Spielhalle','Spielhalle ist eine Einrichtung, in der durch die Spielverordnung geregeltes Automatenspiel betrieben wird.');
		INSERT INTO ax_gebaeudefunktion(wert,beschreibung,dokumentation) VALUES ('3054','Rettungswache','Rettungswache ist ein Gebäude des Rettungsdienstes, in dem sich die Besatzungen der Rettungsdienstfahrzeuge in ihrer einsatzfreien Zeit aufhalten. Hier sind auch die Fahrzeuge und Geräte untergebracht.');
		UPDATE ax_weitere_gebaeudefunktion SET beschreibung='Rettungsstelle, Notaufnahme' WHERE wert='1190';
		UPDATE ax_weitere_gebaeudefunktion SET dokumentation='Toilette ist eine Einrichtung mit sanitären Vorrichtungen zur Aufnahme von Körperausscheidungen.' WHERE wert='1080';
		UPDATE ax_weitere_gebaeudefunktion SET dokumentation='Tempel ist eine Einrichtung, die Personen in der Ausübung ihrer Religion (z. B. Buddhisten, Hinduisten) als Versammlungsort dient.' WHERE wert='1160';
		UPDATE ax_weitere_gebaeudefunktion SET dokumentation='Rettungsstelle, Notaufnahme ist eine Anlaufstelle zur Akutversorgung und ist Teil der Notfallmedizin.' WHERE wert='1190';
		UPDATE ax_weitere_gebaeudefunktion SET dokumentation='Supermarkt ist eine Einrichtung, in der sich ein Einzelhandelsgeschäft befindet, das Lebensmittel und andere Erzeugnisse des täglichen Bedarfs anbietet.' WHERE wert='1230';
		UPDATE ax_weitere_gebaeudefunktion SET dokumentation='Geschäft ist eine Einrichtung, in der sich Räumlichkeiten befinden, in denen Waren oder Dienstleistungen gewerblich zum Verkauf angeboten werden.' WHERE wert='1240';
		INSERT INTO ax_weitere_gebaeudefunktion(wert,beschreibung,dokumentation) VALUES ('1051','Spielhalle','Spielhalle ist eine Einrichtung, in der durch die Spielverordnung geregeltes Automatenspiel betrieben wird.');
		INSERT INTO ax_beschaffenheit_besonderegebaeudelinie(wert,beschreibung,dokumentation) VALUES ('1100','Geschlossene Seite einer Überdachung','Überdachungen sind oftmals an einer oder mehreren Seiten geschlossen. Geschlossene Seite einer Überdachung weist eine geschlossene Seite einer Überdachung bzw. Carport nach.');
		UPDATE ax_bauart_bauteil SET beschreibung='Auskragender Geschossteil / zurückspringendes Geschoss' WHERE wert='2500';
		UPDATE ax_bauart_bauteil SET beschreibung='Auskragender Geschossteil' WHERE wert='2510';
		UPDATE ax_bauart_bauteil SET beschreibung='Zurückspringendes Geschoss' WHERE wert='2520';
		UPDATE ax_bauart_bauteil SET beschreibung='Durchfahrt an überbautem Verkehrsweg' WHERE wert='2620';
		UPDATE ax_bauart_bauteil SET dokumentation='Ein geringergeschossiger Gebäudeteil hat eine niedrigere Geschosshöhe als der größte Teil des Gebäudes.' WHERE wert='1100';
		UPDATE ax_bauart_bauteil SET dokumentation='Ein höhergeschossiger Gebäudeteil hat eine höhere Geschosshöhe als der größte Teil des Gebäudes.' WHERE wert='1200';
		UPDATE ax_bauart_bauteil SET dokumentation='Hochhausgebäudeteil ist der Teil eine Gebäudes, welches die Definiton der Attributart Hochhaus beim AX_Gebaeude erfüllt.' WHERE wert='1300';
		UPDATE ax_bauart_bauteil SET dokumentation='Die abweichende Geschosshöhe bezeichnet einen Bauteil, dessen Geschosshöhe von der Höhe anderer Bauteile des Gebäudes abweicht.' WHERE wert='1400';
		UPDATE ax_bauart_bauteil SET dokumentation='Keller bezeichnet ein Geschoss, welches ganz oder zum Teil unter der Geländeoberfläche liegt.' WHERE wert='2000';
		UPDATE ax_bauart_bauteil SET dokumentation='Tiefgarage ist ein Bauteil unter der Erdoberfläche, in dem Fahrzeuge abgestellt werden.' WHERE wert='2100';
		UPDATE ax_bauart_bauteil SET dokumentation='Loggia ist ein Raum in einem Gebäude, der sich zum Außenraum öffnet.' WHERE wert='2300';
		UPDATE ax_bauart_bauteil SET dokumentation='Wintergarten bezeichnet den fest umbauten Raum einer Terrasse.' WHERE wert='2350';
		UPDATE ax_bauart_bauteil SET dokumentation='Arkade bezeichnet den durch Säulen getragenen Bogengang eines Gebäudes.' WHERE wert='2400';
		UPDATE ax_bauart_bauteil SET dokumentation='Bei einem auskragenden Geschossteil bzw. zurückspringenden Geschoss kann keine eindeutige Zuordnung zu „auskragend“ oder „zurückspringend“ erfolgen.' WHERE wert='2500';
		UPDATE ax_bauart_bauteil SET dokumentation='Bei einem auskragenden Geschossteil ragt ein Teil des Geschosses über den Umring hinaus, der durch das aufgehende Mauerwerk im Erdgeschoss definiert ist.' WHERE wert='2510';
		UPDATE ax_bauart_bauteil SET dokumentation='Bei einem zurückspringenden Geschoss reicht ein Geschoss nicht bis zum Umring, der durch das aufgehende Mauerwerk im Erdgeschoss definiert ist.' WHERE wert='2520';
		UPDATE ax_bauart_bauteil SET dokumentation='Durchfahrt ist eine Stelle, an der mit Fahrzeugen durch Gebäude gefahren werden kann.' WHERE wert='2610';
		UPDATE ax_bauart_bauteil SET dokumentation='Durchfahrt an überbautem Verkehrsweg ist eine Stelle, an der mit Fahrzeugen durch Gebäude gefahren werden kann.' WHERE wert='2620';
		UPDATE ax_bauart_bauteil SET dokumentation='Turm im Gebäude ist ein hochaufragendes Bauteil innerhalb eines Gebäudes.' WHERE wert='2720';
		UPDATE ax_artdergebietsgrenze_gebietsgrenze SET dokumentation='Grenze der Bundesrepublik Deutschland begrenzt das Gebiet der Bundesrepublik Deutschland.' WHERE wert='7101';
		INSERT INTO ax_artdergebietsgrenze_gebietsgrenze(wert,beschreibung,dokumentation) VALUES ('7100','Grenze eines Staates','Grenze eines Staates ist eine politische Grenze zwischen Staaten zur Sicherung der territorialen Integrität und der exakten Definition des räumlichen Geltungsbereichs staatlicher Rechtsordnungen.');
		INSERT INTO ax_artdergebietsgrenze_gebietsgrenze(wert,beschreibung,dokumentation) VALUES ('7108','Grenze eines Kondominiums','Grenze eines Kondominiums begrenzt ein Gebiet, das unter gemeinsamer Verwaltung von zwei oder mehreren Staaten steht.');
		UPDATE ax_sonstigeangaben_bodenschaetzung SET beschreibung='Acker-Hackrain (Hack)' WHERE wert='2400';
		UPDATE ax_sonstigeangaben_bodenschaetzung SET beschreibung='Grünland-Hackrain (Hack)' WHERE wert='2500';
		DELETE FROM ax_klassifizierung_bewertung WHERE wert IN ('2110');
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Hopfen (HOPF)' WHERE wert='2120';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Spargel (SPA)' WHERE wert='2130';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Sonstige Sonderkulturen (SOKU)' WHERE wert='2190';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Forstwirtschaftliche Nutzung (H)' WHERE wert='2200';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weinbauliche Nutzung, allgemein (WG)' WHERE wert='2300';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 1 (WG1)' WHERE wert='2310';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 2 (WG2)' WHERE wert='2320';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 3 (WG3)' WHERE wert='2330';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 4 (WG4)' WHERE wert='2340';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 5 (WG5)' WHERE wert='2350';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 6 (WG6)' WHERE wert='2360';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 7 (WG7)' WHERE wert='2370';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 8 (WG8)' WHERE wert='2380';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weingarten 9 (WG9)' WHERE wert='2390';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Gemüse-/Blumen- und Zierpflanzenbau (G)' WHERE wert='2410';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Obstbau (OBST)' WHERE wert='2420';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Baumschule (BSCH)' WHERE wert='2430';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Anbaufläche unter Glas (GLAS)' WHERE wert='2440';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Kleingarten (KLG)' WHERE wert='2450';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Weihnachtsbaumkultur (WEIH)' WHERE wert='2510';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Saatzucht (SAAT)' WHERE wert='2520';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Teichwirtschaft (TEIW)' WHERE wert='2530';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Abbauland der Land- und Forstwirtschaft (LFAB)' WHERE wert='2610';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Geringstland (GER)' WHERE wert='2620';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Unland (U)' WHERE wert='2630';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Moor (MO)' WHERE wert='2640';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Heide (HEI)' WHERE wert='2650';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Reet (RE)' WHERE wert='2700';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Reet I (RE1)' WHERE wert='2710';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Reet II (RE2)' WHERE wert='2720';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Reet III (RE3)' WHERE wert='2730';
		UPDATE ax_klassifizierung_bewertung SET beschreibung='Nebenfläche des Betriebs der Land- und Forstwirtschaft (NF)' WHERE wert='2800';
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('1000','Grundvermögen','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('1370','Sonstige bebaute Grundstücke, sonstige Anlagen auf fremdem Grund und Boden (Energie-/Wärmegewinnung)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2000','Land- und forstwirtschaftliches Vermögen','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2100','Landwirtschaftliche Nutzung (LN)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2111','Ackerland (A)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2112','Acker-Grünland (AGr)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2113','Acker-Hack (HACK)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2114','Grünland (Gr)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2115','Grünland-Acker (GrA)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2116','Grünland-Hack (HACK)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2117','Wiese (W)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2118','Streuwiese (STR)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2119','Hutung (HU)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2400','Gärtnerische Nutzung/Gartenland (GN)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2411','Gemüsebau (GG)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2412','Blumen-/Zierpflanzenbau (GBZ)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2460','Gartenland (GL)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2500','Sonstige land- und forstwirtschaftliche Nutzung (SOLF)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2531','Karpfenteichwirtschaft (KA)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2532','Forellenteichwirtschaft (FO)','');
		INSERT INTO ax_klassifizierung_bewertung(wert,beschreibung,dokumentation) VALUES ('2540','Binnenfischerei (BIFI)','');
		UPDATE ax_bedeutung_grablochderbodenschaetzung SET beschreibung='Grabloch, bestimmend, lagerichtig (innerhalb der zugehörigen bodengeschätzten Fläche)' WHERE wert='1100';
		UPDATE ax_bedeutung_grablochderbodenschaetzung SET beschreibung='Grabloch, bestimmend, lagerichtig (außerhalb der zugehörigen bodengeschätzten Fläche)' WHERE wert='1200';
		UPDATE ax_bedeutung_grablochderbodenschaetzung SET beschreibung='Grabloch, bestimmend, nicht lagerichtig (innerhalb der zugehörigen bodengeschätzten Fläche)' WHERE wert='1300';
		UPDATE ax_bedeutung_grablochderbodenschaetzung SET beschreibung='Grabloch für Muster- und Vergleichsstück' WHERE wert='2000';
		UPDATE ax_bedeutung_grablochderbodenschaetzung SET beschreibung='Grabloch, nicht bestimmend, lagerichtig' WHERE wert='3000';
		DELETE FROM ax_bodenart_bodenschaetzung WHERE wert IN ('9330','9340');
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Sand mit Moor (SMo)' WHERE wert='6110';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehmiger Sand mit Moor (lSMo)' WHERE wert='6120';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm mit Moor (LMo)' WHERE wert='6130';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Ton mit Moor (TMo)' WHERE wert='6140';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor mit Sand (MoS)' WHERE wert='6210';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor mit lehmigem Sand (MolS)' WHERE wert='6220';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor mit Lehm (MoL)' WHERE wert='6230';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor mit Ton (MoT)' WHERE wert='6240';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Ton auf stark lehmigem Sand (T/SL)' WHERE wert='7510';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Ton auf lehmigem Sand (T/lS)' WHERE wert='7520';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Ton auf anlehmigem Sand (T/Sl)' WHERE wert='7530';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Schwerer Lehm auf lehmigem Sand (LT/lS)' WHERE wert='7610';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Schwerer Lehm auf anlehmigem Sand (LT/Sl)' WHERE wert='7620';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm auf anlehmigem Sand (L/Sl)' WHERE wert='7710';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor auf lehmigem Sand (Mo/lS)' WHERE wert='8220';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm und Moor, Bodenwechsel (L+Mo)' WHERE wert='9120';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehmiger Sand, steinig (lSg)' WHERE wert='9130';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm, steinig (Lg)' WHERE wert='9140';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehmiger Sand und Steine/Blöcke (lS+St)' WHERE wert='9150';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm und Steine/Blöcke (L+St)' WHERE wert='9160';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Steine/Blöcke und lehmiger Sand (St+lS)' WHERE wert='9170';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Steine/Blöcke und Lehm (St+L)' WHERE wert='9180';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehmiger Sand und Felsen (lS+Fe)' WHERE wert='9190';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm und Felsen (L+Fe)' WHERE wert='9200';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Felsen und lehmiger Sand (Fe+lS)' WHERE wert='9210';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Felsen und Lehm (Fe+L)' WHERE wert='9220';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Sand auf lehmigem Sand (S/lS)' WHERE wert='9310';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehmiger Sand mit Mergel (lSMe)' WHERE wert='9370';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehmiger Sand mit Moor auf Mergel (lSMo/Me)' WHERE wert='9380';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Anlehmiger Sand mit Moor (SlMo)' WHERE wert='9390';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Lehm mit Moor auf Mergel (LMo/Me)' WHERE wert='9420';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor mit Lehm auf Mergel (MoL/Me)' WHERE wert='9460';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='Moor mit Mergel (MoMe)' WHERE wert='9470';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='LößDiluvium (LöD)' WHERE wert='9480';
		UPDATE ax_bodenart_bodenschaetzung SET beschreibung='AlluviumDiluvium (AlD)' WHERE wert='9490';
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7100','Sand auf stark lehmigem Sand (S/SL)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7200','Anlehmiger Sand auf sandigem Lehm (Sl/sL)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7300','Lehmiger Sand auf Lehm (lS/L)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7410','Stark lehmiger Sand auf schwerem Lehm (SL/LT)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7420','Stark lehmiger Sand auf Sand (SL/S)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7500','Ton auf sandigem Lehm (T/sL)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7600','Schwerer Lehm auf stark lehmigem Sand (LT/SL)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7700','Lehm auf lehmigem Sand (L/lS)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7810','Sandiger Lehm auf anlehmigem Sand (sL/Sl)','');
		INSERT INTO ax_bodenart_bodenschaetzung(wert,beschreibung,dokumentation) VALUES ('7820','Sandiger Lehm auf Ton (sL/T)','');
		UPDATE ax_landschaftstyp SET beschreibung='Gebirge, Bergland, Hügelland' WHERE wert='1100';
		UPDATE ax_landschaftstyp SET beschreibung='Berg, Berge' WHERE wert='1200';
		UPDATE ax_landschaftstyp SET beschreibung='Becken, Senke' WHERE wert='1300';
		UPDATE ax_landschaftstyp SET beschreibung='Tal, Niederung' WHERE wert='1400';
		UPDATE ax_landschaftstyp SET beschreibung='(Tief-) Ebene, Flachland' WHERE wert='1500';
		UPDATE ax_landschaftstyp SET beschreibung='Plateau, Hochfläche' WHERE wert='1600';
		UPDATE ax_landschaftstyp SET beschreibung='Wald-, Heidelandschaft' WHERE wert='1900';
		UPDATE ax_landschaftstyp SET beschreibung='Siedlungs-, Wirtschaftslandschaft' WHERE wert='2200';
		UPDATE ax_landschaftstyp SET beschreibung='Küstenlandschaft' WHERE wert='2500';
		UPDATE ax_landschaftstyp SET dokumentation='Gebirge, Bergland, Hügelland bezeichnet eine zusammenhängende größere Erhebung der Erdoberfläche. Es besteht aus einzelnen Bergen und Hochflächen, die durch Täler und Senken gegliedert sind.' WHERE wert='1100';
		UPDATE ax_landschaftstyp SET dokumentation='Berg, Berge bezeichnet eine über die Umgebung deutlich herausragende Geländeerhebung, einzeln oder als Teil eines Gebirges.' WHERE wert='1200';
		UPDATE ax_landschaftstyp SET dokumentation='Becken, Senke bezeichnet ein gegenüber der Umgebung tiefer liegendes Land.' WHERE wert='1300';
		UPDATE ax_landschaftstyp SET dokumentation='Tal, Niederung bezeichnet im Bergland einen langgestreckten oder gewundenen, unterschiedlich tiefen und breiten Einschnitt im Gelände mit gleichsinnig gerichtetem Gefälle einschließlich des dazu gehörigen Talraumes, im Flachland eine offene Hohlform. Ferner zählen hierzu auch (talähnliche) Talungen und glaziale Rinnen, die beide kein gleichsinniges Gefälle aufweisen.' WHERE wert='1400';
		UPDATE ax_landschaftstyp SET dokumentation='(Tief-) Ebene, Flachland ist ein Teil der Erdoberfläche mit geringen Höhenunterschieden in einer Höhenlage bis 200- 300 m über NHN.' WHERE wert='1500';
		UPDATE ax_landschaftstyp SET dokumentation='Plateau, Hochfläche, bezeichnet einen Teil der Erdoberfläche mit fehlenden oder kaum wahrnehmbaren Höhenunterschieden in einer Höhenlage ab etwa 200-300 m über NHN.' WHERE wert='1600';
		UPDATE ax_landschaftstyp SET dokumentation='Wald-, Heidelandschaft ist eine größere zusammenhängende, mit Bäumen bestandene Fläche (Wald) einschließlich darin befindlicher Lichtungen. Hierzu gehören viele ehemalige Heiden, die heute vorwiegend ökonomisch genutzte monokulturartige Forste mit meist Fichten- oder Kiefernbeständen bilden.' WHERE wert='1900';
		UPDATE ax_landschaftstyp SET dokumentation='Siedlungs-, Wirtschaftslandschaft ist eine durch Siedlungsverdichtung oder spezielle Wirtschaftsorientierung geprägte Landschaft.' WHERE wert='2200';
		UPDATE ax_landschaftstyp SET dokumentation='Moorlandschaft ist eine durch heutige und ehemalige Moore gekennzeichnete Landschaft.' WHERE wert='2300';
		UPDATE ax_landschaftstyp SET dokumentation='Küstenlandschaft enthält jene auf dem Festland gelegenen Gebiete, die dem Meer abgerungen worden sind (Polder, Marschen), deren Entstehung dem Meer zu verdanken ist (Nehrungen, Haken) oder deren Küste durch das Meer geformt wird (Steilküste, Strände, Halbinseln).' WHERE wert='2500';
		INSERT INTO ax_landschaftstyp(wert,beschreibung,dokumentation) VALUES ('2600','Historische Landschaft','Historische Landschaft bedeutet, dass eine Landschaft auf ein administratives Territorium zurückzuführen ist, das (meist) in den Grenzen um 1792 dargestellt ist. Historische Landschaften liegen oft im Gebiet von mehreren Landschaftstypen.');
		INSERT INTO ax_behoerde(wert,beschreibung,dokumentation) VALUES ('2600','Bauaufsicht','');
		UPDATE ax_administrative_funktion SET dokumentation='Bundesrepublik ist die Bezeichnung Deutschlands und ist aus der Gesamtheit der deutschen Länder (Gliedstaaten) gebildet.' WHERE wert='1001';
		UPDATE ax_administrative_funktion SET dokumentation='Land ist ein teilsouveräner Gliedstaat der Bundesrepublik Deutschland.' WHERE wert='2001';
		UPDATE ax_administrative_funktion SET dokumentation='Freistaat ist ein teilsouveräner Gliedstaat der Bundesrepublik Deutschland (historisch gewachsene Bezeichnung für Land).' WHERE wert='2002';
		UPDATE ax_administrative_funktion SET dokumentation='Freie und Hansestadt ist eine historisch gewachsene Bezeichnung.' WHERE wert='2003';
		UPDATE ax_administrative_funktion SET dokumentation='Regierungsbezirk ist ein Verwaltungsbezirk innerhalb eines Landes, welcher mehrere Stadt- und Landkreise umfasst.' WHERE wert='3001';
		UPDATE ax_administrative_funktion SET dokumentation='Freie Hansestadt ist eine historisch gewachsene Bezeichnung.' WHERE wert='3002';
		UPDATE ax_administrative_funktion SET dokumentation='Bezirk ist ein abgegrenztes Gebiet einer Stadt.' WHERE wert='3003';
		UPDATE ax_administrative_funktion SET dokumentation='Stadt (Bremerhaven) ist die Bezeichnung der kreisfreien Stadt Bremerhaven.' WHERE wert='3004';
		UPDATE ax_administrative_funktion SET dokumentation='Kreis ist eine mehrere Gemeinden bzw. Städte umfassende kommunale Verwaltungseinheit.' WHERE wert='4001';
		UPDATE ax_administrative_funktion SET dokumentation='Landkreis ist eine mehrere Gemeinden bzw. Städte umfassende kommunale Verwaltungseinheit.' WHERE wert='4002';
		UPDATE ax_administrative_funktion SET dokumentation='Kreisfreie Stadt ist eine kommunale Verwaltungseinheit, die keinem Kreis oder Landkreis angehört.' WHERE wert='4003';
		UPDATE ax_administrative_funktion SET dokumentation='Ortsteil ist ein räumlich abgegrenzter Bereich einer Gemeinde.' WHERE wert='4008';
		UPDATE ax_administrative_funktion SET dokumentation='Verbandsfreie Gemeinde ist eine kreisangehörige Gebietskörperschaft, die keiner Verbandsgemeinde angehört.' WHERE wert='5002';
		UPDATE ax_administrative_funktion SET dokumentation='Große kreisangehörige Stadt ist eine kreisangehörige Stadt, die bestimmte Verwaltungsfunktionen vom Landkreis/Kreis übernimmt.

Hinweis: Unterscheidung zu 6013 Große kreisangehoerige Stadt aufgrund länderspezifischer Anforderungen.' WHERE wert='5004';
		UPDATE ax_administrative_funktion SET dokumentation='Verwaltungsgemeinschaft ist eine kommunale Verwaltungskooperation zwischen Gemeinden.' WHERE wert='5006';
		UPDATE ax_administrative_funktion SET dokumentation='Amt ist eine kommunale Verwaltungskooperation zwischen Gemeinden.' WHERE wert='5007';
		UPDATE ax_administrative_funktion SET dokumentation='Samtgemeinde ist eine kommunale Verwaltungskooperation zwischen Gemeinden.' WHERE wert='5008';
		UPDATE ax_administrative_funktion SET dokumentation='Gemeinde, die sich einer erfüllenden Gemeinde bedient ist eine Gemeinde, die Verwaltungsfunktionen von einer anderen Gemeinde erfüllen lässt.' WHERE wert='5012';
		UPDATE ax_administrative_funktion SET dokumentation='Erfüllende Gemeinde ist eine Gemeinde, die Verwaltungsfunktionen für andere Gemeinden erfüllt.' WHERE wert='5013';
		UPDATE ax_administrative_funktion SET dokumentation='Gemeinde ist unterste selbständige Verwaltungseinheit.' WHERE wert='6001';
		UPDATE ax_administrative_funktion SET dokumentation='Ortsgemeinde ist eine Gemeinde, die einer Verbandsgemeinde angehört.' WHERE wert='6002';
		UPDATE ax_administrative_funktion SET dokumentation='Stadt ist eine Gemeinde, die den Titel Stadt trägt.' WHERE wert='6003';
		UPDATE ax_administrative_funktion SET dokumentation='Kreisangehörige Stadt ist eine Stadt, die einem Landkreis/Kreis angehört.' WHERE wert='6004';
		UPDATE ax_administrative_funktion SET dokumentation='Große Kreisstadt ist eine kreisangehörige Stadt, die bestimmte Verwaltungsfunktionen vom Landkreis/Kreis übernimmt.' WHERE wert='6005';
		UPDATE ax_administrative_funktion SET dokumentation='Amtsangehörige Stadt ist eine kreisangehörige Stadt, die einem Amt angehört.' WHERE wert='6006';
		UPDATE ax_administrative_funktion SET dokumentation='Amtsangehörige Landgemeinde‘ ist eine kreisangehörige Gemeinde, die einem Amt angehört.' WHERE wert='6007';
		UPDATE ax_administrative_funktion SET dokumentation='Amtsangehörige Gemeinde ist eine kreisangehörige Gemeinde, die einem Amt angehört.' WHERE wert='6008';
		UPDATE ax_administrative_funktion SET dokumentation='Kreisangehörige Gemeinde ist eine Gemeinde, die einem Landkreis/Kreis angehört.' WHERE wert='6009';
		UPDATE ax_administrative_funktion SET dokumentation='Mitgliedsgemeinde einer Verwaltungsgemeinschaft ist eine kreisangehörige Gemeinde bzw. Stadt, die einer Verwaltungsgemeinschaft angehört.' WHERE wert='6010';
		UPDATE ax_administrative_funktion SET dokumentation='Mitgliedsgemeinde ist eine Gemeinde, die Teil einer Verwaltungskooperation ist.' WHERE wert='6011';
		UPDATE ax_administrative_funktion SET dokumentation='Markt ist eine kreisangehörige Gemeinde, die den Titel Markt trägt.' WHERE wert='6012';
		UPDATE ax_administrative_funktion SET dokumentation='Große kreisangehoerige Stadt ist eine kreisangehörige Stadt, die bestimmte Verwaltungsfunktionen vom Landkreis/Kreis übernimmt.

Hinweis: Unterscheidung zu 5004 Große kreisangehörige Stadt aufgrund länderspezifischer Anforderungen.' WHERE wert='6013';
		UPDATE ax_administrative_funktion SET dokumentation='Kreisangehörige Gemeinde, die die Bezeichnung Stadt führt ist eine Gemeinde, die den Titel Stadt führt und einem Landkreis/Kreis angehört.' WHERE wert='6014';
		UPDATE ax_administrative_funktion SET dokumentation='Gemeindefreies Gebiet ist ein Gebiet, das zu keiner Gemeinde gehört.' WHERE wert='6015';
		UPDATE ax_administrative_funktion SET dokumentation='Gemeindeteil ist ein räumlich abgetrennter Bereich einer Gemeinde.' WHERE wert='7001';
		UPDATE ax_administrative_funktion SET dokumentation='Gemarkung ist eine Flächeneinheit des Katasters.' WHERE wert='7003';
		UPDATE ax_administrative_funktion SET dokumentation='Stadtteil ist ein räumlich abgetrennter Bereich einer Stadt.' WHERE wert='7004';
		UPDATE ax_administrative_funktion SET dokumentation='Stadtbezirk ist ein abgegrenztes Gebiet einer Stadt.' WHERE wert='7005';
		UPDATE ax_administrative_funktion SET dokumentation='Ortsteil ist ein räumlich abgetrennter Bereich einer Gemeinde.' WHERE wert='7007';
		UPDATE ax_administrative_funktion SET dokumentation='Kondominium ist ein Gebiet, welches unter der gemeinsamen Verwaltung mehrerer Staaten steht.' WHERE wert='8001';
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('3005','Regierungsvertretung','Regierungsvertretung ist eine Bezeichung von Referaten des Niedersächsischen Ministeriums für Inneres und Sport.');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('5001','Verbandsgemeinde','Verbandsgemeinde ist eine kommunale Verwaltungskooperation zwischen Gemeinden.');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('5003','Verwaltungsverband','Verwaltungsverband ist eine kommunale Verwaltungskooperation zwischen Gemeinden.');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('5009','Gemeindeverwaltungsverband','Gemeindeverwaltungsverband ist eine kommunale Verwaltungskooperation zwischen Gemeinden.');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('5014','Einheitsgemeinde','Einheitsgemeinde ist die Bezeichnung für eine bestimmte länderspezifische Form eines kommunalen Gemeindetyps in Deutschland.');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('6016','Gemeindefreier Bezirk','');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('6017','Landeshauptstadt','');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('6018','Bergstadt','');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('6019','Hansestadt','');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('6020','Inselgemeinde','');
		INSERT INTO ax_administrative_funktion(wert,beschreibung,dokumentation) VALUES ('6021','Flecken','');
		UPDATE ax_bezeichnung_verwaltungsgemeinschaft SET dokumentation='Verbandsgemeinde umfasst in Rheinland-Pfalz das Gebiet einer Verbandsgemeinde, das aus benachbarten Gemeinden desselben Landkreises 
gebildet wird.' WHERE wert='2000';
		UPDATE ax_artderfestlegung_schutzgebietnachnaturumweltoderbodensc SET dokumentation='Biosphärenreservat ist ein rechtsverbindlich festgesetztes einheitlich zu schützendes und zu entwickelndes Gebiet, das 
1. großräumig und für bestimmte Landschaftstypen charakteristisch ist, 
2. in wesentlichen Teilen seines Gebietes die Voraussetzungen eines Naturschutzgebietes, im Übrigen überwiegend eines Landschaftsschutzgebietes erfüllt, 
3. vornehmlich der Erhaltung, Entwicklung oder Wiederherstellung einer durch hergebrachte vielfältige Nutzung geprägten Landschaft und der darin historisch gewachsenen Arten- und Biotopvielfalt, einschließlich Wild- und frühere Kulturformen wirtschaftlich genutzter oder nutzbarer Tier- und Pflanzenarten dient und 
4. beispielhaft der Entwicklung und Erprobung von Naturgütern besonders schonenden Wirtschaftsweise dient.' WHERE wert='1690';
		UPDATE ax_zone_schutzzone SET dokumentation='Regenerationszone ist eine räumlich begrenzte Fläche eines Biosphärenreservates, für die die Fachverwaltung besondere Schutzbestimmungen festgelegt hat.

Nach §25 Abschnitt 3 des Bundesnaturschutzgesetzes (BNatSchG *Stand:1.03.2010) darf die „Regenerationszone“ nicht mehr verwendet werden.' WHERE wert='1090';
		UPDATE ax_artderfestlegung_bauraumoderbodenordnungsrecht SET beschreibung='Flurbereinigung (Par. 1 und 37 FlurbG)' WHERE wert='2110';
		INSERT INTO ax_artderfestlegung_bauraumoderbodenordnungsrecht(wert,beschreibung,dokumentation) VALUES ('2115','Flurbereinigung nach Par. 1 in Kombination mit Par. 87 FlurbG','');
		INSERT INTO ax_artderfestlegung_bauraumoderbodenordnungsrecht(wert,beschreibung,dokumentation) VALUES ('2190','Neuvermessungsgebiet innerhalb des Bodenordnungsgebietes','');
		INSERT INTO ax_artderfestlegung_bauraumoderbodenordnungsrecht(wert,beschreibung,dokumentation) VALUES ('2900','Verfahren nach dem hessischen Grenzbereinigungsgesetz','');
		INSERT INTO ax_artderfestlegung_anderefestlegungnachwasserrecht(wert,beschreibung,dokumentation) VALUES ('1443','Vorläufig gesichertes Überschwemmungsgebiet','Entsprechend des Hamburgischen Wassergesetzes (HWaG) für den Begriff "Vorläufige Sicherung".');
		INSERT INTO ax_artderfestlegung_sonstigesrecht(wert,beschreibung,dokumentation) VALUES ('4730','Militärbrache','Militärbrache ist eine ehemals militärisch genutzte Fläche, die aktuell nicht mehr militärisch genutzt wird.');
		INSERT INTO ax_artderfestlegung_naturumweltoderbodenschutzrecht(wert,beschreibung,dokumentation) VALUES ('1635','Gesicherte Altlast','');
		INSERT INTO ax_artderfestlegung_naturumweltoderbodenschutzrecht(wert,beschreibung,dokumentation) VALUES ('1636','Gesicherte schädliche Bodenveränderung','');
		INSERT INTO ax_artderfestlegung_naturumweltoderbodenschutzrecht(wert,beschreibung,dokumentation) VALUES ('1644','Abstandszone, Störfallbetrieb','');
		UPDATE ax_datenformat_benutzer SET dokumentation='NAS (Normbasierte Austauschschnittstelle) ist eine Datenschnittstelle zum Austausch von Geoinformationen, die im Rahmen der Modellierung des AAA-Modells definiert wurde.' WHERE wert='1000';
		UPDATE ax_datenformat_benutzer SET dokumentation='DXF (Drawing Interchange Format) ist ein spezifiziertes Dateiformat zum CAD-Datenaustausch. Es enthält neben Geometrien und Fachinformationen auch Angaben für eine einfache graphische Darstellung.' WHERE wert='2000';
		UPDATE ax_datenformat_benutzer SET dokumentation='TIFF (Tagged Image File Format) ist ein Dateiformat zur verlustfreien Speicherung von Bilddaten.' WHERE wert='3000';
		UPDATE ax_datenformat_benutzer SET dokumentation='GeoTIFF ist ein Dateiformat zur verlustfreien Speicherung von Bilddaten mit eingebetteten Informationen zur Georeferenzierung.' WHERE wert='4000';
		INSERT INTO ax_datenformat_benutzer(wert,beschreibung,dokumentation) VALUES ('5000','PDF','Das Portable Document Format (PDF) ist ein plattformunabhängiges Dateiformat für Dokumente, das vom Unternehmen Adobe Systems entwickelt wurde.');
		INSERT INTO ax_datenformat_benutzer(wert,beschreibung,dokumentation) VALUES ('6000','Shape','Shape ist ein von der Firma ESRI entwickeltes Format für Geodaten.');
		UPDATE ax_art_bereichzeitlich SET dokumentation='Stichtagsbezogen ohne Historie selektiert die Differenzdaten zwischen letzter erfolgreicher Datenabgabe und Stichzeitpunkt, in der Sekundärdatenbank ist stets nur der aktuelle Stand der Daten verfügbar.' WHERE wert='1000';
		UPDATE ax_art_bereichzeitlich SET dokumentation='Stichtagsbezogen mit Historie selektiert die Differenzdaten zwischen letzter erfolgreicher Datenabgabe und Stichzeitpunkt, in der Sekundärdatenbank werden zumindest temporär auch untergegangene Objekte und Objektversionen vorgehalten.' WHERE wert='1100';
		UPDATE ax_art_bereichzeitlich SET dokumentation='Fallbezogen ohne Historie selektiert alle Änderungen zwischen letzter erfolgreicher Datenabgabe und Stichzeitpunkt, in der Sekundärdatenbank ist stets nur der aktuelle Stand der Daten verfügbar.' WHERE wert='3000';
		UPDATE ax_art_bereichzeitlich SET dokumentation='Fallbezogen mit Historie selektiert alle Änderungen zwischen letzter erfolgreicher Datenabgabe und Stichzeitpunkt, in der Sekundärdatenbank werden zumindest temporär auch untergegangene Objekte und Objektversionen vorgehalten.' WHERE wert='3100';
		UPDATE ax_ausgabemedium_benutzer SET dokumentation='Analog ist eine Abgabe der Daten in ausgedruckter Form.' WHERE wert='1000';
		UPDATE ax_ausgabemedium_benutzer SET dokumentation='CD-R ist eine CD, die nur einmal bespielbar ist. (Compact Disc Recordable)' WHERE wert='2000';
		UPDATE ax_ausgabemedium_benutzer SET dokumentation='DVD ist ein CD ähnlicher Datenträger mit größerer Speicherkapazität.' WHERE wert='3000';
		UPDATE ax_ausgabemedium_benutzer SET dokumentation='E-Mail ist die Abgabe der Daten in einer briefähnlichen Nachricht auf elektronischem Weg in Computernetzwerken.' WHERE wert='4000';
		UPDATE ax_art_dammwalldeich SET dokumentation='Binnendeich ist ein Deich an kleineren Wasserläufen, der Überschwemmungen durch ablaufendes Oberflächenwasser verhindern soll.' WHERE wert='1980';
		UPDATE ax_art_dammwalldeich SET dokumentation='Wall ist ein meist künstlich aus Erde und Feldsteinen oder Torf errichtetes, langgestrecktes und schmales Landschaftselement, das oft ein- oder beidseitig von Aushubgräben begleitet wird und keinen nennenswerten Bewuchs trägt.' WHERE wert='1990';
		UPDATE ax_art_dammwalldeich SET dokumentation='Knick oder auch Wallhecke ist ein Wall, der mit Sträuchern in Heckenform und einzeln stehenden Bäumen bewachsen ist. Knicks sind landschaftsprägend und können der Grenzmarkierung, Einfriedung und dem Schutz gegen Winderosion dienen.' WHERE wert='2000';
		UPDATE ax_berechnungsmethode SET beschreibung='Polynomansatz' WHERE wert='5340';
		UPDATE ax_funktion_stehendesgewaesser SET dokumentation='See ist eine natürliche oder künstlich angelegte, größere, stehende oder nahezu stehende Wasserfläche, die im allgemeinen Sprachgebrauch als See anzusehen ist (z. B. Stausee, Speicherbecken).' WHERE wert='8610';
		UPDATE ax_funktion_stehendesgewaesser SET dokumentation='Teich ist eine natürliche oder künstlich angelegte, stehende oder nahezu stehende Wasserfläche, die im allgemeinen Sprachgebrauch als Teich anzusehen ist.' WHERE wert='8620';
		UPDATE ax_funktion_stehendesgewaesser SET dokumentation='Baggersee ist ein künstlich geschaffenes Gewässer, aus dem Bodenmaterial gefördert wird oder wurde.' WHERE wert='8640';
		UPDATE ax_funktion_stehendesgewaesser SET dokumentation='Sonstiges bedeutet, dass die Funktion des Stehenden Gewässers bekannt, aber nicht in der Werteliste aufgeführt ist.' WHERE wert='9999';
		UPDATE ax_schifffahrtskategorie SET dokumentation='Binnenwasserstraße ist ein oberirdisches Gewässer oder Küstengewässer, das gesetzlich für den Personen- und/oder Güterverkehr mit Schiffen bestimmt ist. Binnengewässer im Küstengebiet sind gegen das Küstengewässer gesetzlich abgegrenzt. Die Binnenwasserstraße ist ein Gewässer 1. Ordnung.' WHERE wert='1000';
		UPDATE ax_schifffahrtskategorie SET dokumentation='Seewasserstraße ist ein als Wasserstraße gesetzlich festgelegter Teil eines Küstengewässers. Die Seewasserstraße ist ein Gewässer 1. Ordnung.' WHERE wert='2000';
		UPDATE ax_schifffahrtskategorie SET dokumentation='Landesgewässer mit Verkehrsordnung ist eine Wasserstraße, die keine Binnenwasserstraße ist. Die Schiffbarkeit wird durch eine Landesverkehrsordnung geregelt. Das Landesgewässer mit Verkehrsordnung ist ein Gewässer 1. Ordnung.' WHERE wert='3000';
		UPDATE ax_schifffahrtskategorie_kanal SET dokumentation='Binnenwasserstraße ist ein oberirdisches Gewässer oder Küstengewässer, das gesetzlich für den Personen- und/oder Güterverkehr mit Schiffen bestimmt ist. Binnengewässer im Küstengebiet sind gegen das Küstengewässer gesetzlich abgegrenzt. Die Binnenwasserstraße ist ein Gewässer 1. Ordnung.' WHERE wert='1000';
		UPDATE ax_schifffahrtskategorie_kanal SET dokumentation='Seewasserstraße ist ein als Wasserstraße gesetzlich festgelegter Teil eines Küstengewässers. Die Seewasserstraße ist ein Gewässer 1. Ordnung.' WHERE wert='2000';
		UPDATE ax_schifffahrtskategorie_kanal SET dokumentation='Landesgewässer mit Verkehrsordnung ist eine Wasserstraße, die keine Binnenwasserstraße ist. Die Schiffbarkeit wird durch eine Landesverkehrsordnung geregelt. Das Landesgewässer mit Verkehrsordnung ist ein Gewässer 1. Ordnung.' WHERE wert='3000';
		UPDATE ax_funktion_fliessgewaesser SET dokumentation='Fluss ist ein natürliches, fließendes Gewässer (ggf. auch mit begradigten, kanalisierten Teilstücken), das wegen seiner Größe und Bedeutung im allgemeinen Sprachgebrauch als Fluss angesprochen wird.' WHERE wert='8200';
		UPDATE ax_funktion_fliessgewaesser SET dokumentation='Altarm bezeichnet eine an einem Ende des Fließgewässers abgeschnittene Strecke eines Flusses.' WHERE wert='8220';
		UPDATE ax_funktion_fliessgewaesser SET dokumentation='Kanal bezeichnet einen künstlich angelegten Wasserlauf.' WHERE wert='8300';
		UPDATE ax_funktion_fliessgewaesser SET dokumentation='Graben ist ein ständig oder zeitweise fließendes, künstlich angelegtes oder natürliches Gewässer, das im allgemeinen Sprachgebrauch als Graben anzusehen ist.' WHERE wert='8400';
		UPDATE ax_funktion_fliessgewaesser SET dokumentation='Fleet ist die Bezeichnung für eine noch vorhandene, aber stark veränderte oder überhaupt erst künstlich angelegte Wasserverbindung in Hamburg sowie in Bremen - ehemals für einen marschtypischen Entwässerungsgraben genutzte Bezeichnung.' WHERE wert='8410';
		UPDATE ax_funktion_fliessgewaesser SET dokumentation='Bach ist ein natürliches, fließendes Gewässer, das wegen seiner geringen Größe und Bedeutung im allgemeinen Sprachgebrauch als Bach anzusehen ist.' WHERE wert='8500';
		UPDATE ax_funktion_hafenbecken SET dokumentation='Sportboothafenbecken sind Wasserflächen, die dem Anlegen und Festmachen von Sportbooten dienen.' WHERE wert='8810';
		UPDATE ax_zustand_wohnbauflaeche SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_artderbebauung_wohnbauflaeche SET dokumentation='Geschlossen beschreibt die Bebauung von Wohnbaufläche, die vorwiegend durch zusammenhängende Gebäude charakterisiert wird. Die Gebäudeabdeckung ist in der Regel > 50 Prozent der Wohnbaufläche.' WHERE wert='2000';
		UPDATE ax_zustand_flaechebesondererfunktionalerpraegung SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Gebäude- und Freifläche, Mischnutzung mit Wohnen bezeichnet eine Fläche, die Wohn- und anderen Nutzungen zugleich dient, und bei der die Wohn- oder andere Nutzung von nicht ganz untergeordneter Bedeutung ist.' WHERE wert='2100';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Wohnen mit Öffentlich beschreibt eine baulich geprägte Fläche, die sowohl für Wohnzwecke als auch der Allgemeinheit dient. Es dominieren die Wohnzwecke.' WHERE wert='2110';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Wohnen mit Handel und Dienstleistungen beschreibt eine baulich geprägte Fläche, die sowohl für Wohnzwecke als auch für Handels- und/oder Dienstleistungsbetrieben dient. Es dominieren die Wohnzwecke.' WHERE wert='2120';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Wohnen mit Gewerbe und Industrie beschreibt eine baulich geprägte Fläche, die sowohl für Wohnzwecke als auch für Gewerbe- und/oder Industriebetrieben dienen. Es dominieren die Wohnzwecke.' WHERE wert='2130';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Öffentlich mit Wohnen beschreibt eine baulich geprägte Fläche, die sowohl für Wohnzwecke als auch der Allgemeinheit dient. Es dominieren die Zwecke für die Allgemeinheit.' WHERE wert='2140';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Handel und Dienstleistungen mit Wohnen beschreibt eine baulich geprägte Fläche, die sowohl für Wohnzwecke als auch für Handels- und/oder Dienstleistungsbetrieben dient. Es dominieren die Zwecke für Handel und Dienstleistung.' WHERE wert='2150';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Gewerbe und Industrie mit Wohnen‘ beschreibt eine baulich geprägte Fläche, die sowohl für Wohnzwecke als auch für Gewerbe- und/oder Industriebetrieben dienen. Es dominieren die Zwecke für Gewerbe und Industrie.' WHERE wert='2160';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Gebäude- und Freifläche Land- und Forstwirtschaft bezeichnet eine Fläche, die vorwiegend der Land- und Forstwirtschaft dient, einschließlich des Wohnteils.' WHERE wert='2700';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Wohnen ist eine Fläche zu Wohnzwecken, die mit einer Fläche der land- und forstwirtschaftlichen Nutzung in Verbindung steht.' WHERE wert='2710';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Betrieb ist eine Fläche, die betrieblichen Zwecken in der Land- und Forstwirtschaft dient.' WHERE wert='2720';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Wohnen und Betrieb ist eine Fläche, die sowohl Wohn- als auch betrieblichen Zwecken in der Land- und Forstwirtschaft dient.' WHERE wert='2730';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Landwirtschaftliche Betriebsfläche’ ist eine bebaute oder unbebaute Fläche, die dem landwirtschaftlichen Betrieb ohne eine Wohnnutzung dient.' WHERE wert='6800';
		UPDATE ax_funktion_flaechegemischternutzung SET dokumentation='Forstwirtschaftliche Betriebsfläche bezeichnet eine bebaute oder unbebaute Fläche, die dem forstwirtschaftlichen Betrieb ohne eine Wohnnutzung dient.' WHERE wert='7600';
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Parken bezeichnet eine Fläche, die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('3000','Fischereiwirtschaftsfläche','Fischereiwirtschaftsfläche bezeichnet Flächen/Areale, die dem (gewerblichen) Fangen oder Züchten von Fischen und anderen Wassertieren/ im Wasser lebenden Organismen zur Nahrungsgewinnung und Weiterverarbeitung dienen.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('3001','Fischereiwirtschaftsfläche mit Fischzucht, Muschelzucht','Fischereiwirtschaftsfläche mit Fischzucht, Muschelzucht bezeichnet Flächen/Areale, die dem (gewerblichen) Züchten/der kontrollierten Aufzucht von im Wasser lebenden Organismen, insbesondere Fischen und Muscheln, zur Nahrungsgewinnung und Weiterverarbeitung dienen.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('3002','Fischereiwirtschaftsfläche mit Algenzucht','Fischereiwirtschaftsfläche mit Algenzucht bezeichnet Flächen/Areale, die dem (gewerblichen) Züchten/der kontrollierten Aufzucht von im Wasser lebenden Organismen, insbesondere Algen, zur Nahrungsgewinnung und Weiterverarbeitung dienen.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('3003','Fischereiwirtschaftsfläche mit Fischzucht, Muschelzucht und Algenzucht','Fischereiwirtschaftsfläche mit Fischzucht, Muschelzucht und Algenzucht bezeichnet Flächen/Areale, die dem (gewerblichen) Züchten/der kontrollierten Aufzucht von im Wasser lebenden Organismen, insbesondere Fisch, Muscheln und Algen, zur Nahrungsgewinnung und Weiterverarbeitung dienen.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('6810','Landwirtschaftliche Betriebsfläche für Tierhaltung','Landwirtschaftliche Betriebsfläche für Tierhaltung’ bezeichnet eine bebaute oder unbebaute Fläche, die vorwiegend dem landwirtschaftlichen Betrieb, primär der Tierhaltung, dient. Diese umfasst auch die Gebäude- und Freiflächen.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('6820','Landwirtschaftliche Betriebsfläche für pflanzliche Produktion','Landwirtschaftliche Betriebsfläche für pflanzliche Produktion’ bezeichnet eine bebaute oder unbebaute Fläche, die vorwiegend dem landwirtschaftlichen Betrieb, primär der pflanzlichen Produktion, dient. Diese umfasst auch die Gebäude- und Freiflächen.');
		INSERT INTO ax_funktion_flaechegemischternutzung(wert,beschreibung,dokumentation) VALUES ('6830','Landwirtschaftliche Betriebsfläche für Tierhaltung und pflanzliche Produktion','Landwirtschaftliche Betriebsfläche für Tierhaltung und pflanzliche Produktion’ bezeichnet eine bebaute oder unbebaute Fläche, die vorwiegend dem landwirtschaftlichen Betrieb, primär der Tierhaltung und der pflanzlichen Produktion, dient. Diese umfasst auch die Gebäude- und Freiflächen.');
		UPDATE ax_foerdergut_industrieundgewerbeflaeche SET dokumentation='Kohlensäure ist eine schwache Säure, die durch Lösung von Kohlendioxid in Wasser entsteht und gefördert
wird.' WHERE wert='4000';
		UPDATE ax_zustand_sportfreizeitunderholungsflaeche SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET beschreibung='Regierung und Verwaltung' WHERE wert='1110';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET beschreibung='Bildung und Wissenschaft' WHERE wert='1120';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Öffentliche Zwecke bezeichnet eine Fläche, die vorwiegend der Erfüllung öffentlicher Aufgaben und dem Gemeinwesen dient.' WHERE wert='1100';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Regierung und Verwaltung bezeichnet eine Fläche auf der vorwiegend Gebäude der öffentlichen Regierung und Verwaltung, z. B. Rathaus, Gericht, Kreisverwaltung stehen.' WHERE wert='1110';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Bildung und Wissenschaft bezeichnet eine Fläche, auf der vorwiegend Gebäude stehen, in denen geistige, kulturelle und soziale Fähigkeiten vermittelt werden und/oder wissenschaftliche Forschung betrieben wird (z.B. Schulen, Universitäten, Institute).' WHERE wert='1120';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Kultur’ bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude für kulturelle Zwecke, z.B. Konzert- und Museumsgebäude, Bibliotheken, Theater, Schlösser und Burgen stehen.' WHERE wert='1130';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.' WHERE wert='1200';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Historische Anlage ist eine Fläche mit historischen Anlagen, z. B. historischen Stadtmauern und -türmen, Denkmälern und Ausgrabungsstätten, sofern keine konkretere Nutzungszuordnung möglich ist.' WHERE wert='1300';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Burg-, Festungsanlage ist eine Fläche mit historischen Wehranlagen.' WHERE wert='1310';
		UPDATE ax_funktion_flaechebesondererfunktionalerpraegung SET dokumentation='Schlossanlage ist eine Fläche, die der Ansiedlung des Adels dient oder diente.' WHERE wert='1320';
		INSERT INTO ax_funktion_flaechebesondererfunktionalerpraegung(wert,beschreibung,dokumentation) VALUES ('1180','Medien und Kommunikation','Medien und Kommunikation bezeichnet eine Fläche auf der vorwiegend Anlagen und Gebäude für die Erzeugung und Verbreitung von Printmedien, Hörfunk, Film und Fernsehen sowie Internet und Telefonie stehen.');
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Gebäude- und Freifläche Sport' WHERE wert='4101';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Golf' WHERE wert='4110';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Reitsport' WHERE wert='4140';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Tennis' WHERE wert='4170';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Gebäude- und Freifläche Freizeit, Zoologie' WHERE wert='4211';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Freilichtbühne' WHERE wert='4240';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Verkehrsübungsplatz, Testgelände, Fahrsicherheit' WHERE wert='4270';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Modellfluggelände' WHERE wert='4290';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Schwimmen' WHERE wert='4320';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Gebäude- und Freifläche Erholung, Bad' WHERE wert='4321';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Gebäude- und Freifläche Erholung, Camping' WHERE wert='4331';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Siedlungsgrünfläche' WHERE wert='4410';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET beschreibung='Gebäude- und Freifläche Grünanlage, Botanik' WHERE wert='4431';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Sportanlage ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung von (Wettkampf-)Sport und für Zuschauer bestimmt ist.' WHERE wert='4100';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Gebäude- und Freifläche Sport ist eine bebaute Fläche, die dem Sport dient.' WHERE wert='4101';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Golf ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Golfsports genutzt wird.' WHERE wert='4110';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Sportplatz ist eine Freianlage, die sowohl dem organisierten Wettkampfsport als auch nicht wettkampforientierten Sport-, Bewegungs- und Freizeitaktivitäten dient. Auf einem Sportplatz können verschiedene Sportarten betrieben werden.' WHERE wert='4120';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Rennbahn ist eine, je nach Art des Rennens, verschiedenartig gestaltete Strecke (oval, gerade, kurvig), auf der Rennen stattfinden.' WHERE wert='4130';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Reitsport bezeichnet eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Reitsports genutzt wird.' WHERE wert='4140';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Schießanlage ist eine Fläche zum Übungs- und Wettkampfschießen.' WHERE wert='4150';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Eis-, Rollschuhbahn ist eine künstlich angelegte Bahn zum Eislaufen oder Rollschuhfahren.' WHERE wert='4160';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Tennis ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Tennissports genutzt wird.' WHERE wert='4170';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Freizeitanlage bezeichnet eine Fläche, die vorwiegend der Freizeitgestaltung oder dazu dient, Tiere zu zeigen.' WHERE wert='4200';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Gebäude- und Freifläche Freizeit, Zoologie ist eine öffentliche Fläche mit Gebäuden und Bauwerken sowie den unmittelbar zu den Gebäuden gehörigen Freiflächen, in denen Tiere gehalten und gezeigt werden.' WHERE wert='4211';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Freilichtbühne ist eine Anlage mit Bühne und Zuschauerbänken für Aufführungen im Freien.' WHERE wert='4240';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Freilichtmuseum ist eine volkskundliche Museumsanlage, in der Wohnformen oder historische 
Betriebsformen in ihrer natürlichen Umgebung im Freien dargestellt sind.' WHERE wert='4250';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Verkehrsübungsplatz, Testgelände, Fahrsicherheit ist eine Fläche, die Übungs- und Erprobungszwecken dient.' WHERE wert='4270';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Modellfluggelände ist eine Fläche, die zur Ausübung des Modellflugsports dient.' WHERE wert='4290';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Gebäude- und Freifläche Erholung ist eine öffentliche Fläche mit Gebäuden und Bauwerken sowie den unmittelbar zu den Gebäuden gehörigen Freiflächen, die zur Erholung bestimmt sind.' WHERE wert='4301';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Schwimmen ist eine Anlage mit Wasserfläche sowie Anlagen an Ufern von Gewässern für den Badebetrieb und Schwimmsport.' WHERE wert='4320';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Gebäude- und Freifläche Erholung, Bad bezeichnet eine öffentliche Fläche, auf der vorwiegend Anlagen und Gebäude zur Erholung, für den Badebetrieb und den Schwimmsport vorhanden sind.' WHERE wert='4321';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Gebäude- und Freifläche Erholung, Camping bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Erholung sowie für den Betrieb eines Campingplatzes vorhanden sind.' WHERE wert='4331';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Grünanlage ist in erster Linie eine Anlage mit Bäumen, Sträuchern, Rasenflächen, Blumenrabatten und Wegen, die vor allem der Erholung und Verschönerung des Stadtbildes dient.' WHERE wert='4400';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Siedlungsgrünfläche ist eine unbebaute Wiese, Rasenfläche und Parkanlage in Städten und Siedlungen.' WHERE wert='4410';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Botanischer Garten ist ein der Öffentlichkeit zugänglicher Garten zum Studium der Pflanzenwelt; systematisch geordnete Sammlung in Freiland und Gewächshäusern (Warmhäuser).' WHERE wert='4430';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Gebäude- und Freifläche Grünanlage, Botanik ist eine öffentliche Fläche mit Gebäuden und Bauwerken, in der Pflanzen der Öffentlichkeit zugänglich gemacht werden.' WHERE wert='4431';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Kleingarten (Schrebergarten) ist eine Anlage von Gartengrundstücken, die im Unterschied zu Gartenbauland vorwiegend der Freizeit und Erholung dient.' WHERE wert='4440';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Wochenendplatz sind Flächen, die der Freizeitgestaltung dienen.' WHERE wert='4450';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Garten sind Flächen, die nicht im unmittelbaren Zusammenhang mit Wohnbauflächen stehen und nicht dem Bundeskleingartengesetz unterliegen. Der Garten dient, im Gegensatz zum Vorgarten oder Ziergarten, hauptsächlich der Erzeugung von Nutzpflanzen, wie z.B. Kräutern, Obst und Gemüse als Nahrungsmittel zum privaten Gebrauch.' WHERE wert='4460';
		UPDATE ax_funktion_sportfreizeitunderholungsflaeche SET dokumentation='Sonstiges bedeutet, dass die Funktion der Sport-, Freizeit- und Erholungsfläche bekannt, diese aber nicht in der Werteliste aufgeführt ist.' WHERE wert='9999';
		INSERT INTO ax_funktion_sportfreizeitunderholungsflaeche(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		INSERT INTO ax_funktion_sportfreizeitunderholungsflaeche(wert,beschreibung,dokumentation) VALUES ('4235','Kletteranlage','Kletteranlage ist eine Fläche mit Bauwerken und Einrichtungen, die zur Ausübung des Klettersports genutzt wird.');
		INSERT INTO ax_funktion_sportfreizeitunderholungsflaeche(wert,beschreibung,dokumentation) VALUES ('4275','Go-Kart-Bahn','Go-Kart-Bahn umfasst eine abgegrenzte Strecke mit Anlagen und Gebäuden, die zur Ausübung des Kartrennsports genutzt wird. Hierzu gehören Indoor- und Outdoor-Kartbahnen.');
		INSERT INTO ax_funktion_sportfreizeitunderholungsflaeche(wert,beschreibung,dokumentation) VALUES ('4295','Gelände für Luftsportgeräte','Gelände für Luftsportgeräte ist eine Fläche auf der Ultraleichtflug-, Hängegleiter-, Gleitsegel-, Sprungfallschirm-, Gleitflug- und Freiballonaktivitäten ausgeübt werden.');
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET beschreibung='Kohle, Erz und Salz' WHERE wert='2000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET beschreibung='Erdreich' WHERE wert='4000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Baustoffe sind sämtliche im Bauwesen verwendete Materialien, die als Lagergut aufbewahrt werden.' WHERE wert='1000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Kohle, Erz und Salz sind durch Bergbau oder Tagebau gewonnene Abbaugüter, die für eine Weiterverwendung (vorübergehend) gelagert werden.' WHERE wert='2000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Öl ist eine organische Flüssigkeit, die als Rohstoff gewonnen wird und in der Industrie vielseitige Verwendung findet.' WHERE wert='3000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Erdreich bezeichnet eine Fläche auf der Erdreich gelagert wird. Erdreich im vorliegenden Sinne bezeichnet Oberflächenmaterial, das überwiegend aus Mutterboden (Humusanteil, feine Korngrößen) besteht.' WHERE wert='4000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Schutt ist eine nicht verfestigte Anhäufung von Trümmerstücken.' WHERE wert='5000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Schlacke ist ein Rückstand aus einem Schmelz- oder Verbrennungsprozess.' WHERE wert='6000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Abraum sind unbrauchbare Boden- und Gesteinsmassen.' WHERE wert='7000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Schrott, Altmaterial sind Wertstoffe, die als Sekundärrohstoffe dienen.' WHERE wert='8000';
		UPDATE ax_lagergut_industrieundgewerbeflaeche SET dokumentation='Sonstiges bedeutet, dass das Lagergut bekannt, dieses aber in der Werteliste nicht aufgeführt ist.' WHERE wert='9999';
		INSERT INTO ax_lagergut_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('9000','Gas','Gas bezeichnet den Aggregatzustand einer Materie ohne bestimmte Gestalt.');
		UPDATE ax_zustand_halde SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_zustand_bergbaubetrieb SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		DELETE FROM ax_abbaugut_tagebaugrubesteinbruch WHERE wert IN ('1006','1013','2011','2014','5007');
		UPDATE ax_primaerenergie_industrieundgewerbeflaeche SET dokumentation='Gezeiten bedeutet, dass das Kraftwerk die kinetische Energie der Meeresgezeiten in elektrische Energie umwandet.' WHERE wert='5000';
		INSERT INTO ax_primaerenergie_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('7500','Biomasse','Biomasse sind organische Substanzen (z.B. Pflanzen, Futtermittelabfälle, Gülle), die verbrannt und/oder vergärt werden, um Energie zu gewinnen.');
		DELETE FROM ax_abbaugut_bergbaubetrieb WHERE wert IN ('3004','3010');
		INSERT INTO ax_abbaugut_bergbaubetrieb(wert,beschreibung,dokumentation) VALUES ('1003','Kaolin','Kaolin ist ein Abbaugut, das aus weißem, erdigem Gestein, fast reinem Aluminiumsilikat (kieselsaure Tonerde) besteht.');
		UPDATE ax_zustand_flaechegemischternutzung SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_zustand_industrieundgewerbeflaeche SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		INSERT INTO ax_zustand_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('4000','Im Bau','Im Bau bedeutet, dass sich überwiegende Teile der Industrie- und Gewerbefläche im Bau befinden.');
		UPDATE ax_funktion_friedhof SET beschreibung='Parkfriedhof' WHERE wert='9403';
		UPDATE ax_funktion_friedhof SET dokumentation='Gebäude- und Freifläche Friedhof ist eine bebaute oder unbebaute Fläche, die der Bestattung von Verstorbenen dient. Die Friedhofskapelle, das Krematorium oder Leichenhalle sind in der Nutzung Friedhof inbegriffen.' WHERE wert='9401';
		UPDATE ax_funktion_friedhof SET dokumentation='Friedhof (ohne Gebäude) umfasst eingefriedete Flächen für Gräber.' WHERE wert='9402';
		UPDATE ax_funktion_friedhof SET dokumentation='Parkfriedhof ist ein Friedhof, der als Park angelegt ist.' WHERE wert='9403';
		INSERT INTO ax_funktion_friedhof(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		UPDATE ax_zustand_friedhof SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_lagergut_halde SET beschreibung='Erdreich' WHERE wert='4000';
		UPDATE ax_lagergut_halde SET dokumentation='Baustoffe sind sämtliche im Bauwesen verwendete Materialien, die als Lagergut aufbewahrt werden.' WHERE wert='1000';
		UPDATE ax_lagergut_halde SET dokumentation='Kohle ist ein Lagergut, das durch Inkohlung (Umwandlungsprozess pflanzlicher Substanzen) entstanden ist.' WHERE wert='2000';
		UPDATE ax_lagergut_halde SET dokumentation='Erdreich bezeichnet eine Fläche auf der Erdreich gelagert wird. Erdreich im vorliegenden Sinne bezeichnet Oberflächenmaterial, das überwiegend aus Mutterboden (Humusanteil, feine Korngrößen) besteht.' WHERE wert='4000';
		UPDATE ax_lagergut_halde SET dokumentation='Schutt ist eine nicht verfestigte Anhäufung von Trümmerstücken.' WHERE wert='5000';
		UPDATE ax_lagergut_halde SET dokumentation='Schlacke ist ein Rückstand aus einem Schmelz- oder Verbrennungsprozess.' WHERE wert='6000';
		UPDATE ax_lagergut_halde SET dokumentation='Abraum sind unbrauchbare Boden- und Gesteinsmassen.' WHERE wert='7000';
		UPDATE ax_lagergut_halde SET dokumentation='Schrott, Altmaterial sind Wertstoffe, die als Sekundärrohstoffe dienen.' WHERE wert='8000';
		UPDATE ax_lagergut_halde SET dokumentation='Sonstiges bedeutet, dass das Lagergut bekannt, dieses aber in der Werteliste nicht aufgeführt ist.' WHERE wert='9999';
		DELETE FROM ax_funktion_industrieundgewerbeflaeche WHERE wert IN ('2510');
		UPDATE ax_funktion_industrieundgewerbeflaeche SET beschreibung='Freie Berufe und weitere Dienstleistungen' WHERE wert='1410';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET beschreibung='Lagerfläche' WHERE wert='1740';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET beschreibung='Logistik und Transport' WHERE wert='1750';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET beschreibung='Forschung und Entwicklung' WHERE wert='1760';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET beschreibung='Betriebsfläche Versorgungsanlage, Öl' WHERE wert='2552';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Freie Berufe und weitere Dienstleistungen bezeichnet eine Fläche mit Gebäuden und Einrichtungen welche zur Ausübung freier Berufe wie auch weiterer Dienstleistungen genutzt wird.' WHERE wert='1410';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Bank, Kredit bezeichnet eine Fläche mit Gebäuden und Einrichtungen der Bank- oder Kreditunternehmen.' WHERE wert='1420';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Versicherung bezeichnet eine Fläche mit Gebäuden und Einrichtungen der Versicherungsgesellschaften.' WHERE wert='1430';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Handel bezeichnet Anlagen mit Einzelhandels- und Dienstleistungsbetrieben, die durch einheitliche Verwaltung, auf das Einzugsgebiet abgestimmter Anbieter und durch umfangreiche Parkmöglichkeiten geprägt sind.' WHERE wert='1440';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Beherbergung bezeichnet eine Fläche mit Gebäuden und Einrichtungen für das gewerbliche Angebot der Unterbringung von Personen.' WHERE wert='1460';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Restauration bezeichnet eine Fläche mit Gebäuden und Einrichtungen für das gewerbliche Angebot der gastronomischen Versorgung.' WHERE wert='1470';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Vergnügung bezeichnet eine Fläche mit Gebäuden und Einrichtungen, in denen Möglichkeiten zur unterhaltsamen Freizeitgestaltung angeboten werden.' WHERE wert='1480';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Industrie und Gewerbe bezeichnet Flächen, auf denen vorwiegend Industrie- und Gewerbebetriebe vorhanden sind. Darin sind Gebäude- und Freiflächen und die Betriebsfläche Lagerfläche enthalten.' WHERE wert='1700';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Darin sind die Gebäude- und Freiflächen der folgenden Differenzierung enthalten ohne die Betriebsfläche Lagerfläche.' WHERE wert='1701';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Produktion bezeichnet eine Fläche, auf der vorwiegend Produktionsbetriebe vorhanden sind.' WHERE wert='1710';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Handwerk bezeichnet eine Fläche, auf der vorwiegend Handwerksbetriebe vorhanden sind.' WHERE wert='1720';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Tankstelle bezeichnet eine Fläche, auf der sich Gebäude und Einrichtungen befinden, an denen Kraftfahrzeuge mit den benötigten Kraftstoffen versorgt werden.' WHERE wert='1730';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Lagerfläche bezeichnet Areale, auf denen inner- und außerhalb von Gebäuden wirtschaftliche Güter gelagert werden, ohne Zusammenhang zu weiteren Wertearten.' WHERE wert='1740';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Logistik und Transport umfasst Flächen mit Gebäuden und Einrichtungen, die sich mit der Planung, Steuerung und Durchführung von Güter-, Informations- und Personenströmen befassen. Hierzu gehören Speditionen, Bus- und Taxiunternehmen, Kurier-, Express- und Paketdienste.' WHERE wert='1750';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Forschung und Entwicklung bezeichnet eine Fläche, auf der sich vorwiegend industrielle Forschungs- und Entwicklungseinrichtungen befinden.' WHERE wert='1760';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Grundstoff bezeichnet eine Fläche mit Produktionsbetrieben, die Ausgangsmaterialien für die weiterverarbeitende Industrie produzieren.' WHERE wert='1770';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Betriebliche Sozialeinrichtung bezeichnet eine Fläche innerhalb eines Betriebes mit Gebäuden und Einrichtungen für soziale Zwecke.' WHERE wert='1780';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Werft bezeichnet eine Fläche mit Gebäuden und sonstigen Einrichtungen zum Bau oder zur Reparatur von Schiffen.' WHERE wert='1790';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Versorgungsanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur Versorgung mit Elektrizität, Wärme und Wasser vorhanden sind.' WHERE wert='2500';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Gaswerk bezeichnet eine Fläche mit Gebäuden und Einrichtungen zur Aufbereitung von Erdgas.' WHERE wert='2560';
		UPDATE ax_funktion_industrieundgewerbeflaeche SET dokumentation='Funk- und Fernmeldeanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur elektronischen Informationsübertragung stehen.' WHERE wert='2580';
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Parken bezeichnet eine Fläche die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1801','Nahrungs-, Futter-, Genussmittel','Nahrungs-, Futter-, Genussmittel bezeichnet Flächen zur Fertigung von Erzeugnissen der Landwirtschaft, Forstwirtschaft sowie die Herstellung verschiedener Halbwaren, die noch keine Nahrungs- Futter- oder Genussmittel darstellen.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1802','Textil, Bekleidung, Lederwaren','Textil, Bekleidung, Lederwaren bezeichnet Flächen auf denen primär Textil, Bekleidung und Lederwaren wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Textilwaren umfasst Spinnstoffaufbereitung und Spinnerei, Weberei, Veredlung von Textilien und Bekleidung, sowie die Herstellung von konfektionierten Textilwaren. Bekleidung umfasst alle Schneiderarbeiten aus allen Materialien für alle Bekleidungsartikel und Bekleidungszubehör. Lederwaren umfasst das Zurichten und Färben von Pelzen und die Verarbeitung von Fellen zu Leder durch Gerben und Zurichten sowie die Weiterverarbeitung des Leders zu Gebrauchsgegenständen.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1803','Holz-, Naturfaser-, Verpackungsprodukte','Holz-, Naturfaser-, Verpackungsprodukte bezeichnet Flächen auf denen primär Holz-, Naturfaser- oder Verpackungsprodukte wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Holzprodukte umfassen die Herstellung von Bauholz, Sperrholz, Furniere, Verpackungsmittel, Lagerbehälter und Ladungsträger, Bodenbeläge, Fachwerk, vorgefertigte Gebäude. Naturfaserprodukte sind Veredelungen von Holz- und Zellprodukten. Verpackungsprodukte umfasst Flächen für die Fertigung von Verpackungsmaterial aus bspw. Papier, Karton, Pappe und Holz.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1804','Print-, Audio-, Videoprodukte','Print-, Audio-, Videoprodukte bezeichnet Flächen auf denen primär die Erstellung, Bearbeitung oder Vervielfältigung von bespielten Ton-, Bild- und Datenträgern erfolgt.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1805','Mineralölverarbeitung, Kokerei','Mineralölverarbeitung, Kokerei bezeichnet Flächen auf denen primär Rohöl und Kohle zu gebrauchsfertigen Erzeugnissen verarbeitet werden. Das vorherrschende Verfahren ist die Mineralölverarbeitung durch Trennung von Rohöl in Teilerzeugnisse anhand von Verfahren wie Spaltung und Destillation.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1806','Chemie-, Pharma-, Kunststoffprodukte','Chemie-, Pharma-, Kunststoffprodukte bezeichnet Flächen auf denen primär Chemische, Pharma- und Kunststoffprodukte wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Chemische Produkte umfasst die Verarbeitung organischer und anorganischer Rohstoffe in einem chemischen Verfahren zu chemischen Erzeugnissen. Pharmaprodukte umfasst die Herstellung von pharmazeutischen Grundstoffen und pharmazeutischen Spezialitäten wie auch die Herstellung von Arzneimitteln chemischen und botanischen Ursprungs. Kunststoffprodukte umfasst die Herstellung von Harzen, Kunststoffen und nicht vulkanisierbaren thermoplastischen Elastomeren sowie das Mischen von Harzen nach Kundenwunsch und die Herstellung von synthetischen Harzen nach eigener Spezifikation.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1807','Mineralische Bau- und Werkstoffe','Mineralische Bau- und Werkstoffe bezeichnet Flächen auf denen primär Bau- und Werkstoffe wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Baustoffe umfassen den Großhandel mit Steinen, Sand, Kies, Schotter, Zement, Mörtel, Dämmplatten sowie Fertigteilbauten aus mineralischen Stoffen, z. B. Garagen. Werkstoffe umfasst die Herstellung von Waren unter Verwendung von Stoffen mineralischen Ursprungs bezogen auf die Herstellung von Glas und Erzeugnissen daraus, keramischen Erzeugnissen, Ziegeln und Erzeugnissen aus gebranntem Ton sowie Zement und Gips, verarbeiteten Naturstein und sonstigen Mineralerzeugnissen.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1808','Metallerzeugung und -verarbeitung','Metallerzeugung und –verarbeitung umfasst die Flächen für die Tätigkeiten des Schmelzens und Legierens von Eisenmetallen und NE-Metallen aus Erz, Roheisen oder Schrott mit elektrometallurgischen und anderen metallurgischen Verfahren wie auch Flächen für die Herstellung von Metalllegierungen und Superlegierungen durch Zugabe anderer chemischer Elemente zu reinen Metallen.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1809','Technik, Elektrik, Elektronik','Technik, Elektrik, Elektronik umfasst Flächen für die Herstellung von Datenverarbeitungsgeräten, sowie elektronischen und optischen Erzeugnissen.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1810','Maschinenbau','Maschinenbau umfasst Flächen für den Bau von Maschinen, die mechanisch oder durch Wärme auf Materialien einwirken oder an Materialien Vorgänge durchführen, einschließlich ihrer mechanischen Bestandteile, die Kraft erzeugen und anwenden, sowie spezieller Teile dafür.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1811','Fahrzeugbau','Fahrzeugbau umfassen die Flächen für die Herstellung von Raum-, Luft-, Wasser- Schienen- und Strassenfahrzeugen zur Personen- oder Güterbeförderung wie auch die Flächen zur Herstellung verschiedener Teile und Zubehör.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('1812','Möbel und sonstige Konsumgüter','Möbel und sonstige Konsumgüter bezeichnet Flächen auf denen primär Möbel und sonstige Konsumgüter wie nachfolgend beschrieben gefertigt oder verarbeitet werden. Möbel umfassen die Herstellung von Möbeln aller Art und verwandten Erzeugnissen aus beliebigem Material, außer Stein, Beton und Keramik, für alle Einsatzbereiche und die verschiedensten Zwecke. Sonstige Konsumgüter umfasst die Fertigung von weiteren Waren vor allem für den privaten Ge- oder Verbrauch.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('2700','Förderanlage','Förderanlage bezeichnet eine Fläche mit Einrichtungen zur Förderung von Rohstoffen und Energieträgern.');
		INSERT INTO ax_funktion_industrieundgewerbeflaeche(wert,beschreibung,dokumentation) VALUES ('2701','Gebäude- und Freifläche Förderanlage','Gebäude- und Freifläche Förderanlage bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zur 
Förderung von Rohstoffen und Energieträgern vorhanden sind.');
		UPDATE ax_zustand_tagebaugrubesteinbruch SET dokumentation='Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.' WHERE wert='8000';
		UPDATE ax_vegetationsmerkmal_gehoelz SET dokumentation='Latschenkiefer beschreibt den Bewuchs einer Vegetationsfläche mit Latschenkiefer.' WHERE wert='1400';
		UPDATE ax_vegetationsmerkmal_wald SET beschreibung='Laubholz mit Nadelbäumen' WHERE wert='1310';
		UPDATE ax_vegetationsmerkmal_wald SET beschreibung='Nadelholz mit Laubbäumen' WHERE wert='1320';
		UPDATE ax_vegetationsmerkmal_wald SET dokumentation='Laubholz mit Nadelbäumen beschreibt den Bewuchs einer Vegetationsfläche mit Laub- und Nadelbäumen. Dabei dominieren die Laubbäume das Erscheinungsbild.' WHERE wert='1310';
		UPDATE ax_vegetationsmerkmal_wald SET dokumentation='Nadelholz mit Laubbäumen beschreibt den Bewuchs einer Vegetationsfläche mit Nadel- und Laubbäumen. Dabei dominieren die Nadelbäume das Erscheinungsbild.' WHERE wert='1320';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET beschreibung='Gartenbauland' WHERE wert='1030';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET beschreibung='Rebfläche' WHERE wert='1040';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET beschreibung='Obst- und Nussplantage' WHERE wert='1050';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET beschreibung='Obst- und Nussbaumplantage' WHERE wert='1051';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET beschreibung='Obst- und Nussstrauchplantage' WHERE wert='1052';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET dokumentation='Ackerland ist eine Fläche für den Anbau von Feldfrüchten (z.B. Getreide, Hülsenfrüchte, Hackfrüchte) und Beerenfrüchten (z.B. Erdbeeren).' WHERE wert='1010';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET dokumentation='Gartenbauland ist eine Fläche, die dem gewerbsmäßigen Anbau von Gartengewächsen (Gemüse, Obst und Blumen) sowie für die Aufzucht von Kulturpflanzen dient.' WHERE wert='1030';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET dokumentation='Rebfläche ist eine mit speziellen Vorrichtungen ausgestattete Agrarfläche, auf der Weinstöcke angepflanzt sind.' WHERE wert='1040';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET dokumentation='Obst- und Nussplantage ist eine Fläche, die vorwiegend dem Intensivanbau dient und mit Obst-, Nussbäumen oder -sträuchern bepflanzt ist. Im Unterschied zu Streuobst handelt es sich hierbei um gleichmäßige und dichter angelegte Monokulturen.' WHERE wert='1050';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET dokumentation='Obst- und Nussbaumplantage ist eine landwirtschaftliche Fläche, die vorwiegend dem Intensivanbau dient und mit Obst- oder Nussbäumen bepflanzt ist.' WHERE wert='1051';
		UPDATE ax_vegetationsmerkmal_landwirtschaft SET dokumentation='Obst- und Nussstrauchplantage ist eine landwirtschaftliche Fläche, die vorwiegend dem Intensivanbau dient und mit Obst- oder Nusssträuchern bepflanzt ist.' WHERE wert='1052';
		INSERT INTO ax_vegetationsmerkmal_landwirtschaft(wert,beschreibung,dokumentation) VALUES ('1014','Hanf','Hanf beschreibt den Bewuchs einer Agrarfläche mit Nutzhanf.');
		INSERT INTO ax_vegetationsmerkmal_landwirtschaft(wert,beschreibung,dokumentation) VALUES ('1022','Salzweide','Salzweide ist eine vom Meer periodisch überflutete Weidefläche, in der eine Salzpflanzenvegetation gedeiht. Dieser Bereich bildet den natürlichen Übergang vom Meer zum Festland.');
		INSERT INTO ax_vegetationsmerkmal_landwirtschaft(wert,beschreibung,dokumentation) VALUES ('1060','Weihnachtsbaumkultur','Weihnachtsbaumkultur bezeichnet eine landwirtschaftliche Fläche, die vorrangig mit Weihnachtsbäumen bepflanzt ist.');
		INSERT INTO ax_vegetationsmerkmal_landwirtschaft(wert,beschreibung,dokumentation) VALUES ('1100','Kurzumtriebsplantage','Kurzumtriebsplantagen sind Flächen, auf denen Baumarten mit dem Ziel baldiger Holzentnahme angepflanzt werden und deren Bestände eine Umtriebszeit von nicht länger als 20 Jahren haben.');
		UPDATE ax_funktion_unlandvegetationsloseflaeche SET dokumentation='Bebaute Gewässerbegleitfläche bezeichnet eine bebaute Fläche, die einem Gewässer zugeordnet wird. Sie ist nicht Bestandteil der Gewässerfläche.' WHERE wert='1110';
		UPDATE ax_funktion_unlandvegetationsloseflaeche SET dokumentation='Unbebaute Gewässerbegleitfläche bezeichnet eine unbebaute Fläche, die einem Gewässer zugeordnet wird. Sie ist nicht Bestandteil der Gewässerfläche.' WHERE wert='1120';
		UPDATE ax_funktion_unlandvegetationsloseflaeche SET dokumentation='Naturnahe Fläche ist eine nicht zum Anbau von Kulturpflanzen genutzte Fläche, die mit Pflanzen bewachsen ist.' WHERE wert='1300';
		UPDATE ax_funktion_gehoelz SET dokumentation='Windschutz ist ein dichter Gehölzbestand, der die angrenzenden Flächen oder Objekte vor Wind schützt.' WHERE wert='1000';
		UPDATE ax_bahnkategorie SET dokumentation='Güterverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und / oder Fernverkehr Güter transportiert werden.' WHERE wert='1102';
		UPDATE ax_bahnkategorie SET dokumentation='Straßenbahn ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem eine elektrisch betriebene Schienenbahn zur Personenbeförderung fährt. Sie verläuft i. d. R. oberirdisch.' WHERE wert='1201';
		INSERT INTO ax_bahnkategorie(wert,beschreibung,dokumentation) VALUES ('1101','Personenverkehr','Personenverkehr ist die Bezeichnung für einen schienengebundenen Verkehrsweg, auf dem im Nah- und / oder Fernverkehr Personen transportiert werden.');
		INSERT INTO ax_bahnkategorie(wert,beschreibung,dokumentation) VALUES ('1103','Betriebsverkehr','Betriebsverkehr ist die Bezeichnung für eine Bahnverkehrsanlage, das aus innerbetrieblichen Gründen erforderlich ist.');
		UPDATE ax_funktion_weg SET dokumentation='Fahrweg ist ein Weg, auf dem das Befahren mit Fahrzeugen möglich ist.' WHERE wert='5210';
		UPDATE ax_funktion_weg SET dokumentation='Hauptwirtschaftsweg ist ein Weg mit fester Fahrbahndecke zur Erschließung eines oder mehrerer Grundstücke, der für den Kraftverkehr zu jeder Jahreszeit befahrbar ist. Dazu gehören auch Lkw-befahrbare Wege im Wald, die dem forstwirtschaftlichen Holztransport zu jeder Zeit dienen.' WHERE wert='5211';
		UPDATE ax_funktion_weg SET dokumentation='Wirtschaftsweg ist ein leicht- oder unbefestigter Weg zur Erschließung land- und forstwirtschaftlicher Flächen.' WHERE wert='5212';
		UPDATE ax_funktion_weg SET dokumentation='Gang ist ein schmaler Fußweg.' WHERE wert='5230';
		UPDATE ax_funktion_weg SET dokumentation='Reitweg ist ein besonders ausgebauter Weg, auf dem ausschließlich das Reiten zugelassen ist.' WHERE wert='5260';
		UPDATE ax_funktion_weg SET dokumentation='Sonstiges bedeutet, dass die Funktion des Wegs bekannt, diese aber nicht in der Werteliste aufgeführt ist.' WHERE wert='9999';
		INSERT INTO ax_funktion_weg(wert,beschreibung,dokumentation) VALUES ('5270','Begleitfläche Weg','Begleitfläche Weg bezeichnet eine unbebaute Fläche, die einem Weg zugeordnet wird.');
		UPDATE ax_funktion_bahnverkehr SET beschreibung='Begleitfläche Bahnverkehr' WHERE wert='2322';
		UPDATE ax_funktion_bahnverkehr SET dokumentation='Begleitfläche Bahnverkehr bezeichnet eine unbebaute Fläche, die dem Bahnverkehr zugeordnet wird. Die Begleitfläche Bahnverkehr ist nicht Bestandteil der Gleisanlagen.' WHERE wert='2322';
		INSERT INTO ax_funktion_bahnverkehr(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Betriebsfläche Bahnverkehr bezeichnet bebaute oder unbebaute Flächen, die vorwiegend der Versorgung, Unterhaltung und Instandhaltung des Bahnverkehrs dienen.');
		INSERT INTO ax_funktion_bahnverkehr(wert,beschreibung,dokumentation) VALUES ('2323','Betriebsfläche Bahnverkehr','Betriebsfläche Bahnverkehr bezeichnet bebaute oder unbebaute Flächen, die vorwiegend der Versorgung, Unterhaltung und Instandhaltung des Bahnverkehrs dienen.');
		INSERT INTO ax_funktion_bahnverkehr(wert,beschreibung,dokumentation) VALUES ('2324','Trasse, Streckengleisbett','Trasse, Streckengleisbett ist ein befestigtes, dem allgemeinen Schienenverkehr dienendes Gleisbett einschließlich der auf Brücken oder in Tunneln verlaufenden Abschnitte.');
		UPDATE ax_besonderefahrstreifen SET dokumentation='Mit Radweg bedeutet, dass parallel zur Objektart ein Radweg verläuft, der aber nicht als eigenständiges Objekt erfasst wird.' WHERE wert='1000';
		UPDATE ax_besonderefahrstreifen SET dokumentation='Mit Fußweg bedeutet, dass parallel zur Objektart ein Fußweg verläuft, der aber nicht als eigenständiges Objekt erfasst wird.' WHERE wert='2000';
		UPDATE ax_besonderefahrstreifen SET dokumentation='Mit Rad- und Fußweg bedeutet, dass parallel zur Objektart Objektart ein Rad- und Fußweg verläuft, der aber nicht als eigenständiges Objekt erfasst wird.' WHERE wert='3000';
		UPDATE ax_zustand_bahnverkehr SET dokumentation='Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich die Bahnverkehrsfläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.' WHERE wert='2100';
		UPDATE ax_zustand_bahnverkehr SET dokumentation='Im Bau bedeutet, dass sich überwiegende Teile des Bahnverkehrs im Bau befinden.' WHERE wert='4000';
		INSERT INTO ax_zustand_bahnverkehr(wert,beschreibung,dokumentation) VALUES ('8000','Erweiterung, Neuansiedlung','Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		UPDATE ax_befestigung_fahrwegachse SET beschreibung='Leicht befestigt' WHERE wert='1000';
		UPDATE ax_befestigung_fahrwegachse SET dokumentation='Leicht befestigt bedeutet, dass Fahrwegachse mit einem Belag versehen ist.' WHERE wert='1000';
		UPDATE ax_befestigung_fahrwegachse SET dokumentation='Unbefestigt bedeutet, dass Fahrwegachse nicht mit einem Belag versehen ist.' WHERE wert='2000';
		INSERT INTO ax_spurweite(wert,beschreibung,dokumentation) VALUES ('9997','Attribut trifft nicht zu','Attribut trifft nicht zu bedeutet, dass keiner der in der Werteliste aufgeführten Attributwerte dem vorliegenden Sachverhalt entspricht.');
		UPDATE ax_zustand_schiffsverkehr SET dokumentation='Im Bau bedeutet, dass sich überwiegende Teile von Schiffsverkehr im Bau befinden.' WHERE wert='4000';
		INSERT INTO ax_zustand_schiffsverkehr(wert,beschreibung,dokumentation) VALUES ('8000','Erweiterung, Neuansiedlung','Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		UPDATE ax_funktion_platz SET beschreibung='Raststätte, Autohof' WHERE wert='5330';
		UPDATE ax_funktion_platz SET dokumentation='Parkplatz bezeichnet eine Fläche, auf der vorwiegend Anlagen und Gebäude zum Abstellen von Fahrzeugen stehen.' WHERE wert='5310';
		UPDATE ax_funktion_platz SET dokumentation='Rastplatz ist eine Anlage zum Rasten der Verkehrsteilnehmer mit unmittelbarem Anschluss zur Straße ohne Versorgungseinrichtung, ggf. mit Toiletten.' WHERE wert='5320';
		UPDATE ax_funktion_platz SET dokumentation='Raststätte, Autohof ist eine Anlage an Verkehrsstraßen mit Bauwerken und Einrichtungen zur Versorgung und Erholung von Reisenden. Dazu gehören auch Autohöfe gemäß der Verwaltungsvorschriften zur Straßenverkehrsordnung (VwV-StVO).' WHERE wert='5330';
		UPDATE ax_funktion_platz SET dokumentation='Marktplatz ist ein Platz, auf dem Markt abgehalten wird.' WHERE wert='5340';
		INSERT INTO ax_funktion_platz(wert,beschreibung,dokumentation) VALUES ('5360','Busbahnhof','Busbahnhof ist eine Verkehrsanlage, die als zentraler Verknüpfungspunkt verschiedener Buslinien dient.');
		DELETE FROM ax_art_flugverkehr WHERE wert IN ('5510','5520','5540');
		UPDATE ax_art_flugverkehr SET beschreibung='Hubschrauberlandeplatz' WHERE wert='5530';
		UPDATE ax_art_flugverkehr SET dokumentation='Internationaler Flughafen ist ein Verkehrsflughafen, der im Luftfahrthandbuch als solcher ausgewiesen ist.' WHERE wert='5511';
		UPDATE ax_art_flugverkehr SET dokumentation='Regionalflughafen ist ein Verkehrsflughafen der gemäß Raumordnungsgesetz als Regionalflughafen eingestuft ist, bzw. als Flughafen, Verkehrsflughafen oder Regionalflughafen im Luftfahrthandbuch ausgewiesen ist.' WHERE wert='5512';
		UPDATE ax_art_flugverkehr SET dokumentation='Hubschrauberlandeplatz ist ein Flugplatz, der im Luftfahrthandbuch, in der Luftfahrtkarte 1:500000 (ICAO) oder aufgrund von Ländervorschriften als solcher ausgewiesen ist.' WHERE wert='5530';
		UPDATE ax_art_flugverkehr SET dokumentation='Segelfluggelände ist ein Flugplatz, der in der Luftfahrtkarte 1:500000 (ICAO) für den Segelflugsport ausgewiesen ist.' WHERE wert='5550';
		INSERT INTO ax_art_flugverkehr(wert,beschreibung,dokumentation) VALUES ('5513','Sonderflughafen','Sonderflughafen ist ein Flughafen, der im Luftfahrthandbuch als solcher ausgewiesen ist.');
		INSERT INTO ax_art_flugverkehr(wert,beschreibung,dokumentation) VALUES ('5521','Verkehrslandeplatz','Verkehrslandeplatz ist ein Flugplatz, der im Luftfahrthandbuch als Flugplatz, Landeplatz oder Verkehrslandeplatz ausgewiesen ist.');
		INSERT INTO ax_art_flugverkehr(wert,beschreibung,dokumentation) VALUES ('5522','Sonderlandeplatz','Sonderlandeplatz ist ein Flugplatz, der im Luftfahrthandbuch oder in den Bescheiden der zuständigen Luftfahrtbehörden als Sonderlandeplatz ausgewiesen ist.');
		UPDATE ax_elektrifizierung SET dokumentation='Elektrifiziert bedeutet, dass den Schienenfahrzeugen über eine Oberleitung oder eine Stromschiene längs des Fahrweges elektrische Energie zugeführt werden kann.' WHERE wert='1000';
		UPDATE ax_zustand SET dokumentation='Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich die Objektart nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.' WHERE wert='2100';
		UPDATE ax_zustand SET dokumentation='Im Bau bedeutet, dass die Objektart noch nicht fertiggestellt ist.' WHERE wert='4000';
		UPDATE ax_oberflaechenmaterial_strasse SET dokumentation='Beton bedeutet, dass die Oberfläche von der Objektart aus Beton besteht.' WHERE wert='1220';
		UPDATE ax_oberflaechenmaterial_strasse SET dokumentation='Bitumen, Asphalt bedeutet, dass die Oberfläche von der Objektart aus Bitumen bzw. Asphalt besteht.' WHERE wert='1230';
		UPDATE ax_oberflaechenmaterial_strasse SET dokumentation='Pflaster bedeutet, dass die Oberfläche von der Objektart gepflastert ist.' WHERE wert='1240';
		UPDATE ax_oberflaechenmaterial_strasse SET dokumentation='Gestein, zerkleinert bedeutet, dass die Oberfläche von der Objektart aus Schotter, Splitt, Sand oder aus einem Gemisch dieser Materialen besteht.' WHERE wert='1250';
		INSERT INTO ax_funktion_flugverkehr(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Parken bezeichnet eine Fläche, die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		INSERT INTO ax_funktion_flugverkehr(wert,beschreibung,dokumentation) VALUES ('5502','Begleitfläche Flugverkehr','Begleitfläche Flugverkehr bezeichnet eine unbebaute Fläche, die dem Flugverkehr zugeordnet wird. Hierzu gehören z.B. Grünflächen neben den Flugverkehrsflächen.');
		INSERT INTO ax_funktion_flugverkehr(wert,beschreibung,dokumentation) VALUES ('5503','Betriebsfläche Flugverkehr','Betriebsfläche Flugverkehr bezeichnet bebaute oder unbebaute Flächen, die vorwiegend der Versorgung und Unterhaltung des Flugverkehrs dienen.');
		UPDATE ax_funktion_wegachse SET dokumentation='Hauptwirtschaftsweg ist ein Weg mit fester Fahrbahndecke zur Erschließung eines oder mehrerer Grundstücke, der für den Kraftverkehr zu jeder Jahreszeit befahrbar ist. Dazu gehören auch Lkw-befahrbare Wege im Wald, die dem forstwirtschaftlichen Holztransport zu jeder Zeit dienen.' WHERE wert='5211';
		INSERT INTO ax_funktion_wegachse(wert,beschreibung,dokumentation) VALUES ('5240','Radweg','Radweg ist ein Weg, der als besonders gekennzeichneter und abgegrenzter Teil einer Straße oder mit selbständiger Linienführung für den Fahrradverkehr bestimmt ist.');
		INSERT INTO ax_funktion_wegachse(wert,beschreibung,dokumentation) VALUES ('5250','Rad- und Fußweg','Rad- und Fußweg ist ein Weg, der als besonders gekennzeichneter und abgegrenzter Teil einer Straße oder mit selbständiger Linienführung ausschließlich für den Fahrrad- und Fußgängerverkehr bestimmt ist.');
		UPDATE ax_zustand_strasse SET dokumentation='Außer Betrieb, stillgelegt, verlassen bedeutet, dass sich die Straßenverkehrsfläche nicht mehr in regelmäßiger, der Bestimmung entsprechenden Nutzung befindet.' WHERE wert='2100';
		UPDATE ax_zustand_strasse SET dokumentation='Im Bau bedeutet, dass sich überwiegende Teile des Straßenverkehrs im Bau befinden.' WHERE wert='4000';
		INSERT INTO ax_zustand_strasse(wert,beschreibung,dokumentation) VALUES ('8000','Erweiterung, Neuansiedlung','Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		DELETE FROM ax_markierung_wegachse WHERE wert IN ('1403');
		UPDATE ax_zustand_flugverkehr SET dokumentation='Im Bau bedeutet, dass sich überwiegende Teile von Flugverkehr im Bau befinden.' WHERE wert='4000';
		INSERT INTO ax_zustand_flugverkehr(wert,beschreibung,dokumentation) VALUES ('8000','Erweiterung, Neuansiedlung','Erweiterung, Neuansiedlung bedeutet, dass die Fläche in ihrer Nutzung gemäß der Objektart erweitert wird und eine Fertigstellung absehbar ist.');
		UPDATE ax_nutzung_flugverkehr SET dokumentation='Zivil bedeutet, dass Flugverkehr privaten oder öffentlichen Zwecken dient und nicht militärisch genutzt wird.' WHERE wert='1000';
		UPDATE ax_funktion_schiffsverkehr SET beschreibung='Gebäude- und Freifläche zu Verkehrsanlagen, Schifffahrt' WHERE wert='2341';
		INSERT INTO ax_funktion_schiffsverkehr(wert,beschreibung,dokumentation) VALUES ('1200','Parken','Parken bezeichnet eine Fläche, die vorwiegend dem Abstellen von Fahrzeugen dient und zu diesem Zweck ggf. mit Gebäuden, Bauwerken, Anlagen oder Kennzeichnungen versehen ist.');
		INSERT INTO ax_funktion_schiffsverkehr(wert,beschreibung,dokumentation) VALUES ('2342','Begleitfläche Schiffsverkehr','Begleitfläche Schiffverkehr bezeichnet eine unbebaute Fläche, die dem Schiffverkehr zugeordnet wird. Hierzu zählt z.B. Ufer.');
		INSERT INTO ax_funktion_schiffsverkehr(wert,beschreibung,dokumentation) VALUES ('5600','Betriebsfläche Schiffsverkehr','Betriebsfläche Schiffsverkehr bezeichnet bebaute oder unbebaute Flächen die landseitigen dem Betrieb des Schiffsverkehrs dienen.');
		UPDATE ax_funktion_strasse SET beschreibung='Begleitfläche Straßenverkehr' WHERE wert='2312';
		UPDATE ax_funktion_strasse SET dokumentation='Begleitfläche Straßenverkehr bezeichnet eine unbebaute Fläche, die einer Straße zugeordnet wird. Die Begleitfläche Straßenverkehr ist nicht Bestandteil der Fahrbahn.' WHERE wert='2312';
		UPDATE ax_funktion_strasse SET dokumentation='Straßenentwässerungsanlage ist der zur Entwässerung dienende Bestandteil der Verkehrsanlage.' WHERE wert='2313';
		INSERT INTO ax_funktion_strasse(wert,beschreibung,dokumentation) VALUES ('2314','Betriebsfläche Straßenverkehr','Betriebsfläche Straßenverkehr bezeichnet bebaute oder unbebaute Flächen, die vorwiegend der Versorgung und Unterhaltung der Verkehrsflächen des Straßenverkehrs dienen. Hierzu gehören z.B. Straßenmeistereien.');
		INSERT INTO ax_funktion_strasse(wert,beschreibung,dokumentation) VALUES ('2315','Fahrbahn','Fahrbahn bezeichnet Flächen, die den zusammenhängenden, befestigten Teil der Straße bilden, als Verkehrsraum dienen und mit Fahrzeugen befahren werden dürfen. Zur Fahrbahn gehören auch Stand- und Kriechspuren.');
		UPDATE ax_widmung_strasse SET beschreibung='Nicht öffentliche Straße' WHERE wert='9997';
		UPDATE ax_widmung_strasse SET beschreibung='Sonstige öffentliche Straße' WHERE wert='9999';
		UPDATE ax_widmung_strasse SET dokumentation='Nicht öffentliche Straße bedeutet, dass hier ein Straßenverkehr erlaubt ist, dieser aber nur zweckgebunden, z. B. in einem Krankenhausgelände, durchgeführt wird.' WHERE wert='9997';
		UPDATE ax_widmung_strasse SET dokumentation='Sonstige öffentliche Straße bedeutet, dass es sich um eine öffentliche Straße handelt, die aber keiner der vorhandenen Widmung zugewiesen werden kann.' WHERE wert='9999';
		DELETE FROM ax_wirtschaftsart WHERE wert IN ('Historische Anlage','Betriebsfläche','Gebäude- und Freifläche','Übungsgelände');
		UPDATE ax_wirtschaftsart SET dokumentation='Erholungsfläche wird aggregiert aus den Nutzungsartkennungen 18000 und 18400 und deren weiteren Untergliederungen.' WHERE wert='Erholungsfläche';
		UPDATE ax_wirtschaftsart SET dokumentation='Friedhof wird aggregiert aus der Nutzungsartkennung 19000 und deren weitere Untergliederung.' WHERE wert='Friedhof';
		UPDATE ax_wirtschaftsart SET dokumentation='Verkehrsfläche wird aggregiert aus den Nutzungsartkennungen 21000, 22000, 23000, 24000, 25000 und 26000 und deren weiteren Untergliederungen.' WHERE wert='Verkehrsfläche';
		UPDATE ax_wirtschaftsart SET dokumentation='Landwirtschaftsfläche wird aggregiert aus der Nutzungsartkennung 31000 und deren weitere Untergliederung.' WHERE wert='Landwirtschaftsfläche';
		UPDATE ax_wirtschaftsart SET dokumentation='Waldfläche wird aggregiert aus der Nutzungsartkennung 32000 und deren weitere Untergliederung.' WHERE wert='Waldfläche';
		UPDATE ax_wirtschaftsart SET dokumentation='Unland wird aggregiert aus der Nutzungsartkennung 37000 und deren weitere Untergliederung.' WHERE wert='Unland';
		UPDATE ax_wirtschaftsart SET dokumentation='Wasserfläche wird aggregiert aus den Nutzungsartkennungen 41000, 42000, 43000 und 44000 und deren weiteren Untergliederungen.' WHERE wert='Wasserfläche';
		INSERT INTO ax_wirtschaftsart(wert,beschreibung,dokumentation) VALUES ('Wohnbaufläche',NULL,'Wohnbaufläche wird aggregiert aus der Nutzungsartkennung 11000 und deren weitere Untergliederung.');
		INSERT INTO ax_wirtschaftsart(wert,beschreibung,dokumentation) VALUES ('Industrie- und Gewerbefläche',NULL,'Industrie- und Gewerbefläche wird aggregiert aus den Nutzungsartkennungen 12000, 12100, 13000, 14000 und 15000 und deren weiteren Untergliederungen.');
		INSERT INTO ax_wirtschaftsart(wert,beschreibung,dokumentation) VALUES ('Mischnutzung',NULL,'Mischnutzung wird aggregiert aus den Nutzungsartkennungen 16000 und 17000 und deren weiteren Untergliederungen.');
		INSERT INTO ax_wirtschaftsart(wert,beschreibung,dokumentation) VALUES ('Gebäude- und Freifläche Land- und Forstwirtschaft',NULL,'Gebäude- und Freifläche Land- und Forstwirtschaft wird aggregiert aus den Nutzungsartkennungen 16200 und deren weiteren Untergliederungen.');
		INSERT INTO ax_wirtschaftsart(wert,beschreibung,dokumentation) VALUES ('Sonstige Vegetationsfläche',NULL,'Sonstige Vegetationsfläche wird aggregiert aus den Nutzungsartkennungen 33000, 34000, 35000 und 36000 und deren weiteren Untergliederungen.');

		UPDATE alkis_version SET version=100;

		r := alkis_string_append(r, 'ALKIS-Schema migriert');
	END IF;

	IF ver>100 THEN
		RAISE EXCEPTION 'ALKIS-Schema % nicht unterstützt (bis 100).', ver;
	END IF;

	--
	-- ALKIS-Präsentationstabellen
	--
	BEGIN
		SELECT version INTO ver FROM alkis_po_version;

	EXCEPTION WHEN OTHERS THEN
		ver := 0;
		CREATE TABLE alkis_po_version(version INTEGER);
		INSERT INTO alkis_po_version(version) VALUES (ver);
	END;

	RAISE NOTICE 'ALKIS-PO-Schema-Version %', ver;

	IF ver<1 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 1';

		PERFORM alkis_dropobject('alkis_konturen');

		CREATE TABLE alkis_signaturkataloge(id INTEGER PRIMARY KEY, name VARCHAR);
		INSERT INTO alkis_signaturkataloge(id, name) VALUES (1, 'Farbe');

		CREATE TABLE alkis_punkte(katalog integer,signaturnummer varchar,x0 double precision,y0 double precision,x1 double precision,y1 double precision,primary key (katalog,signaturnummer),FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id));

		BEGIN ALTER TABLE po_labels DROP CONSTRAINT po_labels_signaturnummer_fkey; EXCEPTION WHEN OTHERS THEN END;
		BEGIN ALTER TABLE po_lines DROP CONSTRAINT po_lines_signaturnummer_fkey; EXCEPTION WHEN OTHERS THEN END;
		BEGIN ALTER TABLE po_polygons DROP CONSTRAINT po_polygons_sn_randlinie_fkey; EXCEPTION WHEN OTHERS THEN END;
		BEGIN ALTER TABLE po_polygons DROP CONSTRAINT po_polygons_sn_flaeche_fkey; EXCEPTION WHEN OTHERS THEN END;

		BEGIN ALTER TABLE alkis_linie DROP CONSTRAINT alkis_linie_signaturnummer_fkey; EXCEPTION WHEN OTHERS THEN END;
		BEGIN ALTER TABLE alkis_linie DROP CONSTRAINT alkis_linie_strichart_fkey; EXCEPTION WHEN OTHERS THEN END;

		ALTER TABLE po_points ALTER gml_id TYPE character(16);
		ALTER TABLE po_lines ALTER gml_id TYPE character(16);
		ALTER TABLE po_polygons ALTER gml_id TYPE character(16);
		ALTER TABLE po_labels ALTER gml_id TYPE character(16);

		-- Vorhandene Tabellen migrieren
		FOR c IN
			SELECT a.table_name
			FROM information_schema.tables a
			JOIN (SELECT 1 AS o,'alkis_schriften' AS table_name
			UNION SELECT 2 AS o,'alkis_linien'
			UNION SELECT 3 AS o,'alkis_linie'
			UNION SELECT 4 AS o,'alkis_flaechen'
			UNION SELECT 9 AS o,'po_labels'
			) AS b ON a.table_name=b.table_name
			WHERE a.table_schema=current_schema()
			ORDER BY b.o
		LOOP

			IF c.table_name = 'alkis_schriften' THEN
				-- CREATE TABLE alkis_schriften(katalog INTEGER,signaturnummer VARCHAR,            darstellungsprioritaet INTEGER,name VARCHAR[],seite INTEGER,art VARCHAR,stil VARCHAR,grad_pt INTEGER,horizontaleausrichtung VARCHAR,vertikaleausrichtung VARCHAR,farbe INTEGER,alignment_umn CHAR(2),alignment_dxf INTEGER,sperrung_pt INTEGER,effekt VARCHAR,position TEXT,PRIMARY KEY (katalog,signaturnummer),FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id),FOREIGN KEY (farbe) REFERENCES alkis_farben(id));
				-- CREATE TABLE alkis_schriften(                signaturnummer VARCHAR PRIMARY KEY,darstellungsprioritaet INTEGER,name VARCHAR[],seite INTEGER,art VARCHAR,stil VARCHAR,grad_pt INTEGER,horizontaleausrichtung VARCHAR,vertikaleausrichtung VARCHAR,farbe INTEGER,alignment_umn CHAR(2),alignment_dxf INTEGER,sperrung_pt INTEGER,effekt VARCHAR,position TEXT,FOREIGN KEY (farbe) REFERENCES alkis_farben(id));
				ALTER TABLE alkis_schriften ADD katalog INTEGER;
				UPDATE alkis_schriften SET katalog=1;
				ALTER TABLE alkis_schriften DROP CONSTRAINT alkis_schriften_pkey;
				ALTER TABLE alkis_schriften ADD PRIMARY KEY (katalog,signaturnummer);
				ALTER TABLE alkis_schriften ADD FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id);
			END IF;

			IF c.table_name = 'alkis_linien' THEN
				-- CREATE TABLE alkis_linien(                signaturnummer VARCHAR PRIMARY KEY,darstellungsprioritaet INTEGER,farbe INTEGER,name VARCHAR[],seite INTEGER,FOREIGN KEY (farbe) REFERENCES alkis_farben(id));
				-- CREATE TABLE alkis_linien(katalog INTEGER,signaturnummer VARCHAR            ,darstellungsprioritaet INTEGER,              name VARCHAR[],seite INTEGER,PRIMARY KEY (katalog,signaturnummer),FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id));
				ALTER TABLE alkis_linien ADD katalog INTEGER;
				UPDATE alkis_linien SET katalog=1;
				ALTER TABLE alkis_linien DROP CONSTRAINT alkis_linien_pkey;
				ALTER TABLE alkis_linien ADD PRIMARY KEY (katalog,signaturnummer);
				ALTER TABLE alkis_linien ADD FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id);
				ALTER TABLE alkis_linien DROP farbe;
			END IF;

			IF c.table_name = 'alkis_linie' THEN
				-- CREATE TABLE alkis_linie(id INTEGER PRIMARY KEY,i INTEGER NOT NULL,                signaturnummer VARCHAR,strichart INTEGER,kontur INTEGER,abschluss VARCHAR,scheitel VARCHAR,strichstaerke DOUBLE PRECISION,pfeilhoehe DOUBLE PRECISION,pfeillaenge DOUBLE PRECISION,              position TEXT,FOREIGN KEY (        signaturnummer) REFERENCES alkis_linien(signaturnummer),        FOREIGN KEY (strichart) REFERENCES alkis_stricharten(id),FOREIGN KEY (kontur) REFERENCES alkis_konturen(id));
				-- CREATE TABLE alkis_linie(id INTEGER PRIMARY KEY,i INTEGER NOT NULL,katalog INTEGER,signaturnummer VARCHAR,strichart INTEGER               ,abschluss VARCHAR,scheitel VARCHAR,strichstaerke DOUBLE PRECISION,pfeilhoehe DOUBLE PRECISION,pfeillaenge DOUBLE PRECISION,farbe INTEGER,position TEXT,FOREIGN KEY (katalog,signaturnummer) REFERENCES alkis_linien(katalog,signaturnummer),FOREIGN KEY (strichart) REFERENCES alkis_stricharten(id)                                                   ,FOREIGN KEY (farbe) REFERENCES alkis_farben(id));
				ALTER TABLE alkis_linie ADD katalog INTEGER;
				ALTER TABLE alkis_linie ADD farbe INTEGER;
				ALTER TABLE alkis_linie DROP kontur;
				UPDATE alkis_linie SET katalog=1,farbe=(SELECT farbe FROM alkis_linien WHERE alkis_linien.signaturnummer=alkis_linie.signaturnummer);
				ALTER TABLE alkis_linie ADD FOREIGN KEY (katalog,signaturnummer) REFERENCES alkis_linien(katalog,signaturnummer);
				DELETE FROM alkis_linie l WHERE NOT EXISTS (SELECT * FROM alkis_stricharten a WHERE l.strichart=a.id);
				ALTER TABLE alkis_linie ADD FOREIGN KEY (strichart) REFERENCES alkis_stricharten(id);
				ALTER TABLE alkis_linie ADD FOREIGN KEY (farbe) REFERENCES alkis_farben(id);
			END IF;

			IF c.table_name = 'alkis_flaechen' THEN
				-- CREATE TABLE alkis_flaechen(                signaturnummer VARCHAR PRIMARY KEY,darstellungsprioritaet INTEGER,name VARCHAR[],seite INTEGER,farbe INTEGER,randlinie INTEGER,                                                                                                 FOREIGN KEY (farbe) REFERENCES alkis_farben(id),FOREIGN KEY (randlinie) REFERENCES alkis_randlinie(id));
				-- CREATE TABLE alkis_flaechen(katalog INTEGER,signaturnummer VARCHAR            ,darstellungsprioritaet INTEGER,name VARCHAR[],seite INTEGER,farbe INTEGER,randlinie INTEGER,PRIMARY KEY (katalog,signaturnummer),FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id),FOREIGN KEY (farbe) REFERENCES alkis_farben(id),FOREIGN KEY (randlinie) REFERENCES alkis_randlinie(id));
				ALTER TABLE alkis_flaechen ADD katalog INTEGER;
				UPDATE alkis_flaechen SET katalog=1;
				ALTER TABLE alkis_flaechen DROP CONSTRAINT alkis_flaechen_pkey;
				ALTER TABLE alkis_flaechen ADD PRIMARY KEY (katalog,signaturnummer);
				ALTER TABLE alkis_flaechen ADD FOREIGN KEY (katalog) REFERENCES alkis_signaturkataloge(id);
			END IF;

			IF c.table_name = 'po_labels' THEN
				ALTER TABLE po_labels DROP alignment_dxf;
				ALTER TABLE po_labels DROP color_umn;
				ALTER TABLE po_labels DROP font_umn;
				ALTER TABLE po_labels DROP size_umn;
				ALTER TABLE po_labels DROP darstellungsprioritaet;
			END IF;
		END LOOP;
	END IF;

	IF ver<2 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 2';

		COMMENT ON TABLE po_points IS 'BASE: Punktobjekte';
		COMMENT ON TABLE po_lines IS 'BASE: Linienobjekte';
		COMMENT ON TABLE po_polygons IS 'BASE: Flächenobjekte';
		COMMENT ON TABLE po_labels IS 'BASE: Beschriftungsobjekte';

		UPDATE alkis_po_version SET version=2;
	END IF;

	-- Version 3: deferrable Primärschlüssel revidiert

	IF ver<4 THEN
		RAISE NOTICE 'Migriere auf Schema-Version 4';

		CREATE TABLE po_modelle(modell varchar, n integer);

		UPDATE alkis_po_version SET version=4;

		r := coalesce(r||E'\n','') || 'ALKIS-PO-Schema migriert';
	END IF;

	IF ver>4 THEN
		RAISE EXCEPTION 'ALKIS-PO-Schema % nicht unterstützt (bis 4).', ver;
	END IF;

	RETURN r;
END;
$$ LANGUAGE plpgsql;

SELECT pg_temp.alkis_update_schema();
